@@ -1,4 +1,4 @@
-/* $Id: events.c,v 1.16 2001/06/09 09:25:49 amai Exp $ */
+/* $Id: events.c,v 1.18 2001/10/29 08:59:26 amai Exp $ */
 /*****************************************************************************/
 /**       Copyright 1988 by Evans & Sutherland Computer Corporation,        **/
 /**                          Salt Lake City, Utah                           **/
@@ -69,11 +69,8 @@
 #define MOD_MASK	(ShiftMask|ControlMask|Mod1Mask|Mod2Mask|Mod3Mask|\
 			 Mod4Mask | Mod5Mask)
 
-extern int menuFromFrameOrWindowOrTitlebar;
-MwmWindow *win;			/* the current mwm window */
+static MwmWindow *win;			/* the current mwm window */
 static int ShapeEventBase, ShapeErrorBase;
-extern volatile int alarmed;
-extern Bool EnablePagerRedraw;
 
 /*
  * Waits Mwm.click_time, or until it is evident that the user is not
