@@ -1,3 +1,4 @@
+/* $Id: mwm.c,v 1.29 2001/10/29 08:59:26 amai Exp $ */
 /*****************************************************************************/
 /**       Copyright 1988 by Evans & Sutherland Computer Corporation,        **/
 /**                          Salt Lake City, Utah                           **/
@@ -30,10 +31,17 @@
  ****************************************************************************/
 /***********************************************************************
  * The rest of it is all my fault -- MLM
+ *
+ * Copyright (C) 1995-2001 LessTif Development Team
  * mwm - "LessTif Window Manager"
  ***********************************************************************/
 
-#include "mwm.h"
+#include <LTconfig.h>
+
+#include <stdlib.h>
+#include <stdio.h>
+#include <string.h>
+#include <signal.h>
 
 #ifdef HAVE_FCNTL_H
 #include <fcntl.h>
@@ -41,32 +49,76 @@
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
+#ifdef HAVE_SYS_TYPES_H
+#include <sys/types.h>
+#endif
+#ifdef HAVE_SYS_WAIT_H
+#include <sys/wait.h>
+#endif
+#ifdef HAVE_GETRLIMIT
 #ifdef HAVE_SYS_TIME_H
 #include <sys/time.h>
-#ifdef TIME_WITH_SYS_TIME
-#include <time.h>
 #endif
+#include <sys/resource.h>
 #endif
-#ifdef HAVE_SYS_SELECT_H
-#include <sys/select.h>
-#endif
+
 #ifdef __EMX__
 #include <netdb.h>
 #endif
 
-#include <unistd.h>
-#include <stdlib.h>
-
+#include <X11/Intrinsic.h>
 #include <X11/Shell.h>
+#include <X11/Xproto.h>
+
+#include <Xm/Xm.h>
+#include <Xm/MwmUtil.h>
+#include <Xm/XmosP.h>
 #include <Xm/DisplayP.h>
 #include <Xm/ScreenP.h>
 
-#ifdef	HAVE_GETRLIMIT
-#include <sys/types.h>
-#include <sys/resource.h>
+#if XmVERSION >= 2
+#include <XmI/XmI.h>
 #endif
 
-#include <XmI/DebugUtil.h>
+#include "mwm.h"
+
+
+#ifndef HAVE_GETHOSTNAME
+/* our fallback implementation (gethostname.c) */
+extern int gethostname (char *name, size_t len);
+#endif
+
+
+extern int
+SetEnvironment(const char *key, const char *value)
+#ifdef HAVE_PUTENV
+{
+  char *str;
+  int len, rc;
+ 
+  len=strlen(key)+strlen(value)+2;
+  str=(char *)malloc(len);
+  strcpy(str, key);
+  strcat(str, "=");
+  strcat(str, value);
+  rc=putenv(str);
+  /* do not free 'str' here! */
+  return rc;
+}
+#else
+#ifdef HAVE_SETENV
+{
+  int rc;
+  int overwrite=1;
+
+  rc=setenv(key, value, overwrite);
+  return rc;
+}
+#else
+#error You lose (neither putenv() nor setenv() are available!)
+#endif /* #ifdef HAVE_SETENV */
+#endif /* #ifdef HAVE_PUTENV */
+
 
 /*
  * application globals
@@ -76,9 +128,10 @@
 MwmInternalInfo Mwm;
 Display *dpy;			/* which display are we talking to */
 Widget toplevel;
-Widget xmDisplay;
-Boolean multiscreen = False;
-char *mwm_name = "mwm";
+static Widget xmDisplay;
+static Boolean multiscreen = False;
+static char *mwm_name = "mwm";
+
 int verbose = 0;
 
 XContext MwmContext;		/* context for mwm windows */
@@ -93,7 +146,7 @@ char **g_argv;
 
 
 int fd_width, x_fd;
-XtAppContext app;
+static XtAppContext app;
 volatile int alarmed;
 
 static int last_event_type = 0;
@@ -112,50 +165,40 @@ usage(void)
 /*
  * restart on a signal
  */
-static RETSIGTYPE
+static void
 sig_restart(int sig)
 {
     MWM_Done(1, *g_argv);
-#if RETSIGTYPE != void
-    return (RETSIGTYPE) 0;
-#endif
 }
 
 /*
  * exit on a signal
  */
-static RETSIGTYPE
+static void
 sig_done(int nonsense)
 {
     MWM_Done(0, NULL);
-#if RETSIGTYPE != void
-    return (RETSIGTYPE) 0;
-#endif
 }
 
 /*
  * For auto-raising windows, this routine is called
  */
-static RETSIGTYPE
+static void
 sig_alarm(int nonsense)
 {
     alarmed = True;
     signal(SIGALRM, sig_alarm);
-
-#if RETSIGTYPE != void
-    return (RETSIGTYPE) 0;
-#endif
 }
 
 
 /*
  * figures out if there's another WM running
  */
-static XErrorHandler
+static void
 catch_redirect(Display *dpy, XErrorEvent *event)
 {
     fprintf(stderr, "mwm: Error: Another WM is running\n");
-    exit(1);
+    exit(1); /* we don't return (this determines function type) */
 }
 
 /*
@@ -227,6 +270,14 @@ initialize_mwm( void)
 		exit(1);
 	    }
 
+	/*TODO: only default screen names are supported
+	 *   since '-screens' mwm command line option is not implemented yet
+	 *		A.R.
+	 */
+	    /* By default, the screen number is used for the screen name. */
+	    scr->screen_name = (String)XtMalloc(12);
+	    sprintf(scr->screen_name, "%lu", scr->screen);
+
 	    SCREEN_Initialize(scr);
 
 	    Mwm.screen_info[i] = scr;
@@ -249,6 +300,14 @@ initialize_mwm( void)
 	    exit(1);
 	}
 
+	/*TODO: only default screen names are supported
+	 *   since '-screens' mwm command line option is not implemented yet
+	 *		A.R.
+	 */
+	/* By default, the screen number is used for the screen name. */
+	scr->screen_name = (String)XtMalloc(12);
+	sprintf(scr->screen_name, "%lu", scr->screen);
+
 	SCREEN_Initialize(scr);
 
 	Mwm.screen_info[0] = scr;
@@ -271,7 +330,7 @@ MWM_SetErrorHandler(int which)
  * cleanup and exit mwm
  */
 void
-MWM_Done(int restart, char *command)
+MWM_Done(int restart, const char *command)
 {
     ScreenInfo *scr;
     int i, done, j;
@@ -328,6 +387,24 @@ MWM_Done(int restart, char *command)
     }
 }
 
+
+/*
+ * ReapChildren - wait() for all dead child processes
+ */
+void ReapChildren(void)
+{
+#ifdef HAVE_WAITPID
+    while ((waitpid(-1, NULL, WNOHANG)) > 0);
+#else
+#ifdef HAVE_WAIT3
+    while ((wait3(NULL, WNOHANG, NULL)) > 0);
+#else
+#error You lose: neither waitpid() nor wait3() is available!
+#endif
+#endif
+}
+
+
 /*
  * main - start of mwm
  */
@@ -346,23 +423,23 @@ main(int argc, char **argv)
 
     for (i = 1; i < argc; i++)
     {
-	if (strncasecmp(argv[i], "-debug", 6) == 0)
+	if (strncmp(argv[i], "-debug", 6) == 0)
 	    debugging = True;
-	else if (strncasecmp(argv[i], "-multiscreen", 12) == 0)
+	else if (strncmp(argv[i], "-multiscreen", 12) == 0)
 	{
 	    multiscreen = True;
 	}
-	else if (strncasecmp(argv[i], "-name", 5) == 0)
+	else if (strncmp(argv[i], "-name", 5) == 0)
 	{
 	    if (++i >= argc)
 		usage();
 	    mwm_name = argv[i];
 	}
-	else if (strncasecmp(argv[i], "-version", 8) == 0)
+	else if (strncmp(argv[i], "-version", 8) == 0)
 	{
 	    fprintf(stderr, "Mwm Version %s\n", VERSION);
 	}
-	else if (strncasecmp(argv[i], "-V", 2) == 0)
+	else if (strncmp(argv[i], "-V", 2) == 0)
 	{
 	    verbose = 1;
 	}
@@ -425,7 +502,7 @@ main(int argc, char **argv)
     len = strlen(XDisplayString(dpy));
     display_string = XtMalloc(len + 10);
     sprintf(display_string, "DISPLAY=%s", XDisplayString(dpy));
-    putenv(display_string);
+    SetEnvironment("DISPLAY", XDisplayString(dpy));
 
     /*
      * Add a HOSTDISPLAY environment variable, which is the same as
@@ -438,8 +515,9 @@ main(int argc, char **argv)
 
 	gethostname(client, MAXHOSTNAME);
 	rdisplay_string = XtMalloc(len + 14 + strlen(client));
-	sprintf(rdisplay_string, "HOSTDISPLAY=%s:%s", client, &display_string[9]);
-	putenv(rdisplay_string);
+	sprintf(rdisplay_string, "%s:%s", client, &display_string[9]);
+
+	SetEnvironment("HOSTDISPLAY", rdisplay_string);
     }
     else if (strncmp(display_string, "DISPLAY=unix:", 13) == 0)
     {
@@ -447,17 +525,17 @@ main(int argc, char **argv)
 
 	gethostname(client, MAXHOSTNAME);
 	rdisplay_string = XtMalloc(len + 14 + strlen(client));
-	sprintf(rdisplay_string, "HOSTDISPLAY=%s:%s", client,
+	sprintf(rdisplay_string, "%s:%s", client,
 		&display_string[13]);
-	putenv(rdisplay_string);
+	SetEnvironment("HOSTDISPLAY", rdisplay_string);
     }
     else
     {
 	char *rdisplay_string;
 
 	rdisplay_string = XtMalloc(len + 14);
-	sprintf(rdisplay_string, "HOSTDISPLAY=%s", XDisplayString(dpy));
-	putenv(rdisplay_string);
+	sprintf(rdisplay_string, "%s", XDisplayString(dpy));
+	SetEnvironment("HOSTDISPLAY", rdisplay_string);
     }
 
     initialize_mwm();
