@@ -1,3 +1,4 @@
+/* $Id: mwm.h,v 1.27 2001/10/29 08:59:26 amai Exp $ */
 /*****************************************************************************/
 /**       Copyright 1988 by Evans & Sutherland Computer Corporation,        **/
 /**                          Salt Lake City, Utah                           **/
@@ -33,36 +34,11 @@
  * mwm - "LessTif Window Manager"
  ***********************************************************************/
 
-#ifndef MWM_H
-#define MWM_H
 
-#include <LTconfig.h>
+#ifndef _MWM_H
+#define _MWM_H
 
-#include <ctype.h>
-#include <stdio.h>
-#ifdef HAVE_STRING_H
-#include <string.h>
-#else
-#define ANSI_STRING
-#include <strings.h>
-#endif
-#include <stdlib.h>
-#include <signal.h>
-#ifdef HAVE_SYS_WAIT_H
-#include <sys/wait.h>
-#endif
-#include <X11/Xlib.h>
-#include <X11/Xatom.h>
-#include <X11/Xutil.h>
-#include <X11/Xresource.h>
-#include <X11/Xproto.h>
-#include <X11/Intrinsic.h>
-#include <X11/IntrinsicP.h>
-#include <X11/keysym.h>
-#include <X11/cursorfont.h>
-#include <X11/extensions/shape.h>
-#include <Xm/XmP.h>
-#include <Xm/XmosP.h>
+#include <Xm/Xm.h>
 #include <Xm/MwmUtil.h>
 
 /*
@@ -84,7 +60,7 @@
 #define MWM_ICONDIR		XINCL_PATH"/X11/bitmaps:"XINCL_PATH"/X11/pixmaps"
 #else
 #define MWM_ICONDIR		"/XFree86/include/X11/bitmaps;/XFree86/include/X11/pixmaps"
-char mwm_icondir[255];
+/* char mwm_icondir[255]; */
 #endif
 #define USAGE \
 "Mwm Ver %s\n\nusage: mwm [-display dpy] [-debug] [-xrm resourcestring] [-multiscreen] [-name name] [-screens name [name [...]]]\n"
@@ -209,6 +185,7 @@ typedef struct ComponentInfo {
     Pixmap          top_shadow_pixmap;
 
     GC              normal_GC;
+    GC              grayed_GC;
     GC              top_GC;
     GC              bot_GC;
     XFontStruct    *font;
@@ -463,16 +440,6 @@ typedef struct FuncKey {
 #define MENU_DONE	1
 #define SUBMENU_DONE	2
 
-
-/*
- * ReapChildren - wait() for all dead child processes
- */
-#ifdef HAVE_WAITPID
-#define ReapChildren()  while ((waitpid(-1, NULL, WNOHANG)) > 0);
-#else
-#define ReapChildren()  while ((wait3(NULL, WNOHANG, NULL)) > 0);
-#endif
-
 #define SIZE_HINDENT 5
 #define SIZE_VINDENT 3
 #define MAX_WINDOW_WIDTH	32767
@@ -569,7 +536,7 @@ typedef struct MwmWindow {
     XWindowAttributes attr;		/* the child window attributes */
     XSizeHints      hints;		/* normal hints */
     XWMHints       *wmhints;		/* WM hints */
-    XClassHint      class;
+    XClassHint      classhint;
 
     int             Desk;		/* Tells which desktop this window is on */
     int             FocusDesk;		/* Where (if at all) was it focussed */
@@ -641,8 +608,33 @@ typedef struct {
 } PanFrame;
 
 typedef struct ScreenInfo {
+    String          button_bindings;
+    Boolean         clean_text;
+    Boolean         fade_normal_icon;
+    Geometry        feedback_geometry;
+    Dimension       frame_border_width;
+    Geometry        icon_box_geometry;
+    String          icon_box_name;
+    String          icon_box_sb_display_policy;
+    XmString        icon_box_title;
+    long            icon_decoration;
+    Size            icon_image_maximum;
+    Size            icon_image_minimum;
+    unsigned char   icon_placement;
+    Dimension       icon_placement_margin;
+    String          key_bindings;
+    Boolean         limit_resize;
+    Size            maximum_maximum_size;
+    Boolean         move_opaque;
+    Dimension       resize_border_width;
+    Boolean         resize_cursors;
+    long            transient_decoration;
+    long            transient_functions;
+    Boolean         use_icon_box;
 
+    /* instance vars */
     unsigned long   screen;		/* screen number */
+    String	    screen_name;
 
     int             d_depth;		/* copy of DefaultDepth(dpy, screen) */
     int             d_width;		/* copy of DisplayWidth(dpy, screen) */
@@ -749,8 +741,6 @@ typedef struct MwmInternalInfo {
     Boolean         auto_key_focus;
     Time            auto_raise_delay;
     String          bitmap_directory;
-    String          button_bindings;
-    Boolean         clean_text;
     Boolean         client_auto_place;
     unsigned char   colormap_focus_policy;
     String          config_file;
@@ -758,28 +748,12 @@ typedef struct MwmInternalInfo {
     Time            double_click_time;
     Boolean         enable_warp;
     Boolean         enforce_key_focus;
-    Boolean         fade_normal_icon;
-    Geometry        feedback_geometry;
-    Dimension       frame_border_width;
     Boolean         icon_auto_place;
-    Geometry        icon_box_geometry;
-    String          icon_box_name;
-    String          icon_box_sb_display_policy;
-    XmString        icon_box_title;
     Boolean         icon_click;
-    long            icon_decoration;
-    Size            icon_image_maximum;
-    Size            icon_image_minimum;
-    unsigned char   icon_placement;
-    Dimension       icon_placement_margin;
     Boolean         interactive_placement;
-    String          key_bindings;
     unsigned char   keyboard_focus_policy;
-    Boolean         limit_resize;
     Boolean         lower_on_iconify;
-    Size            maximum_maximum_size;
     Dimension       move_threshold;
-    Boolean         move_opaque;
     Boolean         multi_screen;
     Boolean         pass_buttons;
     Boolean         pass_selection_buttons;
@@ -787,14 +761,9 @@ typedef struct MwmInternalInfo {
     Boolean         position_on_screen;
     Time            quit_timeout;
     Boolean         raise_key_focus;
-    Dimension       resize_border_width;
-    Boolean         resize_cursors;
     String          screens;
     long            show_feedback;
     Boolean         startup_key_focus;
-    long            transient_decoration;
-    long            transient_functions;
-    Boolean         use_icon_box;
     Boolean         w_menu_button_click;
     Boolean         w_menu_button_click_2;
     Boolean	    use_pager;
@@ -865,7 +834,7 @@ typedef struct MwmInternalInfo {
  * error handler
  */
 #define REDIRECT	01
-#define GENERAL		02
+#define GENERAL	02
 
 /*
  * gotta know which way
@@ -880,7 +849,7 @@ typedef struct MwmInternalInfo {
 extern void	PAN_Initialize(ScreenInfo *scr);
 extern void	PAN_Raise(ScreenInfo *scr);
 extern void	PAN_CheckBounds(ScreenInfo *scr);
-extern void     PAN_PanDesktop(ScreenInfo *scr, int, int,
+extern void PAN_PanDesktop(ScreenInfo *scr, int, int,
 			       int *, int *, int *, int *, Boolean, XEvent *);
 extern Boolean  PAN_IsPannerWindow(ScreenInfo *scr, Window win);
 
@@ -890,14 +859,14 @@ extern void	DT_ChangeDesks(ScreenInfo *scr, int val1, int val2);
 extern void	DT_WindowChangingDesks(ScreenInfo *scr, MwmWindow *t, int val1);
 
 /* Pager functions */
-extern void     PAGER_Clear(ScreenInfo *scr);
-extern void     PAGER_Redraw(ScreenInfo *scr);
-extern void     PAGER_SwitchPage(ScreenInfo *scr, Bool, Bool, XEvent *event);
-extern void     PAGER_UpdateViewPort(ScreenInfo *scr);
-extern void     PAGER_UpdateView(ScreenInfo *scr, MwmWindow * t);
+extern void PAGER_Clear(ScreenInfo *scr);
+extern void PAGER_Redraw(ScreenInfo *scr);
+extern void PAGER_SwitchPage(ScreenInfo *scr, Bool, Bool, XEvent *event);
+extern void PAGER_UpdateViewPort(ScreenInfo *scr);
+extern void PAGER_UpdateView(ScreenInfo *scr, MwmWindow * t);
 extern void	PAGER_Initialize(ScreenInfo *scr, Position x, Position y);
-extern void     PAGER_Update(ScreenInfo *scr, XEvent *event);
-extern void     PAGER_MoveViewPort(ScreenInfo *scr, int newx, int newy, Boolean);
+extern void PAGER_Update(ScreenInfo *scr, XEvent *event);
+extern void PAGER_MoveViewPort(ScreenInfo *scr, int newx, int newy, Boolean);
 
 /* Parser functions */
 extern void	PARSE_mwmrc(ScreenInfo *scr);
@@ -905,19 +874,20 @@ extern int	PARSE_buf(ScreenInfo *scr, char *buf);
 
 /* Resource functions */
 extern void	RES_Initialize(void);
-extern void	RES_GetClientDefaults(ScreenInfo *scr, MwmWindow *win, char *name, char *class);
+extern void	RES_GetClientDefaults(ScreenInfo *scr, MwmWindow *win, char *name_s, char *class_s);
+extern void	RES_GetScreenDefaults(ScreenInfo *scr);
 extern void	RES_GetComponentDefaults(ScreenInfo *scr);
 
 /* Miscellaneous functions */
 extern Boolean	MISC_Grab(ScreenInfo *scr, int);
-extern void     MISC_Ungrab(ScreenInfo *scr);
+extern void MISC_Ungrab(ScreenInfo *scr);
 extern void	MISC_WaitForButtonsUp(ScreenInfo *scr);
-extern int      MISC_FlushExpose(Window w);
-extern void     MISC_SetTimer(int);
+extern int  MISC_FlushExpose(Window w);
+extern void MISC_SetTimer(int);
 extern Boolean  MISC_StashEventTime(XEvent * ev);
 extern Time	MISC_FetchEventTime(void);
-extern void     MISC_SetFocusSequence(ScreenInfo *scr);
-extern void     MISC_KeyboardShortcut(ScreenInfo *scr, XEvent *, int);
+extern void MISC_SetFocusSequence(ScreenInfo *scr);
+extern void MISC_KeyboardShortcut(ScreenInfo *scr, XEvent *, int);
 extern void	MISC_AddToTree(ScreenInfo *scr, MwmWindow *win);
 extern void	MISC_RemoveFromTree(ScreenInfo *scr, MwmWindow *win);
 extern void	MISC_PrintTree(ScreenInfo *scr);
@@ -934,7 +904,7 @@ extern void	PROP_SetBehavior(ScreenInfo *scr, Boolean custom);
 extern void	PROP_ClearBehavior(ScreenInfo *scr);
 extern void	PROP_SetPriorityColors(ScreenInfo *scr);
 extern Boolean	PROP_CheckDesktop(ScreenInfo *scr);
-extern void     PROP_SetState(MwmWindow *, int);
+extern void PROP_SetState(MwmWindow *, int);
 extern void	PROP_SendClientMessage(Window w, Atom a, Time timestamp);
 extern void	PROP_GetMwmHints(MwmWindow *win);
 extern void	PROP_GetMwmMenu(MwmWindow *win);
@@ -955,18 +925,18 @@ extern ScreenInfo *SCREEN_EventToStruct(XEvent *event);
 extern void	WIN_CaptureWindows(ScreenInfo *scr);
 extern void	WIN_ReleaseWindows(ScreenInfo *scr);
 extern void	WIN_MapWindow(ScreenInfo *scr, Window win);
-extern void     WIN_SetFocus(ScreenInfo *scr, Window, MwmWindow *);
+extern void WIN_SetFocus(ScreenInfo *scr, Window, MwmWindow *);
 extern void	WIN_ChangeFocus(ScreenInfo *scr, MwmWindow *t,
 				int DeIconifyOnly);
-extern void     WIN_RestoreWithdrawn(ScreenInfo *scr, MwmWindow *, Boolean);
+extern void WIN_RestoreWithdrawn(ScreenInfo *scr, MwmWindow *, Boolean);
 extern MwmWindow *WIN_WindowToStruct(ScreenInfo *scr, Window target);	
-extern void     WIN_Raise(ScreenInfo *scr, MwmWindow * t);
-extern void     WIN_Lower(ScreenInfo *scr, MwmWindow * t);
+extern void WIN_Raise(ScreenInfo *scr, MwmWindow * t);
+extern void WIN_Lower(ScreenInfo *scr, MwmWindow * t);
 extern void	WIN_ConstrainWindow(ScreenInfo *scr, MwmWindow *win,
 				    int *widthp, int *heightp);
 extern void	WIN_DrawOutline(ScreenInfo *scr, Window win,
 				int x, int y, int wd, int ht);
-extern void     WIN_FreeNames(MwmWindow * tmp, Bool nukename, Bool nukeicon);
+extern void WIN_FreeNames(MwmWindow * tmp, Bool nukename, Bool nukeicon);
 extern void	WIN_DestroyWindow(ScreenInfo *scr, MwmWindow *Tmp_win);
 extern void	WIN_SetFocusInTree(MwmWindow *win);
 
@@ -976,19 +946,19 @@ extern void	COLOR_PushRootColorMap(ScreenInfo *scr);
 extern void	COLOR_PopRootColorMap(ScreenInfo *scr);
 
 /* Decoration functions */
-extern void     DEC_DrawDecorations(ScreenInfo *, MwmWindow *,
+extern void DEC_DrawDecorations(ScreenInfo *, MwmWindow *,
 				    Bool, Bool, Bool, Window);
-extern void     DEC_DrawTitleBar(ScreenInfo *scr, MwmWindow *, Bool, Bool);
-extern void     DEC_DrawShadows(MwmWindow *, Window, int, int, int, int,
+extern void DEC_DrawTitleBar(ScreenInfo *scr, MwmWindow *, Bool, Bool);
+extern void DEC_DrawShadows(MwmWindow *, Window, int, int, int, int,
 				GC, GC);
-extern void     DEC_DrawBorder(MwmWindow *, Window, int, int, int, int,
+extern void DEC_DrawBorder(MwmWindow *, Window, int, int, int, int,
 			       GC, GC);
-extern void     DEC_CreateDecorations(ScreenInfo *scr, MwmWindow *);
-extern void     DEC_ConfigureDecorations(ScreenInfo *scr, MwmWindow *,
+extern void DEC_CreateDecorations(ScreenInfo *scr, MwmWindow *);
+extern void DEC_ConfigureDecorations(ScreenInfo *scr, MwmWindow *,
 					 int, int, int, int, Boolean);
-extern void     DEC_SelectDecorations(ScreenInfo *scr, MwmWindow *t);
-extern void     DEC_ReselectDecorations(ScreenInfo *scr, MwmWindow *t);
-extern void     DEC_SetShape(MwmWindow *, int);
+extern void DEC_SelectDecorations(ScreenInfo *scr, MwmWindow *t);
+extern void DEC_ReselectDecorations(ScreenInfo *scr, MwmWindow *t);
+extern void DEC_SetShape(MwmWindow *, int);
 
 /* Event functions */
 extern void	EVENT_Initialize(void);
@@ -997,21 +967,21 @@ extern int	EVENT_Next(XEvent *event);
 extern void	EVENT_Dispatch(XEvent *event);
 
 /* Function functions */
-extern void     FUNC_Execute(ScreenInfo *scr, int, char *, Window,
+extern void FUNC_Execute(ScreenInfo *scr, int, char *, Window,
 			     MwmWindow *, XEvent *, unsigned long,
 			     long, long, int, int, MenuRoot *);
 
 /* Icon functions */
-extern void     ICON_CreateWindow(ScreenInfo *scr, MwmWindow *tmp,
+extern void ICON_CreateWindow(ScreenInfo *scr, MwmWindow *tmp,
 				  int def_x, int def_y);
-extern void     ICON_DrawWindow(ScreenInfo *scr, MwmWindow *);
-extern void     ICON_UpdateWindow(ScreenInfo *scr, MwmWindow *, Boolean force);
-extern void     ICON_AutoPlace(ScreenInfo *scr, MwmWindow *);
-extern void     ICON_Iconify(ScreenInfo *scr, MwmWindow *, int, int);
-extern void     ICON_DeIconify(ScreenInfo *scr, MwmWindow *);
+extern void ICON_DrawWindow(ScreenInfo *scr, MwmWindow *);
+extern void ICON_UpdateWindow(ScreenInfo *scr, MwmWindow *, Boolean force);
+extern void ICON_AutoPlace(ScreenInfo *scr, MwmWindow *);
+extern void ICON_Iconify(ScreenInfo *scr, MwmWindow *, int, int);
+extern void ICON_DeIconify(ScreenInfo *scr, MwmWindow *);
 
 /* Menu functions */
-extern MenuRoot *MENU_Create(char *name);
+extern MenuRoot *MENU_Create(const char *name);
 extern void	MENU_FindHotKey(MenuItem *it, KeySym key);
 extern void	MENU_Add(ScreenInfo *scr, MenuRoot *menu);
 extern void	MENU_Remove(ScreenInfo *scr, MenuRoot *menu);
@@ -1021,21 +991,21 @@ extern void	MENU_AddItem(ScreenInfo *scr, MenuRoot *menu,
 			     long func_val_1, long func_val_2,
 			     char unit_1, char unit_2);
 extern void	MENU_LinkUp(ScreenInfo *scr);
-extern void     MENU_Realize(ScreenInfo *scr, MenuRoot *);
-extern void     MENU_RealizeMenus(ScreenInfo *scr);
-extern int      MENU_PopupMenu(ScreenInfo *scr, MenuRoot * menu);
-extern int      MENU_WinMenu(ScreenInfo *scr, MenuRoot *menu,
+extern void MENU_Realize(ScreenInfo *scr, MenuRoot *);
+extern void MENU_RealizeMenus(ScreenInfo *scr);
+extern int  MENU_PopupMenu(ScreenInfo *scr, MenuRoot * menu);
+extern int  MENU_WinMenu(ScreenInfo *scr, MenuRoot *menu,
 			     MwmWindow *win, Boolean button, Boolean icon);
 extern void	MENU_Destroy(MenuRoot *menu);
-extern void     MENU_DestroyMenus(ScreenInfo *scr);
-extern void     MENU_Reset(void);
-extern void     MENU_BuildWindowMenu(ScreenInfo *scr, MwmWindow *win);
-extern void     MENU_DestroyWindowMenu(ScreenInfo *scr, MwmWindow *win);
+extern void MENU_DestroyMenus(ScreenInfo *scr);
+extern void MENU_Reset(void);
+extern void MENU_BuildWindowMenu(ScreenInfo *scr, MwmWindow *win);
+extern void MENU_DestroyWindowMenu(ScreenInfo *scr, MwmWindow *win);
 extern char	*MENU_AcceleratorString(ScreenInfo *scr, KeySym key,
 					int modifiers);
 
 /* Movement functions */
-extern void     MOVE_EventLoop(ScreenInfo *scr, MwmWindow *, int, int, int, int,
+extern void MOVE_EventLoop(ScreenInfo *scr, MwmWindow *, int, int, int, int,
 			       int *, int *, Boolean, Boolean);
 extern void	MOVE_Interactive(ScreenInfo *scr, Window *win, MwmWindow *tmp_win,
 				 int *FinalX, int *FinalY, XEvent *eventp);
@@ -1047,11 +1017,11 @@ extern void	RESIZE_EventLoop(ScreenInfo *scr, Window w, MwmWindow *tmp_win,
 
 /* exit functions */
 extern void	MWM_SetErrorHandler(int which);
-extern void     MWM_Done(int, char *);
+extern void MWM_Done(int, const char *);
 
 /* Debugging functions */
-extern char	 *_MwmPrintC(int x);
-extern char	 *_MwmPrintF(int x);
+extern const char	 *_MwmPrintC(int x);
+extern const char	 *_MwmPrintF(int x);
 
 /* Resource default functions */
 extern void	_WmMultiClickTimeDefault(Widget w, int offset, XrmValue *val);
@@ -1097,6 +1067,11 @@ extern void	mwm_putc(char c);
 extern void	mwm_unputc(char c);
 extern void	yyerror(char *fmt, ...);
 
+/* Misc utility functions */
+extern int SetEnvironment(const char *key, const char *value);
+void ReapChildren(void);
+
+
 /*
  * global data
  */
@@ -1113,6 +1088,26 @@ extern unsigned int JunkWidth, JunkHeight, JunkBW, JunkDepth, JunkMask;
 extern void    *working_base;
 extern ScreenInfo *rscr;
 
+/* menus.c: */
+extern int menuFromFrameOrWindowOrTitlebar;
+extern int Stashed_X, Stashed_Y;
+
+/* move.c: */
+extern Bool NeedToResizeToo;
+
+/* mwm.c: */
+extern volatile int alarmed;
+extern Bool debugging;
+extern char **g_argv;
+extern int verbose;
+
+/* pager.c: */
+extern Bool DoHandlePageing;
+extern Bool pagerOn;
+extern Bool EnablePagerRedraw;
+extern Bool DoHandlePageing;
+
+
 
 extern Atom     XA_MIT_PRIORITY_COLORS;
 extern Atom     XA_WM_CHANGE_STATE;
@@ -1129,4 +1124,4 @@ extern Atom     XA_MWM_MESSAGES;
 extern Atom     XA_MWM_MENU;
 extern Atom     XA_MWM_INFO;
 
-#endif /* _MWM_ */
+#endif /* _MWM_H */
