@@ -1,4 +1,4 @@
-/* $Id: screens.c,v 1.10 2001/06/22 19:06:04 amai Exp $ */
+/* $Id: screens.c,v 1.11 2001/10/24 12:06:44 amai Exp $ */
 /*****************************************************************************/
 /**       Copyright 1988 by Evans & Sutherland Computer Corporation,        **/
 /**                          Salt Lake City, Utah                           **/
@@ -42,6 +42,8 @@
 
 #include <Xm/XmP.h>
 #include <Xm/MwmUtil.h>
+#include <XmI/XmI.h>
+
 #include "mwm.h"
 
 
@@ -59,9 +61,6 @@ static char stipple_bits[] = {
 #endif /* #if 0 */
 
 
-extern Boolean debugging;
-
-extern XmFontList _XmFontListCreateDefault(Display *);
 /*
  * create the GC's for the menus
  */
