@@ -1,70 +1,69 @@
 
 /*  A Bison parser, made from yacc.y
- by  GNU Bison version 1.25
-  */
+    by GNU Bison version 1.28  */
 
 #define YYBISON 1  /* Identify Bison output.  */
 
-#define	STRING	258
-#define	ID	259
-#define	VERSION_t	260
-#define	NAMES	261
-#define	MODULE	262
-#define	VALUE	263
-#define	INTEGER	264
-#define	FLOAT	265
-#define	STRING_TABLE	266
-#define	INTEGER_TYPE	267
-#define	FLOAT_TYPE	268
-#define	STRING_TYPE	269
-#define	ANY_TYPE	270
-#define	BOOLEAN_TYPE	271
-#define	PROCEDURE	272
-#define	PROCEDURES	273
-#define	IMPORTED	274
-#define	CONTROLS	275
-#define	ARGUMENT	276
-#define	ARGUMENTS	277
-#define	OBJECT	278
-#define	CALLBACK	279
-#define	END	280
-#define	EXPORTED	281
-#define	OBJECTS	282
-#define	CHAR_SET	283
-#define	WIDGET	284
-#define	INC_FILE	285
-#define	LIST	286
-#define	UNMANAGED	287
-#define	KEYSYM	288
-#define	ICON	289
-#define	COMPOUND_STRING	290
-#define	SEPARATE	291
-#define	BOOL	292
-#define	GADGET	293
-#define	PRIVATE	294
-#define	REASON	295
-#define	USER_DEFINED	296
-#define	RGB	297
-#define	COLOR	298
-#define	COLOR_TABLE	299
-#define	XBITMAPFILE	300
-#define	XPIXMAPFILE	301
-#define	FONT	302
-#define	FONT_TABLE	303
-#define	FONT_UNIT	304
-#define	BACKGROUND_COLOR	305
-#define	FOREGROUND_COLOR	306
-#define	RIGHT_TO_LEFT	307
-#define	SIXTEEN_BIT	308
+#define	STRING	257
+#define	ID	258
+#define	VERSION_t	259
+#define	NAMES	260
+#define	MODULE	261
+#define	VALUE	262
+#define	INTEGER	263
+#define	FLOAT	264
+#define	STRING_TABLE	265
+#define	INTEGER_TYPE	266
+#define	FLOAT_TYPE	267
+#define	STRING_TYPE	268
+#define	ANY_TYPE	269
+#define	BOOLEAN_TYPE	270
+#define	PROCEDURE	271
+#define	PROCEDURES	272
+#define	IMPORTED	273
+#define	CONTROLS	274
+#define	ARGUMENT	275
+#define	ARGUMENTS	276
+#define	OBJECT	277
+#define	CALLBACK	278
+#define	END	279
+#define	EXPORTED	280
+#define	OBJECTS	281
+#define	CHAR_SET	282
+#define	WIDGET	283
+#define	INC_FILE	284
+#define	LIST	285
+#define	UNMANAGED	286
+#define	KEYSYM	287
+#define	ICON	288
+#define	COMPOUND_STRING	289
+#define	SEPARATE	290
+#define	BOOL	291
+#define	GADGET	292
+#define	PRIVATE	293
+#define	REASON	294
+#define	USER_DEFINED	295
+#define	RGB	296
+#define	COLOR	297
+#define	COLOR_TABLE	298
+#define	XBITMAPFILE	299
+#define	XPIXMAPFILE	300
+#define	FONT	301
+#define	FONT_TABLE	302
+#define	FONT_UNIT	303
+#define	BACKGROUND_COLOR	304
+#define	FOREGROUND_COLOR	305
+#define	RIGHT_TO_LEFT	306
+#define	SIXTEEN_BIT	307
 
 #line 1 "yacc.y"
 
 /**
  *
- * $Id: yacc.y,v 1.12 2000/12/06 14:18:00 amai Exp $
+ * $Id: yacc.y,v 1.13 2001/05/18 09:00:35 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2000 LessTif Development Team
+ * Copyright (C) 1995-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -93,11 +92,10 @@
 #include <stdlib.h>
 #include <stdio.h>
 #include <stdarg.h>
+
 #include "uil.h"	
 #include "glue.h"
 
-static int False = 0;
-static int True = 1;
 extern int LineNumber;
 extern char *FileName;
 
@@ -108,15 +106,22 @@ extern unsigned char yytext[];	/* Unsigned needed on HP/UX */
 #endif
 extern int yylex(void);
 
-/* For the prototype police */ 
-void yyerror(const char *s);
-void yyExit(int line, char *file, const char *fmt, ...);
+/* For the prototype police.
+   GNU bison up to 1.28 doesn't allow us to use the
+   const qualifier here. Shame on it ...
+ */ 
+void yyerror(char *s);
+void yyExit(int line, char *file, char *fmt, ...);
+
+
+static int False = 0;
+static int True = 1;
 
 
 #define YYDEBUG	1
 int yydebug = 1;
 
-#line 191 "yacc.y"
+#line 197 "yacc.y"
 typedef union {
     char	*string;
 } YYSTYPE;
@@ -134,7 +139,7 @@ typedef union {
 #define	YYFLAG		-32768
 #define	YYNTBASE	68
 
-#define YYTRANSLATE(x) ((unsigned)(x) <= 308 ? yytranslate[x] : 97)
+#define YYTRANSLATE(x) ((unsigned)(x) <= 307 ? yytranslate[x] : 97)
 
 static const char yytranslate[] = {     0,
      2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
@@ -162,12 +167,12 @@ static const char yytranslate[] = {     0,
      2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
      2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
      2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
-     2,     2,     2,     2,     2,     1,     2,     3,     4,     5,
-     6,     7,     8,     9,    10,    11,    12,    13,    14,    15,
-    16,    17,    18,    19,    20,    21,    22,    23,    24,    25,
-    26,    27,    28,    29,    30,    31,    32,    33,    34,    35,
-    36,    37,    38,    39,    40,    41,    42,    43,    44,    45,
-    46,    47,    48,    49,    50,    51,    52,    53
+     2,     2,     2,     2,     2,     1,     3,     4,     5,     6,
+     7,     8,     9,    10,    11,    12,    13,    14,    15,    16,
+    17,    18,    19,    20,    21,    22,    23,    24,    25,    26,
+    27,    28,    29,    30,    31,    32,    33,    34,    35,    36,
+    37,    38,    39,    40,    41,    42,    43,    44,    45,    46,
+    47,    48,    49,    50,    51,    52,    53
 };
 
 #if YYDEBUG != 0
@@ -260,20 +265,20 @@ static const short yyrhs[] = {     7,
 
 #if YYDEBUG != 0
 static const short yyrline[] = { 0,
-   197,   200,   206,   211,   216,   220,   224,   231,   235,   240,
-   244,   248,   255,   259,   263,   269,   273,   277,   281,   285,
-   289,   293,   297,   301,   307,   311,   317,   321,   327,   331,
-   335,   341,   345,   349,   353,   357,   361,   365,   369,   375,
-   379,   383,   387,   393,   397,   402,   407,   411,   416,   423,
-   427,   433,   437,   441,   445,   449,   453,   457,   461,   467,
-   472,   477,   482,   488,   492,   498,   502,   507,   511,   517,
-   521,   527,   532,   537,   542,   548,   552,   559,   563,   567,
-   572,   576,   580,   584,   588,   592,   598,   604,   608,   612,
-   616,   622,   626,   630,   634,   640,   644,   648,   654,   658,
-   663,   667,   672,   676,   680,   684,   688,   692,   697,   701,
-   705,   709,   713,   717,   721,   725,   731,   736,   740,   744,
-   750,   754,   760,   767,   771,   777,   781,   786,   790,   794,
-   798,   802,   806,   810,   814
+   203,   206,   212,   217,   222,   226,   230,   237,   241,   246,
+   250,   254,   261,   265,   269,   275,   279,   283,   287,   291,
+   295,   299,   303,   307,   313,   317,   323,   327,   333,   337,
+   341,   347,   351,   355,   359,   363,   367,   371,   375,   381,
+   385,   389,   393,   399,   403,   408,   413,   417,   422,   429,
+   433,   439,   443,   447,   451,   455,   459,   463,   467,   473,
+   478,   483,   488,   494,   498,   504,   508,   513,   517,   523,
+   527,   533,   538,   543,   548,   554,   558,   565,   569,   573,
+   578,   582,   586,   590,   594,   598,   604,   610,   614,   618,
+   622,   628,   632,   636,   640,   646,   650,   654,   660,   664,
+   669,   673,   678,   682,   686,   690,   694,   698,   703,   707,
+   711,   715,   719,   723,   727,   731,   737,   742,   746,   750,
+   756,   760,   766,   773,   777,   783,   787,   792,   796,   800,
+   804,   808,   812,   816,   820
 };
 #endif
 
@@ -532,6 +537,7 @@ static const short yycheck[] = {    50,
 };
 /* -*-C-*-  Note some compilers choke on comments on `#line' lines.  */
 #line 3 "/usr/share/bison.simple"
+/* This file comes from bison-1.28.  */
 
 /* Skeleton output parser for bison,
    Copyright (C) 1984, 1989, 1990 Free Software Foundation, Inc.
@@ -548,47 +554,72 @@ static const short yycheck[] = {    50,
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 59 Temple Place - Suite 330,
+   Boston, MA 02111-1307, USA.  */
 
 /* As a special exception, when this file is copied by Bison into a
    Bison output file, you may use that output file without restriction.
    This special exception was added by the Free Software Foundation
    in version 1.24 of Bison.  */
 
-#ifndef alloca
-#ifdef __GNUC__
-#define alloca __builtin_alloca
-#else /* not GNU C.  */
-#if (!defined (__STDC__) && defined (sparc)) || defined (__sparc__) || defined (__sparc) || defined (__sgi)
-#include <alloca.h>
-#else /* not sparc */
-#if defined (MSDOS) && !defined (__TURBOC__)
-#include <malloc.h>
-#else /* not MSDOS, or __TURBOC__ */
-#if defined(_AIX)
-#include <malloc.h>
- #pragma alloca
-#else /* not MSDOS, __TURBOC__, or _AIX */
-#ifdef __hpux
-#ifdef __cplusplus
-extern "C" {
-void *alloca (unsigned int);
-};
-#else /* not __cplusplus */
-void *alloca ();
-#endif /* not __cplusplus */
-#endif /* __hpux */
-#endif /* not _AIX */
-#endif /* not MSDOS, or __TURBOC__ */
-#endif /* not sparc.  */
-#endif /* not GNU C.  */
-#endif /* alloca not defined.  */
-
 /* This is the parser code that is written into each bison parser
   when the %semantic_parser declaration is not specified in the grammar.
   It was written by Richard Stallman by simplifying the hairy parser
   used when %semantic_parser is specified.  */
 
+#ifndef YYPARSE_RETURN_TYPE
+#define YYPARSE_RETURN_TYPE int
+#endif
+
+
+#ifndef YYSTACK_USE_ALLOCA
+#ifdef alloca
+#define YYSTACK_USE_ALLOCA
+#else /* alloca not defined */
+#ifdef __GNUC__
+#define YYSTACK_USE_ALLOCA
+#define alloca __builtin_alloca
+#else /* not GNU C.  */
+#if (!defined (__STDC__) && defined (sparc)) || defined (__sparc__) || defined (__sparc) || defined (__sgi) || (defined (__sun) && defined (__i386))
+#define YYSTACK_USE_ALLOCA
+#include <alloca.h>
+#else /* not sparc */
+/* We think this test detects Watcom and Microsoft C.  */
+/* This used to test MSDOS, but that is a bad idea
+   since that symbol is in the user namespace.  */
+#if (defined (_MSDOS) || defined (_MSDOS_)) && !defined (__TURBOC__)
+#if 0 /* No need for malloc.h, which pollutes the namespace;
+	 instead, just don't use alloca.  */
+#include <malloc.h>
+#endif
+#else /* not MSDOS, or __TURBOC__ */
+#if defined(_AIX)
+/* I don't know what this was needed for, but it pollutes the namespace.
+   So I turned it off.   rms, 2 May 1997.  */
+/* #include <malloc.h>  */
+ #pragma alloca
+#define YYSTACK_USE_ALLOCA
+#else /* not MSDOS, or __TURBOC__, or _AIX */
+#if 0
+#ifdef __hpux /* haible@ilog.fr says this works for HPUX 9.05 and up,
+		 and on HPUX 10.  Eventually we can turn this on.  */
+#define YYSTACK_USE_ALLOCA
+#define alloca __builtin_alloca
+#endif /* __hpux */
+#endif
+#endif /* not _AIX */
+#endif /* not MSDOS, or __TURBOC__ */
+#endif /* not sparc */
+#endif /* not GNU C */
+#endif /* alloca not defined */
+#endif /* YYSTACK_USE_ALLOCA not defined */
+
+#ifdef YYSTACK_USE_ALLOCA
+#define YYSTACK_ALLOC alloca
+#else
+#define YYSTACK_ALLOC malloc
+#endif
+
 /* Note: there must be only one dollar sign in this file.
    It is replaced by the list of actions, each action
    as one case of the switch.  */
@@ -597,8 +628,8 @@ void *alloca ();
 #define yyclearin	(yychar = YYEMPTY)
 #define YYEMPTY		-2
 #define YYEOF		0
-#define YYACCEPT	return(0)
-#define YYABORT 	return(1)
+#define YYACCEPT	goto yyacceptlab
+#define YYABORT 	goto yyabortlab
 #define YYERROR		goto yyerrlab1
 /* Like YYERROR except do call yyerror.
    This remains here temporarily to ease the
@@ -679,16 +710,12 @@ int yydebug;			/*  nonzero means print parse trace	*/
 #ifndef YYMAXDEPTH
 #define YYMAXDEPTH 10000
 #endif
-
-#ifndef YYPARSE_RETURN_TYPE
-#define YYPARSE_RETURN_TYPE int
-#endif
-
-/* Prevent warning if -Wstrict-prototypes.  */
-#ifdef __GNUC__
-YYPARSE_RETURN_TYPE yyparse (void);
-#endif
 
+/* Define __yy_memcpy.  Note that the size argument
+   should be passed with type unsigned int, because that is what the non-GCC
+   definitions require.  With GCC, __builtin_memcpy takes an arg
+   of type size_t, but it can handle unsigned int.  */
+
 #if __GNUC__ > 1		/* GNU C and GNU C++ define this.  */
 #define __yy_memcpy(TO,FROM,COUNT)	__builtin_memcpy(TO,FROM,COUNT)
 #else				/* not GNU C or C++ */
@@ -700,7 +727,7 @@ static void
 __yy_memcpy (to, from, count)
      char *to;
      char *from;
-     int count;
+     unsigned int count;
 {
   register char *f = from;
   register char *t = to;
@@ -715,10 +742,10 @@ __yy_memcpy (to, from, count)
 /* This is the most reliable way to avoid incompatibilities
    in available built-in functions on various systems.  */
 static void
-__yy_memcpy (char *to, char *from, int count)
+__yy_memcpy (char *to, char *from, unsigned int count)
 {
-  register char *f = from;
   register char *t = to;
+  register char *f = from;
   register int i = count;
 
   while (i-- > 0)
@@ -728,7 +755,7 @@ __yy_memcpy (char *to, char *from, int count)
 #endif
 #endif
 
-#line 196 "/usr/share/bison.simple"
+#line 222 "/usr/share/bison.simple"
 
 /* The user can define YYPARSE_PARAM as the name of an argument to be passed
    into yyparse.  The argument should have type void *.
@@ -749,6 +776,17 @@ __yy_memcpy (char *to, char *from, int count)
 #define YYPARSE_PARAM_DECL
 #endif /* not YYPARSE_PARAM */
 
+/* Prevent warning if -Wstrict-prototypes.  */
+#ifdef __GNUC__
+#ifdef YYPARSE_PARAM
+YYPARSE_RETURN_TYPE
+yyparse (void *);
+#else
+YYPARSE_RETURN_TYPE
+yyparse (void);
+#endif
+#endif
+
 YYPARSE_RETURN_TYPE
 yyparse(YYPARSE_PARAM_ARG)
      YYPARSE_PARAM_DECL
@@ -777,6 +815,9 @@ yyparse(YYPARSE_PARAM_ARG)
 #endif
 
   int yystacksize = YYINITDEPTH;
+#ifndef YYSTACK_USE_ALLOCA
+  int yyfree_stacks = 0;
+#endif
 
 #ifdef YYPURE
   int yychar;
@@ -861,18 +902,34 @@ yynewstate:
       if (yystacksize >= YYMAXDEPTH)
 	{
 	  yyerror("parser stack overflow");
+#ifndef YYSTACK_USE_ALLOCA
+	  if (yyfree_stacks)
+	    {
+	      free (yyss);
+	      free (yyvs);
+#ifdef YYLSP_NEEDED
+	      free (yyls);
+#endif
+	    }
+#endif	    
 	  return 2;
 	}
       yystacksize *= 2;
       if (yystacksize > YYMAXDEPTH)
 	yystacksize = YYMAXDEPTH;
-      yyss = (short *) alloca (yystacksize * sizeof (*yyssp));
-      __yy_memcpy ((char *)yyss, (char *)yyss1, size * sizeof (*yyssp));
-      yyvs = (YYSTYPE *) alloca (yystacksize * sizeof (*yyvsp));
-      __yy_memcpy ((char *)yyvs, (char *)yyvs1, size * sizeof (*yyvsp));
+#ifndef YYSTACK_USE_ALLOCA
+      yyfree_stacks = 1;
+#endif
+      yyss = (short *) YYSTACK_ALLOC (yystacksize * sizeof (*yyssp));
+      __yy_memcpy ((char *)yyss, (char *)yyss1,
+		   size * (unsigned int) sizeof (*yyssp));
+      yyvs = (YYSTYPE *) YYSTACK_ALLOC (yystacksize * sizeof (*yyvsp));
+      __yy_memcpy ((char *)yyvs, (char *)yyvs1,
+		   size * (unsigned int) sizeof (*yyvsp));
 #ifdef YYLSP_NEEDED
-      yyls = (YYLTYPE *) alloca (yystacksize * sizeof (*yylsp));
-      __yy_memcpy ((char *)yyls, (char *)yyls1, size * sizeof (*yylsp));
+      yyls = (YYLTYPE *) YYSTACK_ALLOC (yystacksize * sizeof (*yylsp));
+      __yy_memcpy ((char *)yyls, (char *)yyls1,
+		   size * (unsigned int) sizeof (*yylsp));
 #endif
 #endif /* no yyoverflow */
 
@@ -1033,420 +1090,420 @@ yyreduce:
   switch (yyn) {
 
 case 1:
-#line 198 "yacc.y"
+#line 204 "yacc.y"
 {
 		;
     break;}
 case 2:
-#line 201 "yacc.y"
+#line 207 "yacc.y"
 {
 		    __MrmWarn(LOC,"Empty input file\n");
 		;
     break;}
 case 3:
-#line 207 "yacc.y"
+#line 213 "yacc.y"
 {
 		    __MrmWarn(LOC,"NO OP\n");
 		    yyval.string = yyvsp[-2].string;
 		;
     break;}
 case 4:
-#line 212 "yacc.y"
+#line 218 "yacc.y"
 {
 		    __MrmWarn(LOC,"NO OP\n");
 		    yyval.string = yyvsp[-2].string;
 		;
     break;}
 case 5:
-#line 217 "yacc.y"
+#line 223 "yacc.y"
 {
 		    __MrmWarn(LOC,"NO OP\n");
 		;
     break;}
 case 6:
-#line 221 "yacc.y"
+#line 227 "yacc.y"
 {
 		    yyval.string = body_OBJECT_object(yyvsp[-2].string,yyvsp[0].string);
 		;
     break;}
 case 7:
-#line 225 "yacc.y"
+#line 231 "yacc.y"
 {
 		    yyval.string = NULL;
 		;
     break;}
 case 8:
-#line 232 "yacc.y"
+#line 238 "yacc.y"
 {
 		    __MrmWarn(LOC,"NO OP\n");
 		;
     break;}
 case 9:
-#line 236 "yacc.y"
+#line 242 "yacc.y"
 {
 		    __MrmWarn(LOC,"NO OP\n");
 		    yyval.string = yyvsp[-3].string;
 		;
     break;}
 case 10:
-#line 241 "yacc.y"
+#line 247 "yacc.y"
 {
 		    __MrmWarn(LOC,"NO OP\n");
 		;
     break;}
 case 11:
-#line 245 "yacc.y"
+#line 251 "yacc.y"
 {
 		    __MrmWarn(LOC,"NO OP\n");
 		;
     break;}
 case 12:
-#line 249 "yacc.y"
+#line 255 "yacc.y"
 {
 		    __MrmWarn(LOC,"NO OP\n");
 		    yyval.string = NULL;
 		;
     break;}
 case 13:
-#line 256 "yacc.y"
+#line 262 "yacc.y"
 {
 		    __MrmWarn(LOC,"NO OP\n");
 		;
     break;}
 case 14:
-#line 260 "yacc.y"
+#line 266 "yacc.y"
 {
 		    __MrmWarn(LOC,"NO OP\n");
 		;
     break;}
 case 15:
-#line 264 "yacc.y"
+#line 270 "yacc.y"
 {
 		    __MrmWarn(LOC,"NO OP\n");
 		;
     break;}
 case 16:
-#line 270 "yacc.y"
+#line 276 "yacc.y"
 {
 		    MakeTable(yyvsp[-4].string,yyvsp[-2].string, 0);
 		;
     break;}
 case 17:
-#line 274 "yacc.y"
+#line 280 "yacc.y"
 {
 		    MakeTable(yyvsp[-6].string, yyvsp[-2].string, 0);
 		;
     break;}
 case 18:
-#line 278 "yacc.y"
+#line 284 "yacc.y"
 {
 		    MakeTable(yyvsp[-7].string,yyvsp[-3].string,0);
 		;
     break;}
 case 19:
-#line 282 "yacc.y"
+#line 288 "yacc.y"
 {
 		    MakeTable(yyvsp[-7].string, yyvsp[-3].string, 0);
 		;
     break;}
 case 20:
-#line 286 "yacc.y"
+#line 292 "yacc.y"
 {
 		    __MrmWarn(LOC,"NO OP\n");
 		;
     break;}
 case 21:
-#line 290 "yacc.y"
+#line 296 "yacc.y"
 {
 		    __MrmWarn(LOC,"NO OP\n");
 		;
     break;}
 case 22:
-#line 294 "yacc.y"
+#line 300 "yacc.y"
 {
 		    MakeTable(yyvsp[-5].string, yyvsp[-2].string, 1);
 		;
     break;}
 case 24:
-#line 302 "yacc.y"
+#line 308 "yacc.y"
 {
 			yyval.string = NULL;
 	       	;
     break;}
 case 25:
-#line 308 "yacc.y"
+#line 314 "yacc.y"
 {
 		    yyval.string = AddFont(yyvsp[-4].string, yyvsp[-2].string, yyvsp[0].string);
 		;
     break;}
 case 26:
-#line 312 "yacc.y"
+#line 318 "yacc.y"
 {
 		    yyval.string = AddFont(yyvsp[-2].string, yyvsp[0].string, NULL);
 		;
     break;}
 case 27:
-#line 318 "yacc.y"
+#line 324 "yacc.y"
 {
 		    yyval.string = CharSetName(NULL, yyvsp[0].string);
 		;
     break;}
 case 28:
-#line 322 "yacc.y"
+#line 328 "yacc.y"
 {
 		    yyval.string = CharSetName(yyvsp[-1].string, yyvsp[-2].string);
 		;
     break;}
 case 29:
-#line 328 "yacc.y"
+#line 334 "yacc.y"
 {
 		    yyval.string = CharSetRToL(yyvsp[0].string, (int)(long)yyvsp[-1].string);
 		;
     break;}
 case 30:
-#line 332 "yacc.y"
+#line 338 "yacc.y"
 {
 		    yyval.string = CharSet16Bit(yyvsp[0].string, (int)(long)yyvsp[-1].string);
 		;
     break;}
 case 31:
-#line 336 "yacc.y"
+#line 342 "yacc.y"
 {
 		    yyval.string = MakeNewCharSet();
 		;
     break;}
 case 32:
-#line 342 "yacc.y"
+#line 348 "yacc.y"
 {
 		    yyval.string = AddColor(yyvsp[-4].string,yyvsp[-2].string, yyvsp[0].string, 1);
 		;
     break;}
 case 33:
-#line 346 "yacc.y"
+#line 352 "yacc.y"
 {
 		    yyval.string = AddColor(yyvsp[-2].string,yyvsp[0].string, NULL, 1);
 		;
     break;}
 case 34:
-#line 350 "yacc.y"
+#line 356 "yacc.y"
 {
 		    yyval.string = AddColor(__MrmStore("\"_bg\""),yyvsp[0].string, NULL, 0);
 		;
     break;}
 case 35:
-#line 354 "yacc.y"
+#line 360 "yacc.y"
 {
 		    yyval.string = AddColor(__MrmStore("\"_bg\""), yyvsp[-2].string, yyvsp[0].string, 0);
 		;
     break;}
 case 36:
-#line 358 "yacc.y"
+#line 364 "yacc.y"
 {
 		    yyval.string = AddColor(__MrmStore("\"_fg\""), yyvsp[0].string, NULL, 0);
 		;
     break;}
 case 37:
-#line 362 "yacc.y"
+#line 368 "yacc.y"
 {
 		    yyval.string = AddColor(__MrmStore("\"_fg\""), yyvsp[-2].string, yyvsp[0].string, 0);
 		;
     break;}
 case 38:
-#line 366 "yacc.y"
+#line 372 "yacc.y"
 {
 		    yyval.string = AddColor(yyvsp[-5].string, yyvsp[-2].string, yyvsp[0].string, 0);
 		;
     break;}
 case 39:
-#line 370 "yacc.y"
+#line 376 "yacc.y"
 {
 		    yyval.string = AddColor(yyvsp[-3].string, yyvsp[0].string, NULL, 0);
 		;
     break;}
 case 40:
-#line 376 "yacc.y"
+#line 382 "yacc.y"
 {
 		    yyval.string = InsertString(yyvsp[-2].string, yyvsp[0].string);
 		;
     break;}
 case 41:
-#line 380 "yacc.y"
+#line 386 "yacc.y"
 {
 		    yyval.string = InsertString(yyvsp[-2].string, yyvsp[0].string);
 		;
     break;}
 case 42:
-#line 384 "yacc.y"
+#line 390 "yacc.y"
 {
 		    yyval.string = InsertString(NULL,yyvsp[0].string);
 		;
     break;}
 case 43:
-#line 388 "yacc.y"
+#line 394 "yacc.y"
 {
 		    yyval.string = InsertString(NULL, yyvsp[0].string);
 		;
     break;}
 case 44:
-#line 394 "yacc.y"
+#line 400 "yacc.y"
 {
 		    __MrmWarn(LOC,"NO OP\n");
 		;
     break;}
 case 45:
-#line 398 "yacc.y"
+#line 404 "yacc.y"
 {
 		    __MrmWarn(LOC,"NO OP\n");
 		    yyval.string = yyvsp[-2].string;
 		;
     break;}
 case 46:
-#line 403 "yacc.y"
+#line 409 "yacc.y"
 {
 		    __MrmWarn(LOC,"NO OP\n");
 		    yyval.string = yyvsp[-4].string;
 		;
     break;}
 case 47:
-#line 408 "yacc.y"
+#line 414 "yacc.y"
 {
 		    __MrmWarn(LOC,"NO OP\n");
 		;
     break;}
 case 48:
-#line 412 "yacc.y"
+#line 418 "yacc.y"
 {
 		    __MrmWarn(LOC, "NO OP\n");
 		    yyval.string = yyvsp[-1].string;
 		;
     break;}
 case 49:
-#line 417 "yacc.y"
+#line 423 "yacc.y"
 {
 		    __MrmWarn(LOC,"NO OP\n");
 		    yyval.string = yyvsp[-3].string;
 		;
     break;}
 case 50:
-#line 424 "yacc.y"
+#line 430 "yacc.y"
 {
 		    __MrmWarn(LOC,"NO OP\n");
 		;
     break;}
 case 51:
-#line 428 "yacc.y"
-{
-		    __MrmWarn(LOC,"NO OP\n");
-		;
-    break;}
-case 52:
 #line 434 "yacc.y"
+{
+		    __MrmWarn(LOC,"NO OP\n");
+		;
+    break;}
+case 52:
+#line 440 "yacc.y"
 {
 		    __MrmWarn(LOC,"NO OP\n");
 		;
     break;}
 case 53:
-#line 438 "yacc.y"
+#line 444 "yacc.y"
 {
 		    __MrmWarn(LOC,"NO OP\n");
 		;
     break;}
 case 54:
-#line 442 "yacc.y"
+#line 448 "yacc.y"
 {
 		    __MrmWarn(LOC,"NO OP\n");
 		;
     break;}
 case 55:
-#line 446 "yacc.y"
+#line 452 "yacc.y"
 {
 		    __MrmWarn(LOC,"NO OP\n");
 		;
     break;}
 case 56:
-#line 450 "yacc.y"
+#line 456 "yacc.y"
 {
 		    __MrmWarn(LOC,"NO OP\n");
 		;
     break;}
 case 57:
-#line 454 "yacc.y"
+#line 460 "yacc.y"
 {
 		    __MrmWarn(LOC,"NO OP\n");
 		;
     break;}
 case 58:
-#line 458 "yacc.y"
+#line 464 "yacc.y"
 {
 		    __MrmWarn(LOC,"NO OP\n");
 		;
     break;}
 case 59:
-#line 462 "yacc.y"
+#line 468 "yacc.y"
 {
 		    __MrmWarn(LOC,"NO OP\n");
 		;
     break;}
 case 60:
-#line 468 "yacc.y"
+#line 474 "yacc.y"
 {
 		    AddAttributeList(yyvsp[-6].string, yyvsp[-2].string);
 		    yyval.string = NULL;
 		;
     break;}
 case 61:
-#line 473 "yacc.y"
+#line 479 "yacc.y"
 {
 		    AddControlList(yyvsp[-6].string, yyvsp[-2].string);
 		    yyval.string = NULL;
 		;
     break;}
 case 62:
-#line 478 "yacc.y"
+#line 484 "yacc.y"
 {
 		    AddCallbackList(yyvsp[-6].string, yyvsp[-2].string);
 		    yyval.string = NULL;
 		;
     break;}
 case 63:
-#line 483 "yacc.y"
+#line 489 "yacc.y"
 {
 		    yyval.string = NULL;
 		;
     break;}
 case 64:
-#line 489 "yacc.y"
+#line 495 "yacc.y"
 {
 		    yyval.string = (char *)arglist_arglist_ID_addexpr(yyvsp[-4].string, yyvsp[-3].string, yyvsp[-1].string);
 		;
     break;}
 case 65:
-#line 493 "yacc.y"
+#line 499 "yacc.y"
 {
 		    yyval.string = NULL;
 		;
     break;}
 case 66:
-#line 499 "yacc.y"
+#line 505 "yacc.y"
 {
 		    __MrmWarn(LOC,"NO OP\n");
 		;
     break;}
 case 67:
-#line 503 "yacc.y"
+#line 509 "yacc.y"
 {
 		    ID_ID_features(yyvsp[-6].string,yyvsp[-4].string,yyvsp[-2].string);
 		    yyval.string = yyvsp[-2].string;
 		;
     break;}
 case 68:
-#line 508 "yacc.y"
+#line 514 "yacc.y"
 {
 		    __MrmWarn(LOC,"NO OP\n");
 		;
     break;}
 case 69:
-#line 512 "yacc.y"
+#line 518 "yacc.y"
 {
 		    __MrmWarn(LOC,"NO OP\n");
 		    ID_ID_features(yyvsp[-7].string, yyvsp[-4].string, yyvsp[-2].string);
@@ -1454,334 +1511,334 @@ case 69:
 		;
     break;}
 case 70:
-#line 518 "yacc.y"
+#line 524 "yacc.y"
 {
 		    __MrmWarn(LOC,"NO OP\n");
 		;
     break;}
 case 71:
-#line 522 "yacc.y"
+#line 528 "yacc.y"
 {
 		    /* __MrmWarn(LOC,"Empty object\n"); */
 		;
     break;}
 case 72:
-#line 528 "yacc.y"
+#line 534 "yacc.y"
 {
 		    features_controls(yyvsp[-1].string,yyvsp[0].string);
 		    yyval.string = yyvsp[-1].string;
 		;
     break;}
 case 73:
-#line 533 "yacc.y"
+#line 539 "yacc.y"
 {
 		    features_arguments(yyvsp[-1].string,yyvsp[0].string);
 		    yyval.string = yyvsp[-1].string;
 		;
     break;}
 case 74:
-#line 538 "yacc.y"
+#line 544 "yacc.y"
 {
 		    features_callbacks(yyvsp[-1].string,yyvsp[0].string);
 		    yyval.string = yyvsp[-1].string;
 		;
     break;}
 case 75:
-#line 543 "yacc.y"
+#line 549 "yacc.y"
 {
 		    yyval.string = (char *)Features_NULL();
 		;
     break;}
 case 76:
-#line 549 "yacc.y"
+#line 555 "yacc.y"
 {
 		    yyval.string = yyvsp[-2].string;
 		;
     break;}
 case 77:
-#line 553 "yacc.y"
+#line 559 "yacc.y"
 {
 		    __MrmWarn(LOC,"NO OP\n");
 		    yyval.string = NULL;
 		;
     break;}
 case 78:
-#line 560 "yacc.y"
+#line 566 "yacc.y"
 {
 		    yyval.string = (char *)controllist_controllist_ID_ID(yyvsp[-3].string,yyvsp[-2].string,yyvsp[-1].string,1);
 		;
     break;}
 case 79:
-#line 564 "yacc.y"
+#line 570 "yacc.y"
 {
 		    yyval.string = (char *)control_list_ID_features(yyvsp[-5].string, yyvsp[-4].string, yyvsp[-2].string, 1);
 		;
     break;}
 case 80:
-#line 568 "yacc.y"
+#line 574 "yacc.y"
 {   /* $2 may be wrong for this type of call */
 		    /* I confused this rule for the next one */
 		    yyval.string = (char *)control_list_ID_features(yyvsp[-6].string, yyvsp[-5].string, yyvsp[-2].string, 0);
 		;
     break;}
 case 81:
-#line 573 "yacc.y"
+#line 579 "yacc.y"
 {
 		    yyval.string = (char *)control_list_ID_features(yyvsp[-6].string,yyvsp[-4].string, yyvsp[-2].string, 0);
 		;
     break;}
 case 82:
-#line 577 "yacc.y"
+#line 583 "yacc.y"
 {
 		    __MrmWarn(LOC,"NO OP\n");
 		;
     break;}
 case 83:
-#line 581 "yacc.y"
+#line 587 "yacc.y"
 {
 		    yyval.string = (char *)controllist_controllist_ID_ID(yyvsp[-4].string,yyvsp[-2].string,yyvsp[-1].string,0);
 		;
     break;}
 case 84:
-#line 585 "yacc.y"
+#line 591 "yacc.y"
 {
 		    yyval.string = InheritControls(yyvsp[-3].string, yyvsp[-1].string);
 		;
     break;}
 case 85:
-#line 589 "yacc.y"
+#line 595 "yacc.y"
 {
 		    __MrmWarn(LOC,"NO OP\n");
 		;
     break;}
 case 86:
-#line 593 "yacc.y"
+#line 599 "yacc.y"
 {
 			yyval.string = NULL;
 		;
     break;}
 case 87:
-#line 599 "yacc.y"
+#line 605 "yacc.y"
 {
 		    yyval.string = yyvsp[-2].string;
 		;
     break;}
 case 88:
-#line 605 "yacc.y"
+#line 611 "yacc.y"
 {
 		    yyval.string = arglist_arglist_ID_addexpr(yyvsp[-4].string,yyvsp[-3].string,yyvsp[-1].string);
 		;
     break;}
 case 89:
-#line 609 "yacc.y"
+#line 615 "yacc.y"
 {
 		    yyval.string = WidgetArgument(yyvsp[-5].string, yyvsp[-4].string, yyvsp[-1].string);
 	     	;
     break;}
 case 90:
-#line 613 "yacc.y"
+#line 619 "yacc.y"
 {
 		    yyval.string = InheritArgument(yyvsp[-3].string, yyvsp[-1].string);
 		;
     break;}
 case 91:
-#line 617 "yacc.y"
+#line 623 "yacc.y"
 {
 		    yyval.string = NULL;
 		;
     break;}
 case 92:
-#line 623 "yacc.y"
+#line 629 "yacc.y"
 {
 		    yyval.string = yyvsp[0].string;
 		;
     break;}
 case 93:
-#line 627 "yacc.y"
+#line 633 "yacc.y"
 {
 		    yyval.string = Subtract(yyvsp[-2].string,yyvsp[0].string);
 		;
     break;}
 case 94:
-#line 631 "yacc.y"
+#line 637 "yacc.y"
 {
 		    yyval.string = Add(yyvsp[-2].string,yyvsp[0].string);
 		;
     break;}
 case 95:
-#line 635 "yacc.y"
+#line 641 "yacc.y"
 {
 		    yyval.string = AppendStrings(yyvsp[-2].string, yyvsp[0].string);
 		;
     break;}
 case 96:
-#line 641 "yacc.y"
+#line 647 "yacc.y"
 {
 		    yyval.string = yyvsp[0].string;
 		;
     break;}
 case 97:
-#line 645 "yacc.y"
+#line 651 "yacc.y"
 {
 		    yyval.string = Multiply(yyvsp[-2].string,yyvsp[0].string);
 		;
     break;}
 case 98:
-#line 649 "yacc.y"
+#line 655 "yacc.y"
 {
 		    yyval.string = Divide(yyvsp[-2].string,yyvsp[0].string);
 		;
     break;}
 case 99:
-#line 655 "yacc.y"
+#line 661 "yacc.y"
 {
 		    yyval.string = (char *) expr_ID(yyvsp[0].string);
 		;
     break;}
 case 100:
-#line 659 "yacc.y"
+#line 665 "yacc.y"
 {
 		    __MrmWarn(LOC, "Font Unit not implemented yet\n");
 		    yyval.string = (char *) prim_exp(yyvsp[-1].string);
 		;
     break;}
 case 101:
-#line 664 "yacc.y"
+#line 670 "yacc.y"
 {
 		    yyval.string = (char *)prim_exp(yyvsp[0].string);
 		;
     break;}
 case 102:
-#line 668 "yacc.y"
+#line 674 "yacc.y"
 {
 		    fprintf(stderr,"BLAB BLAB ID = %s\n", yyvsp[0].string);
 		    yyval.string = (char *) expr_STRING(yyvsp[0].string, yyvsp[-1].string,/*Compound?*/ False);
 		;
     break;}
 case 103:
-#line 673 "yacc.y"
+#line 679 "yacc.y"
 {
 		    yyval.string = (char *) expr_STRING(yyvsp[0].string, NULL, /*Compound?*/ False);
 		;
     break;}
 case 104:
-#line 677 "yacc.y"
+#line 683 "yacc.y"
 {
 		    yyval.string = (char *) expr_BOOL(yyvsp[0].string);
 		;
     break;}
 case 105:
-#line 681 "yacc.y"
+#line 687 "yacc.y"
 {
 		    yyval.string = (char *) keysym(yyvsp[-1].string);
 		;
     break;}
 case 106:
-#line 685 "yacc.y"
+#line 691 "yacc.y"
 {
 		    yyval.string = (char *) font(yyvsp[-1].string);
 		;
     break;}
 case 107:
-#line 689 "yacc.y"
+#line 695 "yacc.y"
 {
 		    yyval.string = (char *) keysym(yyvsp[-1].string);
 		;
     break;}
 case 108:
-#line 693 "yacc.y"
+#line 699 "yacc.y"
 {
 		    __MrmWarn(LOC,"NO OP\n");
 		    yyval.string = NULL;
 		;
     break;}
 case 109:
-#line 698 "yacc.y"
+#line 704 "yacc.y"
 {	
 		    yyval.string = (char *) bitmap(yyvsp[-1].string);
 		;
     break;}
 case 110:
-#line 702 "yacc.y"
+#line 708 "yacc.y"
 {
 		    yyval.string = (char *) pixmap(yyvsp[-3].string, yyvsp[-1].string);
 		;
     break;}
 case 111:
-#line 706 "yacc.y"
+#line 712 "yacc.y"
 {
 		    yyval.string = pixmap(NULL,yyvsp[-1].string);
 		;
     break;}
 case 112:
-#line 710 "yacc.y"
+#line 716 "yacc.y"
 {
 		    yyval.string = color(NULL, yyvsp[-5].string, yyvsp[-3].string, yyvsp[-1].string);
 		;
     break;}
 case 113:
-#line 714 "yacc.y"
+#line 720 "yacc.y"
 {
 		    yyval.string = color(yyvsp[-1].string, 0, 0, 0);
 		;
     break;}
 case 114:
-#line 718 "yacc.y"
+#line 724 "yacc.y"
 {
 		    yyval.string = color(yyvsp[-3].string, 0, 0, 0); /* For Now  FIX ME */
 		;
     break;}
 case 115:
-#line 722 "yacc.y"
+#line 728 "yacc.y"
 {
 		    yyval.string = yyvsp[0].string;
 		;
     break;}
 case 116:
-#line 726 "yacc.y"
+#line 732 "yacc.y"
 {	
 		    yyval.string = yyvsp[-1].string;
 		;
     break;}
 case 117:
-#line 732 "yacc.y"
+#line 738 "yacc.y"
 {
 		    /* string, separate, IsAddress */
 		    yyval.string = (char *) expr_STRING_Compound(yyvsp[-5].string,(int)(long)yyvsp[-1].string,False);
 		;
     break;}
 case 118:
-#line 737 "yacc.y"
+#line 743 "yacc.y"
 {
 		    yyval.string = (char *) expr_STRING_Compound(yyvsp[-5].string,(int)(long)yyvsp[-1].string,True);
 		;
     break;}
 case 119:
-#line 741 "yacc.y"
+#line 747 "yacc.y"
 {
 		    yyval.string = (char *) expr_STRING_Compound(yyvsp[-1].string, False, True);
 		;
     break;}
 case 120:
-#line 745 "yacc.y"
+#line 751 "yacc.y"
 {
 		    yyval.string = (char *) expr_STRING_Compound(yyvsp[-1].string, False, False);
 		;
     break;}
 case 121:
-#line 751 "yacc.y"
+#line 757 "yacc.y"
 {
 		    yyval.string = yyvsp[-2].string;
 		;
     break;}
 case 122:
-#line 755 "yacc.y"
+#line 761 "yacc.y"
 {
 		    yyval.string = InheritCallback(yyvsp[-1].string);
 		;
     break;}
 case 123:
-#line 761 "yacc.y"
+#line 767 "yacc.y"
 {
 		    yyval.string = (char *)callbacklist_callbacklist_PROCID_arglist(yyvsp[-8].string,
 									  yyvsp[-7].string,
@@ -1790,79 +1847,79 @@ case 123:
 		;
     break;}
 case 124:
-#line 768 "yacc.y"
+#line 774 "yacc.y"
 {
 		    __MrmWarn(LOC,"NO OP************\n");
 		;
     break;}
 case 125:
-#line 772 "yacc.y"
+#line 778 "yacc.y"
 {
 		    yyval.string = NULL;
 		;
     break;}
 case 126:
-#line 778 "yacc.y"
+#line 784 "yacc.y"
 {
 		    __MrmWarn(LOC, "NO OP\n");
 		;
     break;}
 case 127:
-#line 782 "yacc.y"
+#line 788 "yacc.y"
 {
 		;
     break;}
 case 128:
-#line 787 "yacc.y"
+#line 793 "yacc.y"
 {
 		    yyval.string = Parameter(yyvsp[-2].string, prim_exp(yyvsp[0].string));
 		;
     break;}
 case 129:
-#line 791 "yacc.y"
+#line 797 "yacc.y"
 {
 		    yyval.string = Parameter(yyvsp[-2].string, expr_ID(yyvsp[0].string));
 		;
     break;}
 case 130:
-#line 795 "yacc.y"
+#line 801 "yacc.y"
 {
 		    yyval.string = Parameter(yyvsp[-2].string, expr_STRING(yyvsp[0].string, NULL, 0));
 		;
     break;}
 case 131:
-#line 799 "yacc.y"
+#line 805 "yacc.y"
 {
 		    yyval.string = Parameter(NULL, prim_exp(yyvsp[0].string));
 		;
     break;}
 case 132:
-#line 803 "yacc.y"
+#line 809 "yacc.y"
 {
 		    yyval.string = Parameter(NULL, expr_ID(yyvsp[0].string));
 		;
     break;}
 case 133:
-#line 807 "yacc.y"
+#line 813 "yacc.y"
 {
 		    yyval.string = Parameter(NULL, expr_STRING(yyvsp[0].string, NULL, 0));
 		;
     break;}
 case 134:
-#line 811 "yacc.y"
+#line 817 "yacc.y"
 {
 		    yyval.string = Parameter(NULL, expr_STRING(yyvsp[0].string, NULL, 1));
 		;
     break;}
 case 135:
-#line 815 "yacc.y"
+#line 821 "yacc.y"
 {
 		    yyval.string = Parameter(NULL, NULL);
 		;
     break;}
 }
    /* the action file gets copied in in place of this dollarsign */
-#line 498 "/usr/share/bison.simple"
+#line 554 "/usr/share/bison.simple"
 
   yyvsp -= yylen;
   yyssp -= yylen;
@@ -2057,13 +2114,41 @@ yyerrhandle:
 
   yystate = yyn;
   goto yynewstate;
+
+ yyacceptlab:
+  /* YYACCEPT comes here.  */
+#ifndef YYSTACK_USE_ALLOCA
+  if (yyfree_stacks)
+    {
+      free (yyss);
+      free (yyvs);
+#ifdef YYLSP_NEEDED
+      free (yyls);
+#endif
+    }
+#endif
+  return 0;
+
+ yyabortlab:
+  /* YYABORT comes here.  */
+#ifndef YYSTACK_USE_ALLOCA
+  if (yyfree_stacks)
+    {
+      free (yyss);
+      free (yyvs);
+#ifdef YYLSP_NEEDED
+      free (yyls);
+#endif
+    }
+#endif    
+  return 1;
 }
-#line 821 "yacc.y"
+#line 827 "yacc.y"
 
 
 
 void
-yyerror(const char *s)
+yyerror(char *s)
 {
     fprintf(stderr,"%s:%d: %s\n", FileName, LineNumber, s);
     fprintf(stderr," current token \'%s\'\n", yytext);
@@ -2071,7 +2156,7 @@ yyerror(const char *s)
 
 
 void
-yyExit(int line, char *file, const char *fmt, ...)
+yyExit(int line, char *file, char *fmt, ...)
 {
     va_list ap;
 
