@@ -99,7 +99,7 @@
 
 /**
  *
- * $Id: mwmparse.y,v 1.31 2001/08/02 19:45:28 amai Exp $
+ * $Id: mwmparse.y,v 1.34 2001/10/29 08:59:26 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
  * Copyright (C) 1995-2001 LessTif Development Team
@@ -128,24 +128,39 @@
 #include <stdarg.h>
 #include <stdio.h>
 #include <string.h>
+#include <limits.h>
 #ifdef HAVE_FCNTL_H
 #include <fcntl.h>
 #endif
+
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
+
 #ifdef HAVE_SYS_TYPES_H
 #include <sys/types.h>
 #endif
+
 #ifdef HAVE_PWD_H
 #include <pwd.h>
 #endif
+
 #ifdef HAVE_SYS_STAT_H
 #include <sys/stat.h>
 #endif
+
+#ifdef PATH_MAX
+# define MAX_PATH_LEN PATH_MAX
+#else
+# define MAX_PATH_LEN	2048 /* this is OS dependent, but this should catch most */
+#endif
+
+
 #include <X11/Xfuncs.h>
+
 #ifdef __EMX__
 #include <X11/Xlibint.h>    /* for __XOS2RedirRoot() */
+#define MWM_DDIR (char*)__XOS2RedirRoot("/XFree86/lib/X11/mwm")
 #endif
 
 #include <Xm/Xm.h>
@@ -154,11 +169,6 @@
 #include "mwm.h"
 
 
-/*
- * this is OS dependent, but this should catch most
- */
-#define MAX_PATH_LEN	2048
-
 extern int yydebug;
 extern int yylex(void);
 
@@ -170,7 +180,6 @@ static Boolean button_bind_match;
 static Boolean button_bind_found;
 static Boolean key_bind_match;
 static Boolean key_bind_found;
-extern int	verbose;
 
 /*
  * this must be here for the parser
@@ -178,7 +187,7 @@ extern int	verbose;
 static int lineno;
 
 
-#line 238 "mwmparse.y"
+#line 247 "mwmparse.y"
 typedef union {
     char	*string;
     int		number;
@@ -313,20 +322,20 @@ static const short yyrhs[] = {   102,
 
 #if YYDEBUG != 0
 static const short yyrline[] = { 0,
-   264,   265,   268,   269,   270,   273,   292,   295,   296,   302,
-   305,   411,   430,   433,   434,   440,   443,   495,   500,   506,
-   507,   513,   516,   618,   620,   624,   626,   630,   632,   634,
-   636,   638,   640,   642,   644,   646,   648,   650,   654,   659,
-   666,   671,   678,   680,   684,   686,   688,   690,   692,   694,
-   696,   698,   700,   704,   710,   716,   722,   728,   734,   740,
-   746,   752,   758,   764,   770,   776,   782,   788,   794,   800,
-   806,   812,   818,   824,   833,   835,   837,   845,   849,   859,
-   863,   868,   873,   878,   883,   888,   893,   898,   903,   908,
-   913,   918,   923,   928,   933,   938,   943,   948,   953,   958,
-   963,   968,   973,   978,   983,   988,   993,   998,  1003,  1008,
-  1013,  1018,  1023,  1028,  1033,  1038,  1043,  1048,  1053,  1061,
-  1063,  1067,  1069,  1071,  1073,  1075,  1077,  1079,  1081,  1083,
-  1085,  1088
+   273,   274,   277,   278,   279,   282,   301,   304,   305,   311,
+   314,   420,   439,   442,   443,   449,   452,   504,   509,   515,
+   516,   522,   525,   627,   629,   633,   635,   639,   641,   643,
+   645,   647,   649,   651,   653,   655,   657,   659,   663,   668,
+   675,   680,   687,   689,   693,   695,   697,   699,   701,   703,
+   705,   707,   709,   713,   719,   725,   731,   737,   743,   749,
+   755,   761,   767,   773,   779,   785,   791,   797,   803,   809,
+   815,   821,   827,   833,   842,   844,   846,   854,   858,   868,
+   872,   877,   882,   887,   892,   897,   902,   907,   912,   917,
+   922,   927,   932,   937,   942,   947,   952,   957,   962,   967,
+   972,   977,   982,   987,   992,   997,  1002,  1007,  1012,  1017,
+  1022,  1027,  1032,  1037,  1042,  1047,  1052,  1057,  1062,  1070,
+  1072,  1076,  1078,  1080,  1082,  1084,  1086,  1088,  1090,  1092,
+  1094,  1097
 };
 #endif
 
@@ -1089,7 +1098,7 @@ yyreduce:
   switch (yyn) {
 
 case 6:
-#line 274 "mwmparse.y"
+#line 283 "mwmparse.y"
 {
 			    if (!skip_test) {
 				if (button_bind_found == False) {
@@ -1110,7 +1119,7 @@ case 6:
 			;
     break;}
 case 9:
-#line 297 "mwmparse.y"
+#line 306 "mwmparse.y"
 {
 			    yyerror("Invalid button binding");
 			    yyerrok;
@@ -1118,7 +1127,7 @@ case 9:
 			;
     break;}
 case 11:
-#line 306 "mwmparse.y"
+#line 315 "mwmparse.y"
 {
 			    int contexts = yyvsp[-1].number;
 			    int mods, func;
@@ -1224,7 +1233,7 @@ case 11:
 			;
     break;}
 case 12:
-#line 412 "mwmparse.y"
+#line 421 "mwmparse.y"
 {
 			    if (!skip_test) {
 				if (key_bind_found == False) {
@@ -1245,7 +1254,7 @@ case 12:
 			;
     break;}
 case 15:
-#line 435 "mwmparse.y"
+#line 444 "mwmparse.y"
 {
 			    yyerror("Invalid key binding");
 			    yyerrok;
@@ -1253,7 +1262,7 @@ case 15:
 			;
     break;}
 case 17:
-#line 444 "mwmparse.y"
+#line 453 "mwmparse.y"
 {
 			    FuncKey        *tmp = NULL;
 			    KeySym          keysym;
@@ -1305,20 +1314,20 @@ case 17:
 			;
     break;}
 case 18:
-#line 496 "mwmparse.y"
+#line 505 "mwmparse.y"
 {
 			    num_items = 0;
 			    cur_menu = MENU_Create(yyvsp[0].string);
 			;
     break;}
 case 19:
-#line 501 "mwmparse.y"
+#line 510 "mwmparse.y"
 {
 			    MENU_Add(pscr, cur_menu);
 			;
     break;}
 case 21:
-#line 508 "mwmparse.y"
+#line 517 "mwmparse.y"
 {
 			    yyerror("Invalid menu item");
 			    yyerrok;
@@ -1326,7 +1335,7 @@ case 21:
 			;
     break;}
 case 23:
-#line 517 "mwmparse.y"
+#line 526 "mwmparse.y"
 {
 			    MenuItem *tmp;
 			    int width, width2;
@@ -1428,139 +1437,139 @@ case 23:
 			;
     break;}
 case 24:
-#line 619 "mwmparse.y"
+#line 628 "mwmparse.y"
 { yyval.hotkey = yyvsp[0].hotkey; ;
     break;}
 case 25:
-#line 621 "mwmparse.y"
+#line 630 "mwmparse.y"
 { yyval.hotkey.modifiers = 0; yyval.hotkey.key = 0; ;
     break;}
 case 26:
-#line 625 "mwmparse.y"
+#line 634 "mwmparse.y"
 { yyval.number = yyvsp[-2].number | yyvsp[0].number; ;
     break;}
 case 27:
-#line 627 "mwmparse.y"
+#line 636 "mwmparse.y"
 { yyval.number = yyvsp[0].number; ;
     break;}
 case 28:
-#line 631 "mwmparse.y"
+#line 640 "mwmparse.y"
 { yyval.number = C_ROOT; ;
     break;}
 case 29:
-#line 633 "mwmparse.y"
+#line 642 "mwmparse.y"
 { yyval.number = C_ICON; ;
     break;}
 case 30:
-#line 635 "mwmparse.y"
+#line 644 "mwmparse.y"
 { yyval.number = C_MENUB; ;
     break;}
 case 31:
-#line 637 "mwmparse.y"
+#line 646 "mwmparse.y"
 { yyval.number = C_MINIMIZEB; ;
     break;}
 case 32:
-#line 639 "mwmparse.y"
+#line 648 "mwmparse.y"
 { yyval.number = C_MAXIMIZEB; ;
     break;}
 case 33:
-#line 641 "mwmparse.y"
+#line 650 "mwmparse.y"
 { yyval.number = C_WINDOW|C_FRAME|C_TITLE|C_LALL|C_RALL|C_ICON; ;
     break;}
 case 34:
-#line 643 "mwmparse.y"
+#line 652 "mwmparse.y"
 { yyval.number = C_TITLE; ;
     break;}
 case 35:
-#line 645 "mwmparse.y"
+#line 654 "mwmparse.y"
 { yyval.number = C_FRAME|C_TITLE|C_LALL|C_RALL; ;
     break;}
 case 36:
-#line 647 "mwmparse.y"
+#line 656 "mwmparse.y"
 { yyval.number = C_FRAME; ;
     break;}
 case 37:
-#line 649 "mwmparse.y"
+#line 658 "mwmparse.y"
 { yyval.number = C_WINDOW; ;
     break;}
 case 38:
-#line 651 "mwmparse.y"
+#line 660 "mwmparse.y"
 { yyerror("Invalid context"); yyval.number = 0; ;
     break;}
 case 39:
-#line 655 "mwmparse.y"
+#line 664 "mwmparse.y"
 {
 			    yyval.button = yyvsp[-1].button;
 			    yyval.button.modifiers = yyvsp[-3].modifiers;
 			;
     break;}
 case 40:
-#line 660 "mwmparse.y"
+#line 669 "mwmparse.y"
 {
 			    yyval.button = yyvsp[-1].button;
 			    yyval.button.modifiers = 0;
 			;
     break;}
 case 41:
-#line 667 "mwmparse.y"
+#line 676 "mwmparse.y"
 {
 			    yyval.hotkey.modifiers = yyvsp[-4].modifiers;
 			    yyval.hotkey.key = XStringToKeysym(yyvsp[0].string);
 			;
     break;}
 case 42:
-#line 672 "mwmparse.y"
+#line 681 "mwmparse.y"
 {
 			    yyval.hotkey.modifiers = 0;
 			    yyval.hotkey.key = XStringToKeysym(yyvsp[0].string);
 			;
     break;}
 case 43:
-#line 679 "mwmparse.y"
+#line 688 "mwmparse.y"
 { yyval.modifiers = yyvsp[-1].modifiers | yyvsp[0].modifiers; ;
     break;}
 case 44:
-#line 681 "mwmparse.y"
+#line 690 "mwmparse.y"
 { yyval.modifiers = yyvsp[0].modifiers; ;
     break;}
 case 45:
-#line 685 "mwmparse.y"
+#line 694 "mwmparse.y"
 { yyval.modifiers = ControlMask; ;
     break;}
 case 46:
-#line 687 "mwmparse.y"
+#line 696 "mwmparse.y"
 { yyval.modifiers = ShiftMask; ;
     break;}
 case 47:
-#line 689 "mwmparse.y"
+#line 698 "mwmparse.y"
 { yyval.modifiers = pscr->alt_mask; ;
     break;}
 case 48:
-#line 691 "mwmparse.y"
+#line 700 "mwmparse.y"
 { yyval.modifiers = LockMask; ;
     break;}
 case 49:
-#line 693 "mwmparse.y"
+#line 702 "mwmparse.y"
 { yyval.modifiers = Mod1Mask; ;
     break;}
 case 50:
-#line 695 "mwmparse.y"
+#line 704 "mwmparse.y"
 { yyval.modifiers = Mod2Mask; ;
     break;}
 case 51:
-#line 697 "mwmparse.y"
+#line 706 "mwmparse.y"
 { yyval.modifiers = Mod3Mask; ;
     break;}
 case 52:
-#line 699 "mwmparse.y"
+#line 708 "mwmparse.y"
 { yyval.modifiers = Mod4Mask; ;
     break;}
 case 53:
-#line 701 "mwmparse.y"
+#line 710 "mwmparse.y"
 { yyval.modifiers = Mod5Mask; ;
     break;}
 case 54:
-#line 705 "mwmparse.y"
+#line 714 "mwmparse.y"
 {
 			    yyval.button.button = Button1Mask;
 			    yyval.button.event = ButtonPressMask;
@@ -1568,7 +1577,7 @@ case 54:
 			;
     break;}
 case 55:
-#line 711 "mwmparse.y"
+#line 720 "mwmparse.y"
 {
 			    yyval.button.button = Button1Mask;
 			    yyval.button.event = ButtonReleaseMask;
@@ -1576,7 +1585,7 @@ case 55:
 			;
     break;}
 case 56:
-#line 717 "mwmparse.y"
+#line 726 "mwmparse.y"
 {
 			    yyval.button.button = Button1Mask;
 			    yyval.button.event = ButtonPressMask|ButtonReleaseMask;
@@ -1584,7 +1593,7 @@ case 56:
 			;
     break;}
 case 57:
-#line 723 "mwmparse.y"
+#line 732 "mwmparse.y"
 {
 			    yyval.button.button = Button1Mask;
 			    yyval.button.event = ButtonPressMask|ButtonReleaseMask;
@@ -1592,7 +1601,7 @@ case 57:
 			;
     break;}
 case 58:
-#line 729 "mwmparse.y"
+#line 738 "mwmparse.y"
 {
 			    yyval.button.button = Button2Mask;
 			    yyval.button.event = ButtonPressMask;
@@ -1600,7 +1609,7 @@ case 58:
 			;
     break;}
 case 59:
-#line 735 "mwmparse.y"
+#line 744 "mwmparse.y"
 {
 			    yyval.button.button = Button2Mask;
 			    yyval.button.event = ButtonReleaseMask;
@@ -1608,7 +1617,7 @@ case 59:
 			;
     break;}
 case 60:
-#line 741 "mwmparse.y"
+#line 750 "mwmparse.y"
 {
 			    yyval.button.button = Button2Mask;
 			    yyval.button.event = ButtonPressMask|ButtonReleaseMask;
@@ -1616,7 +1625,7 @@ case 60:
 			;
     break;}
 case 61:
-#line 747 "mwmparse.y"
+#line 756 "mwmparse.y"
 {
 			    yyval.button.button = Button2Mask;
 			    yyval.button.event = ButtonPressMask|ButtonReleaseMask;
@@ -1624,7 +1633,7 @@ case 61:
 			;
     break;}
 case 62:
-#line 753 "mwmparse.y"
+#line 762 "mwmparse.y"
 {
 			    yyval.button.button = Button3Mask;
 			    yyval.button.event = ButtonPressMask;
@@ -1632,7 +1641,7 @@ case 62:
 			;
     break;}
 case 63:
-#line 759 "mwmparse.y"
+#line 768 "mwmparse.y"
 {
 			    yyval.button.button = Button3Mask;
 			    yyval.button.event = ButtonReleaseMask;
@@ -1640,7 +1649,7 @@ case 63:
 			;
     break;}
 case 64:
-#line 765 "mwmparse.y"
+#line 774 "mwmparse.y"
 {
 			    yyval.button.button = Button3Mask;
 			    yyval.button.event = ButtonPressMask|ButtonReleaseMask;
@@ -1648,7 +1657,7 @@ case 64:
 			;
     break;}
 case 65:
-#line 771 "mwmparse.y"
+#line 780 "mwmparse.y"
 {
 			    yyval.button.button = Button3Mask;
 			    yyval.button.event = ButtonPressMask|ButtonReleaseMask;
@@ -1656,7 +1665,7 @@ case 65:
 			;
     break;}
 case 66:
-#line 777 "mwmparse.y"
+#line 786 "mwmparse.y"
 {
 			    yyval.button.button = Button4Mask;
 			    yyval.button.event = ButtonPressMask;
@@ -1664,7 +1673,7 @@ case 66:
 			;
     break;}
 case 67:
-#line 783 "mwmparse.y"
+#line 792 "mwmparse.y"
 {
 			    yyval.button.button = Button4Mask;
 			    yyval.button.event = ButtonReleaseMask;
@@ -1672,7 +1681,7 @@ case 67:
 			;
     break;}
 case 68:
-#line 789 "mwmparse.y"
+#line 798 "mwmparse.y"
 {
 			    yyval.button.button = Button4Mask;
 			    yyval.button.event = ButtonPressMask|ButtonReleaseMask;
@@ -1680,7 +1689,7 @@ case 68:
 			;
     break;}
 case 69:
-#line 795 "mwmparse.y"
+#line 804 "mwmparse.y"
 {
 			    yyval.button.button = Button4Mask;
 			    yyval.button.event = ButtonPressMask|ButtonReleaseMask;
@@ -1688,7 +1697,7 @@ case 69:
 			;
     break;}
 case 70:
-#line 801 "mwmparse.y"
+#line 810 "mwmparse.y"
 {
 			    yyval.button.button = Button5Mask;
 			    yyval.button.event = ButtonPressMask;
@@ -1696,7 +1705,7 @@ case 70:
 			;
     break;}
 case 71:
-#line 807 "mwmparse.y"
+#line 816 "mwmparse.y"
 {
 			    yyval.button.button = Button5Mask;
 			    yyval.button.event = ButtonReleaseMask;
@@ -1704,7 +1713,7 @@ case 71:
 			;
     break;}
 case 72:
-#line 813 "mwmparse.y"
+#line 822 "mwmparse.y"
 {
 			    yyval.button.button = Button5Mask;
 			    yyval.button.event = ButtonPressMask|ButtonReleaseMask;
@@ -1712,7 +1721,7 @@ case 72:
 			;
     break;}
 case 73:
-#line 819 "mwmparse.y"
+#line 828 "mwmparse.y"
 {
 			    yyval.button.button = Button5Mask;
 			    yyval.button.event = ButtonPressMask|ButtonReleaseMask;
@@ -1720,7 +1729,7 @@ case 73:
 			;
     break;}
 case 74:
-#line 825 "mwmparse.y"
+#line 834 "mwmparse.y"
 {
 			    yyerror("Invalid button event name");
 			    yyval.button.button = 0;
@@ -1729,15 +1738,15 @@ case 74:
 			;
     break;}
 case 75:
-#line 834 "mwmparse.y"
+#line 843 "mwmparse.y"
 { yyval.label.type = IS_STRING; yyval.label.string = yyvsp[0].string; ;
     break;}
 case 76:
-#line 836 "mwmparse.y"
+#line 845 "mwmparse.y"
 { yyval.label.type = IS_BITMAP; yyval.label.string = yyvsp[0].string; ;
     break;}
 case 77:
-#line 838 "mwmparse.y"
+#line 847 "mwmparse.y"
 {
 			    yyerror("Invalid label");
 			    yyval.label.type = IS_STRING;
@@ -1745,11 +1754,11 @@ case 77:
 			;
     break;}
 case 78:
-#line 846 "mwmparse.y"
+#line 855 "mwmparse.y"
 { yyval.string = yyvsp[0].string; ;
     break;}
 case 79:
-#line 850 "mwmparse.y"
+#line 859 "mwmparse.y"
 {
 			    if (strlen(yyvsp[0].string) != 1) {
 				yyerror("Invalid mnemonic specification");
@@ -1761,277 +1770,277 @@ case 79:
 			;
     break;}
 case 80:
-#line 860 "mwmparse.y"
+#line 869 "mwmparse.y"
 { yyval.key = 0; ;
     break;}
 case 81:
-#line 864 "mwmparse.y"
+#line 873 "mwmparse.y"
 {
 			    yyval.function.func = F_BEEP;
 			    yyval.function.arg = "";
 			;
     break;}
 case 82:
-#line 869 "mwmparse.y"
+#line 878 "mwmparse.y"
 {
 			    yyval.function.func = F_CIRCULATE_DOWN;
 			    yyval.function.arg = yyvsp[0].string;
 			;
     break;}
 case 83:
-#line 874 "mwmparse.y"
+#line 883 "mwmparse.y"
 {
 			    yyval.function.func = F_CIRCULATE_UP;
 			    yyval.function.arg = yyvsp[0].string;
 			;
     break;}
 case 84:
-#line 879 "mwmparse.y"
+#line 888 "mwmparse.y"
 {
 			    yyval.function.func = F_EXEC;
 			    yyval.function.arg = yyvsp[0].string;
 			;
     break;}
 case 85:
-#line 884 "mwmparse.y"
+#line 893 "mwmparse.y"
 {
 			    yyval.function.func = F_EXEC;
 			    yyval.function.arg = yyvsp[0].string;
 			;
     break;}
 case 86:
-#line 889 "mwmparse.y"
+#line 898 "mwmparse.y"
 {
 			    yyval.function.func = F_FOCUS_COLOR;
 			    yyval.function.arg = "";
 			;
     break;}
 case 87:
-#line 894 "mwmparse.y"
+#line 903 "mwmparse.y"
 {
 			    yyval.function.func = F_FOCUS_KEY;
 			    yyval.function.arg = "";
 			;
     break;}
 case 88:
-#line 899 "mwmparse.y"
+#line 908 "mwmparse.y"
 {
 			    yyval.function.func = F_CLOSE;
 			    yyval.function.arg = "";
 			;
     break;}
 case 89:
-#line 904 "mwmparse.y"
+#line 913 "mwmparse.y"
 {
 			    yyval.function.func = F_LOWER;
 			    yyval.function.arg = yyvsp[0].string;
 			;
     break;}
 case 90:
-#line 909 "mwmparse.y"
+#line 918 "mwmparse.y"
 {
 			    yyval.function.func = F_MAXIMIZE;
 			    yyval.function.arg = "";
 			;
     break;}
 case 91:
-#line 914 "mwmparse.y"
+#line 923 "mwmparse.y"
 {
 			    yyval.function.func = F_POPUP;
 			    yyval.function.arg = yyvsp[0].string;
 			;
     break;}
 case 92:
-#line 919 "mwmparse.y"
+#line 928 "mwmparse.y"
 {
 			    yyval.function.func = F_ICONIFY;
 			    yyval.function.arg = "";
 			;
     break;}
 case 93:
-#line 924 "mwmparse.y"
+#line 933 "mwmparse.y"
 {
 			    yyval.function.func = F_MOVE;
 			    yyval.function.arg = "";
 			;
     break;}
 case 94:
-#line 929 "mwmparse.y"
+#line 938 "mwmparse.y"
 {
 			    yyval.function.func = F_NEXT_CMAP;
 			    yyval.function.arg = "";
 			;
     break;}
 case 95:
-#line 934 "mwmparse.y"
+#line 943 "mwmparse.y"
 {
 			    yyval.function.func = F_NEXT_KEY;
 			    yyval.function.arg = yyvsp[0].string;
 			;
     break;}
 case 96:
-#line 939 "mwmparse.y"
+#line 948 "mwmparse.y"
 {
 			    yyval.function.func = F_NOP;
 			    yyval.function.arg = "";
 			;
     break;}
 case 97:
-#line 944 "mwmparse.y"
+#line 953 "mwmparse.y"
 {
 			    yyval.function.func = F_NORMALIZE;
 			    yyval.function.arg = "";
 			;
     break;}
 case 98:
-#line 949 "mwmparse.y"
+#line 958 "mwmparse.y"
 {
 			    yyval.function.func = F_NORM_AND_RAISE;
 			    yyval.function.arg = "";
 			;
     break;}
 case 99:
-#line 954 "mwmparse.y"
+#line 963 "mwmparse.y"
 {
 			    yyval.function.func = F_PACK_ICONS;
 			    yyval.function.arg = "";
 			;
     break;}
 case 100:
-#line 959 "mwmparse.y"
+#line 968 "mwmparse.y"
 {
 			    yyval.function.func = F_PASS_KEYS;
 			    yyval.function.arg = "";
 			;
     break;}
 case 101:
-#line 964 "mwmparse.y"
+#line 973 "mwmparse.y"
 {
 			    yyval.function.func = F_W_POPUP;
 			    yyval.function.arg = "";
 			;
     break;}
 case 102:
-#line 969 "mwmparse.y"
+#line 978 "mwmparse.y"
 {
 			    yyval.function.func = F_PREV_CMAP;
 			    yyval.function.arg = "";
 			;
     break;}
 case 103:
-#line 974 "mwmparse.y"
+#line 983 "mwmparse.y"
 {
 			    yyval.function.func = F_PREV_KEY;
 			    yyval.function.arg = yyvsp[0].string;
 			;
     break;}
 case 104:
-#line 979 "mwmparse.y"
+#line 988 "mwmparse.y"
 {
 			    yyval.function.func = F_QUIT;
 			    yyval.function.arg = "";
 			;
     break;}
 case 105:
-#line 984 "mwmparse.y"
+#line 993 "mwmparse.y"
 {
 			    yyval.function.func = F_RAISE;
 			    yyval.function.arg = yyvsp[0].string;
 			;
     break;}
 case 106:
-#line 989 "mwmparse.y"
+#line 998 "mwmparse.y"
 {
 			    yyval.function.func = F_RAISELOWER;
 			    yyval.function.arg = yyvsp[0].string;
 			;
     break;}
 case 107:
-#line 994 "mwmparse.y"
+#line 1003 "mwmparse.y"
 {
 			    yyval.function.func = F_REFRESH;
 			    yyval.function.arg = "";
 			;
     break;}
 case 108:
-#line 999 "mwmparse.y"
+#line 1008 "mwmparse.y"
 {
 			    yyval.function.func = F_REFRESH_WIN;
 			    yyval.function.arg = "";
 			;
     break;}
 case 109:
-#line 1004 "mwmparse.y"
+#line 1013 "mwmparse.y"
 {
 			    yyval.function.func = F_RESIZE;
 			    yyval.function.arg = "";
 			;
     break;}
 case 110:
-#line 1009 "mwmparse.y"
+#line 1018 "mwmparse.y"
 {
 			    yyval.function.func = F_ICONIFY;
 			    yyval.function.arg = "";
 			;
     break;}
 case 111:
-#line 1014 "mwmparse.y"
+#line 1023 "mwmparse.y"
 {
 			    yyval.function.func = F_RESTORE_AND_RAISE;
 			    yyval.function.arg = "";
 			;
     break;}
 case 112:
-#line 1019 "mwmparse.y"
+#line 1028 "mwmparse.y"
 {
 			    yyval.function.func = F_RESTART;
 			    yyval.function.arg = yyvsp[0].string;
 			;
     break;}
 case 113:
-#line 1024 "mwmparse.y"
+#line 1033 "mwmparse.y"
 {
 			    yyval.function.func = F_SCREEN;
 			    yyval.function.arg = yyvsp[0].string;
 			;
     break;}
 case 114:
-#line 1029 "mwmparse.y"
+#line 1038 "mwmparse.y"
 {
 			    yyval.function.func = F_SEND_MSG;
 			    yyval.function.arg = yyvsp[0].string;
 			;
     break;}
 case 115:
-#line 1034 "mwmparse.y"
+#line 1043 "mwmparse.y"
 {
 			    yyval.function.func = F_NOP;
 			    yyval.function.arg = "";
 			;
     break;}
 case 116:
-#line 1039 "mwmparse.y"
+#line 1048 "mwmparse.y"
 {
 			    yyval.function.func = F_SET_BEHAVIOR;
 			    yyval.function.arg = "";
 			;
     break;}
 case 117:
-#line 1044 "mwmparse.y"
+#line 1053 "mwmparse.y"
 {
 			    yyval.function.func = F_TITLE;
 			    yyval.function.arg = "";
 			;
     break;}
 case 118:
-#line 1049 "mwmparse.y"
+#line 1058 "mwmparse.y"
 {
 			    yyval.function.func = F_WINDOWLIST;
 			    yyval.function.arg = "";
 			;
     break;}
 case 119:
-#line 1054 "mwmparse.y"
+#line 1063 "mwmparse.y"
 {
 			    yyerror("Invalid mnemonic, accelerator, or function");
 			    yyval.function.func = F_NOP;
@@ -2039,55 +2048,55 @@ case 119:
 			;
     break;}
 case 120:
-#line 1062 "mwmparse.y"
+#line 1071 "mwmparse.y"
 { yyval.string = yyvsp[0].string; ;
     break;}
 case 121:
-#line 1064 "mwmparse.y"
+#line 1073 "mwmparse.y"
 { yyval.string = ""; ;
     break;}
 case 122:
-#line 1068 "mwmparse.y"
+#line 1077 "mwmparse.y"
 { yyval.string = yyvsp[0].string; ;
     break;}
 case 123:
-#line 1070 "mwmparse.y"
+#line 1079 "mwmparse.y"
 { yyval.string = "ROOT"; ;
     break;}
 case 124:
-#line 1072 "mwmparse.y"
+#line 1081 "mwmparse.y"
 { yyval.string = "WINDOW"; ;
     break;}
 case 125:
-#line 1074 "mwmparse.y"
+#line 1083 "mwmparse.y"
 { yyval.string = "TRANSIENT"; ;
     break;}
 case 126:
-#line 1076 "mwmparse.y"
+#line 1085 "mwmparse.y"
 { yyval.string = "ICON"; ;
     break;}
 case 127:
-#line 1078 "mwmparse.y"
+#line 1087 "mwmparse.y"
 { yyval.string = "WITHIN"; ;
     break;}
 case 128:
-#line 1080 "mwmparse.y"
+#line 1089 "mwmparse.y"
 { yyval.string = "FREE_FAMILY"; ;
     break;}
 case 129:
-#line 1082 "mwmparse.y"
+#line 1091 "mwmparse.y"
 { yyval.string = "NEXT"; ;
     break;}
 case 130:
-#line 1084 "mwmparse.y"
+#line 1093 "mwmparse.y"
 { yyval.string = "PREV"; ;
     break;}
 case 131:
-#line 1086 "mwmparse.y"
+#line 1095 "mwmparse.y"
 { yyval.string = "BACK"; ;
     break;}
 case 132:
-#line 1089 "mwmparse.y"
+#line 1098 "mwmparse.y"
 { yyval.string = yyvsp[0].string; ;
     break;}
 }
@@ -2316,7 +2325,7 @@ yyerrhandle:
 #endif    
   return 1;
 }
-#line 1091 "mwmparse.y"
+#line 1100 "mwmparse.y"
 
 
 /*
@@ -2351,98 +2360,97 @@ yyerror(char *fmt, ...) {
 /*
  * find the config file
  */
+/*
+ * The "Motif User's Guide [1]"  didn't mention what to do if; a. configFile
+ *  is NOT defined,   b. configFile IS defined but it does not refer to a proper file
+ *  (mulformed or unreadable), c. configFile does begin with "~" but not "~/".
+ * The code below deals with these cases for conveniences.
+ *
+ * [1] (http://w3.pppl.gov/misc/motif/MotifUserGuide/en_US/Understanding_the_Resource_Description_File.html)
+ */
+ 
 static Boolean
-find_config_file2(const char *the_file) {
-    if (verbose)
-	printf("Checking for config file '%s'\n", the_file);
-    if (access(the_file, R_OK) == 0)
-	return True;
-    return False;
-}
+find_config_file(char *buf)
+{
+    char *head = NULL;
+    char *middle = NULL;
+    char *ptr;
+    char tmpbuf[MAX_PATH_LEN];
+    struct stat *st;
 
+#if defined(HAVE_SYS_TYPES_H) && defined(HAVE_PWD_H)
+    struct passwd *passwd;
+#endif
 
-static Boolean
-find_config_file3(char *buf, const char *cfile) {
-    char *lang, *ptr;
+    ptr =  Mwm.config_file;
 
-    /* Shall overrun check be done for each strcat()??? */
-    strcat(buf, "/");
+    if (strlen(Mwm.config_file) > MAX_PATH_LEN)
+	return False;
 
-    lang = getenv("LANG");
-    if (!lang)
-	lang = "";
-
-    ptr = buf + strlen(buf);
-
-    if (strlen(lang) != 0) {
-	strcat(buf, lang);
-	strcat(buf, "/");
-	strcat(buf, cfile);
-	if (find_config_file2(buf)) {
-	    return True;
-	}
-    }
-
-    strcpy(ptr, cfile);
-    if (find_config_file2(buf)) {
-	return True;
-    }
-    return False;
-}
-
-
-static Boolean
-find_config_file(char *buf, const char *cfile) {
-    char *home;
-
-    home = getenv("HOME");
-
-    if (!home)
-	home = getcwd(NULL, MAX_PATH_LEN);
-
-    switch (*cfile) {
+    switch (Mwm.config_file[0])
+    {
     case '/':
-	if (find_config_file2(cfile)) {
-	    strcpy(buf, cfile);
-	    return True;
-	}
+	head = "";
+	ptr = Mwm.config_file;
 	break;
     case '~':
-	if (*(cfile+1) == '/') {
-	    strcpy(buf, home);
-	    strcat(buf, "/");
-	    strcat(buf, cfile+2);
-	    if (find_config_file2(buf)) {
-		return True;
+	ptr++;
+	if (Mwm.config_file[1] == '/')
+	{   /* ~ => $HOME */
+	    head = getenv("HOME");
+	    middle = getenv("LANG");
+	}
+	else
+#if defined(HAVE_SYS_TYPES_H) && defined(HAVE_PWD_H)	    
+	{   /* ~hoge => hoge's home */
+	    int idx;
+
+	    idx = strcspn(ptr, "/");
+	    if (*(ptr + idx) == '\0')
+		head = NULL;
+	    else
+	    {
+		strncpy(tmpbuf, ptr, idx);
+		if ((passwd = getpwnam(tmpbuf)))  {
+		    head = strcpy(tmpbuf, passwd->pw_dir);
+		    ptr += idx;
+		}
+		else
+		    head = NULL; /* no such user "hoge" */
 	    }
 	}
-	else {
-	    /* XXX function not implemented yet */
-	    if (verbose)
-		printf("~user notation is not implemented.\n");
-	}
 	break;
-    default: /* check for home dir */
-	strcpy(buf, home);
-	if (find_config_file3(buf, cfile))
-	    return True;
-    }  /* switch (*cfile) */
 
-
-    strcpy(buf, home);
-    if (find_config_file3(buf, HOME_MWMRC))
-	return True;
-#ifndef __EMX__
-    strcpy(buf, MWM_DDIR);
 #else
-    strcpy(buf, (char*)__XOS2RedirRoot("/XFree86/lib/X11/mwm"));
+	;  /* no <pwd.h>, no ~hoge */
+	head = NULL;
+	break;
 #endif
-    if (find_config_file3(buf, SYSTEM_MWMRC))
-	return True;
 
-    return False;
+    default:
+        /* search for the current dir */
+	head = getcwd(buf, MAX_PATH_LEN);
+	break;
+
+    } /* switch (Mwm.config_file[0]) */
+
+
+    if (!head || strlen(head) + strlen(ptr) > MAX_PATH_LEN)
+	sprintf(buf, "%s/%s", MWM_DDIR, SYSTEM_MWMRC);	/* should be ok */
+    else
+    {
+	sprintf(buf, "%s%s", head, ptr);
+	if (middle && strlen(head) + 1 + strlen(middle) + strlen(ptr) <= MAX_PATH_LEN)
+	    {
+		sprintf(tmpbuf, "%s%s%s%s", head, "/", middle, ptr);	    
+		if (stat(tmpbuf, st) == 0)
+		    strcpy(buf, tmpbuf);
+	    }
+    }
+    return True;
 }
 
+
 char
 mwm_getc(void) {
     char c;
@@ -2529,7 +2537,7 @@ do_custom(ScreenInfo *scr)
 #endif
 
     ptr = Mwm.config_file;
-    if (!find_config_file(buf, Mwm.config_file)) {
+    if (!find_config_file(buf)) {
 	yyerror("Cannot find configuration file.  "
 		"Using builtin defaults.\n");
 
@@ -2541,10 +2549,10 @@ do_custom(ScreenInfo *scr)
 
 	do_standard(scr);
     }
-#ifndef __EMX__
-    else if ((fd = open(buf, O_RDONLY)) < 0) {
-#else
+#ifdef __EMX__
     else if ((fd = open(buf, O_RDONLY|O_BINARY)) < 0) {
+#else
+    else if ((fd = open(buf, O_RDONLY)) < 0) {
 #endif
 	yyerror("Cannot open configuration file '%s'.  "
 		"Using builtin defaults.\n");
