@@ -1,7 +1,8 @@
 /*
- * $Id: LTmisc.h,v 1.2 1998/09/02 19:22:42 danny Exp $
+ * $Id: LTmisc.h,v 1.7 2001/03/26 14:23:23 amai Exp $
  * 
  * Copyright (C) 1998 Free Software Foundation, Inc.
+ * Copyright (C) 1998-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -21,30 +22,27 @@
  *
  **/
 
+#ifndef _LTMISC_H
+#define _LTMISC_H
+
 #ifndef	HAVE_STRCASECMP
-#ifdef	strcasecmp
-#undef	strcasecmp
-#endif
-int strcasecmp(char *, char *);
+int _Lt_strcasecmp(const char *str1, const char *str2);
+#define strcasecmp _Lt_strcasecmp
 #endif
 
 #ifndef	HAVE_STRNCASECMP
-#ifdef	strncasecmp
-#undef	strncasecmp
-#endif
-int strncasecmp(char *, char *, int);
+int _Lt_strncasecmp(const char *str1, const char *str2, size_t count);
+#define strncasecmp _Lt_strncasecmp
 #endif
 
-#ifndef	HAVE_STRSTR
-#ifdef	strstr
-#undef	strstr
-#endif
-char *strstr(char *, char *);
+#ifndef HAVE_BASENAME
+char *_Lt_basename(char *path);
+#define basename _Lt_basename
 #endif
 
-#ifndef	HAVE_MEMMOVE
-#ifdef	memmove
-#undef	memmove
-#endif
-void *memmove(void *, void *, size_t);
+#ifndef HAVE_DIRNAME
+char *_Lt_dirname(char *dirname);
+#define dirname _Lt_dirname
 #endif
+
+#endif /* _LTMISC_H */
