@@ -1,8 +1,9 @@
 /**
  *
- * $Id: DrawP.h,v 1.5 1998/11/13 07:38:22 gritton Exp $
+ * $Header: /cvsroot/lesstif/lesstif/include/Motif-1.2/Xm/DrawP.h,v 1.7 2001/06/17 10:23:57 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,8 +23,8 @@
  *
  **/
 
-#ifndef XM_DRAW_P_H
-#define XM_DRAW_P_H
+#ifndef _XM_DRAWP_H
+#define _XM_DRAWP_H
 
 #include <Xm/XmP.h>
 
@@ -108,4 +109,4 @@ extern void _XmUnhighlightBorder(Widget w);
 }
 #endif
 
-#endif /* XM_DRAW_P_H */
+#endif /* _XM_DRAWP_H */
