@@ -1,8 +1,9 @@
 /**
  *
- * $Id: MacrosI.h,v 1.38 1999/07/08 00:21:40 rwscott Exp $
+ * $Id: MacrosI.h,v 1.41 2000/09/23 17:00:49 amai Exp $
  * 
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,12 +23,14 @@
  *
  **/
 
-#ifndef MACROS_I_H
-#define MACROS_I_H
+#ifndef _XMI_MACROSI_H
+#define _XMI_MACROSI_H
 
 #include <Xm/LabelGP.h>
 #include <Xm/LabelP.h>
 
+
+
 /*
  * object shorthand
  */
@@ -1263,16 +1266,16 @@
     (((XmFormConstraintRec *)((w)->core.constraints))->form.preferred_height)
 
 #define FormC_X(w) \
-    (((XmFormConstraintRec *)((w)->core.constraints))->form.x)
+    (((XmFormConstraintRec *)((w)->core.constraints))->form.att[0].value)
 
 #define FormC_Y(w) \
-    (((XmFormConstraintRec *)((w)->core.constraints))->form.y)
+    (((XmFormConstraintRec *)((w)->core.constraints))->form.att[2].value)
 
 #define FormC_W(x) \
-    (((XmFormConstraintRec *)((x)->core.constraints))->form.w)
+    (((XmFormConstraintRec *)((x)->core.constraints))->form.att[1].value)
 
 #define FormC_H(w) \
-    (((XmFormConstraintRec *)((w)->core.constraints))->form.h)
+    (((XmFormConstraintRec *)((w)->core.constraints))->form.att[3].value)
 
 #define FormC_WFS(w) \
     (((XmFormConstraintRec *)((w)->core.constraints))->form.width_from_side)
@@ -1300,22 +1303,24 @@
     (((XmFormConstraintRec *)(c))->form.preferred_height)
 
 #define FCP_X(c) \
-    (((XmFormConstraintRec *)(c))->form.x)
+    (((XmFormConstraintRec *)(c))->form.att[0].value)
 
 #define FCP_Y(c) \
-    (((XmFormConstraintRec *)(c))->form.y)
+    (((XmFormConstraintRec *)(c))->form.att[2].value)
 
 #define FCP_W(c) \
-    (((XmFormConstraintRec *)(c))->form.w)
+    (((XmFormConstraintRec *)(c))->form.att[1].value)
 
 #define FCP_H(c) \
-    (((XmFormConstraintRec *)(c))->form.h)
+    (((XmFormConstraintRec *)(c))->form.att[3].value)
 
+#if 0
 #define FCP_WidthFromSide(c) \
     (((XmFormConstraintRec *)(c))->form.width_from_side)
 
 #define FCP_HeightFromSide(c) \
     (((XmFormConstraintRec *)(c))->form.height_from_side)
+#endif
 
 /*
  * FILE SELECTIONBOX WIDGET ACCESS MACROS
@@ -2742,4 +2747,4 @@
  */
 #define _XmStringIsSpecified(x) ((x) != NULL && (x) != (XmString)XmUNSPECIFIED)
 
-#endif /* MacrosI.h */
+#endif /* _XMI_MACROSI_H */
