@@ -1,8 +1,9 @@
 /**
  *
- * $Id: XmP.h,v 1.6 1999/08/13 13:18:23 danny Exp $
+ * $Id: XmP.h,v 1.19 2001/09/11 22:01:33 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,12 +23,17 @@
  *
  **/
 
-#ifndef XM_P_H
-#define XM_P_H
+#ifndef _XM_XMP_H
+#define _XM_XMP_H
 
+#include <X11/IntrinsicP.h>
 #include <Xm/Xm.h>
 #include <Xm/DrawP.h>
-#include <X11/IntrinsicP.h>
+
+#ifndef XmConst
+#define XmConst	const
+#endif /* !XmConst */
+
 
 #ifdef __cplusplus
 extern "C" {
@@ -101,18 +107,7 @@ extern "C" {
 /*
  * #defines for useful core record variables
  */
-#ifdef	__BOUNDS_CHECKING_ON
-/* This is a version that works with Bounds Checking GCC */
-#define	XtWidth(w)	 (((XmGadget)(w))->rectangle.width)
-#define	XtHeight(w)	 (((XmGadget)(w))->rectangle.height)
-#define XtX(w)		 (((XmGadget)(w))->rectangle.x)
-#define XtY(w)		 (((XmGadget)(w))->rectangle.y)
-#define XtBackground(w)	 (((Widget)(w))->core.background_pixel)
-#define XtBorderWidth(w) (((XmGadget)(w))->rectangle.border_width)
-#define XtSensitive(w)	 (((XmGadget)(w))->rectangle.sensitive && \
-			  ((XmGadget)(w))->rectangle.ancestor_sensitive)
-#define XtCoreProc(w,p)  (((XmGadget)(w))->core.widget_class->core_class.p)
-#else
+
 #define XtWidth(w)	 (((Widget)(w))->core.width)
 #define XtHeight(w)	 (((Widget)(w))->core.height)
 #define XtX(w)		 (((Widget)(w))->core.x)
@@ -122,18 +117,6 @@ extern "C" {
 #define XtSensitive(w)	 (((Widget)(w))->core.sensitive && \
 			  ((Widget)(w))->core.ancestor_sensitive)
 #define XtCoreProc(w,p)  (((Widget)(w))->core.widget_class->core_class.p)
-#endif
-
-/*
- * idiocy for K&R (which, BTW, won't work anyway).
- */
-#ifndef XmConst
-#if (defined(__STDC__) && __STDC__) || !defined(NO_CONST)
-#define XmConst	const
-#else
-#define XmConst
-#endif /* __STDC__ */
-#endif /* !XmConst */
 
 /*
  * menu values
@@ -962,6 +945,9 @@ typedef struct _XmRegion {
     XmRegionBox	extents;
 } XmRegionRec, *XmRegion;
 
+/*********************** Trait.c ***********************************/
+#include <Xm/TraitP.h>
+
 /*********************** GadgetUtils.c *****************************/
 
 XmGadget _XmInputInGadget(Widget cw, int x, int y);
@@ -1055,21 +1041,27 @@ Boolean _XmMatchKeyEvent(XEvent *event,
 XImage *_XmGetImageFromFile(char *filename);
 XImage *_XmGetImageAndHotSpotFromFile(char *filename, int *hot_x, int *hot_y);
 
+/************************* RenderTable.c ****************************/
+
+Boolean XmeRenderTableGetDefaultFont(XmRenderTable renderTable,
+                                     XFontStruct  **fontStruct);
+
 /************************* ResConvert.c *****************************/
 
 enum { XmLABEL_FONTLIST = 1,
        XmBUTTON_FONTLIST,
        XmTEXT_FONTLIST
 };
-enum {	XmLABEL_RENDER_TABLE = 1, 
-	XmBUTTON_RENDER_TABLE, 
-	XmTEXT_RENDER_TABLE  
+
+enum { XmLABEL_RENDER_TABLE = 1, 
+       XmBUTTON_RENDER_TABLE, 
+       XmTEXT_RENDER_TABLE  
 };
 
 
 void _XmRegisterConverters(void);
-void _XmWarning(Widget w, char *message, ...);
-void XmeWarning(Widget w, char *message, ...);
+#define _XmWarning XmeWarning
+void XmeWarning(Widget w, const char *message, ...);
 Boolean _XmStringsAreEqual(char *in_str, char *text_str);
 Boolean XmeNamesAreEqual(char *in_str, char *text_str);
 XmFontList _XmGetDefaultFontList(Widget w, unsigned char fontListType);
@@ -1148,6 +1140,7 @@ void _XmUnitTypeDefault(Widget widget,
 		        XrmValue *value);
 unsigned char _XmGetUnitType(Widget widget);
 
+
 /************************* UniqueEvent.c *****************************/
 
 Boolean _XmIsEventUnique(XEvent *event);
@@ -1266,9 +1259,30 @@ char * _XmStringGetTextConcat(XmString string);
 Boolean _XmStringIsCurrentCharset(XmStringCharSet c);
 Boolean _XmStringSingleSegment(XmString str, char **pTextOut,
 			       XmStringCharSet *pCharsetOut);
+
 void _XmStringUpdateWMShellTitle(XmString xmstr, Widget shell);
 void XmeStringUpdateWMShellTitle(XmString xmstr, Widget shell);
 
+XmIncludeStatus XmeGetNextCharacter(XtPointer *text_in_out,
+                                    XtPointer text_end,
+                                    XmTextType type,
+                                    XmStringTag tag,
+                                    XmParseMapping entry,
+                                    int pattern_length,
+                                    XmString *str_include,
+                                    XtPointer call_data);
+
+XmIncludeStatus XmeGetDirection(XtPointer *text_in_out,
+                                XtPointer text_end,
+                                XmTextType type,
+                                XmStringTag tag,
+                                XmParseMapping entry,
+                                int pattern_length,
+                                XmString *str_include,
+                                XtPointer call_data);
+
+
+
 /************************* Traversal.c ********************************/
 
 #define XmTAB_ANY	((XmNavigationType)255)
@@ -1540,7 +1554,30 @@ void _XmDragOverSetInitialPosition(Widget w,
 
 void _XmDragUnderAnimation(Widget w, XtPointer clientData, XtPointer callData);
 
-/**********************************************************************/
+/************************** Xme.c **************************************/
+
+void XmeVirtualToActualKeysym(Display *Dsp, KeySym VirtualKeysym,
+                                     KeySym *RealKeysymReturn,
+                                     Modifiers *ModifierReturn);
+
+void XmeResolvePartOffsets(WidgetClass widget_class,
+                           XmOffsetPtr *offset,
+                           XmOffsetPtr *constraint_offset);
+
+Cursor XmeGetNullCursor(Widget w);
+
+void XmeQueryBestCursorSize(Widget widget, Dimension *width, Dimension *height);
+
+void XmeSetWMShellTitle(XmString xmstr, Widget shell);
+			   
+/************************* Xmos.c *************************************/
+
+extern int XmeMicroSleep(long secs);
+
+XmString XmeGetLocalizedString(char *reserved, Widget widget,                                                                                  
+                               char *resource, String string);
+
+
 
 /****************** THESE AREN'T SUPPOSED TO BE USED ******************/
 
@@ -1603,14 +1640,16 @@ extern WidgetClass xmScreenObjectClass;
 
 /**********************************************************************/
 
+#ifdef __cplusplus
+}
+#endif
+
+
 #include <Xm/VendorSP.h>
 #include <Xm/ManagerP.h>
 #include <Xm/PrimitiveP.h>
 #include <Xm/GadgetP.h>
 #include <Xm/BaseClassP.h> 
 
-#ifdef __cplusplus
-}
-#endif
 
-#endif /* XM_P_H */
+#endif /* _XM_XMP_H */
