@@ -1,9 +1,9 @@
 /**
  *
- * $Id: XmI.h,v 1.37 2000/11/07 12:33:13 amai Exp $
+ * $Id: XmI.h,v 1.41 2001/03/16 13:47:25 amai Exp $
  * 
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2000 LessTif Development Team
+ * Copyright (C) 1995-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -121,6 +121,13 @@ typedef unsigned char XmIMInputPolicy;
 #define	IP_PER_WIDGET		1
 #define	IP_PER_SHELL		2
 
+void _XmImSendSpot(Widget w);
+#if XmVERSION == 1
+XIC XmImGetXIC(Widget w, XmIMInputPolicy input_policy,
+           ArgList args, Cardinal num_args);
+XIC XmImSetXIC(Widget w, XIC xic);
+#endif
+
 /*
  * GENERIC PROTOTYPES
  */
@@ -230,11 +237,7 @@ void _XmSetupImageCache(void);
 
 /* from MenuUtil.c */
 void _XmFakeExpose(Widget menu_shell);
-void _XmSetInPMMode(Widget w, Boolean flag);
-Boolean _XmGetInPMMode(Widget w);
-
-/* from RowColumn.c */
-void _XmRCSetKidGeo(XmRCKidGeometry kg, Widget instigator);
+Boolean _XmMenuGetInPMMode(Widget w);
 
 /* used as the operation parameter for _XmMenuFocus. */
 enum {
@@ -252,6 +255,11 @@ void _XmInstallStippleImages(Widget w);
 #define XmEVEN_STIPPLE_IMAGE	"xm_even_stipple"
 #define XmODD_STIPPLE_IMAGE	"xm_odd_stipple"
 
+/* from RCUtils.c */
+void _XmRCSetMargins(Widget rc);
+XtGeometryResult _XmRCAdjustSize(Widget rc, Widget instig, XtWidgetGeometry *instig_request);
+void _XmRCPreferredSize(Widget rc, XtWidgetGeometry *rcg);
+
 /* from ResInd */
 void _XmExportXmString(Widget w, int offset, XtArgVal *value);
 void _XmExportString(Widget w, int offset, XtArgVal *value);
@@ -289,9 +297,6 @@ Boolean _XmSelectionBoxMatch(XmSelectionBoxWidget w);
 /* for TearOff */
 void _XmPushButtonSetTranslation(Widget, int);
 
-/* TearOff */
-void _XmTearOffInitiate(Widget w, XEvent *event);
-
 /* Text */
 void _XmChangeVSB(XmTextWidget w, XmTextPosition pos);
 void _XmRedisplayHBar(XmTextWidget w, int offset);
@@ -363,6 +368,23 @@ void _XmObjectLock(Widget w);
 void _XmObjectUnlock(Widget w);
 
 
+/*
+ * from LTCvt.c
+ */
+#ifdef NONSTANDARD_CONVERTERS
+void _XmRegisterNSEConverters(void);
+#endif
+
+/*
+ * from Shadow.c 
+ */
+/* old backward compatibility stuff */
+void _XmDrawSquareButton(Widget w, int x, int y, int size,
+                         GC top_gc, GC bottom_gc, GC select_gc, Boolean fill);
+void _XmDrawDiamondButton(Widget w, int x, int y, int size,
+                          GC top_gc, GC bottom_gc, GC select_gc, Boolean fill);
+
+
 #if XmVERSION >= 2
 /* from Xmos.c: 
    private, but exported stuff from Motif 1.2 which is used within LessTif,
@@ -440,4 +462,8 @@ void _XmInitTraits(void);
 
 #endif /* XmVERSION >= 2 */
 
+/* from Vendor.c */
+extern Boolean _LtCheckClassOfVendorShell(Widget w);
+
+
 #endif /* _XMI_XMI_H */
