@@ -1,9 +1,9 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/CSText.c,v 1.5 2000/09/23 15:05:26 amai Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/CSText.c,v 1.8 2001/04/02 19:05:43 amai Exp $
  *
  * Copyright (C) 1997 Free Software Foundation, Inc.
- * Copyright (C) 1997-2000 LessTif Development Team
+ * Copyright (C) 1997-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -25,13 +25,17 @@
 
 
 #include <LTconfig.h>
+
 #include <Xm/XmP.h>
 #include <Xm/CSTextP.h>
 
+#include <XmI/DebugUtil.h>
+
+
 /*
   MODULE: CSText.c
   DESCRIPTION:
-  This is just a stub.
+  This is just a stub!
   END:
 */
 
@@ -133,7 +137,11 @@ XmCSTextClassRec xmCSTextClassRec  = {
 	/* synthetic resources   */ NULL,
 	/* num syn res           */ 0,
 	/* extension             */ (XtPointer)&_XmCSTextPrimClassExtRec
-    }
+    },
+    /* CSText Class part */
+   {
+    NULL
+   }
 };
 
 WidgetClass xmCSTextWidgetClass = (WidgetClass)&xmCSTextClassRec;
@@ -143,30 +151,38 @@ static void class_initialize(void) {
     _XmWarning(NULL, "class_initialize(): XmCSText is not yet implemented!");
 }
 
+
 static void class_part_initialize(WidgetClass w_class) {
-    _XmWarning(NULL, "class_initialize(): XmCSText is not yet implemented!");
+    _XmWarning(NULL, "class_part_initialize(): XmCSText is not yet implemented!");
 }
 
+
 static void initialize(Widget request, Widget new_w,
 		       ArgList args, Cardinal *num_args) {
-    _XmWarning(NULL, "class_initialize(): XmCSText is not yet implemented!");
+    _XmWarning(NULL, "initialize(): XmCSText is not yet implemented!");
 }
 
+
 static void initialize_prehook(Widget request, Widget new_w,
 			       ArgList args, Cardinal *num_args) {
-    _XmWarning(NULL, "class_initialize(): XmCSText is not yet implemented!");
+    _XmWarning(NULL, "initialize_prehook(): XmCSText is not yet implemented!");
 }
+
 			       
 static void initialize_posthook(Widget request, Widget new_w,
 				ArgList args, Cardinal *num_args) {
-    _XmWarning(NULL, "class_initialize(): XmCSText is not yet implemented!");
+    _XmWarning(NULL, "initialize_posthooke(): XmCSText is not yet implemented!");
 }
 
+
 static void destroy(Widget w) {
-    _XmWarning(NULL, "class_initialize(): XmCSText is not yet implemented!");
+    _XmWarning(NULL, "destroy(): XmCSText is not yet implemented!");
 }
 
-Widget 
+
+/* ************************ Public Interfaces *********************** */
+
+extern Widget 
 XmCreateCSText(Widget parent, String name, ArgList arglist, Cardinal argcount)
 {
    /* FIXTHIS: Needs to be implemented */
@@ -174,7 +190,8 @@ XmCreateCSText(Widget parent, String name, ArgList arglist, Cardinal argcount)
    return NULL;
 }
 
-Widget 
+
+extern Widget 
 XmCreateScrolledCSText(Widget parent, 
                        String name, 
                        ArgList arglist, 
@@ -186,20 +203,23 @@ XmCreateScrolledCSText(Widget parent,
 }
 
 
-XmString XmCSTextGetString(Widget widget) {
+extern XmString
+XmCSTextGetString(Widget widget) {
 
   _XmWarning(NULL, "XmCSTextGetString(): not yet implemented!");
   return NULL;
 }
 
 
-void XmCSTextSetString(Widget w, XmString value) {
+extern void
+XmCSTextSetString(Widget w, XmString value) {
 
   _XmWarning(NULL, "XmCSTextSetString(): not yet implemented!");
 }
 
 
-void XmCSTextReplace(Widget w,
+extern void 
+XmCSTextReplace(Widget w,
                      XmTextPosition from_pos,
                      XmTextPosition to_pos,
                      XmString value) {
@@ -208,7 +228,8 @@ void XmCSTextReplace(Widget w,
 }
 
 
-void XmCSTextRead(Widget w,
+extern void
+XmCSTextRead(Widget w,
                   XmTextPosition frompos,
                   XmTextPosition topos,
                   XmString *value) {
@@ -217,7 +238,8 @@ void XmCSTextRead(Widget w,
 }
 
 
-void XmCSTextInsert(Widget w,
+extern void
+XmCSTextInsert(Widget w,
                     XmTextPosition position,
                     XmString value) {
 
@@ -225,14 +247,16 @@ void XmCSTextInsert(Widget w,
 }
 
 
-Boolean XmCSTextGetEditable(Widget w) {
+extern Boolean
+XmCSTextGetEditable(Widget w) {
 
   _XmWarning(NULL, "XmCSTextGetEditable(): not yet implemented!");
   return False;
 }
 
 
-void XmCSTextSetEditable(Widget w,
+extern void
+XmCSTextSetEditable(Widget w,
 #if NeedWidePrototypes
                          int editable)
 #else
@@ -244,40 +268,46 @@ void XmCSTextSetEditable(Widget w,
 }
 
  
-int XmCSTextGetMaxLength(Widget w) {
+extern int
+XmCSTextGetMaxLength(Widget w) {
 
   _XmWarning(NULL, "XmCSTextGetMaxLength(): not yet implemented!");
   return 0;
 }
 
 
-void XmCSTextSetMaxLength(Widget w, int max_length) {
+extern void
+XmCSTextSetMaxLength(Widget w, int max_length) {
 
   _XmWarning(NULL, "XmCSTextGetMaxLength(): not yet implemented!");
 }
 
 
-XmStringDirection XmCSTextGetTextPath(Widget w) {
+extern XmStringDirection
+XmCSTextGetTextPath(Widget w) {
 
   _XmWarning(NULL, "XmCSTextGetTextPath(): not yet implemented!");
   return 0;
 }
 
 
-void XmCSTextSetTextPath(Widget w, XmStringDirection path) {
+extern void
+XmCSTextSetTextPath(Widget w, XmStringDirection path) {
 
   _XmWarning(NULL, "XmCSTextSetTextPath(): not yet implemented!");
 }
 
 
-XmString XmCSTextGetSelection(Widget w) {
+extern XmString
+XmCSTextGetSelection(Widget w) {
 
   _XmWarning(NULL, "XmCSTextGetSelection(): not yet implemented!");
   return NULL;
 }
 
 
-Boolean XmCSTextGetSelectionPosition(Widget w, 
+extern Boolean
+XmCSTextGetSelectionPosition(Widget w, 
                                      XmTextPosition *left,
                                      XmTextPosition *right) {
 
@@ -286,7 +316,8 @@ Boolean XmCSTextGetSelectionPosition(Widget w,
 }
 
 
-void XmCSTextSetSelection(Widget w,
+extern void
+XmCSTextSetSelection(Widget w,
                           XmTextPosition first,
                           XmTextPosition last,
                           Time time) {
@@ -295,65 +326,75 @@ void XmCSTextSetSelection(Widget w,
 }
 
 
-void XmCSTextClearSelection(Widget w, Time time) {
+extern void
+XmCSTextClearSelection(Widget w, Time time) {
 
   _XmWarning(NULL, "XmCSTextClearSelection(): not yet implemented!");
 }
 
 
-Boolean XmCSTextCopy(Widget w, Time time) {
+extern Boolean
+XmCSTextCopy(Widget w, Time time) {
 
   _XmWarning(NULL, "XmCSTextCopy(): not yet implemented!");
   return False;
 }
 
 
-Boolean XmCSTextCut(Widget w, Time time) {
+extern Boolean
+XmCSTextCut(Widget w, Time time) {
 
   _XmWarning(NULL, "XmCSTextCut(): not yet implemented!");
   return False;
 }
 
 
-Boolean XmCSTextPaste(Widget w) {
+extern Boolean
+XmCSTextPaste(Widget w) {
 
   _XmWarning(NULL, "XmCSTextPaste(): not yet implemented!");
   return False;
 }
 
 
-Boolean XmCSTextRemove(Widget w) {
+extern Boolean
+XmCSTextRemove(Widget w) {
 
   _XmWarning(NULL, "XmCSTextRemove(): not yet implemented!");
   return False;
 }
 
 
-void XmCSTextShowPosition(Widget w, XmTextPosition position) {
+extern void
+XmCSTextShowPosition(Widget w, XmTextPosition position) {
 
   _XmWarning(NULL, "XmCSTextShowPosition(): not yet implemented!");
 }
 
 
-void XmCSTextScroll(Widget w, int lines) {
+extern void
+XmCSTextScroll(Widget w, int lines) {
 
   _XmWarning(NULL, "XmCSTextScroll(): not yet implemented!");
 }
 
 
-void XmCSTextDisableRedisplay(Widget w) {
+extern void
+XmCSTextDisableRedisplay(Widget w) {
 
   _XmWarning(NULL, "XmCSTextDisableRedisplay(): not yet implemented!");
 }
 
 
-void XmCSTextEnableRedisplay(Widget w) {
+extern void
+XmCSTextEnableRedisplay(Widget w) {
 
   _XmWarning(NULL, "XmCSTextEnableRedisplay(): not yet implemented!");
 }
 
 
-void XmCSTextMarkRedraw(Widget w,
+extern void
+XmCSTextMarkRedraw(Widget w,
                         XmTextPosition  left,
                         XmTextPosition  right) {
 
@@ -361,7 +402,8 @@ void XmCSTextMarkRedraw(Widget w,
 }
 
 
-void XmCSTextSetHighlight(Widget w,
+extern void
+XmCSTextSetHighlight(Widget w,
                           XmTextPosition left,
                           XmTextPosition right,
                           XmHighlightMode mode) {
@@ -370,47 +412,54 @@ void XmCSTextSetHighlight(Widget w,
 }
 
 
-XmTextPosition XmCSTextGetTopCharacter(Widget w) {
+extern XmTextPosition
+XmCSTextGetTopCharacter(Widget w) {
 
   _XmWarning(NULL, "XmCSTextGetTopCharacter(): not yet implemented!");
   return 0;
 }
 
 
-void XmCSTextSetTopCharacter(Widget w, XmTextPosition top_position) {
+extern void
+XmCSTextSetTopCharacter(Widget w, XmTextPosition top_position) {
 
   _XmWarning(NULL, "XmCSTextSetTopCharacter(): not yet implemented!");
 }
 
 
-XmTextPosition XmCSTextGetLastPosition(Widget w) {
+extern XmTextPosition
+XmCSTextGetLastPosition(Widget w) {
 
   _XmWarning(NULL, "XmCSTextGetLastPosition(): not yet implemented!");
   return 0;
 }
 
 
-XmTextPosition XmCSTextGetCursorPosition(Widget w) {
+extern XmTextPosition
+XmCSTextGetCursorPosition(Widget w) {
 
   _XmWarning(NULL, "XmCSTextGetCursorPosition(): not yet implemented!");
   return 0;
 }
 
 
-XmTextPosition XmCSTextGetInsertionPosition(Widget w) {
+extern XmTextPosition
+XmCSTextGetInsertionPosition(Widget w) {
 
   _XmWarning(NULL, "XmCSTextGetInsertionPosition(): not yet implemented!");
   return 0;
 }
 
 
-void XmCSTextSetInsertionPosition(Widget w, XmTextPosition position) {
+extern void
+XmCSTextSetInsertionPosition(Widget w, XmTextPosition position) {
 
   _XmWarning(NULL, "XmCSTextSetInsertionPosition(): not yet implemented!");
 }
 
 
-XmTextPosition XmCSTextXYToPos(Widget w,
+extern XmTextPosition
+XmCSTextXYToPos(Widget w,
 #if NeedWidePrototypes
                                int x,
                                int y)
@@ -425,7 +474,8 @@ XmTextPosition XmCSTextXYToPos(Widget w,
 }
 
 
-Boolean XmCSTextPosToXY(Widget w,
+extern Boolean
+XmCSTextPosToXY(Widget w,
                         XmTextPosition position,
                         Position *x,
                         Position *y) {
@@ -435,7 +485,8 @@ Boolean XmCSTextPosToXY(Widget w,
 }
 
 
-XmString XmCSTextGetStringWrapped(Widget w,
+extern XmString
+XmCSTextGetStringWrapped(Widget w,
                         XmTextPosition start,
                         XmTextPosition end) {
 
@@ -444,7 +495,8 @@ XmString XmCSTextGetStringWrapped(Widget w,
 }
 
 
-Boolean XmCSTextFindString(Widget w,
+extern Boolean
+XmCSTextFindString(Widget w,
                            XmTextPosition start,
                            String string,
                            XmTextDirection direction,
@@ -455,7 +507,8 @@ Boolean XmCSTextFindString(Widget w,
 }
 
 
-Boolean XmCSTextFindStringWcs(Widget w,
+extern Boolean
+XmCSTextFindStringWcs(Widget w,
                               XmTextPosition start,
                               wchar_t *wcstring,
                               XmTextDirection direction,
@@ -466,8 +519,8 @@ Boolean XmCSTextFindStringWcs(Widget w,
 }
 
 
-
-int XmCSTextGetSubstring(Widget w,
+extern int
+XmCSTextGetSubstring(Widget w,
                          XmTextPosition start,
                          int num_chars,
                          int buffer_size,
@@ -478,8 +531,8 @@ int XmCSTextGetSubstring(Widget w,
 }
 
 
-
-int XmCSTextGetSubstringWcs(Widget w,
+extern int
+XmCSTextGetSubstringWcs(Widget w,
                             XmTextPosition start,
                             int num_chars,
                             int buffer_size,
@@ -490,8 +543,8 @@ int XmCSTextGetSubstringWcs(Widget w,
 }
 
 
-
-void XmCSTextSetAddMode(Widget w,
+extern void
+XmCSTextSetAddMode(Widget w,
 #if NeedWidePrototypes
                         int state)
 #else
@@ -503,7 +556,8 @@ void XmCSTextSetAddMode(Widget w,
 }
 
 
-void XmCSTextSetSource(Widget w,
+extern void
+XmCSTextSetSource(Widget w,
                        XmCSTextSource source,
                        XmTextPosition top_character,
                        XmTextPosition cursor_position) {
@@ -512,28 +566,32 @@ void XmCSTextSetSource(Widget w,
 }
 
 
-XmCSTextSource XmCSTextGetSource(Widget w) {
+extern XmCSTextSource
+XmCSTextGetSource(Widget w) {
 
   _XmWarning(NULL, "XmCSTextGetSource(): not yet implemented!");
   return NULL;
 }
 
 
-int XmCSTextGetBaseline(Widget w) {
+extern int
+XmCSTextGetBaseline(Widget w) {
 
   _XmWarning(NULL, "XmCSTextGetBaseline(): not yet implemented!");
   return 0;
 }
 
 
-Boolean XmCSTextPasteLink(Widget w) {
+extern Boolean
+XmCSTextPasteLink(Widget w) {
 
   _XmWarning(NULL, "XmCSTextPasteLink(): not yet implemented!");
   return False;
 }
 
 
-Boolean XmCSTextCopyLink(Widget w, Time time) {
+extern Boolean
+XmCSTextCopyLink(Widget w, Time time) {
 
   _XmWarning(NULL, "XmCSTextCopyLink(): not yet implemented!");
   return False;
