@@ -1,8 +1,9 @@
 /**
  *
- * $Id: Direction.c,v 1.2 1999/01/19 12:32:50 pgw Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/Direction.c,v 1.7 2001/07/27 18:55:20 dannybackx Exp $
  *
  * Copyright (C) 1998 Free Software Foundation, Inc.
+ * Copyright (C) 1998-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,15 +23,17 @@
  *
  **/
 
-static const char rcsid[] = "$Id: Direction.c,v 1.2 1999/01/19 12:32:50 pgw Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/Direction.c,v 1.7 2001/07/27 18:55:20 dannybackx Exp $";
 
 #include <LTconfig.h>
+
 #include <Xm/XmP.h>
 #include <Xm/TraitP.h>
 #include <Xm/LayoutT.h>
-#include <XmI/DebugUtil.h>
 #include <XmI/DirectionI.h>
 
+#include <XmI/DebugUtil.h>
+
 #define Unused(x) (void)(x)
 
 /* ================================================================ */
@@ -43,7 +46,7 @@ _XmDirectionDefault(Widget w, int offset, XrmValue *value)
 
    static XmDirection dir = XmDEFAULT_DIRECTION;
 
-   DEBUGOUT(XdbDebug(__FILE__, w, "_XmDirectionDefault\n"));
+   DEBUGOUT(_LtDebug(__FILE__, w, "_XmDirectionDefault\n"));
 
    value->addr = (char *) &dir;
    value->size = sizeof(XmDirection);
@@ -57,7 +60,9 @@ _XmGetLayoutDirection(Widget w)
    XmSpecifyLayoutDirectionTrait ptrait;
    XmDirection dir = XmDEFAULT_DIRECTION;
 
-   if ((ptrait = (XmSpecifyLayoutDirectionTrait) XmeTraitGet(XtClass(w), XmQTspecifyLayoutDirection))!= NULL)
+   if ((ptrait = (XmSpecifyLayoutDirectionTrait)
+                  XmeTraitGet((XtPointer)XtClass(w),
+		  XmQTspecifyLayoutDirection))!= NULL)
    {
       if(ptrait->get_direction != NULL)
       {
