@@ -1,9 +1,8 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/IconG.c,v 1.13 2001/07/27 18:55:20 dannybackx Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/IconG.c,v 1.24 2001/11/14 20:11:43 dannybackx Exp $
  *
- * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2001 LessTif Development Team
+ * Copyright  1997, 1998, 1999, 2000, 2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +22,7 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/IconG.c,v 1.13 2001/07/27 18:55:20 dannybackx Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/IconG.c,v 1.24 2001/11/14 20:11:43 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -43,6 +42,9 @@ static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/IconG.
 #include <Xm/XmosP.h>
 #include <X11/ShellP.h>
 
+#include <Xm/ContItemT.h>
+#include <Xm/ContainerP.h>
+
 #include <XmI/DebugUtil.h>
 
 
@@ -51,92 +53,56 @@ static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/IconG.
 #endif
 
 #ifndef IG_Font
-#define IG_Font(w) \
-       (((XmIconGadget)(w))->icong.cache->render_table)
+#define IG_Font(w)	(((XmIconGadget)(w))->icong.cache->render_table)
 #endif
 
 /* Forward Declarations */
 
 static void class_initialize(void);
-
 static void class_part_initialize(WidgetClass w_class);
-
 static void initialize(Widget request, Widget new_w,
 		       ArgList args, Cardinal *num_args);
-
 static void destroy(Widget w);
-
 static void resize(Widget w);
-
 static void expose(Widget w, XEvent *event, Region region);
-
 static XtGeometryResult query_geometry(Widget w,
 				       XtWidgetGeometry *proposed,
 				       XtWidgetGeometry *answer);
-
 static void get_values_hook(Widget w, ArgList args, Cardinal *num_args);
-
 static void input_dispatch(Widget gadget, XEvent *event, Mask event_mask);
-
-static Boolean set_values(Widget current, Widget request, Widget new_w,
+static Boolean SetValues(Widget current, Widget request, Widget new_w,
 			  ArgList args, Cardinal *num_args);
-
 static void secondary_object_create(Widget request, Widget new_w,
 				    ArgList args, Cardinal *num_args);
-
 static void initialize_prehook(Widget request,
 			       Widget new_w, ArgList args, Cardinal *num_args);
-
 static void initialize_posthook(Widget request,
 				Widget new_w, ArgList args, Cardinal *num_args);
-
 static Boolean set_values_prehook(Widget old, Widget request, Widget new_w,
 				  ArgList args, Cardinal *num_args);
-
 static Boolean set_values_posthook(Widget old, Widget request, Widget new_w,
 				   ArgList args, Cardinal *num_args);
-
 static void get_values_prehook(Widget new_w, ArgList args, Cardinal *num_args);
-
 static void get_values_posthook(Widget new_w, ArgList args, Cardinal *num_args);
-
 static Cardinal get_sec_res_data(WidgetClass wc,
 				 XmSecondaryResourceData **data);
-
 static void export_label_string(Widget w, int offset, XtArgVal *value);
 
 
-#if 0
-static void Arm(Widget w, XEvent *event,
-		String *params, Cardinal *num_params);
+static int _XmIconCacheCompare(XtPointer A, XtPointer B);
+static void _XmCalcIconGDimensions(Widget w);
 
-static void Activate(Widget w, XEvent *event,
-		     String *params, Cardinal *num_params);
+/*
+ * Container Item trait
+ */
+static void _ContainerItemGetValues(Widget w, XmContainerItemData d);
+static void _ContainerItemSetValues(Widget w, XmContainerItemData d);
 
-static void Disarm(Widget w, XEvent *event,
-		   String *params, Cardinal *num_params);
-
-static void ArmAndActivate(Widget w, XEvent *event,
-			   String *params, Cardinal *num_params);
-
-static void Help(Widget w, XEvent *event,
-		 String *params, Cardinal *num_params);
-
-static void EnterWindow(Widget w, XEvent *event,
-			String *params, Cardinal *num_params);
-
-static void LeaveWindow(Widget w, XEvent *event,
-			String *params, Cardinal *num_params);
-
-static void ButtonUp(Widget w, XEvent *event,
-		     String *params, Cardinal *num_params);
-
-static void ButtonDown(Widget w, XEvent *event,
-		       String *params, Cardinal *num_params);
-#endif
-
-
-int _XmIconCacheCompare(XtPointer A, XtPointer B);
+static XmContainerItemTraitRec _ContainerItemTrait = {
+	/* version */		0,
+	/* setvalues */		_ContainerItemGetValues,
+	/* getvalues */		_ContainerItemSetValues
+};
 
 /*
  * resources
@@ -201,7 +167,7 @@ static XtResource cache_resources[] =
     },
 };
 
-/* *INDENT-OFF* */
+
 XmIconGCacheObjClassRec xmIconGCacheObjClassRec = {
     /* Object class part */
     {
@@ -307,6 +273,7 @@ static XtResource resources[] = {
     },
 };
 
+
 static XmSyntheticResource syn_resources[] = {
     {
 	XmNlabelString,
@@ -315,6 +282,7 @@ static XmSyntheticResource syn_resources[] = {
     }
 };
 
+
 static XmCacheClassPart cache_part = {
     /* cache head part */
     {
@@ -360,6 +328,7 @@ static XmGadgetClassExtRec _XmIconGadgetClassExtRec = {
     /* size                      */ sizeof(XmGadgetClassExtRec),
     /* widget_baseline_proc      */ NULL,
     /* display_rect_proc         */ NULL,
+    /* margins proc              */ NULL
 };
 
 XmIconGadgetClassRec xmIconGadgetClassRec = {
@@ -386,7 +355,7 @@ XmIconGadgetClassRec xmIconGadgetClassRec = {
 	/* destroy               */ destroy,
 	/* resize                */ resize,
 	/* expose                */ expose,
-	/* set_values            */ set_values,
+	/* set_values            */ SetValues,
 	/* set_values_hook       */ NULL,
 	/* set_values_almost     */ XtInheritSetValuesAlmost,
 	/* get_values_hook       */ get_values_hook,
@@ -412,10 +381,10 @@ XmIconGadgetClassRec xmIconGadgetClassRec = {
     },
     /* XmIconGadget part */
     {
-	/* extension          */ NULL, 
+	/* extension          */ NULL,
+	                         NULL
     },
 };
-/* *INDENT-ON* */
 
 WidgetClass xmIconGadgetClass = (WidgetClass)&xmIconGadgetClassRec;
 
@@ -473,7 +442,8 @@ secondary_object_create(Widget request, Widget new_w,
     IG_Cache(request) = &(((XmIconGCacheObject)rsec)->icon_cache);
 }
 
-int
+
+static int
 _XmIconCacheCompare(XtPointer A, XtPointer B)
 {
     return !memcmp(((XmIconGCacheObjPart *)A),
@@ -526,14 +496,22 @@ class_initialize(void)
     xmIconGCacheObjClassRec.object_class.resources = combined;
     xmIconGCacheObjClassRec.object_class.num_resources = ncom;
 #endif
+
+    if (! XmeTraitSet((XtPointer)xmIconGadgetClass, XmQTcontainerItem,
+			(XtPointer)&_ContainerItemTrait)) {
+	_XmWarning(NULL, "XmIconGadget ClassInitialize: XmeTraitSet failed\n");
+    }
+
 }
 
+
 static void
 class_part_initialize(WidgetClass widget_class)
 {
     _XmFastSubclassInit(widget_class, XmICON_GADGET_BIT);
 }
 
+
 static void
 CreateNormalGC(Widget w)
 {
@@ -553,6 +531,7 @@ CreateNormalGC(Widget w)
     IG_NormalGC(w) = XtGetGC(w, mask, &values);
 }
 
+
 #if 0
 static void
 CreateBackgroundGC(Widget w)
@@ -607,53 +586,66 @@ initialize_posthook(Widget request, Widget new_w,
     XtFree((char *)ext);
 }
 
-void
+static void
 _XmCalcIconGDimensions(Widget w)
 {
-Dimension TextHeight, TextWidth;
-unsigned int IconHeight, IconWidth;
+	Dimension TextHeight, TextWidth;
+	unsigned int IconHeight, IconWidth;
+	unsigned int tmp;
+	int tmpx,tmpy;
+	Window tmpwin;
+	unsigned Depth;
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "_XmCalcIconGDimensions\n"));
-    if (_XmStringIsXmString((XmString)IG_LabelString(w)))
-    {
-	IG_LabelString(w) = (XmString)_XmStringCreate((XmString)IG_LabelString(w));
-    }
 
-    _XmStringExtent(IG_Font(w),
-		    (_XmString) IG_LabelString(w),
-		    &TextWidth,
-		    &TextHeight);
-    DEBUGOUT(_LtDebug(__FILE__, w, "\t Text width %d height %d\n",
-    		TextWidth, TextHeight));
+	DEBUGOUT(_LtDebug(__FILE__, w, "_XmCalcIconGDimensions\n"));
 
-    {
-    unsigned int tmp;
-    int tmpx,tmpy;
-    Window tmpwin;
-    unsigned Depth;
+	if (_XmStringIsXmString((XmString)IG_LabelString(w))) {
+		IG_LabelString(w) =
+			(XmString)_XmStringCreate((XmString)IG_LabelString(w));
+	}
 
-    XGetGeometry(XtDisplayOfObject(w),
-		 IG_SmallIconPixmap(w),
-		 &tmpwin,
-		 &tmpx, &tmpy,
-		 &IconWidth, &IconHeight,
-		 &tmp, &Depth);
-    }
-    DEBUGOUT(_LtDebug(__FILE__, w, "\t Icon width %d height %d\n",
-    		IconWidth, IconHeight));
+	_XmStringExtent(IG_Font(w),
+		(_XmString) IG_LabelString(w),
+		&TextWidth, &TextHeight);
 
-    XtWidth(w) = TextWidth + IconWidth
-	    + 2 * (G_ShadowThickness(w) 
-	    + G_HighlightThickness(w));
-    XtHeight(w) = TextHeight > IconHeight ? TextHeight : IconHeight
-	    + 2 * G_HighlightThickness(w);
-    DEBUGOUT(_LtDebug(__FILE__, w, "\t width %d height %d\n",
-    		XtWidth(w), XtHeight(w)));
+	DEBUGOUT(_LtDebug(__FILE__, w, "\t Text width %d height %d\n", TextWidth, TextHeight));
+
+	/* Danny 28/8/2001 try to make this look at two types of Pixmap,
+	 * see E-mails on mailing list about Xplore 1.1 */
+	if (IG_ViewType(w) == XmSMALL_ICON && IG_SmallIconPixmap(w) != XmUNSPECIFIED_PIXMAP) {
+		XGetGeometry(XtDisplayOfObject(w), IG_SmallIconPixmap(w),
+			&tmpwin, &tmpx, &tmpy,
+			&IconWidth, &IconHeight,
+			&tmp, &Depth);
+	} else if (IG_ViewType(w) == XmLARGE_ICON && IG_LargeIconPixmap(w) != XmUNSPECIFIED_PIXMAP) {
+		XGetGeometry(XtDisplayOfObject(w), IG_LargeIconPixmap(w),
+			&tmpwin, &tmpx, &tmpy,
+			&IconWidth, &IconHeight,
+			&tmp, &Depth);
+#if 0
+	} else if (IG_IconPixmap(w) != XmUNSPECIFIED_PIXMAP) {
+		XGetGeometry(XtDisplayOfObject(w), IG_IconPixmap(w),
+			&tmpwin, &tmpx, &tmpy,
+			&IconWidth, &IconHeight,
+			&tmp, &Depth);
+#endif
+	} else {
+		IconWidth = IconHeight = 0;
+	}
+
+	DEBUGOUT(_LtDebug(__FILE__, w, "\t Icon width %d height %d\n", IconWidth, IconHeight));
+
+	XtWidth(w) = TextWidth + IconWidth
+		+ 2 * (G_ShadowThickness(w) + G_HighlightThickness(w));
+	XtHeight(w) = (TextHeight > IconHeight) ? TextHeight : IconHeight
+		+ 2 * G_HighlightThickness(w);
+
+	DEBUGOUT(_LtDebug(__FILE__, w, "\t width %d height %d\n", XtWidth(w), XtHeight(w)));
 }
 
+
 static void
-initialize(Widget request, Widget new_w,
-	   ArgList args, Cardinal *num_args)
+initialize(Widget request, Widget new_w, ArgList args, Cardinal *num_args)
 {
     DEBUGOUT(_LtDebug(__FILE__, new_w,
 		      "initialize: %i args\n"
@@ -668,14 +660,10 @@ initialize(Widget request, Widget new_w,
 
     /* get the default fontlist if the label was created without one. */
     /* this should come from the renderTable (whatever that is??) FIXME */
-    if (IG_Font(new_w) == (XmFontList)XmUNSPECIFIED ||
-	IG_Font(new_w) == NULL)
-    {
+    if (IG_Font(new_w) == (XmFontList)XmUNSPECIFIED || IG_Font(new_w) == NULL) {
 	IG_Font(new_w) = _XmGetDefaultFontList(new_w, XmLABEL_FONTLIST);
-    }
-    /* if the user specified one, COPY it */
-    else
-    {
+    } else {
+	/* if the user specified one, COPY it */
 	IG_Font(new_w) = XmFontListCopy(IG_Font(new_w));
     }
 
@@ -694,44 +682,34 @@ initialize(Widget request, Widget new_w,
 	IG_LabelString(new_w) = (XmString) _XmStringCreate(xmstring);
     }
 
-    if (_XmStringIsXmString((XmString)IG_LabelString(new_w)))
-    {
+    if (_XmStringIsXmString((XmString)IG_LabelString(new_w))) {
 	IG_LabelString(new_w) = (XmString) _XmStringCreate((XmString)IG_LabelString(new_w));
     }
 
     if (IG_LargeIconPixmap(new_w) != XmUNSPECIFIED_PIXMAP &&
-        IG_LargeIconMask(new_w) == XmUNSPECIFIED_PIXMAP)
-    {
+        IG_LargeIconMask(new_w) == XmUNSPECIFIED_PIXMAP) {
     }
 
     if (IG_SmallIconPixmap(new_w) != XmUNSPECIFIED_PIXMAP &&
-        IG_SmallIconMask(new_w) == XmUNSPECIFIED_PIXMAP)
-    {
+        IG_SmallIconMask(new_w) == XmUNSPECIFIED_PIXMAP) {
     }
 
-    if (IG_RenderTable(new_w) != (XmRenderTable)NULL)
-    {
+    if (IG_RenderTable(new_w) != (XmRenderTable)NULL) {
     }
 
-#if 0
-/* We do not have a container yet!!! */
-    if (XmIsContainerWidget(XtParent(new_w)) &&
-        (Container_EntryViewType(XtParent(new_w)) == XmLARGE_ICON ||
-         Container_EntryViewType(XtParent(new_w)) == XmSMALL_ICON))
-    {
-    	IG_ViewType(new_w) = Container_ViewType(XtParent(new_w));
+    if (XmIsContainer(XtParent(new_w)) &&
+		(ContainerEntryViewType(XtParent(new_w)) == XmLARGE_ICON ||
+		 ContainerEntryViewType(XtParent(new_w)) == XmSMALL_ICON)) {
+    	IG_ViewType(new_w) = ContainerEntryViewType(XtParent(new_w));
     }
-#endif
 
     /* have to check request since new_w may have been polluted by a
      * superclass 
      */
-    if (XtWidth(request) == (Dimension)0)
-    {
+    if (XtWidth(request) == (Dimension)0) {
 	XtWidth(new_w) = 0;
     }
-    if (XtHeight(request) == (Dimension)0)
-    {
+    if (XtHeight(request) == (Dimension)0) {
 	XtHeight(new_w) = 0;
     }
 
@@ -741,45 +719,37 @@ initialize(Widget request, Widget new_w,
     /*
      * the user might have wanted something.  Change it back, if so
      */
-    if (XtWidth(request) != 0)
-    {
+    if (XtWidth(request) != 0) {
 	XtWidth(new_w) = XtWidth(request);
     }
-    if (XtHeight(request) != 0)
-    {
+    if (XtHeight(request) != 0) {
 	XtHeight(new_w) = XtHeight(request);
     }
 
     /* surge protection */
-    if (XtWidth(new_w) == 0)
-    {
+    if (XtWidth(new_w) == 0) {
 	XtWidth(new_w) = 1;
     }
-    if (XtHeight(new_w) == 0)
-    {
+    if (XtHeight(new_w) == 0) {
 	XtHeight(new_w) = 1;
     }
 
     CreateNormalGC(new_w);
 
-    if (!XtIsSubclass(XtParent(new_w), xmManagerWidgetClass))
-    {
+    if (!XtIsSubclass(XtParent(new_w), xmManagerWidgetClass)) {
 	_XmError(new_w, "parent should be manager.");
     }
 
 #if 0
     if (LabG_Pixmap(new_w) == XmUNSPECIFIED_PIXMAP &&
-	IG_ArmPixmap(new_w) != XmUNSPECIFIED_PIXMAP)
-    {
+		IG_ArmPixmap(new_w) != XmUNSPECIFIED_PIXMAP) {
 
 	LabG_Pixmap(new_w) = IG_ArmPixmap(new_w);
 
-	if (XtWidth(request) == 0)
-	{
+	if (XtWidth(request) == 0) {
 	    XtWidth(new_w) = 0;
 	}
-	if (XtHeight(request) == 0)
-	{
+	if (XtHeight(request) == 0) {
 	    XtHeight(new_w) = 0;
 	}
 
@@ -790,15 +760,12 @@ initialize(Widget request, Widget new_w,
 
     IG_UnarmPixmap(new_w) = LabG_Pixmap(new_w);
 
-    if (IN_MENU(new_w))
-    {
+    if (IN_MENU(new_w)) {
 	LabG_Highlight(new_w) = 0;
 	/* FIX ME - I just added the line below because I think it belongs here;
 	 * not sure if it's right though. Danny 18/5/1996 */
 	G_TraversalOn(new_w) = True;
-    }
-    else
-    {
+    } else {
 	/* take care of the default button shadow stuff */
 	/*
 	 * This new code adjusts button size in two cases : when ShowAsDefault
@@ -817,22 +784,17 @@ initialize(Widget request, Widget new_w,
 	 * MLM
 	 */
 
-	if (IG_DefaultButtonShadowThickness(new_w) > 0)
-	{
+	if (IG_DefaultButtonShadowThickness(new_w) > 0) {
 	    IG_Compatible(new_w) = False;
-	}
-	else
-	{
+	} else {
 	    IG_Compatible(new_w) = True;
 	}
 
-	if (IG_Compatible(new_w))
-	{
+	if (IG_Compatible(new_w)) {
 	    IG_DefaultButtonShadowThickness(new_w) = IG_ShowAsDefault(new_w);
 	}
 
-	if (IG_DefaultButtonShadowThickness(new_w))
-	{
+	if (IG_DefaultButtonShadowThickness(new_w)) {
 	    margin = 2 * IG_DefaultButtonShadowThickness(new_w) + LabG_Shadow(new_w);
 	    margin_extra = Xm3D_ENHANCE_PIXEL;
 
@@ -867,15 +829,13 @@ resize(Widget w)
 {
     DEBUGOUT(_LtDebug(__FILE__, w,"resize\n"));
 
-    if (!XmIsLabelGadget(w))
-    {
+    if (!XmIsLabelGadget(w)) {
 	return;
     }
 }
 
 static Boolean
-set_values_prehook(Widget old, Widget request, Widget new_w,
-		   ArgList args, Cardinal *num_args)
+set_values_prehook(Widget old, Widget request, Widget new_w, ArgList args, Cardinal *num_args)
 {
     XmBaseClassExt *bce;
     XmWidgetExtData ed;
@@ -986,25 +946,37 @@ set_values_posthook(Widget old, Widget request, Widget new_w,
     return False;
 }
 
+/*
+ * FIX ME
+ */
 static Boolean
-set_values(Widget old, Widget request, Widget new_w,
-	   ArgList args, Cardinal *num_args)
+SetValues(Widget old, Widget request, Widget new_w, ArgList args, Cardinal *num_args)
 {
-    Boolean refresh_needed = False;
+	Boolean refresh_needed = False;
 
-    DEBUGOUT(_LtDebug(__FILE__, new_w,
-		      "set_values: %i args\n"
-		      "\t    old X %5i Y %5i W %5i H %5i\n"
-		      "\trequest X %5i Y %5i W %5i H %5i\n"
-		      "\t  new_w X %5i Y %5i W %5i H %5i\n",
-		      *num_args,
-		      XtX(old), XtY(old),
-		      XtWidth(old), XtHeight(old),
-		      XtX(request), XtY(request),
-		      XtWidth(request), XtHeight(request),
-		      XtX(new_w), XtY(new_w),
-		      XtWidth(new_w), XtHeight(new_w)));
-    DEBUGOUT(_LtDebugPrintArgList(__FILE__, new_w, args, *num_args, False));
+	DEBUGOUT(_LtDebug(__FILE__, new_w,
+		"set_values: %i args\n"
+			"\t    old X %5i Y %5i W %5i H %5i\n"
+			"\trequest X %5i Y %5i W %5i H %5i\n"
+			"\t  new_w X %5i Y %5i W %5i H %5i\n",
+		*num_args,
+		XtX(old), XtY(old),
+		XtWidth(old), XtHeight(old),
+		XtX(request), XtY(request),
+		XtWidth(request), XtHeight(request),
+		XtX(new_w), XtY(new_w),
+		XtWidth(new_w), XtHeight(new_w)));
+	DEBUGOUT(_LtDebugPrintArgList(__FILE__, new_w, args, *num_args, False));
+
+	if (IG_VisualEmphasis(new_w) != IG_VisualEmphasis(old)) {
+		refresh_needed = True;
+	}
+	if (IG_ViewType(new_w) != IG_ViewType(old)) {
+		refresh_needed = True;
+	}
+	if (IG_DetailCount(new_w) != IG_DetailCount(old)) {
+		refresh_needed = True;
+	}
 
 #if 0
     if (IG_ArmColor(new_w) != IG_ArmColor(old))
@@ -1161,9 +1133,10 @@ set_values(Widget old, Widget request, Widget new_w,
     }
 #endif
 
-    return refresh_needed;
+	return refresh_needed;
 }
 
+
 static void
 get_values_prehook(Widget new_w, ArgList args, Cardinal *num_args)
 {
@@ -1213,6 +1186,7 @@ get_values_prehook(Widget new_w, ArgList args, Cardinal *num_args)
     _XmExtGetValuesHook((Widget)nsec, args, num_args);
 }
 
+
 static void
 get_values_posthook(Widget new_w, ArgList args, Cardinal *num_args)
 {
@@ -1225,12 +1199,17 @@ get_values_posthook(Widget new_w, ArgList args, Cardinal *num_args)
     XtFree((char *)ext);
 }
 
+
 static void
 get_values_hook(Widget w, ArgList args, Cardinal *num_args)
 {
     DEBUGOUT(_LtDebug(__FILE__, w, "GetValuesHook\n"));
 }
 
+
+/*
+ * FIX ME how about IG_VisualEmphasis ?
+ */
 static void
 expose(Widget w, XEvent *event, Region region)
 {
@@ -1240,6 +1219,10 @@ expose(Widget w, XEvent *event, Region region)
     unsigned int IconHeight, IconWidth;
     XRectangle cliprect;
     GC myGC;
+    unsigned int tmp;
+    int tmpx,tmpy;
+    Window tmpwin;
+    unsigned Depth;
 
     DEBUGOUT(_LtDebug(__FILE__, w, "expose\n"));
     /*
@@ -1262,7 +1245,7 @@ expose(Widget w, XEvent *event, Region region)
     cliprect.x = XtX(w) + G_HighlightThickness(w) + G_ShadowThickness(w);
     cliprect.y = XtY(w) + G_HighlightThickness(w) /*+ G_ShadowThickness(w)*/;
     cliprect.width = XtWidth(w) -
-	2 * (G_ShadowThickness(w) + G_HighlightThickness(w));
+	2 * (/* G_ShadowThickness(w) + */ G_HighlightThickness(w));
     cliprect.height = XtHeight(w) -
 	2 * (/*G_ShadowThickness(w) +*/ G_HighlightThickness(w));
 
@@ -1271,24 +1254,17 @@ expose(Widget w, XEvent *event, Region region)
     		cliprect.x, cliprect.y,
     		cliprect.width, cliprect.height));
 
-    {
-    unsigned int tmp;
-    int tmpx,tmpy;
-    Window tmpwin;
-    unsigned Depth;
-
-    XGetGeometry(XtDisplayOfObject(w),
-		 IG_SmallIconPixmap(w),
-		 &tmpwin,
-		 &tmpx, &tmpy,
-		 &IconWidth, &IconHeight,
-		 &tmp, &Depth);
+    if (IG_ViewType(w) == XmSMALL_ICON && IG_SmallIconPixmap(w) != XmUNSPECIFIED_PIXMAP) {
+	XGetGeometry(XtDisplayOfObject(w), IG_SmallIconPixmap(w), &tmpwin,
+		 &tmpx, &tmpy, &IconWidth, &IconHeight, &tmp, &Depth);
+    } else if (IG_ViewType(w) == XmLARGE_ICON && IG_LargeIconPixmap(w) != XmUNSPECIFIED_PIXMAP) {
+	XGetGeometry(XtDisplayOfObject(w), IG_LargeIconPixmap(w), &tmpwin,
+		 &tmpx, &tmpy, &IconWidth, &IconHeight, &tmp, &Depth);
+    } else {
+	IconWidth = IconHeight = 0;
     }
 
-    _XmStringExtent(IG_Font(w),
-		    (_XmString) IG_LabelString(w),
-		    &TextWidth,
-		    &TextHeight);
+    _XmStringExtent(IG_Font(w), (_XmString) IG_LabelString(w), &TextWidth, &TextHeight);
 
     switch (IG_ViewType(w))
     {
@@ -1302,14 +1278,15 @@ expose(Widget w, XEvent *event, Region region)
 	break;
     }
 
-    XCopyArea(XtDisplay(w),
-		  IG_SmallIconPixmap(w),
-		  XtWindow(w),
-		  myGC,
-		  0,
-		  0,
-		  IconWidth, IconHeight,
-		  IconX, IconY);
+    if (IG_ViewType(w) == XmSMALL_ICON && IG_SmallIconPixmap(w) != XmUNSPECIFIED_PIXMAP) {
+	XCopyArea(XtDisplay(w), IG_SmallIconPixmap(w), XtWindow(w), myGC,
+		0, 0, IconWidth, IconHeight, IconX, IconY);
+    } else if (IG_ViewType(w) == XmLARGE_ICON && IG_LargeIconPixmap(w) != XmUNSPECIFIED_PIXMAP) {
+	XCopyArea(XtDisplay(w), IG_LargeIconPixmap(w), XtWindow(w), myGC,
+		0, 0, IconWidth, IconHeight, IconX, IconY);
+    } else {
+	/* ?? */
+    }
 
     _XmStringDraw(XtDisplayOfObject(w),
 		  XtWindowOfObject(w),
@@ -1336,6 +1313,7 @@ expose(Widget w, XEvent *event, Region region)
     XSetClipMask(XtDisplay(w), myGC, None);
 }
 
+
 static XtGeometryResult
 query_geometry(Widget w, XtWidgetGeometry *proposed, XtWidgetGeometry *answer)
 {
@@ -1392,6 +1370,7 @@ query_geometry(Widget w, XtWidgetGeometry *proposed, XtWidgetGeometry *answer)
     }
 }
 
+
 static Cardinal
 get_sec_res_data(WidgetClass wc, XmSecondaryResourceData **data)
 {
@@ -1401,455 +1380,6 @@ get_sec_res_data(WidgetClass wc, XmSecondaryResourceData **data)
 				    data, NULL, NULL, NULL, NULL);
 }
 
-#if 0
-static void
-Arm(Widget w, XEvent *event, String *params, Cardinal *num_params)
-{
-    XmPushButtonCallbackStruct cbs;
-    XtExposeProc exp = XtClass(w)->core_class.expose;
-
-    XmProcessTraversal(w, XmTRAVERSE_CURRENT);
-
-    IG_Armed(w) = True;
-
-    (*exp) (w, event, NULL);
-
-    if (IG_ArmCallback(w))
-    {
-	cbs.reason = XmCR_ARM;
-	cbs.event = event;
-	cbs.click_count = IG_ClickCount(w);
-
-	XFlush(XtDisplay(w));
-
-	XtCallCallbackList(w,
-			   IG_ArmCallback(w),
-			   (XtPointer)&cbs);
-    }
-}
-
-static void
-Disarm(Widget w, XEvent *event, String *params, Cardinal *num_params)
-{
-    XmPushButtonCallbackStruct cbs;
-    XtExposeProc exp = XtClass(w)->core_class.expose;
-
-    if (IG_Armed(w))
-    {
-	IG_Armed(w) = False;
-	(*exp) (w, event, NULL);
-    }
-
-    if (IG_DisarmCallback(w))
-    {
-	cbs.reason = XmCR_DISARM;
-	cbs.event = event;
-	cbs.click_count = IG_ClickCount(w);
-
-	XFlush(XtDisplay(w));
-	XtCallCallbackList(w,
-			   IG_DisarmCallback(w),
-			   (XtPointer)&cbs);
-    }
-}
-
-static void
-Activate(Widget w, XEvent *event, String *params, Cardinal *num_params)
-{
-    XmPushButtonCallbackStruct cbs;
-    XButtonEvent *ev = (XButtonEvent *)event;
-    XtExposeProc exp = XtClass(w)->core_class.expose;
-
-    DEBUGOUT(_LtDebug(__FILE__, w, "Activate\n"));
-
-    if (IG_Armed(w) == False)
-    {
-	return;
-    }
-
-    IG_Armed(w) = False;
-
-    (*exp) (w, event, NULL);
-
-    /*
-     * Having this test breaks accelerators. Danny
-     * MLM: Not having means PB's break if the button is released outside
-     * the widget after it is armed.
-     *
-     * Test refined so it doesn't fail for accelerators. -- Danny
-     */
-    if (ev->type == KeyPress || ev->type == KeyRelease
-	|| ((ev->x > XtX(w) && ev->x < XtX(w) + XtWidth(w))
-	    && (ev->y > XtY(w) && ev->y < XtY(w) + XtHeight(w))))
-    {
-
-	if (!LabG_SkipCallback(w) && IG_ActivateCallback(w))
-	{
-	    cbs.reason = XmCR_ACTIVATE;
-	    cbs.event = event;
-	    cbs.click_count = IG_ClickCount(w);
-
-	    XFlush(XtDisplay(w));
-
-	    XtCallCallbackList(w,
-			       IG_ActivateCallback(w),
-			       (XtPointer)&cbs);
-	}
-    }
-
-    Disarm(w, event, params, num_params);
-}
-
-static void
-ArmTimeout(XtPointer data, XtIntervalId *id)
-{
-    XmPushButtonCallbackStruct cbs;
-    Widget w = (Widget)data;
-    XtExposeProc exp = XtClass(w)->core_class.expose;
-
-    DEBUGOUT(_LtDebug(__FILE__, w, "Activate\n"));
-
-    if (IG_Armed(w) == False)
-    {
-	return;
-    }
-
-    IG_Armed(w) = False;
-
-    (*exp) (w, NULL, NULL);
-
-    if (!LabG_SkipCallback(w) && IG_ActivateCallback(w))
-    {
-	cbs.reason = XmCR_ACTIVATE;
-	cbs.event = NULL;
-	cbs.click_count = IG_ClickCount(w);
-
-	XFlush(XtDisplay(w));
-
-	XtCallCallbackList(w,
-			   IG_ActivateCallback(w),
-			   (XtPointer)&cbs);
-    }
-
-    Disarm(w, NULL, NULL, 0);
-}
-
-static void
-ArmAndActivate(Widget w, XEvent *event, String *params, Cardinal *num_params)
-{
-    DEBUGOUT(_LtDebug(__FILE__, w, "ArmAndActivate\n"));
-
-    Arm(w, event, params, num_params);
-
-    IG_Timer(w) = XtAppAddTimeOut(XtWidgetToApplicationContext(w),
-				   ACTIVATE_DELAY, ArmTimeout, (XtPointer)w);
-}
-
-static void
-EnterWindow(Widget w,
-	    XEvent *event,
-	    String *params,
-	    Cardinal *num_params)
-{
-    /*
-    XmPushButtonCallbackStruct cbs;
-    XtExposeProc exp = XtClass(w)->core_class.expose;
-    */
-
-    DEBUGOUT(_LtDebug(__FILE__, w, "EnterWindow()\n"));
-
-#if 0
-    if (!IN_MENU(w))
-#endif
-    {
-	_XmEnterGadget(w, event, NULL, NULL);
-#if 0
-	if (IG_Armed(w))
-	{
-	    (*exp) (w, event, NULL);
-	}
-#endif
-    }
-#if 0
-    else
-	/* we're in a menu */
-    {
-	if (_XmGetInDragMode(w))
-	{
-	    ShellWidget popupShell;
-
-	    popupShell = (ShellWidget)_XmGetRC_PopupPosted(XtParent(w));
-	    if (popupShell)
-	    {
-		if (popupShell->shell.popped_up)
-		    (*xmLabelGadgetClassRec.label_class.menuProcs) (XmMENU_SHELL_POPDOWN,
-							    (Widget)popupShell,
-								    NULL,
-								    event,
-								    NULL);
-	    }
-
-	    IG_Armed(w) = True;
-
-	    (*exp) (w, event, NULL);
-
-	    MGR_SelectedGadget(XtParent(w)) = (XmGadget)w;
-
-	    if (IG_ArmCallback(w))
-	    {
-		cbs.reason = XmCR_ARM;
-		cbs.event = event;
-		cbs.click_count = IG_ClickCount(w);
-
-		XFlush(XtDisplay(w));
-
-		XtCallCallbackList(w,
-				   IG_ArmCallback(w),
-				   (XtPointer)&cbs);
-	    }
-	}
-    }
-#endif
-}
-
-static void
-LeaveWindow(Widget w, XEvent *event, String *params, Cardinal *num_params)
-{
-    /*
-    XmPushButtonCallbackStruct cbs;
-    XtExposeProc exp = XtClass(w)->core_class.expose;
-    */
-
-#if 0
-    if (!IN_MENU(w))
-#endif
-    {
-	_XmLeaveGadget(w, event, NULL, NULL);
-#if 0
-	if (IG_Armed(w))
-	{
-	    (*exp) (w, event, NULL);
-	}
-#endif
-    }
-#if 0
-    else
-	/* we're in a menu */
-    {
-	if (_XmGetInDragMode(w))
-	{
-	    IG_Armed(w) = False;
-
-	    (*exp) (w, event, NULL);
-
-	    MGR_SelectedGadget(XtParent(w)) = NULL;
-
-	    if (IG_DisarmCallback(w))
-	    {
-		cbs.reason = XmCR_DISARM;
-		cbs.event = event;
-		cbs.click_count = IG_ClickCount(w);
-
-		XFlush(XtDisplay(w));
-
-		XtCallCallbackList(w,
-				   IG_DisarmCallback(w),
-				   (XtPointer)&cbs);
-	    }
-	}
-    }
-#endif
-}
-#endif
-
-#if 0
-static void
-ButtonUp(Widget w, XEvent *event, String *params, Cardinal *num_params)
-{
-    Widget parent, shell;
-    Boolean validButton, poppedUp;
-    XmPushButtonCallbackStruct cbs;
-
-    DEBUGOUT(_LtDebug(__FILE__, w, "ButtonUp()\n"));
-
-    /* queue events until the next button event */
-    XAllowEvents(XtDisplay(w), SyncPointer, CurrentTime);
-
-    parent = XtParent(w);
-
-    shell = parent;
-    while (!XtIsShell(shell))
-	shell = XtParent(shell);
-
-    if (event && (event->type == ButtonRelease))
-    {
-	(*xmLabelGadgetClassRec.label_class.menuProcs) (XmMENU_BUTTON, parent,
-						    NULL, event, &validButton);
-    }
-
-    if (!validButton)
-    {
-	return;
-    }
-
-    if (!IG_Armed(w))
-    {
-	return;
-    }
-
-    IG_Armed(w) = False;
-
-#if 0
-    if (IN_MENU(w) && !XmIsMenuShell(shell))
-    {
-	(*xmLabelGadgetClassRec.label_class.menuProcs) (XmMENU_POPDOWN, w,
-							NULL, event, &poppedUp);
-    }
-    else
-#endif
-    {
-	(*xmLabelGadgetClassRec.label_class.menuProcs) (XmMENU_BUTTON_POPDOWN, w,
-							NULL, event, &poppedUp);
-    }
-
-    _XmRecordEvent(event);
-
-    if (poppedUp)
-#if 0
-/* rws 28 Mar 1997 Like pushb Why ?? */
-	return;
-#endif
-
-    _XmClearBorder(XtDisplay(w),
-		   XtWindow(w),
-		   LabG_Highlight(w),
-		   LabG_Highlight(w),
-		   XtWidth(w) - 2 * LabG_Highlight(w),
-		   XtHeight(w) - 2 * LabG_Highlight(w),
-		   LabG_Shadow(w));
-
-    if (!LabG_SkipCallback(w) && IG_ActivateCallback(w))
-    {
-	cbs.reason = XmCR_ACTIVATE;
-	cbs.event = event;
-	cbs.click_count = IG_ClickCount(w);
-
-	XFlush(XtDisplay(w));
-
-	XtCallCallbackList(w,
-			   IG_ActivateCallback(w),
-			   (XtPointer)&cbs);
-    }
-    if (IG_DisarmCallback(w))
-    {
-	cbs.reason = XmCR_DISARM;
-	cbs.event = event;
-	cbs.click_count = IG_ClickCount(w);
-
-	XFlush(XtDisplay(w));
-
-	XtCallCallbackList(w,
-			   IG_DisarmCallback(w),
-			   (XtPointer)&cbs);
-    }
-
-    _XmSetInDragMode(w, False);
-}
-
-
-static void
-ButtonDown(Widget w, XEvent *event, String *params, Cardinal *num_params)
-{
-    /* modified from the MegaButton widget */
-    ShellWidget popupShell;
-    int validButton;
-    XmPushButtonCallbackStruct cbs;
-
-    /* queue events until the next button event */
-    XAllowEvents(XtDisplay(w), SyncPointer, CurrentTime);
-
-    if (event && (event->type == ButtonPress))
-    {
-	(*xmLabelGadgetClassRec.label_class.menuProcs) (XmMENU_BUTTON,
-							XtParent(w),
-							NULL,
-							event,
-							&validButton);
-	if (!validButton)
-	{
-	    return;
-	}
-    }
-
-    _XmSetInDragMode(w, True);
-
-    MGR_SelectedGadget(XtParent(w)) = (XmGadget)w;
-
-    popupShell = (ShellWidget)_XmGetRC_PopupPosted(XtParent(w));
-    if (popupShell)
-    {
-	if (popupShell->shell.popped_up)
-	{
-	    (*xmLabelGadgetClassRec.label_class.menuProcs) (XmMENU_SHELL_POPDOWN,
-							    (Widget)popupShell,
-							    NULL,
-							    event,
-							    NULL);
-	}
-    }
-
-    _XmDrawShadows(XtDisplay(w),
-		   XtWindow(w),
-		   XmParentTopShadowGC(w),
-		   XmParentBottomShadowGC(w),
-		   XtX(w) + LabG_Highlight(w),
-		   XtY(w) + LabG_Highlight(w),
-		   XtWidth(w) - 2 * LabG_Highlight(w),
-		   XtHeight(w) - 2 * LabG_Highlight(w),
-		   LabG_Shadow(w),
-		   XmSHADOW_OUT);
-
-    if (!IG_Armed(w))
-    {
-	IG_Armed(w) = True;
-	if (IG_ArmCallback(w))
-	{
-	    cbs.reason = XmCR_DISARM;
-	    cbs.event = event;
-	    cbs.click_count = IG_ClickCount(w);
-
-	    XFlush(XtDisplay(w));
-
-	    XtCallCallbackList(w,
-			       IG_DisarmCallback(w),
-			       (XtPointer)&cbs);
-	}
-    }
-
-    _XmRecordEvent(event);
-}
-
-static void
-Help(Widget w, XEvent *event, String *params, Cardinal *num_params)
-{
-    Widget cur = w;
-    XmAnyCallbackStruct cbs;
-
-    cbs.reason = XmCR_HELP;
-    cbs.event = event;
-
-    while (cur != NULL)
-    {
-	if (XtHasCallbacks(w, XmNhelpCallback) == XtCallbackHasSome)
-	{
-	    XtCallCallbacks(w, XmNhelpCallback, (XtPointer)&cbs);
-	    return;
-	}
-	cur = XtParent(cur);
-    }
-}
-#endif
-
 static void
 input_dispatch(Widget gadget, XEvent *event, Mask event_mask)
 {
@@ -1960,6 +1490,7 @@ input_dispatch(Widget gadget, XEvent *event, Mask event_mask)
 #endif
 }
 
+
 static void
 export_label_string(Widget w, int offset, XtArgVal *value)
 {
@@ -1970,15 +1501,65 @@ export_label_string(Widget w, int offset, XtArgVal *value)
         : (XtArgVal)NULL;
 }
 
-void
-_XmClearIconCompatibility(Widget pbg)
-{
-}
 
 Widget
-XmCreateIconGadget(Widget parent, char *name,
-			 Arg *arglist, Cardinal argcount)
+XmCreateIconGadget(Widget parent, char *name, Arg *arglist, Cardinal argcount)
 {
     return XtCreateWidget(name, xmIconGadgetClass, parent,
 			  arglist, argcount);
 }
+
+static void _ContainerItemGetValues(Widget w, XmContainerItemData d)
+{
+	XmIconGadget	ig = (XmIconGadget)w;
+
+	DEBUGOUT(_LtDebug(__FILE__, w, "XmIconGadget _ContainerItemGetValues\n"));
+
+	if (d->valueMask & ContItemViewType) {
+		d->view_type = IG_ViewType(w);
+	}
+	if (d->valueMask & ContItemVisualEmphasis) {
+		d->visual_emphasis = IG_VisualEmphasis(w);
+	}
+	if (d->valueMask & ContItemIconWidth) {
+		/* FIX ME not sure which resource to read here */
+		d->icon_width = 0;
+	}
+	if (d->valueMask & ContItemDetailCount) {
+		d->detail_count = IG_DetailCount(w);
+	}
+}
+
+/*
+ * Trait function "SetValues" for ContainerItem trait.
+ * FIX ME the implementation is currently a quick hack.
+ */
+static void _ContainerItemSetValues(Widget w, XmContainerItemData d)
+{
+	Arg	al[4];
+	int	ac = 0;
+
+	DEBUGOUT(_LtDebug(__FILE__, w, "XmIconGadget _ContainerItemSetValues\n"));
+
+	if (d->valueMask & ContItemViewType) {
+		XtSetArg(al[ac], XmNviewType, d->view_type);
+		ac++;
+	}
+	if (d->valueMask & ContItemVisualEmphasis) {
+		XtSetArg(al[ac], XmNvisualEmphasis, d->visual_emphasis);
+		ac++;
+	}
+	if (d->valueMask & ContItemIconWidth) {
+		/* FIX ME not sure what to set ?? */
+#if 0
+		XtSetArg(al[ac], XmNiconWidth, d->icon_width);
+		ac++;
+#endif
+	}
+	if (d->valueMask & ContItemDetailCount) {
+		XtSetArg(al[ac], XmNdetailCount, d->detail_count);
+		ac++;
+	}
+
+	XtSetValues(w, al, ac);
+}
