@@ -1,10 +1,9 @@
-#undef	CREATE_SCROLLER_IN_REALIZE
-#define	LARGE_PAGE
 /**
  *
- * $Header: /cvsroot/hungry/lesstif/lib/Xm-2.0/Notebook.c,v 1.24 1999/09/19 16:34:13 rwscott Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/Notebook.c,v 1.39 2001/07/27 18:55:20 dannybackx Exp $
  *
  * Copyright (C) 1997-1998 Free Software Foundation, Inc.
+ * Copyright (C) 1998-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -24,8 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/hungry/lesstif/lib/Xm-2.0/Notebook.c,v 1.24 1999/09/19 16:34:13 rwscott Exp $";
-
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/Notebook.c,v 1.39 2001/07/27 18:55:20 dannybackx Exp $";
 
 /*
  * This is a widget whose main purpose is to do geometry management for its
@@ -51,15 +49,18 @@ static const char rcsid[] = "$Header: /cvsroot/hungry/lesstif/lib/Xm-2.0/Noteboo
  * XmPushButton, XmPushButtonGadget, XmArrowButton, XmArrowButtonGadget,
  * XmText, XmTextField, XmScrollBar, XmDrawnButton; and all their subclasses.
  */
+
+/* definitions used below */
+#define	LARGE_PAGE
 #define	TRAIT_WORKAROUND
 
 #include <LTconfig.h>
+
 #include <XmI/XmI.h>
 #include <Xm/XmP.h>
-#include <XmI/DebugUtil.h>
 
 #include <Xm/NotebookP.h>
-#include <XmI/XmXpm.h>
+#include <Xm/XpmP.h>
 
 /*
  * Traits used by Notebook
@@ -86,9 +87,12 @@ static const char rcsid[] = "$Header: /cvsroot/hungry/lesstif/lib/Xm-2.0/Noteboo
 #include <Xm/ScrollBar.h>
 #endif
 
+#include <XmI/DebugUtil.h>
+
+
 /* Forward Declarations */
 
-static void ClassInitialize();
+static void ClassInitialize(void);
 
 static void ClassPartInitialize(WidgetClass w_class);
 
@@ -124,7 +128,7 @@ static Boolean ConstraintSetValues(Widget current, Widget request, Widget nw,
 		      ArgList args, Cardinal *num_args);
 static void _XmNBDefaultLastPageNumber(Widget w, int offset, XrmValue *val);
 static void _XmNBChangeGC(Widget w);
-static void Layout(Widget w /* ... */);
+static void Layout(Widget w);
 static void PreferredSize(Widget nb, Widget instig, XtWidgetGeometry *ig,
 		Dimension *widp, Dimension *htp);
 static void _XmNBFrameBackgroundDefault(Widget w, int offset, XrmValue *val);
@@ -385,7 +389,7 @@ static XtActionsRec actions[] =
 char _XmNotebook_defaultTranslations[] = "";
 char _XmNotebook_traversalTranslations[] = "";
 
-/* *INDENT-OFF* */
+
 static XmBaseClassExtRec _XmNotebookCoreClassExtRec = {
     /* next_extension            */ NULL,
     /* record_type               */ NULLQUARK,                             
@@ -501,24 +505,25 @@ XmNotebookClassRec xmNotebookClassRec = {
 	/* extension */ NULL,
     },
 };
-/* *INDENT-ON* */
+
 
 
 WidgetClass xmNotebookWidgetClass = (WidgetClass)&xmNotebookClassRec;
 
 static void
-ClassInitialize()
+ClassInitialize(void)
 {
     _XmNotebookCoreClassExtRec.record_type = XmQmotif;
 
-    if (! XmeTraitSet(xmNotebookWidgetClass, XmQTscrollFrame,
-		&_XmNBScrollFrameTraitRec)) {
+    if (! XmeTraitSet((XtPointer)xmNotebookWidgetClass, XmQTscrollFrame,
+		(XtPointer)&_XmNBScrollFrameTraitRec)) {
 	_XmWarning(NULL,
 		"XmNotebook ClassInitialize: XmeTraitSet failed\n");
     } 
 
 }
 
+
 static void
 ClassPartInitialize(WidgetClass widget_class)
 {
@@ -548,13 +553,14 @@ ClassPartInitialize(WidgetClass widget_class)
     _XmFastSubclassInit(widget_class, XmNOTEBOOK_BIT);
 }
 
+
 /*
  * Show the child indicated, don't show any other XmPAGE child.
  */
 static void
 _XmNotebookShowChild(Widget nb, Widget child, Widget status)
 {
-	int	i;
+	Cardinal i;
 
 	if (NBC_ChildType(child) != XmPAGE) {
 		_XmWarning(child, "XmNotebook : this child is not an XmPAGE\n");
@@ -570,7 +576,7 @@ _XmNotebookShowChild(Widget nb, Widget child, Widget status)
 				/* Move out of sight */
 				_XmMoveObject(c, -10000, -10000);	/* FIX ME */
 
-				DEBUGOUT(XdbDebug2(__FILE__, nb, c,
+				DEBUGOUT(_LtDebug2(__FILE__, nb, c,
 					"Move child out of sight\n"));
 			}
 		}
@@ -585,9 +591,9 @@ _XmNotebookShowChild(Widget nb, Widget child, Widget status)
 			/* y */	0,
 			/* w */	NB_PageWidth(nb),
 			/* h */	NB_PageHeight(nb),
-			/* bw */XtBorderWidth(child));
+			/* bw */	XtBorderWidth(child));
 
-		DEBUGOUT(XdbDebug2(__FILE__, nb, child, "Move child to %d %d sz %d %d\n",
+		DEBUGOUT(_LtDebug2(__FILE__, nb, child, "Move child to %d %d sz %d %d\n",
 			/* x */	NB_BindingWidth(nb) + NB_MarginWidth(nb),
 			/* y */	0,
 			/* w */	NB_PageWidth(nb),
@@ -603,9 +609,9 @@ _XmNotebookShowChild(Widget nb, Widget child, Widget status)
 			/* y */	NB_PageHeight(nb),
 			/* w */	NB_StatusWidth(nb),
 			/* h */	NB_StatusHeight(nb),
-			/* bw */XtBorderWidth(child));
+			/* bw */	XtBorderWidth(child));
 
-		DEBUGOUT(XdbDebug2(__FILE__, nb, status, "Move status to %d %d sz %d %d\n",
+		DEBUGOUT(_LtDebug2(__FILE__, nb, status, "Move status to %d %d sz %d %d\n",
 			/* x */	NB_BindingWidth(nb) + NB_MarginWidth(nb),
 			/* y */	NB_PageHeight(nb),
 			/* w */	NB_StatusWidth(nb),
@@ -615,10 +621,11 @@ _XmNotebookShowChild(Widget nb, Widget child, Widget status)
 	NB_ConstraintChild(nb) = child;
 }
 
+
 static void
 _XmNotebookShowPage(Widget w, int page, int reason, XEvent *evp)
 {
-	int				i;
+	Cardinal i;
 	XmNotebookCallbackStruct	cbs;
 	Widget				cl = NULL, status = 0;
 	XmNavigatorTrait		t;
@@ -638,21 +645,21 @@ _XmNotebookShowPage(Widget w, int page, int reason, XEvent *evp)
 	    if (NBC_ChildType(c) == XmPAGE && NBC_PageNumber(c) == page) {
 		cl = c;
 #if 0
-		DEBUGOUT(XdbDebug2(__FILE__, w, cl, "page child found\n"));
+		DEBUGOUT(_LtDebug2(__FILE__, w, cl, "page child found\n"));
 #endif
 	    }
 
 	    if (NBC_ChildType(c) == XmSTATUS_AREA && NBC_PageNumber(c) == page) {
 		status = c;
 #if 0
-		DEBUGOUT(XdbDebug2(__FILE__, w, status, "Status child found\n"));
+		DEBUGOUT(_LtDebug2(__FILE__, w, status, "Status child found\n"));
 #endif
 	    }
 	}
 
 	if (cl == NULL) {
 		/* What to do here ?? FIX ME */
-		DEBUGOUT(XdbDebug(__FILE__, w,
+		DEBUGOUT(_LtDebug(__FILE__, w,
 			"_XmNotebookShowPage(%d) : not found\n", page));
 		return;
 	}
@@ -675,7 +682,7 @@ _XmNotebookShowPage(Widget w, int page, int reason, XEvent *evp)
 	/*
 	 * Show the XmPAGE widget and the STATUS_AREA.
 	 */
-	DEBUGOUT(XdbDebug2(__FILE__, w, cl,
+	DEBUGOUT(_LtDebug2(__FILE__, w, cl,
 		"_XmNotebookShowPage nr %d\n", page));
 	_XmNotebookShowChild(w, cl, status);
 
@@ -683,7 +690,7 @@ _XmNotebookShowPage(Widget w, int page, int reason, XEvent *evp)
 	 * Use trait method to update XmPAGE_SCROLLER
 	 */
 	if (NB_Scroller(w)) {
-	    t = XmeTraitGet(XtClass(NB_Scroller(w)), XmQTnavigator);
+	    t = (XmNavigatorTrait)XmeTraitGet((XtPointer)XtClass(NB_Scroller(w)), XmQTnavigator);
 	    if (t) {
 		nd.valueMask = NavValue | NavMinimum | NavMaximum;
 		nd.value = &ndval;
@@ -699,17 +706,17 @@ _XmNotebookShowPage(Widget w, int page, int reason, XEvent *evp)
 	}
 }
 
+
 static void
 Initialize(Widget request, Widget nw,
 	   ArgList args, Cardinal *num_args)
 {
     Arg	*l, al[1];
 
-    DEBUGOUT(XdbDebug(__FILE__, nw,
+    DEBUGOUT(_LtDebug(__FILE__, nw,
 		      "Notebook initialize: w/h %d %d\n",
 		      XtWidth(nw), XtHeight(nw)));
 
-    NB_DynamicLastPageNum(nw) = False;
     NB_ScrollerChild(nw) = NULL;
 
     XtSetArg(al[0], XmNnotebookChildType, XmMINOR_TAB);
@@ -727,7 +734,7 @@ Initialize(Widget request, Widget nw,
 
     NB_Scroller(nw) = NULL;
 
-    XtFree((XtPointer)l);
+    XtFree((char *)l);
 
     NB_BackPageGc(nw) = NULL;
     NB_FrameGc(nw) = NULL;
@@ -747,7 +754,6 @@ Initialize(Widget request, Widget nw,
     XtHeight(nw) = 100;
 #endif
 
-#ifndef CREATE_SCROLLER_IN_REALIZE
     /*
      * The spec says this should happen in Realize() but that's a really odd
      *	and inconvenient place.
@@ -766,14 +772,36 @@ Initialize(Widget request, Widget nw,
 		xmTextFieldWidgetClass, NB_Scroller(nw), al, 2);
 
 	XtManageChild(NB_Scroller(nw));
+
+    } else {
+	XmNavigatorTrait		t;
+	XmNavigatorDataRec		nd;
+	XmTwoDIntRec			ndmin, ndmax, ndval;
+	/*
+	 * Update the scroller for first/last page
+	 * This also happens in SetValues().
+	 */
+	t = (XmNavigatorTrait)XmeTraitGet((XtPointer)XtClass(NB_Scroller(nw)), XmQTnavigator);
+	if (t) {
+		nd.valueMask = NavValue | NavMinimum | NavMaximum;
+		nd.value = &ndval;
+		nd.minimum = &ndmin;
+		nd.maximum = &ndmax;
+
+		ndval.x = 0;	/* FIX ME */
+		ndmin.x = NB_FirstPageNumber(nw);
+		ndmax.x = NB_LastPageNumber(nw);
+
+		t->setValue(NB_Scroller(nw), &nd, True);
+	}
     }
-#endif
 }
 
+
 static void
 destroy(Widget w)
 {
-	DEBUGOUT(XdbDebug(__FILE__, w, "Destroy\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "Destroy\n"));
 
 	XFreeColors(XtDisplay(w),
 		DefaultColormapOfScreen(XtScreenOfObject(w)),
@@ -781,6 +809,7 @@ destroy(Widget w)
 		0);	/* ??? FIX ME */
 }
 
+
 static Boolean
 SetValues(Widget old, Widget request, Widget nw,
 	   ArgList args, Cardinal *num_args)
@@ -788,7 +817,7 @@ SetValues(Widget old, Widget request, Widget nw,
     Boolean	need_refresh = False,
 		need_layout = False;
 
-    DEBUGOUT(XdbDebug(__FILE__, nw, "SetValues\n"));
+    DEBUGOUT(_LtDebug(__FILE__, nw, "SetValues\n"));
 
 #define	NE(x)	(x(nw) != x(old))
 
@@ -812,6 +841,32 @@ SetValues(Widget old, Widget request, Widget nw,
 	need_refresh = True;
     }
 
+    if (NE(NB_LastPageNumber)) {
+	NB_DynamicLastPageNum(nw) = False;
+    }
+
+    if (NE(NB_FirstPageNumber) || NE(NB_LastPageNumber)) {
+	XmNavigatorTrait		t;
+	XmNavigatorDataRec		nd;
+	XmTwoDIntRec			ndmin, ndmax;
+	/*
+	 * Use trait method to update XmPAGE_SCROLLER
+	 */
+	if (NB_Scroller(nw)) {
+	    t = (XmNavigatorTrait)XmeTraitGet((XtPointer)XtClass(NB_Scroller(nw)), XmQTnavigator);
+	    if (t) {
+		nd.valueMask = NavMinimum | NavMaximum;
+		nd.minimum = &ndmin;
+		nd.maximum = &ndmax;
+
+		ndmin.x = NB_FirstPageNumber(nw);
+		ndmax.x = NB_LastPageNumber(nw);
+
+		t->setValue(NB_Scroller(nw), &nd, True);
+	    }
+	}
+    }
+
     need_refresh = True;	/* FIX ME */
 
     return need_refresh;
@@ -819,6 +874,7 @@ SetValues(Widget old, Widget request, Widget nw,
 #undef	NE
 }
 
+
 static void
 draw_back_pages(Widget w)
 {
@@ -845,8 +901,10 @@ draw_back_pages(Widget w)
 		NB_BindingWidth(w) + NB_MarginWidth(w) + NB_PageWidth(w) + NB_BackPageSize(w) / 2,
 		NB_PageHeight(w) + NB_MarginHeight(w) + NB_StatusHeight(w) + NB_BackPageSize(w) / 2);
 #endif
+
 }
 
+
 static void
 draw_binding_pixmap(Widget w, Pixmap p)
 {
@@ -864,6 +922,7 @@ draw_binding_pixmap(Widget w, Pixmap p)
     return;
 }
 
+
 static void
 draw_binding(Widget w)
 {
@@ -896,12 +955,14 @@ draw_binding(Widget w)
     draw_binding_pixmap(w, p);
 }
 
+
 static void
 draw_frame(Widget w)
 {
    /* FIX ME: draw frame */
 }
 
+
     /* Now display other stuff */
 static void
 expose(Widget w, XEvent *event, Region region)
@@ -909,7 +970,7 @@ expose(Widget w, XEvent *event, Region region)
     if (! XtWindow(w))
 	return;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "Expose\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "Expose\n"));
 
     /* Display back page first */
     draw_back_pages(w);
@@ -923,36 +984,39 @@ expose(Widget w, XEvent *event, Region region)
     _XmRedisplayGadgets(w, event, region);
 }
 
+
 static void
 resize(Widget w)
 {
-	DEBUGOUT(XdbDebug(__FILE__, w, "Resize\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "Resize\n"));
 	if (XtIsRealized(w))
 		XClearArea(XtDisplay(w), XtWindow(w), 0, 0, 0, 0, False);
 	Layout(w);
 	_XmNotebookShowPage(w, NB_CurrentPageNumber(w), 0, NULL);
 }
 
+
 static void
 _XmNBTabCallback(Widget w, XtPointer client, XtPointer call)
 {
-	int			r = (int)client;
+	int			r = (int)(long)client;
 	XmAnyCallbackStruct	*cbp = (XmAnyCallbackStruct *)call;
 
-	DEBUGOUT(XdbDebug(__FILE__, w, "_XmNBTabCallback\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "_XmNBTabCallback\n"));
 
 	_XmNotebookShowPage(XtParent(w), NBC_PageNumber(w),
 		/* reason */	r,
 		/* event */	cbp->event);
 }
 
+
 static void
 _XmNBPageScrollerCallback(Widget w, XtPointer client, XtPointer call)
 {
 	int			r, page, oldpage;
 	XmSpinBoxCallbackStruct	*cbp = (XmSpinBoxCallbackStruct *)call;
 
-	DEBUGOUT(XdbDebug(__FILE__, w, "_XmNBPageScrollerCallback\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "_XmNBPageScrollerCallback\n"));
 
 	/*
 	 * Figure out whether we increment or decrement,
@@ -988,6 +1052,7 @@ _XmNBPageScrollerCallback(Widget w, XtPointer client, XtPointer call)
 		/* event */	cbp->event);
 }
 
+
 /*
  * Major tabs should only show if they represent a page,
  * which is not yet represented by a minor tab.
@@ -1035,6 +1100,7 @@ MajorTabsActive(Widget n)
 	return change;
 }
 
+
 static void
 ConstraintInitialize(Widget request, Widget nw,
 		      ArgList args, Cardinal *num_args)
@@ -1042,45 +1108,45 @@ ConstraintInitialize(Widget request, Widget nw,
     Widget nb = XtParent(nw);
     XtPointer	t;
 
-    DEBUGOUT(XdbDebug2(__FILE__, nb, nw, "ConstraintInitialize\n"));
+    DEBUGOUT(_LtDebug2(__FILE__, nb, nw, "ConstraintInitialize\n"));
 
     if (NBC_ChildType(nw) == XmNONE) {
 	/* Assign a default child type. */
-	if (XmeTraitGet(XtClass(nw), XmQTaccessTextual) != NULL) {
+	if (XmeTraitGet((XtPointer)XtClass(nw), XmQTaccessTextual) != NULL) {
 		NBC_ChildType(nw) = XmSTATUS_AREA;
 		NBC_Active(nw) = False;
-		DEBUGOUT(XdbDebug2(__FILE__, nb, nw, "is a XmSTATUS_AREA\n"));
-	} else if (XmeTraitGet(XtClass(nw), XmQTactivatable) != NULL) {
+		DEBUGOUT(_LtDebug2(__FILE__, nb, nw, "is a XmSTATUS_AREA\n"));
+	} else if (XmeTraitGet((XtPointer)XtClass(nw), XmQTactivatable) != NULL) {
 		NBC_ChildType(nw) = XmMAJOR_TAB;
 		NBC_Active(nw) = False;
-		DEBUGOUT(XdbDebug2(__FILE__, nb, nw, "is a XmMAJOR_TAB\n"));
-	} else if (XmeTraitGet(XtClass(nw), XmQTnavigator) != NULL) {
+		DEBUGOUT(_LtDebug2(__FILE__, nb, nw, "is a XmMAJOR_TAB\n"));
+	} else if (XmeTraitGet((XtPointer)XtClass(nw), XmQTnavigator) != NULL) {
 		NBC_ChildType(nw) = XmPAGE_SCROLLER;
 		NBC_Active(nw) = False;
-		DEBUGOUT(XdbDebug2(__FILE__, nb, nw, "is a XmPAGE_SCROLLER\n"));
+		DEBUGOUT(_LtDebug2(__FILE__, nb, nw, "is a XmPAGE_SCROLLER\n"));
 		NB_Scroller(nb) = nw;
 #ifdef	TRAIT_WORKAROUND
 	} else if (XtIsSubclass(nw, xmTextWidgetClass)
 			|| XtIsSubclass(nw, xmTextFieldWidgetClass)) {
 		NBC_ChildType(nw) = XmSTATUS_AREA;
 		NBC_Active(nw) = False;
-		DEBUGOUT(XdbDebug2(__FILE__, nb, nw, "is a XmSTATUS_AREA\n"));
+		DEBUGOUT(_LtDebug2(__FILE__, nb, nw, "is a XmSTATUS_AREA\n"));
 	} else if (XtIsSubclass(nw, xmPushButtonWidgetClass)
 			|| XtIsSubclass(nw, xmPushButtonGadgetClass)
 			|| XtIsSubclass(nw, xmArrowButtonWidgetClass)
 			|| XtIsSubclass(nw, xmArrowButtonGadgetClass)) {
 		NBC_ChildType(nw) = XmMAJOR_TAB;
 		NBC_Active(nw) = False;
-		DEBUGOUT(XdbDebug2(__FILE__, nb, nw, "is a XmMAJOR_TAB\n"));
+		DEBUGOUT(_LtDebug2(__FILE__, nb, nw, "is a XmMAJOR_TAB\n"));
 	} else if (XtIsSubclass(nw, xmScrollBarWidgetClass)) {
 		NBC_ChildType(nw) = XmPAGE_SCROLLER;
 		NBC_Active(nw) = False;
-		DEBUGOUT(XdbDebug2(__FILE__, nb, nw, "is a XmPAGE_SCROLLER\n"));
+		DEBUGOUT(_LtDebug2(__FILE__, nb, nw, "is a XmPAGE_SCROLLER\n"));
 		NB_Scroller(nb) = nw;
 #endif
 	} else {
 		NBC_ChildType(nw) = XmPAGE;
-		DEBUGOUT(XdbDebug2(__FILE__, nb, nw, "is a XmPAGE\n"));
+		DEBUGOUT(_LtDebug2(__FILE__, nb, nw, "is a XmPAGE\n"));
 	}
     }
 
@@ -1092,15 +1158,15 @@ ConstraintInitialize(Widget request, Widget nw,
 	else
 		rc = XmCR_MINOR_TAB;
 
-	t = XmeTraitGet(XtClass(nw), XmQTactivatable);
+	t = XmeTraitGet((XtPointer)XtClass(nw), XmQTactivatable);
 	if (t)
 		((XmActivatableTrait)t)->changeCB(nw,
-			_XmNBTabCallback, (XtPointer)rc,
+			_XmNBTabCallback, (XtPointer)(long)rc,
 			True);	/* Add it */
 	else
 		_XmWarning(nw, "has no XmQTactivatable trait\n");
     } else if (NBC_ChildType(nw) == XmPAGE_SCROLLER) {
-	t = XmeTraitGet(XtClass(nw), XmQTnavigator);
+	t = XmeTraitGet((XtPointer)XtClass(nw), XmQTnavigator);
 	if (t) {
 		((XmNavigatorTrait)t)->changeMoveCB(nw,
 			_XmNBPageScrollerCallback, NULL,
@@ -1116,7 +1182,7 @@ ConstraintInitialize(Widget request, Widget nw,
 	 * number.
 	 */
 	if (NBC_PageNumber(nw) == 0) {
-	    int	i, pn;
+	    Cardinal i, pn;
 
 	    pn = 0;
 	    for (i=0; i<MGR_NumChildren(nb); i++) {
@@ -1133,15 +1199,17 @@ ConstraintInitialize(Widget request, Widget nw,
 	} else {
 	    /* FIX ME */
 
-	    if (NB_FirstPageNumber(nb) > NBC_PageNumber(nw))
+	}
+	if (NB_FirstPageNumber(nb) > NBC_PageNumber(nw)) {
 		NB_FirstPageNumber(nb) = NBC_PageNumber(nw);
-	    if (NB_LastPageNumber(nb) < NBC_PageNumber(nw))
+	}
+	if (NB_DynamicLastPageNum(nb) && (NB_LastPageNumber(nb) < NBC_PageNumber(nw))) {
 		NB_LastPageNumber(nb) = NBC_PageNumber(nw);
 	}
 
 	NB_LastAllocNum(nb) = NBC_PageNumber(nw);
 
-	DEBUGOUT(XdbDebug2(__FILE__, nb, nw, "Child has page no %d\n",
+	DEBUGOUT(_LtDebug2(__FILE__, nb, nw, "Child has page no %d\n",
 		NBC_PageNumber(nw)));
 
 	if (XtWidth(nw) > NB_PageWidth(nb))
@@ -1179,6 +1247,7 @@ ConstraintInitialize(Widget request, Widget nw,
     Layout(nb);
 }
 
+
 static Boolean
 ConstraintSetValues(Widget current, Widget request, Widget nw,
 		      ArgList args, Cardinal *num_args)
@@ -1188,7 +1257,7 @@ ConstraintSetValues(Widget current, Widget request, Widget nw,
 		need_layout = True;
 	Widget	nb = XtParent(nw);
 
-	DEBUGOUT(XdbDebug2(__FILE__, nb, nw, "ConstraintSetValues\n"));
+	DEBUGOUT(_LtDebug2(__FILE__, nb, nw, "ConstraintSetValues\n"));
 
 	/* This resource cannot be changed after creation */
 	if (NBC_ChildType(nw) != NBC_ChildType(current))
@@ -1203,6 +1272,7 @@ ConstraintSetValues(Widget current, Widget request, Widget nw,
 	return need_refresh;
 }
 
+
 /*
  * Calculate the preferred size for this widget.
  *
@@ -1216,7 +1286,7 @@ static void
 PreferredSize(Widget nb, Widget instig, XtWidgetGeometry *ig,
 		Dimension *widp, Dimension *htp)
 {
-	int		i;
+	Cardinal    i;
 	Dimension	wid = 0, ht = 0;
 	Dimension	vw, vh, hw, hh;
 	Dimension	verttabwid = 0, verttabht = 0,	/* vertical tab */
@@ -1238,7 +1308,7 @@ PreferredSize(Widget nb, Widget instig, XtWidgetGeometry *ig,
 			continue;
 
 		if (NBC_ChildType(child) == XmPAGE) {
-		    DEBUGOUT(XdbDebug2(__FILE__, nb, child,
+		    DEBUGOUT(_LtDebug2(__FILE__, nb, child,
 			"PreferredSize PAGE size %d %d\n",
 			XtWidth(child), XtHeight(child)));
 
@@ -1256,7 +1326,7 @@ PreferredSize(Widget nb, Widget instig, XtWidgetGeometry *ig,
 				    ht = XtHeight(child);
 			}
 		} else if (NBC_ChildType(child) == XmMAJOR_TAB) {
-		    DEBUGOUT(XdbDebug2(__FILE__, nb, child,
+		    DEBUGOUT(_LtDebug2(__FILE__, nb, child,
 			"PreferredSize MAJOR TAB size %d %d\n",
 			XtWidth(child), XtHeight(child)));
 
@@ -1276,7 +1346,7 @@ PreferredSize(Widget nb, Widget instig, XtWidgetGeometry *ig,
 			    hortabwid = XtWidth(child);
 		    }
 		} else if (NBC_ChildType(child) == XmMINOR_TAB) {
-		    DEBUGOUT(XdbDebug2(__FILE__, nb, child,
+		    DEBUGOUT(_LtDebug2(__FILE__, nb, child,
 			"PreferredSize MINOR TAB size %d %d\n",
 			XtWidth(child), XtHeight(child)));
 
@@ -1296,7 +1366,7 @@ PreferredSize(Widget nb, Widget instig, XtWidgetGeometry *ig,
 			    verttabwid = XtWidth(child);
 		    }
 		} else if (NBC_ChildType(child) == XmSTATUS_AREA) {
-		    DEBUGOUT(XdbDebug2(__FILE__, nb, child,
+		    DEBUGOUT(_LtDebug2(__FILE__, nb, child,
 			"PreferredSize STATUS AREA size %d %d\n",
 			XtWidth(child), XtHeight(child)));
 
@@ -1305,7 +1375,7 @@ PreferredSize(Widget nb, Widget instig, XtWidgetGeometry *ig,
 			if (saht < XtHeight(child))
 				saht = XtHeight(child);
 		} else if (NBC_ChildType(child) == XmPAGE_SCROLLER) {
-		    DEBUGOUT(XdbDebug2(__FILE__, nb, child,
+		    DEBUGOUT(_LtDebug2(__FILE__, nb, child,
 			"PreferredSize PAGE SCROLLER size %d %d\n",
 			XtWidth(child), XtHeight(child)));
 
@@ -1329,7 +1399,7 @@ PreferredSize(Widget nb, Widget instig, XtWidgetGeometry *ig,
 	NB_StatusWidth(nb) = sawid;
 	NB_StatusHeight(nb) = saht;
 
-	DEBUGOUT(XdbDebug(__FILE__, nb,
+	DEBUGOUT(_LtDebug(__FILE__, nb,
 		"PreferredSize: %d major tabs (%d x %d), %d minor tabs (%d x %d)\n",
 		nverttab, verttabwid, verttabht,
 		nhortab, hortabwid, hortabht));
@@ -1341,7 +1411,7 @@ PreferredSize(Widget nb, Widget instig, XtWidgetGeometry *ig,
 			+ 2 * NB_MarginHeight(nb);
 		vw = verttabwid + NB_MarginWidth(nb);
 
-		DEBUGOUT(XdbDebug(__FILE__, nb,
+		DEBUGOUT(_LtDebug(__FILE__, nb,
 			"PreferredSize: add %d %d for column of tabs\n",
 			vw, vh));
 
@@ -1354,7 +1424,7 @@ PreferredSize(Widget nb, Widget instig, XtWidgetGeometry *ig,
 			+ 2 * NB_MarginHeight(nb);
 		hw = hortabwid + NB_MarginWidth(nb);
 
-		DEBUGOUT(XdbDebug(__FILE__, nb,
+		DEBUGOUT(_LtDebug(__FILE__, nb,
 			"PreferredSize: add %d %d for row of tabs\n",
 			hw, hh));
 
@@ -1378,7 +1448,7 @@ PreferredSize(Widget nb, Widget instig, XtWidgetGeometry *ig,
 		NB_ScrollerWidth(nb) = XtWidth(NB_Scroller(nb));
 		NB_ScrollerHeight(nb) = XtHeight(NB_Scroller(nb));
 
-		DEBUGOUT(XdbDebug2(__FILE__, nb, NB_Scroller(nb),
+		DEBUGOUT(_LtDebug2(__FILE__, nb, NB_Scroller(nb),
 			"Page Scroller adds %d + 2 * %d to height\n",
 			XtHeight(NB_Scroller(nb)), NB_MarginHeight(nb)));
 	}
@@ -1396,20 +1466,21 @@ PreferredSize(Widget nb, Widget instig, XtWidgetGeometry *ig,
 	wid += NB_BindingWidth(nb) + NB_MarginWidth(nb) + NB_BackPageSize(nb);
 	ht += NB_BackPageSize(nb);
 
-	DEBUGOUT(XdbDebug(__FILE__, nb, "PreferredSize => %d %d\n", wid, ht));
+	DEBUGOUT(_LtDebug(__FILE__, nb, "PreferredSize => %d %d\n", wid, ht));
 
 	if (widp) *widp = wid;
 	if (htp) *htp = ht;
 }
 
+
 static void
-Layout(Widget w /* ... */)
+Layout(Widget w )
 {
-	int		i;
+	Cardinal	i;
 	Position	majx, majy;
 	Position	minx, miny;
 
-	DEBUGOUT(XdbDebug(__FILE__, w, "Layout (nb wid %d ht %d)\n",
+	DEBUGOUT(_LtDebug(__FILE__, w, "Layout (nb wid %d ht %d)\n",
 		XtWidth(w), XtHeight(w)));
 
 #ifdef LARGE_PAGE
@@ -1426,7 +1497,7 @@ Layout(Widget w /* ... */)
 	    else
 		NB_PageHeight(w) -= NB_BindingWidth(w);
 
-	    DEBUGOUT(XdbDebug(__FILE__, w, "Layout: set page size to %d %d\n",
+	    DEBUGOUT(_LtDebug(__FILE__, w, "Layout: set page size to %d %d\n",
 		NB_PageWidth(w), NB_PageHeight(w)));
 	}
 
@@ -1449,7 +1520,7 @@ Layout(Widget w /* ... */)
 		_XmMoveObject(child, majx, majy);
 		majy += XtHeight(child) + NB_MajorSpacing(w);
 	    } else if (NBC_ChildType(child) == XmMINOR_TAB) {
-		DEBUGOUT(XdbDebug2(__FILE__, w, child, "Layout: XmMINOR_TAB\n"));
+		DEBUGOUT(_LtDebug2(__FILE__, w, child, "Layout: XmMINOR_TAB\n"));
 		_XmMoveObject(child, minx, miny);
 		minx += XtWidth(child) + NB_MinorSpacing(w);
 /* HERE */
@@ -1458,37 +1529,40 @@ Layout(Widget w /* ... */)
 			NB_BindingWidth(w) + NB_MarginWidth(w) * 2 + NB_StatusWidth(w),
 			NB_PageHeight(w) + NB_MarginHeight(w));
 	    } else if (NBC_ChildType(child) == XmSTATUS_AREA) {
-		DEBUGOUT(XdbDebug2(__FILE__, w, child, "Layout: XmSTATUS_AREA\n"));
+		DEBUGOUT(_LtDebug2(__FILE__, w, child, "Layout: XmSTATUS_AREA\n"));
 	    } else {
 		/* XmPAGE treated elsewhere */
 	    }
 	}
 }
 
+
 static void
 InsertChild(Widget w)
 {
-	Widget	nb = XtParent(w);
+	/* Widget	nb = XtParent(w); */
 
-	DEBUGOUT(XdbDebug2(__FILE__, nb, w, "InsertChild\n"));
+	DEBUGOUT(_LtDebug2(__FILE__, XtParent(w), w, "InsertChild\n"));
 
 #define	superclass	(&xmManagerClassRec)
 	(*superclass->composite_class.insert_child)(w);
 #undef	superclass
 }
 
+
 static void
 DeleteChild(Widget w)
 {
-	Widget	nb = XtParent(w);
+	/* Widget	nb = XtParent(w); */
 
-	DEBUGOUT(XdbDebug2(__FILE__, nb, w, "DeleteChild\n"));
+	DEBUGOUT(_LtDebug2(__FILE__, XtParent(w), w, "DeleteChild\n"));
 
 #define	superclass	(&xmManagerClassRec)
 	(*superclass->composite_class.delete_child)(w);
 #undef	superclass
 }
 
+
 static XtGeometryResult
 QueryGeometry(Widget w, XtWidgetGeometry *proposed, XtWidgetGeometry *answer)
 {
@@ -1497,7 +1571,7 @@ QueryGeometry(Widget w, XtWidgetGeometry *proposed, XtWidgetGeometry *answer)
 
 #define	Wants(x)	((geo.request_mode & x) == x)
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "QueryGeometry\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "QueryGeometry\n"));
 
     geo = *proposed;
 
@@ -1521,6 +1595,7 @@ QueryGeometry(Widget w, XtWidgetGeometry *proposed, XtWidgetGeometry *answer)
     return XtGeometryYes;
 }
 
+
 static XtGeometryResult
 GeometryManager(Widget w,
 		 XtWidgetGeometry *request,
@@ -1533,11 +1608,12 @@ GeometryManager(Widget w,
 	XtWidgetGeometry	req, preq;
 #endif
 
-	DEBUGOUT(XdbDebug2(__FILE__, XtParent(w), w, "GeometryManager\n"));
+	DEBUGOUT(_LtDebug2(__FILE__, XtParent(w), w, "GeometryManager\n"));
 
 	return XtGeometryNo;
 }
 
+
 static void
 ChangeManaged(Widget w)
 {
@@ -1547,41 +1623,36 @@ ChangeManaged(Widget w)
 	(void)MajorTabsActive(w);
 	Layout(w);
 
-	DEBUGOUT(XdbDebug(__FILE__, w, "ChangeManaged\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "ChangeManaged\n"));
 }
 
-Widget
-XmCreateNotebook(Widget parent, char *name,
-		    Arg *arglist, Cardinal argcount)
-{
-	return XtCreateWidget(name, xmNotebookWidgetClass, parent,
-			  arglist, argcount);
-}
 
 static void
 TraverseTab(Widget w, XEvent *evp, String *par, Cardinal *npar)
 {
-	DEBUGOUT(XdbDebug(__FILE__, w, "TraverseTab\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "TraverseTab\n"));
 }
 
+
 static void
 _XmNBDefaultLastPageNumber(Widget w, int offset, XrmValue *val)
 {
-	DEBUGOUT(XdbDebug(__FILE__, w, "_XmNBDefaultLastPageNumber\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "_XmNBDefaultLastPageNumber\n"));
 
 	NB_DynamicLastPageNum(w) = True;
 	NB_LastPageNumber(w) = 1;
 }
 
+
 static void
 _XmNBCreateSpiralPixmap(Widget w)
 {
-	_LtXpmAttributes   attrib; 
+	XpmAttributes   attrib; 
         Pixmap          mask;
 
 	attrib.valuemask = 0;
 
-	_LtXpmCreatePixmapFromData(XtDisplay(w),
+	XpmCreatePixmapFromData(XtDisplay(w),
                 XRootWindowOfScreen(XtScreen(w)),
                 spiral,
                 &NB_SpiralPixmap(w),
@@ -1598,6 +1669,7 @@ _XmNBCreateSpiralPixmap(Widget w)
 	}
 }
 
+
 /*
  * Free the old Graphics Contexts (if any), and allocate new ones.
  *
@@ -1647,48 +1719,30 @@ _XmNBChangeGC(Widget w)
 	   _XmNBCreateSpiralPixmap(w);
 }
 
+
 static void
 Realize(Widget w, XtValueMask *value_mask, XSetWindowAttributes *attributes)
 {
-    DEBUGOUT(XdbDebug(__FILE__, w, "Realize\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "Realize\n"));
 
 #define superclass (&xmManagerClassRec)
     (*superclass->core_class.realize) (w, value_mask, attributes);
 #undef superclass
 
-#ifdef	CREATE_SCROLLER_IN_REALIZE
-    /*
-     * This is an odd place to do this, but that's what the spec says.
-     */
-    if (NB_Scroller(w) == NULL) {
-	Arg	al[1];
-
-	NB_Scroller(w) = XtCreateWidget("PageScroller",
-		xmSpinBoxWidgetClass, w, NULL, 0);
-
-	/* FIX ME should we add a child to it ? */
-	XtSetArg(al[0], XmNspinBoxChildType, XmNUMERIC);
-
-	(void) XtCreateManagedWidget("TextField",
-		xmTextFieldWidgetClass, NB_Scroller(w), al, 1);
-
-	XtManageChild(NB_Scroller(w));
-    }
-#endif
-
     if (NB_SpiralPixmap(w) == XmUNSPECIFIED_PIXMAP)
 	   _XmNBCreateSpiralPixmap(w);
 
     Layout(w);
     _XmNotebookShowPage(w, 1, 0, NULL);
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "Realize (end)\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "Realize (end)\n"));
 }
 
+
 static void
 _XmNBFrameBackgroundDefault(Widget w, int offset, XrmValue *val)
 {
-    DEBUGOUT(XdbDebug(__FILE__, w, "_XmNBFrameBackgroundDefault\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "_XmNBFrameBackgroundDefault\n"));
 
     /*
      * The current solution is to copy the overall background colour
@@ -1697,6 +1751,7 @@ _XmNBFrameBackgroundDefault(Widget w, int offset, XrmValue *val)
     _XmBackgroundColorDefault(w, offset, val);
 }
 
+
 /*
  * This should be a lower intensity version of XmNframeBackground
  */
@@ -1726,41 +1781,80 @@ _XmNBBackPageBackgroundDefault(Widget w, int offset, XrmValue *val)
 	back.pixel = color.pixel;
     }
 
-    DEBUGOUT(XdbDebug(__FILE__, w,
+    DEBUGOUT(_LtDebug(__FILE__, w,
 	"_XmNBBackPageBackgroundDefault %d (%d,%d,%d) -> %d (%d,%d,%d)\n",
 	color.pixel, color.red, color.green, color.blue,
 	back.pixel, back.red, back.green, back.blue));
 
 
-    val->addr = (XtPointer)&back.pixel;
+    val->addr = (XPointer)&back.pixel;
 }
 
+
 static void
 _XmNBTraitInit(Widget sfw, XtCallbackProc moveCB, Widget sw)
 {
-	DEBUGOUT(XdbDebug(__FILE__, sfw, "_XmNBTraitInit\n"));
+	DEBUGOUT(_LtDebug(__FILE__, sfw, "_XmNBTraitInit\n"));
 }
 
+
 static Boolean
 _XmNBTraitGetInfo(Widget sfw,
 		Cardinal *dimension,
 		Widget **nav_list,
 		Cardinal *num_nav_list)
 {
-	DEBUGOUT(XdbDebug(__FILE__, sfw, "_XmNBTraitGetInfo\n"));
+	DEBUGOUT(_LtDebug(__FILE__, sfw, "_XmNBTraitGetInfo\n"));
 
 	/* FIX ME unimplemented */
 	return False;
 }
 
+
 static void
 _XmNBTraitAddNavigator(Widget sfw, Widget nw, Mask dimMask)
 {
-	DEBUGOUT(XdbDebug(__FILE__, sfw, "_XmNBTraitAddNavigator\n"));
+	DEBUGOUT(_LtDebug(__FILE__, sfw, "_XmNBTraitAddNavigator\n"));
 }
 
+
 static void
 _XmNBTraitRemoveNavigator(Widget sfw, Widget nw)
 {
-	DEBUGOUT(XdbDebug(__FILE__, sfw, "_XmNBTraitRemoveNavigator\n"));
+	DEBUGOUT(_LtDebug(__FILE__, sfw, "_XmNBTraitRemoveNavigator\n"));
+}
+
+
+/* public interfaces */
+
+extern Widget
+XmCreateNotebook(Widget parent, char *name,
+		    Arg *arglist, Cardinal argcount)
+{
+	return XtCreateWidget(name, xmNotebookWidgetClass, parent,
+			  arglist, argcount);
+}
+
+
+extern XmNotebookPageStatus
+XmNotebookGetPageInfo(Widget w,
+                      int page_number,
+                      XmNotebookPageInfo *page_info)
+{
+	Cardinal i;
+	Widget cl=NULL;
+
+	_XmWarning(w, "XmNotebookGetPageInfo() is not yet implemented\n");
+
+	/* amai: no, this is not the correct code, but makes the compiler happy */
+	for (i=0; i<MGR_NumChildren(w); i++) {
+	    Widget c = MGR_Children(w)[i];
+
+	    if (NBC_ChildType(c) == XmPAGE && NBC_PageNumber(c) == page_number)
+		cl = c;
+       }
+	if (cl)
+		return XmPAGE_FOUND;
+	else
+		return XmPAGE_INVALID;
 }
