@@ -1,8 +1,9 @@
 /**
  *
- * $Header: /cvsroot/hungry/lesstif/lib/Xm-2.0/SpinBox.c,v 1.23 1999/01/21 22:36:04 danny Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/SpinBox.c,v 1.41 2001/09/12 19:43:52 dannybackx Exp $
  *
- * Copyright (C) 1997-1998 Free Software Foundation, Inc.
+ * Copyright (C) 1997, 1998 Free Software Foundation, Inc.
+ * Copyright  1998, 1999, 2000, 2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,27 +23,28 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/hungry/lesstif/lib/Xm-2.0/SpinBox.c,v 1.23 1999/01/21 22:36:04 danny Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/SpinBox.c,v 1.41 2001/09/12 19:43:52 dannybackx Exp $";
+
+#include <LTconfig.h>
 
 #include <stdio.h>
-#include <LTconfig.h>
+#include <stdlib.h>
+
 #include <XmI/XmI.h>
 #include <Xm/XmP.h>
-#include <XmI/DebugUtil.h>
-
 #include <Xm/SpinBP.h>
-
 #include <Xm/Text.h>
 #include <Xm/TextF.h>
-
 #include <Xm/TraitP.h>
 #include <Xm/AccTextT.h>
 #include <Xm/NavigatorT.h>
 #include <Xm/ScrollFrameT.h>
 
+#include <XmI/DebugUtil.h>
+
 /* Forward Declarations */
 
-static void class_initialize();
+static void class_initialize(void);
 
 static void class_part_initialize(WidgetClass w_class);
 
@@ -112,6 +114,11 @@ static XtResource resources[] =
 	sizeof(unsigned char), Offset(arrow_layout),
 	XmRImmediate, (XtPointer)XmARROWS_END
     },
+    {
+	XmNarrowOrientation, XmCArrowOrientation, XmRArrowOrientation,
+	sizeof(unsigned char), Offset(arrow_orientation),
+	XmRImmediate, (XtPointer)XmARROWS_VERTICAL
+    },
     {
 	XmNarrowSize, XmCArrowSize, XmRArrowSize,
 	sizeof(Dimension), Offset(arrow_size),
@@ -198,6 +205,9 @@ static XtActionsRec actions[] =
 	{"SpinBoxFocusOut",	SpinBoxFocusOut}
 };
 
+/*
+ * Constraint resources, i.e. resources magically added to all XmSpinBox children.
+ */
 #define Offset(field) XtOffsetOf(XmSpinBoxConstraintRec, spinBox.field)
 static XtResource ConstraintResources[] = {
     {
@@ -235,6 +245,11 @@ static XtResource ConstraintResources[] = {
 	sizeof(int), Offset(position),
 	XmRImmediate, (XtPointer)0
     },
+    {
+	XmNpositionType, XmCPositionType, XmRChar,
+	sizeof(unsigned char), Offset(position_type),
+	XmRImmediate, (XtPointer)XmPOSITION_VALUE
+    },
     {
 	XmNspinBoxChildType, XmCSpinBoxChildType, XmRSpinBoxChildType,
 	sizeof(unsigned char), Offset(sb_child_type),
@@ -244,7 +259,12 @@ static XtResource ConstraintResources[] = {
 	XmNvalues, XmCValues, XmRXmStringTable,
 	sizeof(XmStringTable), Offset(values),
 	XmRImmediate, (XtPointer)NULL
-    }
+    },
+    {
+	XmNpositionType, XmCPositionType, XmRChar,
+	sizeof(unsigned char), Offset(position_type),
+	XmRImmediate, (XtPointer)XmPOSITION_INDEX
+    },
 };
 
 /* FIX ME - this should go in other files */
@@ -280,7 +300,6 @@ char _XmSpinBox_ChildAccelerators[] =
 	"<Key>osfBeginData:		SpinBFirst()\n"
 	"<Key>osfEndData:		SpinBLast()\n";
 
-/* *INDENT-OFF* */
 static XmBaseClassExtRec _XmSpinBoxCoreClassExtRec = {
     /* next_extension            */ NULL,
     /* record_type               */ NULLQUARK,                             
@@ -396,7 +415,6 @@ XmSpinBoxClassRec xmSpinBoxClassRec = {
 	/* extension */ NULL,
     },
 };
-/* *INDENT-ON* */
 
 
 WidgetClass xmSpinBoxWidgetClass = (WidgetClass)&xmSpinBoxClassRec;
@@ -409,12 +427,14 @@ XmNavigatorTraitRec _XmSPBNavigatorTraitRec = {
 };
 
 static void
-class_initialize()
+class_initialize(void)
 {
     _XmSpinBoxCoreClassExtRec.record_type = XmQmotif;
 
-    XmeTraitSet(xmSpinBoxWidgetClass, XmQTnavigator, &_XmSPBNavigatorTraitRec);
-    XmeTraitSet(xmSpinBoxWidgetClass, XmQTnavigator, &_XmSPBNavigatorTraitRec);
+    XmeTraitSet((XtPointer)xmSpinBoxWidgetClass, XmQTnavigator,
+                (XtPointer)&_XmSPBNavigatorTraitRec);
+    XmeTraitSet((XtPointer)xmSpinBoxWidgetClass, XmQTnavigator,
+                (XtPointer)&_XmSPBNavigatorTraitRec);
 }
 
 static void
@@ -453,11 +473,11 @@ initialize(Widget request, Widget nw,
 {
 	XmScrollFrameTrait	t;
 
-	DEBUGOUT(XdbDebug(__FILE__, nw,
+	DEBUGOUT(_LtDebug(__FILE__, nw,
 		      "SpinBox initialize: w/h %d %d\n",
 		      XtWidth(nw), XtHeight(nw)));
 #if 0
-	DEBUGOUT(XdbPrintArgList(__FILE__, nw, args, *num_args, False));
+	DEBUGOUT(_LtDebugPrintArgList(__FILE__, nw, args, *num_args, False));
 #endif
 
 	SPB_TextW(nw) = NULL;
@@ -471,7 +491,7 @@ initialize(Widget request, Widget nw,
 	}
 
 	/* Find out if our parent is a ScrollFrame */
-	t = (XmScrollFrameTrait) XmeTraitGet(XtClass(XtParent(nw)),
+	t = (XmScrollFrameTrait) XmeTraitGet((XtPointer)XtClass(XtParent(nw)),
 					XmQTscrollFrame);
 	if (t) {
 		t->init(XtParent(nw), _XmSPBTraitMoveCB, nw);	/* ??? FIX ME */
@@ -490,7 +510,7 @@ SetValues(Widget old, Widget request, Widget nw,
     Boolean	need_refresh = False,
 		need_layout = False;
 
-    DEBUGOUT(XdbDebug(__FILE__, nw, "SetValues()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, nw, "SetValues()\n"));
 
 #define	NE(x)	(x(old) != x(nw))
 
@@ -506,8 +526,10 @@ SetValues(Widget old, Widget request, Widget nw,
     if (NE(SPB_UpX) || NE(SPB_UpY)
      || NE(SPB_UpWidth) || NE(SPB_UpHeight)
      || NE(SPB_DownX) || NE(SPB_DownY)
-     || NE(SPB_DownWidth) || NE(SPB_DownHeight))
-		;
+     || NE(SPB_DownWidth) || NE(SPB_DownHeight)) {
+	/* FIX ME What to do ? This'll recalculate (i.e. overrule) them again. */
+	need_layout = True;
+    }
 
     if (need_layout) {
 	Layout(nw, NULL);
@@ -521,7 +543,8 @@ SetValues(Widget old, Widget request, Widget nw,
 static void
 expose(Widget w, XEvent *event, Region region)
 {
-	DEBUGOUT(XdbDebug(__FILE__, w, "Expose\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "Expose up %d %d down %d %d\n",
+		SPB_UpX(w), SPB_UpY(w), SPB_DownX(w), SPB_DownY(w)));
 
 	_XmRedisplayGadgets(w, event, region);
 
@@ -534,7 +557,7 @@ expose(Widget w, XEvent *event, Region region)
 			SPB_UpWidth(w),
 			SPB_UpHeight(w),
 			SPB_DetailShadowThickness(w),
-			XmARROW_RIGHT);
+			(SPB_ArrowOrientation(w) == XmARROWS_HORIZONTAL) ? XmARROW_RIGHT : XmARROW_UP);
 	XmeDrawArrow(XtDisplay(w), XtWindow(w),
 			MGR_BottomShadowGC(w),
 			MGR_TopShadowGC(w),
@@ -544,13 +567,13 @@ expose(Widget w, XEvent *event, Region region)
 			SPB_DownWidth(w),
 			SPB_DownHeight(w),
 			SPB_DetailShadowThickness(w),
-			XmARROW_LEFT);
+			(SPB_ArrowOrientation(w) == XmARROWS_HORIZONTAL) ? XmARROW_LEFT : XmARROW_DOWN);
 }
 
 static void
 resize(Widget w)
 {
-	DEBUGOUT(XdbDebug(__FILE__, w, "Resize\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "Resize\n"));
 }
 
 /*
@@ -564,26 +587,28 @@ ConstraintInitialize(Widget request, Widget nw,
 {
     Widget sb = XtParent(nw);
 
-	DEBUGOUT(XdbDebug2(__FILE__, sb, nw, "ConstraintInitialize\n"));
+	DEBUGOUT(_LtDebug2(__FILE__, sb, nw, "ConstraintInitialize\n"));
 #if 0
-	DEBUGOUT(XdbPrintArgList(__FILE__, nw, args, *num_args, False));
+	DEBUGOUT(_LtDebugPrintArgList(__FILE__, nw, args, *num_args, False));
 #endif
 
-		if (SPBC_Numeric(nw))
-			DEBUGOUT(XdbDebug(__FILE__, nw,
+		if (SPBC_Numeric(nw)) {
+			DEBUGOUT(_LtDebug(__FILE__, nw,
 				"ConstraintInitialize(XmNUMERIC) min %d max %d inc %d\n",
 				SPBC_Minimum(nw),
 				SPBC_Maximum(nw),
 				SPBC_Increment(nw) ));
-		else
-			DEBUGOUT(XdbDebug(__FILE__, nw,
+		}
+		else {
+			DEBUGOUT(_LtDebug(__FILE__, nw,
 				"ConstraintInitialize(XmSTRING) num_values %d\n",
 				SPBC_NumValues(nw)));
+		}
 
 	if (SPBC_ArrowSensitivity(nw) == XmARROWS_DEFAULT_SENSITIVITY)
 		SPBC_ArrowSensitivity(nw) = SPB_DefaultSensitivity(sb);
 
-	if (XmeTraitGet(XtClass(nw), XmQTaccessTextual))
+	if (XmeTraitGet((XtPointer)XtClass(nw), XmQTaccessTextual))
 		_XmSpinBoxShowValue(sb, nw);
 }
 
@@ -594,9 +619,9 @@ ConstraintSetValues(Widget curr, Widget req, Widget nw,
 	Widget	sb = XtParent(nw);
 	Boolean	r = False;
 
-	DEBUGOUT(XdbDebug2(__FILE__, sb, nw, "ConstraintSetValues\n"));
+	DEBUGOUT(_LtDebug2(__FILE__, sb, nw, "ConstraintSetValues\n"));
 #if 0
-	DEBUGOUT(XdbPrintArgList(__FILE__, nw, args, *num_args, False));
+	DEBUGOUT(_LtDebugPrintArgList(__FILE__, nw, args, *num_args, False));
 #endif
 
 #define	NE(x)	(x(curr) != x(nw))
@@ -628,7 +653,7 @@ static void
 PreferredSize(	Widget w, Widget instig, XtWidgetGeometry *ig,
 				Dimension *wid, Dimension *ht)
 {
-	int		i;
+	Cardinal i;
 	Position	xx, yy;
 	Dimension	hh = 0;
 
@@ -643,28 +668,18 @@ PreferredSize(	Widget w, Widget instig, XtWidgetGeometry *ig,
 				hh = XtHeight(child);
 
 			xx += XtWidth(child) + SPB_Spacing(w);
-			DEBUGOUT(XdbDebug2(__FILE__, w, child,
+			DEBUGOUT(_LtDebug2(__FILE__, w, child,
 				"PreferredSize: add width %d\n",
 				XtWidth(child)));
 	}
 
-	SPB_DownX(w) = xx;
-	SPB_DownY(w) = yy;
-	SPB_DownWidth(w) = SPB_ArrowSize(w);
-	SPB_DownHeight(w) = SPB_ArrowSize(w);
-
 	xx += SPB_DownWidth(w) + SPB_Spacing(w);
-
-	SPB_UpX(w) = xx;
-	SPB_UpY(w) = yy;
-	SPB_UpWidth(w) = SPB_ArrowSize(w);
-	SPB_UpHeight(w) = SPB_ArrowSize(w);
 	xx += SPB_UpWidth(w) + SPB_MarginWidth(w);
 
 	*wid = xx;
 	*ht = hh + 2 * SPB_MarginHeight(w);;
 
-	DEBUGOUT(XdbDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 	"PreferredSize => %d %d (ArrowSize %d MarginWidth %d"
 	" MarginHeight %d Spacing %d)\n",
 		*wid, *ht,
@@ -676,15 +691,26 @@ PreferredSize(	Widget w, Widget instig, XtWidgetGeometry *ig,
 /*
  * Layout is primarily influenced by
  *	SPB_ArrowLayout (XmARROWS_BEGINNING, XmARROWS_END, XmARROWS_SPLIT).
+ *
+ * FIX ME
+ *	Should also take VendorShell's XmNlayoutDirection into account.
+ *	ArrowLayout XmARROWS_FLAT_BEGINNING, XmARROWS_FLAT_END missing.
  */
 static void
 Layout(Widget w, Widget instig)
 {
-	int		i;
+	Cardinal i;
 	Position	xx, yy;
 	Dimension	hh = 0;
 
-	DEBUGOUT(XdbDebug(__FILE__, w, "XmSpinBox Layout\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "XmSpinBox Layout %s\n",
+		(SPB_ArrowLayout(w) == XmARROWS_BEGINNING) ? "XmARROWS_BEGINNING" :
+		(SPB_ArrowLayout(w) == XmARROWS_END) ? "XmARROWS_END" :
+		(SPB_ArrowLayout(w) == XmARROWS_SPLIT) ? "XmARROWS_SPLIT" :
+		(SPB_ArrowLayout(w) == XmARROWS_FLAT_BEGINNING) ? "XmARROWS_FLAT_BEGINNING" :
+		(SPB_ArrowLayout(w) == XmARROWS_FLAT_END) ? "XmARROWS_FLAT_END" :
+		"??"
+	));
 
 	for (i=0; i<MGR_NumChildren(w); i++)
 	    if (XtHeight(MGR_Children(w)[i]) > hh)
@@ -713,10 +739,11 @@ Layout(Widget w, Widget instig)
 		if (XtIsManaged(MGR_Children(w)[i])) {
 			Widget	child = MGR_Children(w)[i];
 
-				XtX(child) = xx;
-				XtY(child) = SPB_MarginHeight(w);
+			_XmConfigureObject(child, xx, SPB_MarginHeight(w),
+				XtWidth(child), XtHeight(child),
+				XtBorderWidth(child));
 
-				xx += XtWidth(child) + SPB_Spacing(w);
+			xx += XtWidth(child) + SPB_Spacing(w);
 		}
 
 		break;
@@ -728,10 +755,11 @@ Layout(Widget w, Widget instig)
 		if (XtIsManaged(MGR_Children(w)[i])) {
 			Widget	child = MGR_Children(w)[i];
 
-				XtX(child) = xx;
-				XtY(child) = SPB_MarginHeight(w);
+			_XmConfigureObject(child, xx, SPB_MarginHeight(w),
+				XtWidth(child), XtHeight(child),
+				XtBorderWidth(child));
 
-				xx += XtWidth(child) + SPB_Spacing(w);
+			xx += XtWidth(child) + SPB_Spacing(w);
 		}
 
 	    SPB_DownX(w) = xx;
@@ -758,22 +786,84 @@ Layout(Widget w, Widget instig)
 		if (XtIsManaged(MGR_Children(w)[i])) {
 			Widget	child = MGR_Children(w)[i];
 
-				XtX(child) = xx;
-				XtY(child) = SPB_MarginHeight(w);
+			_XmConfigureObject(child, xx, SPB_MarginHeight(w),
+				XtWidth(child), XtHeight(child),
+				XtBorderWidth(child));
 
-				xx += XtWidth(child) + SPB_Spacing(w);
+			xx += XtWidth(child) + SPB_Spacing(w);
 		}
 
 	    SPB_UpX(w) = xx;
 	    SPB_UpY(w) = yy;
 	    SPB_UpWidth(w) = SPB_ArrowSize(w);
 	    SPB_UpHeight(w) = SPB_ArrowSize(w);
+	    break;
+	case XmARROWS_FLAT_BEGINNING:				/* FIX ME */
+	    SPB_DownX(w) = SPB_MarginWidth(w);
+	    SPB_DownY(w) = yy;
+	    SPB_DownWidth(w) = SPB_ArrowSize(w);
+	    SPB_DownHeight(w) = SPB_ArrowSize(w);
+
+	    xx = SPB_MarginWidth(w) + SPB_Spacing(w) + SPB_DownWidth(w);
+
+	    SPB_UpX(w) = xx;
+	    SPB_UpY(w) = yy;
+	    SPB_UpWidth(w) = SPB_ArrowSize(w);
+	    SPB_UpHeight(w) = SPB_ArrowSize(w);
+
+	    xx += SPB_MarginWidth(w) + SPB_Spacing(w) + SPB_UpWidth(w) + SPB_ArrowSize(w);
+
+	    for (i=0; i<MGR_NumChildren(w); i++)
+		if (XtIsManaged(MGR_Children(w)[i])) {
+			Widget	child = MGR_Children(w)[i];
+
+			_XmConfigureObject(child, xx, SPB_MarginHeight(w),
+				XtWidth(child), XtHeight(child),
+				XtBorderWidth(child));
+
+			xx += XtWidth(child) + SPB_Spacing(w);
+		}
+
+	    break;
+	case XmARROWS_FLAT_END:				/* FIX ME */
+	    xx = SPB_MarginWidth(w);
+
+	    for (i=0; i<MGR_NumChildren(w); i++)
+		if (XtIsManaged(MGR_Children(w)[i])) {
+			Widget	child = MGR_Children(w)[i];
+
+			_XmConfigureObject(child, xx, SPB_MarginHeight(w),
+				XtWidth(child), XtHeight(child),
+				XtBorderWidth(child));
+
+			xx += XtWidth(child) + SPB_Spacing(w);
+		}
+
+	    SPB_DownX(w) = xx;
+	    SPB_DownY(w) = yy;
+	    SPB_DownWidth(w) = SPB_ArrowSize(w);
+	    SPB_DownHeight(w) = SPB_ArrowSize(w);
+
+	    xx += SPB_MarginWidth(w) + SPB_ArrowSize(w) + SPB_Spacing(w);
+
+	    SPB_UpX(w) = xx;
+	    SPB_UpY(w) = yy;
+	    SPB_UpWidth(w) = SPB_ArrowSize(w);
+	    SPB_UpHeight(w) = SPB_ArrowSize(w);
+	    break;
 	}
 
-	DEBUGOUT(XdbDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 	    "SpinBoxLayout: down at %d %d up at %d %d, spb size %d %d\n",
 	    SPB_DownX(w), SPB_DownY(w), SPB_UpX(w), SPB_UpY(w),
 	    XtWidth(w), XtHeight(w)));
+	 for (i=0; i<MGR_NumChildren(w); i++) {
+		if (XtIsManaged(MGR_Children(w)[i])) {
+			Widget	child = MGR_Children(w)[i];
+			DEBUGOUT(_LtDebug2(__FILE__, w, child, "x %d y %d sz %d %d\n",
+				XtX(child), XtY(child), XtWidth(child), XtHeight(child)));
+		}
+	}
 }
 
 static XtGeometryResult
@@ -784,7 +874,7 @@ QueryGeometry(Widget w, XtWidgetGeometry *proposed, XtWidgetGeometry *answer)
 
 #define	Wants(x)	((geo.request_mode & x) == x)
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "QueryGeometry\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "QueryGeometry\n"));
 
     geo = *proposed;
 
@@ -798,16 +888,16 @@ QueryGeometry(Widget w, XtWidgetGeometry *proposed, XtWidgetGeometry *answer)
 
     if (Wants(CWHeight) && (geo.height != answer->height))
     {
-	DEBUGOUT(XdbDebug(__FILE__, w, "QueryGeometry => No.\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "QueryGeometry => No.\n"));
 	return XtGeometryNo;
     }
     if (Wants(CWWidth) && (geo.width != answer->width))
     {
-	DEBUGOUT(XdbDebug(__FILE__, w, "QueryGeometry => No.\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "QueryGeometry => No.\n"));
 	return XtGeometryNo;
     }
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "QueryGeometry => Yes.\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "QueryGeometry => Yes.\n"));
     return XtGeometryYes;
 }
 
@@ -816,7 +906,7 @@ GeometryManager(Widget w,
 		 XtWidgetGeometry *request,
 		 XtWidgetGeometry *reply)
 {
-	DEBUGOUT(XdbDebug(__FILE__, w, "GeometryManager\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "GeometryManager\n"));
 
 	/* FIX ME */
 
@@ -830,17 +920,17 @@ ChangeManaged(Widget w)
 	XtWidgetGeometry	geo;
 	XtGeometryResult	r;
 
-	DEBUGOUT(XdbDebug(__FILE__, w, "ChangeManaged\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "ChangeManaged\n"));
 
 	/* Make sure that our size is right */
 	PreferredSize(w, NULL, NULL, &geo.width, &geo.height);
 	geo.request_mode = CWWidth | CWHeight;
 
 	r = _XmMakeGeometryRequest(w, &geo);
-	DEBUGOUT(XdbDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 		"ChangeManaged Geometry Request %s -> %s\n",
-		XdbWidgetGeometry2String(&geo),
-		XdbGeometryResult2String(r)));
+		_LtDebugWidgetGeometry2String(&geo),
+		_LtDebugGeometryResult2String(r)));
 
 	if (r == XtGeometryYes) {
 		/* FIX ME */
@@ -882,9 +972,10 @@ SpinBModify(Widget w, XEvent *evp, int reason)
 	char				*s = NULL;
 
 	tw = SPB_TextW(w);
+	spb.crossed_boundary = False;	/* Detected below */
 
 	if (tw == NULL) {
-		DEBUGOUT(XdbDebug(__FILE__, w, "SpinBModify: no text widget\n"));
+		DEBUGOUT(_LtDebug(__FILE__, w, "SpinBModify: no text widget\n"));
 		return;
 	}
 
@@ -905,14 +996,18 @@ SpinBModify(Widget w, XEvent *evp, int reason)
 		case XmCR_SPIN_NEXT:
 			SPBC_Position(tw)++;
 			if (SPBC_Position(tw) >
-				((SPBC_Maximum(tw) - SPBC_Minimum(tw)) / SPBC_Increment(tw)))
+				((SPBC_Maximum(tw) - SPBC_Minimum(tw)) / SPBC_Increment(tw))) {
 					SPBC_Position(tw) = 0;
+					spb.crossed_boundary = True;
+			}
 			break;
 		case XmCR_SPIN_PRIOR:
 			SPBC_Position(tw)--;
-			if (SPBC_Position(tw) < 0)
-					SPBC_Position(tw) = ((SPBC_Maximum(tw) - SPBC_Minimum(tw))
-							/ SPBC_Increment(tw));
+			if (SPBC_Position(tw) < 0) {
+				SPBC_Position(tw) = ((SPBC_Maximum(tw) - SPBC_Minimum(tw))
+						/ SPBC_Increment(tw));
+				spb.crossed_boundary = True;
+			}
 			break;
 		case XmCR_SPIN_FIRST:
 			SPBC_Position(tw) = SPBC_Minimum(tw);
@@ -926,7 +1021,7 @@ SpinBModify(Widget w, XEvent *evp, int reason)
 		s = _XmSpinBoxNumericString(tw);
 		xms = XmStringCreateSimple(s);
 
-		DEBUGOUT(XdbDebug(__FILE__, w,
+		DEBUGOUT(_LtDebug(__FILE__, w,
 			"SpinBModify(NUMERIC) %d [%d,%d]\n",
 			SPBC_Position(tw), SPBC_Minimum(tw), SPBC_Maximum(tw)));
 	} else {
@@ -935,13 +1030,17 @@ SpinBModify(Widget w, XEvent *evp, int reason)
 		switch (reason) {
 		case XmCR_SPIN_NEXT:
 			SPBC_Position(tw)++;
-			if (SPBC_Position(tw) >= SPBC_NumValues(tw))
+			if (SPBC_Position(tw) >= SPBC_NumValues(tw)) {
 				SPBC_Position(tw) = 0;
+				spb.crossed_boundary = True;
+			}
 			break;
 		case XmCR_SPIN_PRIOR:
 			SPBC_Position(tw)--;
-			if (SPBC_Position(tw) <= 0)
-					SPBC_Position(tw) = SPBC_NumValues(tw);
+			if (SPBC_Position(tw) <= 0) {
+				SPBC_Position(tw) = SPBC_NumValues(tw);
+				spb.crossed_boundary = True;
+			}
 			break;
 		case XmCR_SPIN_FIRST:
 			SPBC_Position(tw) = 1;
@@ -954,7 +1053,7 @@ SpinBModify(Widget w, XEvent *evp, int reason)
 
 		xms = XmStringCopy(SPBC_Values(tw)[SPBC_Position(tw)]);
 
-		DEBUGOUT(XdbDebug(__FILE__, w,
+		DEBUGOUT(_LtDebug(__FILE__, w,
 			"SpinBModify(STRING) %d [%d,%d]\n",
 			SPBC_Position(tw), 0, SPBC_NumValues(tw)));
 	}
@@ -967,7 +1066,6 @@ SpinBModify(Widget w, XEvent *evp, int reason)
 	spb.doit = True;
 	spb.position = SPBC_Position(tw);
 	spb.value = xms;
-	spb.crossed_boundary = False;	/* FIX ME */
 
 	XtCallCallbackList(w, SPB_ModifyVerifyCB(w), (XtPointer)&spb);
 
@@ -992,7 +1090,7 @@ _XmSpinBoxTimer(XtPointer client, XtIntervalId *timerid)
 {
 	Widget	spb = (Widget)client;
 
-	DEBUGOUT(XdbDebug(__FILE__, spb, "_XmSpinBoxTimer\n"));
+	DEBUGOUT(_LtDebug(__FILE__, spb, "_XmSpinBoxTimer\n"));
 
 	if (SPB_UpArrowPressed(spb))
 			SpinBModify(spb, NULL, XmCR_SPIN_NEXT);
@@ -1008,7 +1106,7 @@ SpinBArm(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
 	Widget	tw;
 
-	DEBUGOUT(XdbDebug(__FILE__, w, "SpinBArm at %d %d\n",
+	DEBUGOUT(_LtDebug(__FILE__, w, "SpinBArm at %d %d\n",
 		event->xbutton.x, event->xbutton.y));
 
 	if ((tw = SPB_TextW(w)) == NULL)
@@ -1069,7 +1167,7 @@ SpinBArm(Widget w, XEvent *event, String *params, Cardinal *num_params)
 static void
 SpinBDisarm(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
-	DEBUGOUT(XdbDebug(__FILE__, w, "SpinBDisarm\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "SpinBDisarm\n"));
 
 	if (SPB_TimerId(w))
 		XtRemoveTimeOut(SPB_TimerId(w));
@@ -1082,37 +1180,37 @@ SpinBDisarm(Widget w, XEvent *event, String *params, Cardinal *num_params)
 static void
 SpinBFirst(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
-	DEBUGOUT(XdbDebug(__FILE__, w, "SpinBFirst\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "SpinBFirst\n"));
 }
 
 static void
 SpinBLast(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
-	DEBUGOUT(XdbDebug(__FILE__, w, "SpinBLast\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "SpinBLast\n"));
 }
 
 static void
 SpinBLeft(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
-	DEBUGOUT(XdbDebug(__FILE__, w, "SpinBLeft\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "SpinBLeft\n"));
 }
 
 static void
 SpinBRight(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
-	DEBUGOUT(XdbDebug(__FILE__, w, "SpinBRight\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "SpinBRight\n"));
 }
 
 static void
 SpinBNext(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
-	DEBUGOUT(XdbDebug(__FILE__, w, "SpinBNext\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "SpinBNext\n"));
 }
 
 static void
 SpinBPrior(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
-	DEBUGOUT(XdbDebug(__FILE__, w, "SpinBPrior\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "SpinBPrior\n"));
 }
 
 static void
@@ -1120,7 +1218,7 @@ _XmSpinBoxChildFocus(Widget w, XtPointer client, XtPointer call)
 {
 	Widget	spb = (Widget)client;
 
-	DEBUGOUT(XdbDebug2(__FILE__, spb, w, "_XmSpinBoxChildFocus\n"));
+	DEBUGOUT(_LtDebug2(__FILE__, spb, w, "_XmSpinBoxChildFocus\n"));
 
 	SPB_TextW(spb) = w;
 }
@@ -1130,17 +1228,17 @@ InsertChild(Widget w)
 {
     Widget	spb = XtParent(w);
 
-    DEBUGOUT(XdbDebug2(__FILE__, (Widget)spb, w, "SpinBox InsertChild\n"));
+    DEBUGOUT(_LtDebug2(__FILE__, (Widget)spb, w, "SpinBox InsertChild\n"));
 
 #define superclass (&xmManagerClassRec)
     (*superclass->composite_class.insert_child) (w);
 #undef superclass
 
-	if (XmeTraitGet(XtClass(w), XmQTaccessTextual)) {
+	if (XmeTraitGet((XtPointer)XtClass(w), XmQTaccessTextual)) {
 #if 0
 		Arg		a;
 
-		DEBUGOUT(XdbDebug2(__FILE__, spb, w,
+		DEBUGOUT(_LtDebug2(__FILE__, spb, w,
 			"Adding accelerators to child\n"));
 
 		XtSetArg(a, XmNtranslations,
@@ -1190,12 +1288,13 @@ _XmSpinBoxShowValue(Widget spb, Widget t)
 	XmString	xms;
 	XmAccessTextualTrait	trait;
 
-	DEBUGOUT(XdbDebug(__FILE__, spb, "_XmSpinBoxShowValue\n"));
+	DEBUGOUT(_LtDebug(__FILE__, spb, "_XmSpinBoxShowValue\n"));
 
 	if (spb == NULL || t == NULL)
 		return;
 
-	trait = (XmAccessTextualTrait)XmeTraitGet(XtClass(t), XmQTaccessTextual);
+	trait = (XmAccessTextualTrait)XmeTraitGet((XtPointer)XtClass(t),
+	                                           XmQTaccessTextual);
 
 	if (trait == NULL) {
 	    _XmError(t, "_XmSpinBoxShowValue: no trait XmQTaccessTextual\n");
@@ -1224,7 +1323,7 @@ _XmSpinBoxShowValue(Widget spb, Widget t)
 			XmTextSetString(t, s);
 			XtFree(s);
 		} else
-			trait->setValue(t, xms, XmFORMAT_XmSTRING);
+			trait->setValue(t, (XtPointer)xms, XmFORMAT_XmSTRING);
 		/* Do *not* free xms */
 	}
 
@@ -1233,19 +1332,19 @@ _XmSpinBoxShowValue(Widget spb, Widget t)
 static void
 SpinBoxEnter(Widget w, XEvent *evp, String *par, Cardinal *npar)
 {
-	DEBUGOUT(XdbDebug(__FILE__, w, "SpinBoxEnter\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "SpinBoxEnter\n"));
 }
 
 static void
 SpinBoxFocusIn(Widget w, XEvent *evp, String *par, Cardinal *npar)
 {
-	DEBUGOUT(XdbDebug(__FILE__, w, "SpinBoxFocusIn\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "SpinBoxFocusIn\n"));
 }
 
 static void
 SpinBoxFocusOut(Widget w, XEvent *evp, String *par, Cardinal *npar)
 {
-	DEBUGOUT(XdbDebug(__FILE__, w, "SpinBoxFocusOut\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "SpinBoxFocusOut\n"));
 }
 
 /*
@@ -1257,7 +1356,7 @@ _XmSPBTraitChangeMoveCB(Widget nav,
 			XtPointer closure,
 			Boolean setUnset)
 {
-	DEBUGOUT(XdbDebug(__FILE__, nav,
+	DEBUGOUT(_LtDebug(__FILE__, nav,
 		"_XmSPBTraitChangeMoveCB (%s)\n",
 		setUnset ? "set" : "unset"));
 
@@ -1272,7 +1371,7 @@ _XmSPBTraitSetValue(Widget nav, XmNavigatorData navigatorData, Boolean notify)
 {
 	Widget	tw;
 
-	DEBUGOUT(XdbDebug(__FILE__, nav, "_XmSPBTraitSetValue\n"));
+	DEBUGOUT(_LtDebug(__FILE__, nav, "_XmSPBTraitSetValue\n"));
 
 	tw = SPB_TextW(nav);
 	if (tw == NULL)
@@ -1281,6 +1380,18 @@ _XmSPBTraitSetValue(Widget nav, XmNavigatorData navigatorData, Boolean notify)
 	if (navigatorData == NULL)
 		return;
 
+	if (navigatorData->valueMask & NavMinimum) {
+		SPBC_Minimum(tw) = navigatorData->minimum->x;
+	}
+
+	if (navigatorData->valueMask & NavMaximum) {
+		SPBC_Maximum(tw) = navigatorData->maximum->x;
+	}
+
+	if (navigatorData->valueMask & NavValue) {
+		/* FIX ME */
+	}
+
 	SPBC_Position(tw) = navigatorData->value->x;
 
 	_XmSpinBoxShowValue(nav, tw);
@@ -1289,7 +1400,7 @@ _XmSPBTraitSetValue(Widget nav, XmNavigatorData navigatorData, Boolean notify)
 static int
 _XmSPBTraitGetValue(Widget nav, XmNavigatorData navigatorData)
 {
-	DEBUGOUT(XdbDebug(__FILE__, nav, "_XmSPBTraitGetValue\n"));
+	DEBUGOUT(_LtDebug(__FILE__, nav, "_XmSPBTraitGetValue\n"));
 	return 0;
 }
 
@@ -1299,7 +1410,7 @@ _XmSPBTraitGetValue(Widget nav, XmNavigatorData navigatorData)
 static void
 _XmSPBTraitMoveCB(Widget nav, XtPointer client, XtPointer call)
 {
-	DEBUGOUT(XdbDebug(__FILE__, nav, "_XmSPBTraitMoveCB\n"));
+	DEBUGOUT(_LtDebug(__FILE__, nav, "_XmSPBTraitMoveCB\n"));
 
 	/*
 	 * This gets called when a navigator (e.g. Notebook) that we're
@@ -1308,3 +1419,84 @@ _XmSPBTraitMoveCB(Widget nav, XtPointer client, XtPointer call)
 	 * By getting this call we can change our appearance (e.g. page number).
 	 */
 }
+
+
+/*
+ * An excerpt from http://www.motifdeveloper.com/tips/tip13.html :
+ *
+ * int XmSpinBoxValidatePosition(Widget text, int *position_value)
+ *
+ * XmSpinBoxValidatePosition() checks that the text child of an XmSpinBox has a valid position and
+ * value. If the current position is valid, it is returned into the address specified by
+ * position_value. The function also returns an integer representing the status of the check,
+ * as follows: 
+ *	XmCURRENT_VALUE 
+ *		This is returned if the XmNspinBoxChildType of text is not XmNUMERIC. 
+ *	XmMINIMUM_VALUE 
+ *		The current XmNposition resource of text is less than the XmNminimumValue
+ *		resource of the widget. 
+ *	XmMAXIMUM_VALUE 
+ *		The current XmNposition resource of text is greater than the XmNmaximumValue
+ *		resource of the widget. 
+ *	XmINCREMENT_VALUE 
+ *		The current XmNposition resource of text falls between the minimum and maximum
+ *		bounds set for the widget. In addition, the position should not fall on an
+ *		increment boundary. That is, it is not defined by: 
+ *			minimum + (n * increment) 
+ *		The nearest value (not less than the current value) which does fall on an
+ *		increment is calculated, and returned in the position_value parameter of the
+ *		function. 
+ *	XmNVALID_VALUE 
+ *		The current XmNposition resource of text falls between the minimum and maximum
+ *		bounds set for the widget. In addition, unlike the case for XmINCREMENT_VALUE,
+ *		the position does fall on an increment boundary. 
+ * Note that this routine does not modify the current position associated with text. 
+ */
+extern int
+XmSpinBoxValidatePosition(Widget t, int *position)
+{
+	int			intval, i;
+	XmAccessTextualTrait	trait;
+	char			*s;
+	double			d;
+
+	if (! SPBC_Numeric(t)) {
+		return XmCURRENT_VALUE;
+	}
+
+	trait = (XmAccessTextualTrait)XmeTraitGet((XtPointer)XtClass(t), XmQTaccessTextual);
+	if (trait == NULL) {
+		_XmError(t, "_XmSpinBoxShowValue: no trait XmQTaccessTextual\n");
+		return XmCURRENT_VALUE;
+	} else if (trait->version != 0) {
+		_XmWarning(t, "Version of trait record is %d not %d\n", trait->version, 0);
+	}
+
+	s = trait->getValue(t, XmFORMAT_WCS);
+	if (s == 0) {
+		_XmWarning(t, "XmSpinBoxValidatePosition TraitGetValue -> NULL : this shouldn't happen\n");
+		return XmCURRENT_VALUE;	/* Maybe the app doesn't crash if we do this */
+	}
+	d = atof(s);
+	for (i=0; i<SPBC_DecimalPoints(t); i++)
+		d /= 10;
+	intval = d;
+
+	if (intval < SPBC_Minimum(t))
+		return XmMINIMUM_VALUE;
+	if (intval > SPBC_Maximum(t))
+		return XmMAXIMUM_VALUE;
+
+	/* Calculate the nearest greater value that does fall on an increment */
+	d = intval;
+	d = (d - SPBC_Minimum(t)) / SPBC_Increment(t);
+	i = d;
+	if (i != d)
+		i++;
+
+	*position = SPBC_Minimum(t) + i * SPBC_Increment(t);
+
+	if (i == d)
+		return XmVALID_VALUE;
+	return XmINCREMENT_VALUE;
+}
