@@ -1,6 +1,6 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/Trait.c,v 1.16 2001/07/27 18:55:21 dannybackx Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/Trait.c,v 1.19 2001/09/11 17:34:00 dannybackx Exp $
  *
  * Copyright (C) 1997 Free Software Foundation, Inc.
  * Copyright (C) 1997-2001 LessTif Development Team
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/Trait.c,v 1.16 2001/07/27 18:55:21 dannybackx Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/Trait.c,v 1.19 2001/09/11 17:34:00 dannybackx Exp $";
 
 /*
  * This file contains a poor man's implementation of traits.
@@ -204,25 +204,25 @@ XmeTraitSet(XtPointer obj, XrmQuark trait, XtPointer rec)
 		    _traits[i].num += NUM_TRAITS;
 		    if (_traits[i].traits) {
 		    	_traits[i].traits = (_XmTraitRec *) XtRealloc(
-			(char *)_traits[i].traits,
-			sizeof(_XmTraitRec) * _traits[i].num);
-			_LtDebug(__FILE__, NULL,
+				(char *)_traits[i].traits,
+				sizeof(_XmTraitRec) * _traits[i].num);
+			DEBUGOUT(_LtDebug(__FILE__, NULL,
 				"XmeTraitSet: _traits[%d].traits = %p,"
 				" size %d = %d * %d\n",
 				i, _traits[i].traits,
 				_traits[i].num * sizeof(_XmTraitRec),
 				_traits[i].num,
-				sizeof(_XmTraitRec));
+				sizeof(_XmTraitRec)));
 		    } else {
 		    	_traits[i].traits = (_XmTraitRec *) XtCalloc(
 				_traits[i].num, sizeof(_XmTraitRec));
-			_LtDebug(__FILE__, NULL,
+			DEBUGOUT(_LtDebug(__FILE__, NULL,
 				"XmeTraitSet: _traits[%d].traits = %p,"
 				" size %d = %d * %d\n",
 				i, _traits[i].traits,
 				_traits[i].num * sizeof(_XmTraitRec),
 				_traits[i].num,
-				sizeof(_XmTraitRec));
+				sizeof(_XmTraitRec)));
 		    }
 		}
 
@@ -235,10 +235,10 @@ XmeTraitSet(XtPointer obj, XrmQuark trait, XtPointer rec)
 			 * Code for supporting this is in XmeTraitGet */
 			_traits[i].traits[j].traitrec = rec;
 
-			_LtDebug(__FILE__, NULL,
+			DEBUGOUT(_LtDebug(__FILE__, NULL,
 				"XmeTraitSet: overwrite _traits[%d]."
 				"traits[%d].traitrec\n",
-				i, j);
+				i, j));
 
 			return True;
 		    }
@@ -250,39 +250,41 @@ XmeTraitSet(XtPointer obj, XrmQuark trait, XtPointer rec)
 			_traits[i].traits = (_XmTraitRec *) XtRealloc(
 			(char *)_traits[i].traits,
 			sizeof(_XmTraitRec) * _traits[i].num);
-			_LtDebug(__FILE__, NULL,
+			DEBUGOUT(_LtDebug(__FILE__, NULL,
 				"XmeTraitSet: _traits[%d].traits = %p,"
 				" size %d = %d * %d\n",
 				i, _traits[i].traits,
 				_traits[i].num * sizeof(_XmTraitRec),
 				_traits[i].num,
-				sizeof(_XmTraitRec));
+				sizeof(_XmTraitRec)));
 		    } else {
 			_traits[i].traits = (_XmTraitRec *) XtCalloc(
 				_traits[i].num, sizeof(_XmTraitRec));
-			_LtDebug(__FILE__, NULL,
+			DEBUGOUT(_LtDebug(__FILE__, NULL,
 				"XmeTraitSet: _traits[%d].traits = %p,"
 				" size %d = %d * %d\n",
 				i, _traits[i].traits,
 				_traits[i].num * sizeof(_XmTraitRec),
 				_traits[i].num,
-				sizeof(_XmTraitRec));
+				sizeof(_XmTraitRec)));
 		    }
 		}
 
 		/* Add the trait to the list */
 		_traits[i].traits[j].trait = trait;
 		_traits[i].traits[j].traitrec = rec;
+#if 0
 		_traits[i].traits[j+1].trait = NULLQUARK;
+#endif
 
-		_LtDebug(__FILE__, NULL,
+		DEBUGOUT(_LtDebug(__FILE__, NULL,
 			"XmeTraitSet: write _traits[%d]."
 			"traits[%d].traitrec\n",
-			i, j);
-		_LtDebug(__FILE__, NULL,
+			i, j));
+		DEBUGOUT(_LtDebug(__FILE__, NULL,
 			"XmeTraitSet: write _traits[%d]."
 			"traits[%d].traitrec\n",
-			i, j+1);
+			i, j+1));
 
 		return True;
 	    }
@@ -299,16 +301,16 @@ XmeTraitSet(XtPointer obj, XrmQuark trait, XtPointer rec)
 		} else {
 		    _traits = (struct _XmTraitWidgetList *) XtCalloc(
 			_max_traits, sizeof(struct _XmTraitWidgetList));
-		    _LtDebug(__FILE__, NULL,
+		    DEBUGOUT(_LtDebug(__FILE__, NULL,
 			"XmeTraitSet: _traits = %p, size %d = %d * %d\n",
 			_traits,
 			_max_traits * sizeof(struct _XmTraitWidgetList),
 			_max_traits,
-			sizeof(struct _XmTraitWidgetList));
+			sizeof(struct _XmTraitWidgetList)));
 		}
 	}
 
-	_LtDebug(__FILE__, NULL, "XmeTraitSet: set _traits[%d]\n", i);
+	DEBUGOUT(_LtDebug(__FILE__, NULL, "XmeTraitSet: set _traits[%d]\n", i));
 
 	_traits[i].wc = (WidgetClass)obj;
 	_traits[i].num = 0;
@@ -346,3 +348,22 @@ _XmInitTraits(void)
 	XmQTtakesDefault = XrmStringToQuark("XmQTtakesDefault");
 	XmQTtransfer = XrmStringToQuark("XmQTtransfer");
 }
+
+#if 1
+#include <stdio.h>
+#include <X11/CoreP.h>
+
+void _LtDebugTraitReport(void)
+{
+	int		i, j;
+	XrmQuark	q;
+
+	for (i=0; i<_num_traits; i++) {
+		fprintf(stderr, "Widget class '%s'\n", _traits[i].wc->core_class.class_name);
+		for (j=0; _traits[i].traits[j].trait && j<_traits[i].num; j++) {
+			q = _traits[i].traits[j].trait;
+			fprintf(stderr, "\t\t%s\n", XrmQuarkToString(q));
+		}
+	}
+}
+#endif
