@@ -1,8 +1,9 @@
 /**
  *
- * $Header: /cvsroot/hungry/lesstif/lib/Xm-2.0/Xme.c,v 1.10 1999/08/13 13:18:26 danny Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/Xme.c,v 1.25 2001/04/02 19:05:43 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,37 +23,43 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/hungry/lesstif/lib/Xm-2.0/Xme.c,v 1.10 1999/08/13 13:18:26 danny Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.0/Xme.c,v 1.25 2001/04/02 19:05:43 amai Exp $";
+
+#include <LTconfig.h>
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <stdarg.h>
+#include <string.h>
 
-#include <XmI/DebugUtil.h>
-
-#include <LTconfig.h>
 #include <XmI/XmI.h>
 #include <Xm/XmP.h>
 #include <Xm/DragIconP.h>
 #include <Xm/XmosP.h>
 #include <Xm/VirtKeysP.h>
 #include <Xm/VendorSEP.h>
+#include <Xm/ColorObjP.h>
+#include <Xm/TransferP.h>
 #include <XmI/MessagesI.h>
 
-#ifndef __STDC__
-#include <varargs.h>
-#else
-#include <stdarg.h>
-#endif
+#include <XmI/DebugUtil.h>
+
+
+/* required prototypes of exported, but private Intrinsic stuff: */
+extern void _XtAddCallback(XtCallbackList *, XtCallbackProc, XtPointer);
+extern void _XtRemoveCallback(XtCallbackList *, XtCallbackProc, XtPointer);
+
 
 /* DragIcon */
-Widget
+extern Widget
 XmeGetTextualDragIcon(Widget w)
 {
     return _XmGetTextualDragIcon(w);
 }
 
+
 /* GeoUtils */
-XtGeometryResult
+extern XtGeometryResult
 XmeReplyToQueryGeometry(Widget w,
 			XtWidgetGeometry *request,
 			XtWidgetGeometry *reply)
@@ -60,8 +67,9 @@ XmeReplyToQueryGeometry(Widget w,
     return _XmGMReplyToQueryGeometry(w, request, reply);
 }
 
+
 /* GadgetUtil */
-void
+extern void
 XmeConfigureObject(Widget g,
 		   Position x, Position y,
 		   Dimension width, Dimension height, Dimension border_width)
@@ -69,15 +77,17 @@ XmeConfigureObject(Widget g,
     _XmConfigureObject(g, x, y, width, height, border_width);
 }
 
+
 /* GadgetUtil */
-void
+extern void
 XmeRedisplayGadgets(Widget w, XEvent *event, Region region)
 {
     _XmRedisplayGadgets(w, event, region);
 }
 
+
 /* ImageCache */
-Boolean
+extern Boolean
 XmeGetPixmapData(Screen *screen, Pixmap pixmap,
 		 char **image_name,
 		 int *depth, Pixel *foreground, Pixel *background,
@@ -90,78 +100,16 @@ XmeGetPixmapData(Screen *screen, Pixmap pixmap,
 			    hot_x, hot_y, width, height);
 }
 
-/* ResConvert */
-void
-#ifdef __STDC__
-XmeWarning(Widget w, char *fmt,...)
-{
-    va_list arg_list;
-    char buf[256];
 
-    va_start(arg_list, fmt);
-#else
-XmeWarning(Widget w, fmt, va_list)
-     Widget w;
-     char *fmt;
-     va_dcl
-{
-    char buf[256];
-
-    va_start(arg_list);
-#endif
-    if (w)
-    {
-	sprintf(buf, "\n    Name: %s\n    Class: %s\n    ",
-		XtName(w), XtClass(w)->core_class.class_name);
-
-	vsprintf(buf + strlen(buf), fmt, arg_list);
-	va_end(arg_list);
-
-	strcat(buf, "\n");
-
-#ifdef	LESSTIF_PRODUCTION
-	XtAppWarning(XtWidgetToApplicationContext(w), buf);
-#else
-	if (getenv("DEBUG_REDIRECT_XMWARNING"))
-	{
-	    XdbPrintString(buf);
-	}
-	else
-	{
-	    XtAppWarning(XtWidgetToApplicationContext(w), buf);
-	}
-#endif
-    }
-    else
-    {
-	buf[0] = '\0';
-	vsprintf(buf + strlen(buf), fmt, arg_list);
-	va_end(arg_list);
-
-#ifdef	LESSTIF_PRODUCTION
-	XtWarning(buf);
-#else
-	if (getenv("DEBUG_REDIRECT_XMWARNING"))
-	{
-	    XdbPrintString(buf);
-	}
-	else
-	{
-	    XtWarning(buf);
-	}
-#endif
-    }
-}
-
-/* ResConvert */
-Boolean
+extern Boolean
 XmeNamesAreEqual(char *in_str, char *text_str)
 {
     return _XmStringsAreEqual(in_str, text_str);
 }
 
+
 /* ResInd */
-void
+extern void
 XmeFromHorizontalPixels(Widget widget,
 			int offset,
 			XtArgVal *value)
@@ -169,8 +117,9 @@ XmeFromHorizontalPixels(Widget widget,
     _XmFromHorizontalPixels(widget, offset, value);
 }
 
+
 /* ResInd */
-void
+extern void
 XmeFromVerticalPixels(Widget widget,
 		      int offset,
 		      XtArgVal *value)
@@ -178,8 +127,9 @@ XmeFromVerticalPixels(Widget widget,
     _XmFromVerticalPixels(widget, offset, value);
 }
 
+
 /* ResInd */
-XmImportOperator
+extern XmImportOperator
 XmeToHorizontalPixels(Widget widget,
 		      int offset,
 		      XtArgVal *value)
@@ -187,8 +137,9 @@ XmeToHorizontalPixels(Widget widget,
     return _XmToHorizontalPixels(widget, offset, value);
 }
 
+
 /* ResInd */
-XmImportOperator
+extern XmImportOperator
 XmeToVerticalPixels(Widget widget,
 		    int offset,
 		    XtArgVal *value)
@@ -196,38 +147,46 @@ XmeToVerticalPixels(Widget widget,
     return _XmToVerticalPixels(widget, offset, value);
 }
 
+
 /* Screen */
-Cursor
+extern Cursor
 XmeGetNullCursor(Widget w)
 {
     return _XmGetNullCursor(w);
 }
 
+
 /* Traversal */
-Boolean
+extern Boolean
 XmeFocusIsInShell(Widget wid)
 {
     return _XmFocusIsInShell(wid);
 }
 
+
 /* Traversal */
-void
+extern void
 XmeNavigChangeManaged(Widget w)
 {
     _XmNavigChangeManaged(w);
 }
 
+
 /* Vendor */
-Display *
+/* FIXME: does this still exist?? */
+extern Display *
 XmeGetDefaultDisplay(void)
 {
     return _XmGetDefaultDisplay();
 }
 
-void 
+
+extern void 
 XmeAddFocusChangeCallback(Widget w, XtCallbackProc cp, XtPointer udata)
 {
-    XmWidgetExtData extData;
+    XmBaseClassExt *bce;
+    XtPointer nsec;
+    int size;
 
     if(!XmIsVendorShell(w))
     {
@@ -235,20 +194,33 @@ XmeAddFocusChangeCallback(Widget w, XtCallbackProc cp, XtPointer udata)
         return;
     }
 
-    extData = _XmGetWidgetExtData(w, XmSHELL_EXTENSION);
-    if (extData == NULL)
-    {
-        XmeWarning(w, "Can not find Vendor Shell Extention Data.");
-        return;
-    }
+    bce = _XmGetBaseClassExtPtr(XtClass(w), XmQmotif);
+    size = (*bce)->secondaryObjectClass->core_class.widget_size;
+    nsec = XtCalloc(1, size);
 
-    XtAddCallback(extData->widget, XmNfocusMovedCallback, cp, udata);
+    ((XmExtRec *)nsec)->object.self = (Widget)nsec;
+    ((XmExtRec *)nsec)->object.widget_class = (*bce)->secondaryObjectClass;
+    ((XmExtRec *)nsec)->object.parent = w;
+    ((XmExtRec *)nsec)->object.xrm_name = w->core.xrm_name;
+    ((XmExtRec *)nsec)->object.being_destroyed = False;
+    ((XmExtRec *)nsec)->object.destroy_callbacks = NULL;
+    ((XmExtRec *)nsec)->object.constraints = NULL;
+
+    ExtObj_LogicalParent(nsec) = w;
+    ExtObj_ExtensionType(nsec) = XmSHELL_EXTENSION;
+
+    _XtAddCallback(&VSEP_FocusMovedCallback(nsec),
+		   cp, udata);
+    XtFree((char *)nsec);
 }
 
-void
+
+extern void
 XmeRemoveFocusChangeCallback(Widget w, XtCallbackProc cp, XtPointer udata)
 {
-    XmWidgetExtData extData;
+    XmBaseClassExt *bce;
+    XtPointer nsec;
+    int size;
 
     if(!XmIsVendorShell(w))
     {
@@ -256,18 +228,29 @@ XmeRemoveFocusChangeCallback(Widget w, XtCallbackProc cp, XtPointer udata)
         return;
     }
 
-    extData = _XmGetWidgetExtData(w, XmSHELL_EXTENSION);
-    if (extData == NULL)
-    {
-        XmeWarning(w, "Can not find Vendor Shell Extention Data.");
-        return;
-    }
+    bce = _XmGetBaseClassExtPtr(XtClass(w), XmQmotif);
+    size = (*bce)->secondaryObjectClass->core_class.widget_size;
+    nsec = XtCalloc(1, size);
 
-    XtRemoveCallback(extData->widget, XmNfocusMovedCallback, cp, udata);
+    ((XmExtRec *)nsec)->object.self = (Widget)nsec;
+    ((XmExtRec *)nsec)->object.widget_class = (*bce)->secondaryObjectClass;
+    ((XmExtRec *)nsec)->object.parent = w;
+    ((XmExtRec *)nsec)->object.xrm_name = w->core.xrm_name;
+    ((XmExtRec *)nsec)->object.being_destroyed = False;
+    ((XmExtRec *)nsec)->object.destroy_callbacks = NULL;
+    ((XmExtRec *)nsec)->object.constraints = NULL;
+
+    ExtObj_LogicalParent(nsec) = w;
+    ExtObj_ExtensionType(nsec) = XmSHELL_EXTENSION;
+
+    _XtRemoveCallback(&VSEP_FocusMovedCallback(nsec),
+                      cp, udata);
+    XtFree((char *)nsec);
 }
 
+
 /* Visual */
-void
+extern void
 XmeGetDefaultPixel(Widget widget,
 		   int type,
 		   int offset,
@@ -287,11 +270,12 @@ XmeGetDefaultPixel(Widget widget,
 					  XmIsGadget(widget) ?
 					  XmParentBackground(widget) :
 					  XtBackground(widget)),
-			     type);
+					  type);
 }
 
+
 /* VirtKeys */
-void
+extern void
 XmeVirtualToActualKeysym(Display *Dsp,
 			 KeySym VirtualKeysym,
 			 KeySym *RealKeysymReturn,
@@ -301,36 +285,120 @@ XmeVirtualToActualKeysym(Display *Dsp,
 			     ModifierReturn);
 }
 
+
 /* XmString */
-void
+extern void
 XmeStringUpdateWMShellTitle(XmString xmstr, Widget shell)
 {
+   /* This is not specified by Motif 2.1 ... */
     _XmStringUpdateWMShellTitle(xmstr, shell);
 }
 
-void
+
+extern void
 XmeSetWMShellTitle(XmString xmstr, Widget shell)
 {
-	/* Apparently the same thing as the above. */
-	_XmStringUpdateWMShellTitle(xmstr, shell);
+    /* Apparently the same thing as the above. */
+    _XmStringUpdateWMShellTitle(xmstr, shell);
 }
 
+
 /* Xmos */
-int
+extern int
 XmeMicroSleep(long secs)
 {
     return _XmMicroSleep(secs);
 }
 
-/* Xmos */
-String
-XmeGetHomeDirName(void)
-{
-    return _XmOSGetHomeDirName();
-}
 
 XmFontList
 XmeGetDefaultRenderTable(Widget w, unsigned int fontListType)
 {
-	return NULL;
+	return (XmFontList)NULL;
+}
+
+
+/* Transfer */
+extern Atom
+*XmeStandardTargets(Widget w,
+                    int count,
+                    int *count_return)
+{
+   _XmWarning(NULL, "XmeStandardTargets(): not yet implemented!");
+   return (Atom *)NULL;
+}
+
+
+/* Transfer */
+extern void 
+XmeStandardConvert(Widget w,
+                   XtPointer ignore,
+                   XmConvertCallbackStruct *call_data)
+{
+   _XmWarning(NULL, "XmeStandardConvert(): not yet implemented!");
+}
+
+
+extern void
+XmeQueryBestCursorSize(Widget widget, Dimension *width, Dimension *height) 
+{
+   _XmWarning(NULL, "XmeQueryBestCursorSize(): not yet implemented!");
+}
+
+
+extern void
+XmeResolvePartOffsets(WidgetClass widget_class,
+                           XmOffsetPtr *offset,
+                           XmOffsetPtr *constraint_offset)
+{
+   _XmWarning(NULL, "XmeResolvePartOffsets(): not yet implemented!");
+}
+
+
+extern void 
+XmeConvertMerge(XtPointer data, Atom type,
+                int format, unsigned long length,
+                XmConvertCallbackStruct *call_data)
+{
+   _XmWarning(NULL, "XmeConvertMerge(): not yet implemented!");
+}
+
+
+extern Boolean
+XmeGetDesktopColorCells(Screen *screen,
+                        Colormap colormap,
+                        XColor *colors,
+                        int n_colors,
+                        int *n_colors_ret)
+{
+   _XmWarning(NULL, "XmeGetDesktopColorCells(): not yet implemented!");
+   return False;
+}
+
+
+extern Boolean
+XmeGetColorObjData(int *screen,
+                   int *coloruse,
+                   XmPixelSet *pixel_set,
+                   unsigned short pixel_set_size,
+                   short *active,
+                   short *inactive,
+                   short *primary,
+                   short *secondary,
+                   short *text)
+{
+   _XmWarning(NULL, "XmeGetColorObjData(): not yet implemented!");
+   return False;
+}
+
+
+extern Widget
+XmeCreateClassDialog(WidgetClass widget_class,
+                     Widget parent,
+                     String name,
+                     ArgList args,
+                     Cardinal arg_count)
+{
+   _XmWarning(NULL, "XmeCreateClassDialog(): not yet implemented!");
+   return NULL;
 }
