@@ -1,6 +1,6 @@
 /**
  * 
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/PrintShell.c,v 1.21 2001/07/27 18:51:58 dannybackx Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/PrintShell.c,v 1.22 2001/09/13 13:34:14 amai Exp $
  *
  * Copyright  2000,2001 LessTif Development Team
  *
@@ -22,7 +22,7 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/PrintShell.c,v 1.21 2001/07/27 18:51:58 dannybackx Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/PrintShell.c,v 1.22 2001/09/13 13:34:14 amai Exp $";
 
 #include <LTconfig.h>
 
@@ -116,7 +116,7 @@ static XtActionsRec actions[] =
 #if 0
     {"MenuShellPopdownOne", MenuShellPopdownOne},
 #endif
-    {NULL}
+    {NULL, NULL}
 };
 
 
