@@ -1,9 +1,9 @@
 /**
  *
- * $Id: ArrowB.c,v 1.34 2000/09/23 15:05:23 amai Exp $
+ * $Id: ArrowB.c,v 1.37 2001/07/27 18:51:55 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2000 LessTif Development Team
+ * Copyright (C) 1995-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: ArrowB.c,v 1.34 2000/09/23 15:05:23 amai Exp $";
+static const char rcsid[] = "$Id: ArrowB.c,v 1.37 2001/07/27 18:51:55 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -159,7 +159,6 @@ static void MultiArm(Widget w, XEvent *event,
 		     String *params, Cardinal *num_params);
 
 
-/* *INDENT-OFF* */
 static XtActionsRec actions[] = {
     {"Activate",                Activate},
     {"MultiActivate",           MultiActivate},
@@ -230,7 +229,6 @@ XmArrowButtonClassRec xmArrowButtonClassRec = {
 	/* extension */ NULL
     }
 };
-/* *INDENT-ON* */
 
 
 WidgetClass xmArrowButtonWidgetClass = (WidgetClass)&xmArrowButtonClassRec;
@@ -239,8 +237,8 @@ WidgetClass xmArrowButtonWidgetClass = (WidgetClass)&xmArrowButtonClassRec;
 static void
 class_initialize(void)
 {
-    if (! XmeTraitSet(xmArrowButtonWidgetClass, XmQTactivatable,
-		&_XmArrowBTraitRec)) {
+    if (! XmeTraitSet((XtPointer)xmArrowButtonWidgetClass, XmQTactivatable,
+		(XtPointer)&_XmArrowBTraitRec)) {
 	_XmWarning(NULL,
 	    "XmArrowButtonWidget ClassInitialize: XmeTraitSet failed\n");
     }
@@ -353,7 +351,7 @@ set_values(Widget old, Widget request, Widget new_w,
 			     AB_MultiClick(new_w), new_w))
 	AB_MultiClick(new_w) = AB_MultiClick(old);
 
-    DEBUGOUT(XdbDebug(__FILE__, new_w, "ArrowB set_values\n"));
+    DEBUGOUT(_LtDebug(__FILE__, new_w, "ArrowB set_values\n"));
 
     if (AB_Direction(old) != AB_Direction(new_w) ||
 #if XmVERSION > 1
@@ -473,7 +471,7 @@ Arm(Widget w, XEvent *event, String *params, Cardinal *num_params)
     int margin;
     XmArrowButtonCallbackStruct cbs;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "Arm\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "Arm\n"));
 
     if (!AB_Armed(w))
     {
@@ -522,7 +520,7 @@ Activate(Widget w, XEvent *event, String *params, Cardinal *num_params)
     XmArrowButtonCallbackStruct cbs;
     XButtonEvent *ev = (XButtonEvent *)event;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "Activate 000\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "Activate 000\n"));
 
     if (XtIsRealized(w))
     {
@@ -567,7 +565,7 @@ Disarm(Widget w, XEvent *event, String *params, Cardinal *num_params)
     int margin;
     XmArrowButtonCallbackStruct cbs;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "Disarm\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "Disarm\n"));
 
     if (AB_Armed(w))
     {
@@ -608,7 +606,7 @@ ArmTimeout(XtPointer data, XtIntervalId *id)
     int margin;
     Widget w = (Widget)data;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "ArmTimeout\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "ArmTimeout\n"));
 
     AB_Timer(w) = 0;
 
@@ -650,7 +648,7 @@ ArmAndActivate(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
     XmArrowButtonCallbackStruct cbs;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "ArmAndActivate\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "ArmAndActivate\n"));
 
     /* Arm, Activate, and Disarm now, but draw the disarmed state later */
 
@@ -692,7 +690,7 @@ EnterWindow(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
     int margin = Prim_ShadowThickness(w) + Prim_HighlightThickness(w);
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "EnterWindow\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "EnterWindow\n"));
 
     if (AB_Armed(w))
     {
@@ -716,7 +714,7 @@ LeaveWindow(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
     int margin = Prim_ShadowThickness(w) + Prim_HighlightThickness(w);
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "LeaveWindow\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "LeaveWindow\n"));
 
     if (AB_Armed(w))
     {
@@ -738,7 +736,7 @@ LeaveWindow(Widget w, XEvent *event, String *params, Cardinal *num_params)
 static void
 MultiArm(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(XdbDebug(__FILE__, w, "MultiArm\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "MultiArm\n"));
 
     if (AB_MultiClick(w) == XmMULTICLICK_KEEP)
     {
@@ -753,7 +751,7 @@ MultiActivate(Widget w, XEvent *event, String *params, Cardinal *num_params)
     XButtonEvent *ev = (XButtonEvent *)event;
     XmPushButtonCallbackStruct cbs;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "PushB: MultiClick\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "PushB: MultiClick\n"));
 
     if (AB_MultiClick(w) == XmMULTICLICK_KEEP)
     {
