@@ -1,8 +1,9 @@
 /**
  *
- * $Id: ArrowBG.c,v 1.25 1999/03/06 05:26:17 gritton Exp $
+ * $Id: ArrowBG.c,v 1.33 2001/07/27 18:51:55 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,11 +23,11 @@
  *
  **/
 
-static const char rcsid[] = "$Id: ArrowBG.c,v 1.25 1999/03/06 05:26:17 gritton Exp $";
+static const char rcsid[] = "$Id: ArrowBG.c,v 1.33 2001/07/27 18:51:55 dannybackx Exp $";
 
 #include <LTconfig.h>
-#include <XmI/XmI.h>
 
+#include <XmI/XmI.h>
 #include <Xm/XmP.h>
 #include <Xm/ArrowBGP.h>
 #include <Xm/RepType.h>
@@ -64,7 +65,7 @@ static XmActivatableTraitRec _XmArrowBGTraitRec = {
 
 
 #if XmVERSION > 1
-static void class_initialize();
+static void class_initialize(void);
 #endif
 
 static void class_part_initialize(WidgetClass w_class);
@@ -160,7 +161,6 @@ static void LeaveWindow(Widget w, XEvent *event,
 			String *params, Cardinal *num_params);
 
 
-/* *INDENT-OFF* */
 #if 0
 static XmBaseClassExtRec _XmArrowBGRectClassExtRec = {
     /* next_extension            */ NULL,
@@ -259,7 +259,6 @@ XmArrowButtonGadgetClassRec xmArrowButtonGadgetClassRec = {
 	/* extension */ NULL
     },
 };
-/* *INDENT-ON* */
 
 
 WidgetClass xmArrowButtonGadgetClass =
@@ -267,14 +266,14 @@ WidgetClass xmArrowButtonGadgetClass =
 
 #if XmVERSION > 1
 static void
-class_initialize()
+class_initialize(void)
 {
 #if 0
     _XmArrowBGRectClassExtRec.record_type = XmQmotif;
 #endif
 
-    if (! XmeTraitSet(xmArrowButtonGadgetClass, XmQTactivatable,
-		&_XmArrowBGTraitRec)) {
+    if (! XmeTraitSet((XtPointer)xmArrowButtonGadgetClass, XmQTactivatable,
+		(XtPointer)&_XmArrowBGTraitRec)) {
 	_XmWarning(NULL,
 	    "XmArrowButtonGadget ClassInitialize: XmeTraitSet failed\n");
     }
@@ -380,6 +379,7 @@ destroy(Widget w)
     if (ABG_Timer(w) != 0)
     {
 	XtRemoveTimeOut(ABG_Timer(w));
+	ABG_Timer(w) = 0;
     }
 
     XtReleaseGC(w, ABG_ArrowGC(w));
@@ -641,7 +641,7 @@ ArmTimeout(XtPointer data, XtIntervalId *id)
     int margin;
     Widget w = (Widget)data;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "ArmTimeout\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "ArmTimeout\n"));
 
     ABG_Timer(w) = 0;
 
@@ -683,7 +683,7 @@ ArmAndActivate(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
     XmArrowButtonCallbackStruct cbs;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "ArmAndActivate\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "ArmAndActivate\n"));
 
     /* Arm, Activate, and Disarm now, but draw the disarmed state later */
 
@@ -713,6 +713,7 @@ ArmAndActivate(Widget w, XEvent *event, String *params, Cardinal *num_params)
     if (ABG_Timer(w) != 0)
     {
 	XtRemoveTimeOut(ABG_Timer(w));
+	ABG_Timer(w) = 0;
     }
 
     ABG_Timer(w) = XtAppAddTimeOut(XtWidgetToApplicationContext(w),
@@ -787,26 +788,26 @@ input_dispatch(Widget gadget, XEvent *event, Mask event_mask)
     switch (event_mask)
     {
     case XmARM_EVENT:
-	DEBUGOUT(XdbDebug(__FILE__, gadget,
+	DEBUGOUT(_LtDebug(__FILE__, gadget,
 		 "ArrowButtonGadget got arm event\n"));
 	Arm(gadget, event, NULL, &num_params);
 	break;
 
     case XmACTIVATE_EVENT:
-	DEBUGOUT(XdbDebug(__FILE__, gadget,
+	DEBUGOUT(_LtDebug(__FILE__, gadget,
 		 "ArrowButtonGadget got activate event\n"));
 	ABG_ClickCount(gadget) = 1;
 	Activate(gadget, event, NULL, &num_params);
 	break;
 
     case XmENTER_EVENT:
-	DEBUGOUT(XdbDebug(__FILE__, gadget,
+	DEBUGOUT(_LtDebug(__FILE__, gadget,
 		 "ArrowButtonGadget got enter event\n"));
 	EnterWindow(gadget, event, NULL, &num_params);
 	break;
 
     case XmLEAVE_EVENT:
-	DEBUGOUT(XdbDebug(__FILE__, gadget,
+	DEBUGOUT(_LtDebug(__FILE__, gadget,
 		 "ArrowButtonGadget got leave event\n"));
 	LeaveWindow(gadget, event, NULL, &num_params);
 	break;
