@@ -1,8 +1,9 @@
 /**
  *
- * $Id: BulletinBoard.c,v 1.49 1999/07/28 17:45:29 danny Exp $
+ * $Id: BulletinBoard.c,v 1.62 2001/07/27 18:51:55 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,9 +23,10 @@
  *
  **/
 
-static const char rcsid[] = "$Id: BulletinBoard.c,v 1.49 1999/07/28 17:45:29 danny Exp $";
+static const char rcsid[] = "$Id: BulletinBoard.c,v 1.62 2001/07/27 18:51:55 dannybackx Exp $";
 
 #include <LTconfig.h>
+
 #include <XmI/XmI.h>
 
 #include <Xm/XmP.h>
@@ -39,9 +41,31 @@ static const char rcsid[] = "$Id: BulletinBoard.c,v 1.49 1999/07/28 17:45:29 dan
 #include <Xm/PushB.h>
 #include <Xm/PushBG.h>
 #include <Xm/MwmUtil.h>
+#include <Xm/VendorSEP.h>
 
 #include <XmI/DebugUtil.h>
 
+/* #defines being used in this file:
+      #ifdef USE_WIDGETS
+*/
+
+
+/* We use a 'private', i.e. non-declared but actually
+   exported call from OpenGroup's Intrinsic sources
+   (lib/Xt/Callback.c) in this file.
+   Note that we don't give the precise type here ...
+ */
+extern void 
+_XtRemoveAllCallbacks(
+  /* InternalCallbackList *callbacks; */
+ void *callbacks);
+
+/* similar for this ... */
+extern void
+_XtAddCallback(XtCallbackList *,
+               XtCallbackProc,
+               XtPointer);
+
 /* Forward Declarations */
 
 static void class_initialize(void);
@@ -233,7 +257,7 @@ static XtActionsRec actions[] =
 
 static XtTranslations mapTrans;
 static XtTranslations defTrans;
-/* *INDENT-OFF* */
+
 #if 0
 static XmBaseClassExtRec _XmBulletinBCoreClassExtRec = {
     /* next_extension            */ NULL,
@@ -354,7 +378,6 @@ XmBulletinBoardClassRec xmBulletinBoardClassRec = {
 	/* extension			*/ NULL,
     },
 };
-/* *INDENT-ON* */
 
 
 WidgetClass xmBulletinBoardWidgetClass = (WidgetClass)&xmBulletinBoardClassRec;
@@ -464,8 +487,11 @@ initialize(Widget request, Widget new_w, ArgList args, Cardinal *num_args)
 	BB_TextFontList(bb) = XmFontListCopy(BB_TextFontList(new_w));
     }
 
-    XtAugmentTranslations(new_w, mapTrans);
-    XtAugmentTranslations(new_w, defTrans);
+    if (((XmBulletinBoardWidgetClass)XtClass(new_w))->bulletin_board_class.always_install_accelerators)
+    {
+	XtAugmentTranslations(new_w, mapTrans);
+	XtAugmentTranslations(new_w, defTrans);
+    }
     /* rws 30 Aug 1998
        We seem to loose a few hundred bytes every time we parse a translation
        table, so like mapTrans lets parse it in class_initialize and use the
@@ -553,8 +579,9 @@ initialize(Widget request, Widget new_w, ArgList args, Cardinal *num_args)
 
 	if ((ve = _LtFindVendorExt(new_w)) != NULL)
 	{
-	    XtAddCallback(ve, XmNfocusMovedCallback,
-			bbclass->bulletin_board_class.focus_moved_proc, new_w);
+	    _XtAddCallback(&VSEP_FocusMovedCallback(ve),
+			   bbclass->bulletin_board_class.focus_moved_proc,
+                           (XtPointer)new_w);
 	}
     }
 
@@ -563,6 +590,7 @@ initialize(Widget request, Widget new_w, ArgList args, Cardinal *num_args)
     BB_OldHeight(new_w) = -1;
 
     BB_GeoCache(new_w) = NULL;
+    MGR_InitialFocus(new_w) = BB_DefaultButton(new_w);
     BB_InSetValues(new_w) = False;
 }
 
@@ -571,15 +599,21 @@ destroy(Widget w)
 {
   Widget ve;
 
-    DEBUGOUT(XdbDebug("RWS", w,"%s:destroy(%d)\n",
+    DEBUGOUT(_LtDebug("RWS", w,"%s:destroy(%d)\n",
     	__FILE__, __LINE__
     	));
+
+    if (BB_DialogTitle(w))
+        XmStringFree(BB_DialogTitle(w));
     XmFontListFree(BB_LabelFontList(w));
     XmFontListFree(BB_ButtonFontList(w));
     XmFontListFree(BB_TextFontList(w));
     if ((ve = _LtFindVendorExt(w)) != NULL)
       {
+	_XtRemoveAllCallbacks(&VSEP_FocusMovedCallback(ve));
+	/* mitch
 	XtRemoveAllCallbacks(ve,XmNfocusMovedCallback);
+	*/
       }
     
 
@@ -596,7 +630,7 @@ set_values(Widget old,
     XmBulletinBoardWidget nw = (XmBulletinBoardWidget)new_w;
     Boolean need_refresh = False;
 
-    DEBUGOUT(XdbDebug(__FILE__, new_w,
+    DEBUGOUT(_LtDebug(__FILE__, new_w,
 		      "%s(%d):set_values - %i args\n"
 		      "\t    old X %5i Y %5i W %5i H %5i\n"
 		      "\trequest X %5i Y %5i W %5i H %5i\n"
@@ -609,13 +643,13 @@ set_values(Widget old,
 		      XtWidth(request), XtHeight(request),
 		      XtX(new_w), XtY(new_w),
 		      XtWidth(new_w), XtHeight(new_w)));
-    DEBUGOUT(XdbPrintArgList(__FILE__, new_w, args, *num_args, False));
+    DEBUGOUT(_LtDebugPrintArgList(__FILE__, new_w, args, *num_args, False));
 
     BB_InSetValues(new_w) = True;
 
     if (BB_DefaultButton(ow) != BB_DefaultButton(nw))
     {
-	int i;
+	Cardinal i;
 
 	/* the default button has changed, so set the old one's showAsDefault
 	   to 0, and make the new one display as the default. */
@@ -627,6 +661,7 @@ set_values(Widget old,
 
 	_XmBBUpdateDynDefaultButton(new_w);
 
+	MGR_InitialFocus(new_w) = BB_DefaultButton(nw);
 	need_refresh = True;	/* do we need to ? */
     }
 
@@ -648,6 +683,11 @@ set_values(Widget old,
 		BB_DialogTitle(new_w) = XmStringCopy(BB_DialogTitle(new_w));
 	    }
 
+            XmStringFree(BB_DialogTitle(old));
+        }
+        else if (BB_DialogTitle(old) != BB_DialogTitle(new_w))
+        {
+            BB_DialogTitle(new_w) = XmStringCopy(BB_DialogTitle(new_w));
 	    XmStringFree(BB_DialogTitle(old));
 	}
 
@@ -742,9 +782,9 @@ query_geometry(Widget w, XtWidgetGeometry *proposed, XtWidgetGeometry *answer)
     XmBulletinBoardWidgetClass bbc = (XmBulletinBoardWidgetClass)XtClass(w);
     XtGeometryResult res;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "%s:query_geometry(%d) - proposed %s\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "%s:query_geometry(%d) - proposed %s\n",
     		__FILE__, __LINE__,
-    		XdbWidgetGeometry2String(proposed)));
+    		_LtDebugWidgetGeometry2String(proposed)));
 
     if (bbc->bulletin_board_class.geo_matrix_create)
     {
@@ -758,7 +798,7 @@ query_geometry(Widget w, XtWidgetGeometry *proposed, XtWidgetGeometry *answer)
 				   BB_MarginWidth(w), BB_MarginHeight(w),
 				   BB_ResizePolicy(w));
 
-    DEBUGOUT(XdbDebug(__FILE__, w,
+    DEBUGOUT(_LtDebug(__FILE__, w,
 		      "BB wants %d %d\n", answer->width, answer->height));
 
     return res;
@@ -806,7 +846,7 @@ resize(Widget w)
 {
     XmBulletinBoardClassRec *bb = (XmBulletinBoardClassRec *)XtClass(w);
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "resize\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "resize\n"));
 
     if (bb->bulletin_board_class.geo_matrix_create)
     {
@@ -869,9 +909,9 @@ handle_geometry_manager(Widget w,
     Widget bb = XtParent(w);
     XtGeometryResult res;
 
-    DEBUGOUT(XdbDebug2(__FILE__, bb, w,
+    DEBUGOUT(_LtDebug2(__FILE__, bb, w,
 		       "handle_geometry_manager\n\tdesired %s\n",
-		       	XdbWidgetGeometry2String(desired)));
+		       	_LtDebugWidgetGeometry2String(desired)));
 
     if (!(desired->request_mode & (CWWidth | CWHeight)))
     {
@@ -924,7 +964,7 @@ geometry_manager(Widget w, XtWidgetGeometry *desired, XtWidgetGeometry *allowed)
     Widget bb = XtParent(w);
     XmBulletinBoardWidgetClass bbc = (XmBulletinBoardWidgetClass)XtClass(bb);
 
-    DEBUGOUT(XdbDebug2(__FILE__, bb, w, "GeometryManager\n"));
+    DEBUGOUT(_LtDebug2(__FILE__, bb, w, "GeometryManager\n"));
 
     if (bbc->bulletin_board_class.geo_matrix_create)
     {
@@ -1009,9 +1049,9 @@ handle_change_managed(Widget w, XmGeoCreateProc mat_make)
     XtGeometryResult res;
 
 	res = _XmMakeGeometryRequest(w, &request);
-	DEBUGOUT(XdbDebug(__FILE__, w, "handle_change_managed request %s %s\n",
-		XdbWidgetGeometry2String(&request),
-		XdbGeometryResult2String(res)));
+	DEBUGOUT(_LtDebug(__FILE__, w, "handle_change_managed request %s %s\n",
+		_LtDebugWidgetGeometry2String(&request),
+		_LtDebugGeometryResult2String(res)));
     	if (res == XtGeometryNo)
     	{
 	    /* rws 16 Aug 1998
@@ -1056,7 +1096,7 @@ change_managed(Widget w)
 {
     XmBulletinBoardClassRec *bb = (XmBulletinBoardClassRec *)XtClass(w);
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "ChangeManaged\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "ChangeManaged\n"));
 
     if (bb->bulletin_board_class.geo_matrix_create)
     {
@@ -1129,8 +1169,8 @@ XmCreateBulletinBoardDialog(Widget parent, char *name,
 static void
 constraint_initialize(Widget request, Widget new_w, Arg *args, Cardinal *nargs)
 {
-    DEBUGOUT(XdbDebug(__FILE__, new_w, "constraint_initialize\n"));
-    DEBUGOUT(XdbDebug2(__FILE__, XtParent(new_w), new_w,
+    DEBUGOUT(_LtDebug(__FILE__, new_w, "constraint_initialize\n"));
+    DEBUGOUT(_LtDebug2(__FILE__, XtParent(new_w), new_w,
 		       "_XmBulletinBoardconstraint_initialize: %i args\n\t"
 		       "request X %5i Y %5i W %5i H %5i\n\t  new_w X %5i Y %5i"
 		       " W %5i H %5i\n\t   BB W %5i H %5i\n",
@@ -1141,7 +1181,7 @@ constraint_initialize(Widget request, Widget new_w, Arg *args, Cardinal *nargs)
 		       XtWidth(new_w), XtHeight(new_w),
 		       XtWidth(XtParent(new_w)), XtHeight(XtParent(new_w))));
 
-    DEBUGOUT(XdbPrintArgList(__FILE__, new_w, args, *nargs, False));
+    DEBUGOUT(_LtDebugPrintArgList(__FILE__, new_w, args, *nargs, False));
 
     if (XtWidth(request) != 0)
     {
@@ -1157,9 +1197,9 @@ static Boolean
 constraint_set_values(Widget old, Widget request, Widget new_w,
 		      Arg *args, Cardinal *nargs)
 {
-    DEBUGOUT(XdbDebug2(__FILE__, XtParent(new_w), new_w,
+    DEBUGOUT(_LtDebug2(__FILE__, XtParent(new_w), new_w,
 		       "constraint_set_values\n"));
-    DEBUGOUT(XdbDebug2(__FILE__, XtParent(new_w), new_w,
+    DEBUGOUT(_LtDebug2(__FILE__, XtParent(new_w), new_w,
 		       "_XmBulletinBoardconstraint_set_values: %i args\n\t"
 		       "current X %5i Y %5i W %5i H %5i\n\trequest X %5i Y %5i"
 		       " W %5i H %5i\n\t  new_w X %5i Y %5i W %5i H %5i\n\t"
@@ -1172,7 +1212,7 @@ constraint_set_values(Widget old, Widget request, Widget new_w,
 		       XtX(new_w), XtY(new_w),
 		       XtWidth(new_w), XtHeight(new_w),
 		       XtWidth(XtParent(new_w)), XtHeight(XtParent(new_w))));
-    DEBUGOUT(XdbPrintArgList(__FILE__, new_w, args, *nargs, False));
+    DEBUGOUT(_LtDebugPrintArgList(__FILE__, new_w, args, *nargs, False));
 
     return False;
 }
@@ -1264,7 +1304,7 @@ realize(Widget w,
     if (XtHeight(w) == 0) XtHeight(w) = 1;
 #endif
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "%s:realize(%d) - %dx%d\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "%s:realize(%d) - %dx%d\n",
     	__FILE__, __LINE__,
     	XtWidth(w), XtHeight(w)));
 
@@ -1314,7 +1354,7 @@ realize(Widget w,
 static void
 expose(Widget w, XEvent *event, Region region)
 {
-    DEBUGOUT(XdbDebug(__FILE__, w, "expose\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "expose\n"));
 
     if (BB_OldWidth(w) != XtWidth(w) ||
         BB_OldHeight(w) != XtHeight(w) ||
@@ -1345,7 +1385,7 @@ _XmBbButton(Widget w, XtPointer client, XtPointer call)
 {
     XmBulletinBoardWidget bb = (XmBulletinBoardWidget)XtParent(w);
 
-    DEBUGOUT(XdbDebug2(__FILE__, (Widget)bb, w, "XmBbButton\n"));
+    DEBUGOUT(_LtDebug2(__FILE__, (Widget)bb, w, "XmBbButton\n"));
 
     /*
      * How do we make sure the APPLY or HELP buttons don't
@@ -1361,7 +1401,7 @@ _XmBbButton(Widget w, XtPointer client, XtPointer call)
 	if (XtIsSubclass(s, xmDialogShellWidgetClass))
 	{
 	    XtUnmanageChild((Widget)bb);
-	    DEBUGOUT(XdbDebug2(__FILE__, (Widget)bb, w, "AutoUnmanage\n"));
+	    DEBUGOUT(_LtDebug2(__FILE__, (Widget)bb, w, "AutoUnmanage\n"));
 
 #if 0
 	    /* rws 19 Sep 1998
@@ -1401,7 +1441,7 @@ delete_child(Widget w)
 {
     Widget bb = XtParent(w);
 
-    DEBUGOUT(XdbDebug2(__FILE__, bb, w, "delete_child\n"));
+    DEBUGOUT(_LtDebug2(__FILE__, bb, w, "delete_child\n"));
 
 #define	superclass	(&xmManagerClassRec)
     (*superclass->composite_class.delete_child) (w);
@@ -1411,12 +1451,25 @@ delete_child(Widget w)
     {
 	BB_CancelButton(bb) = NULL;
     }
+    if (w == BB_DynamicCancelButton(bb))
+    {
+	BB_DynamicCancelButton(bb) = NULL;
+    }
+    if (w == BB_DynamicDefaultButton(bb))
+    {
+	BB_DynamicDefaultButton(bb) = NULL;
+    }
+    if (w == BB_DefaultButton(bb))
+    {
+	BB_DefaultButton(bb) = NULL;
+	MGR_InitialFocus(bb) = NULL;
+    }
 }
 
 static Boolean
 _XmBBParentProcess(Widget widget, XmParentProcessData data)
 {
-    DEBUGOUT(XdbDebug(__FILE__, widget, "_XmBBParentProcess\n"));
+    DEBUGOUT(_LtDebug(__FILE__, widget, "_XmBBParentProcess\n"));
 
     if (data->input_action.process_type == XmINPUT_ACTION)
     {
@@ -1444,10 +1497,10 @@ _XmBBParentProcess(Widget widget, XmParentProcessData data)
 	}
 	else if (data->input_action.action == XmPARENT_CANCEL)
 	{
-	    DEBUGOUT(XdbDebug(__FILE__, widget, "_XmBBParentProcess CANCEL\n"));
+	    DEBUGOUT(_LtDebug(__FILE__, widget, "_XmBBParentProcess CANCEL\n"));
 	    if (BB_CancelButton(widget))
 	    {
-		DEBUGOUT(XdbDebug(__FILE__, widget, "_XmBBParentProcess CANCEL %s\n",XtName(BB_CancelButton(widget))));
+		DEBUGOUT(_LtDebug(__FILE__, widget, "_XmBBParentProcess CANCEL %s\n",XtName(BB_CancelButton(widget))));
 		_XmBulletinBoardCancel(widget,
 				       data->input_action.event,
 				       data->input_action.params,
@@ -1460,7 +1513,7 @@ _XmBBParentProcess(Widget widget, XmParentProcessData data)
 	    Widget w = XtParent(widget);
 	    XmManagerWidgetClass mwc = (XmManagerWidgetClass)w->core.widget_class;
 
-		DEBUGOUT(XdbDebug(__FILE__, widget, "_XmBBParentProcess CANCEL no button\n"));
+		DEBUGOUT(_LtDebug(__FILE__, widget, "_XmBBParentProcess CANCEL no button\n"));
 		if (XmIsManager(w) && mwc->manager_class.parent_process)
 		{
 		    return((*mwc->manager_class.parent_process) (w, data));
@@ -1567,7 +1620,11 @@ _XmBulletinBoardFocusMoved(Widget wid, XtPointer client_data, XtPointer data)
     Widget default_button = NULL;
     Widget par;
 
-    DEBUGOUT(XdbDebug(__FILE__, wid, "_XmBulletinBoardFocusMoved\n"));
+    DEBUGOUT(_LtDebug(__FILE__, wid, "%s:%d - %s %s %s\n",
+    	__FILE__, __LINE__,
+    	cbs->cont ? "True" : "False",
+    	cbs->old_focus ? XtName(cbs->old_focus) : "NULL",
+    	cbs->new_focus ? XtName(cbs->new_focus) : "NULL"));
 
     if (!cbs->cont)
     {
@@ -1778,6 +1835,10 @@ _XmBulletinBoardSetDynDefaultButton(Widget wid, Widget newDefaultButton)
 {
     Arg argl[2];
 
+    DEBUGOUT(_LtDebug(__FILE__, wid, "%s:%d - %s\n",
+    	__FILE__, __LINE__,
+    	newDefaultButton ? XtName(newDefaultButton) : "NULL"));
+
     if (newDefaultButton && wid != XtParent(newDefaultButton))
     {
     	return;
@@ -1812,7 +1873,14 @@ _XmBulletinBoardSetDynDefaultButton(Widget wid, Widget newDefaultButton)
 void
 _XmBBUpdateDynDefaultButton(Widget bb)
 {
-    if (BB_DynamicDefaultButton(bb))
+    DEBUGOUT(_LtDebug(__FILE__, bb, "%s:_XmBBUpdateDynDefault(%d) - %s(%smanaged) %s\n",
+    	__FILE__, __LINE__,
+    	BB_DynamicDefaultButton(bb) ? XtName(BB_DynamicDefaultButton(bb)) : "NULL",
+    	BB_DynamicDefaultButton(bb) ? XtIsManaged(BB_DynamicDefaultButton(bb)) ? "" : "not " : "not ",
+    	BB_DefaultButton(bb) ? XtName(BB_DefaultButton(bb)) : "NULL"));
+
+    if (BB_DynamicDefaultButton(bb) &&
+        XtIsManaged(BB_DynamicDefaultButton(bb)))
     {
 	_XmBulletinBoardSetDynDefaultButton(bb, BB_DynamicDefaultButton(bb));
     }
@@ -1838,6 +1906,5 @@ _XmBulletinBoardDialogStyleDefault(Widget w,
 	style = XmDIALOG_WORK_AREA;
     }
 
-    val->addr = (XtPointer)&style;
+    val->addr = (XPointer)&style;
 }
-
