@@ -1,6 +1,6 @@
 /**
  *
- * $Id: DebugUtil.c,v 1.83 2001/07/27 18:51:55 dannybackx Exp $
+ * $Id: DebugUtil.c,v 1.89 2001/12/14 12:14:21 amai Exp $
  * 
  * Copyright (C) 1995 Free Software Foundation, Inc.
  * Copyright (C) 1995-2001 LessTif Development Team 
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: DebugUtil.c,v 1.83 2001/07/27 18:51:55 dannybackx Exp $";
+static const char rcsid[] = "$Id: DebugUtil.c,v 1.89 2001/12/14 12:14:21 amai Exp $";
 
 #include <LTconfig.h>
 
@@ -46,6 +46,9 @@ static const char rcsid[] = "$Id: DebugUtil.c,v 1.83 2001/07/27 18:51:55 dannyba
 #include <Xm/DrawingAP.h>
 #include <Xm/Display.h>
 
+/* for strcasecmp(), etc. */
+#include "LTmisc.h"
+
 /* This includes <dmalloc.h> if required */
 #include <XmI/DebugUtil.h>
 /* this we need to fetch explicitly? */
@@ -104,9 +107,8 @@ static Boolean siginstall(void);
  * - DEBUG_SIGNAL: define to the macro which belongs to the signal which
  *      should be accepted by the program as a switch to toggle
  *      debugging on/off. No value or "none" will turn the feature off.
- *      Valid values are compile time dependent (WRT libXm) and
- *      are currently a subset of: SIGBREAK, SIGUSR1, SIGUSR2
- *      e.g. DEBUG_SIGNAL=SIGUSR1
+ *      Valid values are compile time dependent (WRT libXm),
+ *      check below what's actually supported.
  *
  *  - DEBUG_TOGGLE: initial value whether debugging should be
  *      enabled or disabled upon program start. Valid Values are on/off.
@@ -542,11 +544,23 @@ static const struct
 	XmNnumColumns, _LtDebugSHORT, NULL
     }
     ,
+    {
+	XmNinitialFocus, _LtDebugWIDGET, NULL
+    }
+    ,
 #if XmVERSION > 1
     {
 	XmNcomboBoxType, _LtDebugCOMBOBOX_TYPE, NULL
     }
     ,
+    {
+	XmNlargeCellWidth, _LtDebugINT, NULL
+    }
+    ,
+    {
+    	XmNlargeCellHeight, _LtDebugINT, NULL
+    }
+    ,
 #endif
     {
 	NULL, 0, NULL
@@ -559,7 +573,8 @@ static const struct
 #ifndef LESSTIF_PRODUCTION
 /* catches the signal defined by DEBUG_SIGNAL and toggles the
    global debugging flag.
-   Avoid calling C-runtime function from within here if possible */
+   Avoid calling C-runtime functions from within here if possible 
+   (which in turn might also raise signals) */
 static void
 sighandler (int signo)
 {
@@ -589,7 +604,7 @@ siginstall (void)
 #ifdef DEBUGSIG
       fprintf (stderr, "siginstall(): trying to catch %s\n", ptr);
 #endif
-      if ((*ptr == '\0')||(strcmp(ptr, "none")==0))
+      if ((*ptr == '\0')||(strcasecmp(ptr, "none")==0))
 	{
 	  fprintf(stderr, "siginstall(): empty value for DEBUG_SIGNAL\n");
 	}
@@ -608,6 +623,10 @@ siginstall (void)
 #if defined(SIGUSR2)
       else if (strcmp (ptr, "SIGUSR2") == 0)
 	signo = SIGUSR2;
+#endif
+#if defined(SIGUSR3)
+      else if (strcmp (ptr, "SIGUSR3") == 0)
+	signo = SIGUSR3;
 #endif
       else
 	fprintf(stderr, "siginstall(): unknown signal in DEBUG_SIGNAL: %s\n",
@@ -704,18 +723,18 @@ _LtDebugOpenFile(void)
         char *formatstr, *p;
 	
         fn = XtMalloc(strlen(s) + 10);
-	formatstr=XtMalloc(strlen(s)+1);
-	strcpy(formatstr, s);
-	p = strstr(formatstr, "%p");
-	*(p + 1) = 'd';
-	sprintf(fn, s, getpid());
-	XtFree(formatstr);
+        formatstr=XtMalloc(strlen(s)+1);
+        strcpy(formatstr, s);
+        p = strstr(formatstr, "%p");
+        *(p + 1) = 'd';
+        sprintf(fn, s, getpid());
+        XtFree(formatstr);
     }
     else
 #endif /* HAVE_GETPID */
     {
         fn = XtMalloc(strlen(s) + 1);
-	strcpy(fn, s);
+        strcpy(fn, s);
     }
 
     /* "a" means append, create if doesn't exist */
@@ -724,8 +743,8 @@ _LtDebugOpenFile(void)
     {
         /* if fopen() fails do something reasonable */
         fprintf(stderr, "_LtDebugOpenFile(): Can't open file %s\n", fn);
-	_LtDebugFile = stderr;
-	/* disable buffering */
+        _LtDebugFile = stderr;
+        /* disable buffering */
         setbuf(_LtDebugFile, NULL);
     }
     else
@@ -735,7 +754,6 @@ _LtDebugOpenFile(void)
     }
     XtFree(fn);
 }
-#endif /* #ifndef LESSTIF_PRODUCTION */
 
 
 /*
@@ -744,7 +762,6 @@ _LtDebugOpenFile(void)
  * The ".c" suffix for sources is not required (i.e. Form is equivalent
  * to Form.c).
  */
-#ifndef LESSTIF_PRODUCTION
 static Boolean
 ValidateSource(const char *fn)
 {
@@ -765,8 +782,8 @@ ValidateSource(const char *fn)
           /* for compatibility with earlier versions */
           sourcelist = getenv("DEBUGSOURCES");
        }
-       
-       if ( sourcelist && (strcmp(sourcelist, "all")!=0) && (strcmp(sourcelist, "none")!=0) ) 
+       /* No keyword "all" or "none" */       
+       if ( sourcelist && (strcasecmp(sourcelist, "all")!=0) && (strcasecmp(sourcelist, "none")!=0) ) 
          {
           const char *s, *p;
 
@@ -817,10 +834,10 @@ ValidateSource(const char *fn)
           search is later on required: */
 
        /* list does not exist, is empty or set to "none" */
-       if ((!sourcelist) || (!*sourcelist) || (strcmp(sourcelist, "none")==0) )
+       if ((!sourcelist) || (!*sourcelist) || (strcasecmp(sourcelist, "none")==0) )
 	  flag_none = True;
        /* "all" Sources */
-       else if (strcmp(sourcelist, "all") == 0)
+       else if (strcasecmp(sourcelist, "all") == 0)
           flag_all = True;
 
        init = True;
@@ -1068,6 +1085,18 @@ _LtDebugToggle(void)
 }
 
 
+/* Allow user to query the state of Debugging System */
+extern Boolean
+_LtDebugQueryState(void)
+{
+#ifndef LESSTIF_PRODUCTION
+  return _LtDebugFlag;
+#else
+  return False;
+#endif
+}
+
+
 #ifndef LESSTIF_PRODUCTION
 static Boolean
 __LtDebugPrintWidgetID(void)
@@ -1129,6 +1158,7 @@ __LtDebugPrintTree(Widget w, int level)
 }
 #endif
 
+
 extern void 
 _LtDebugPrintTree(Widget w)
 {
@@ -1159,7 +1189,7 @@ extern void
 _LtDebugPrintArgList(const char *fn, Widget w, ArgList al, int n, Boolean Get)
 {
 #ifndef LESSTIF_PRODUCTION
-    int i, j;
+    int i;
     unsigned num;
 
     if (_LtDebugFlag && ValidateSource(fn))
@@ -1304,9 +1334,10 @@ _LtDebugPrintArgList(const char *fn, Widget w, ArgList al, int n, Boolean Get)
 
 		if (num != 0xdeadbeef)
 		{
-		    fprintf(_LtDebugFile, "Arg[%d] : %s(%d):\n", i, al[i].name, num);
+		    int j;
 
-		    for (j = 0; j < num; j++)
+		    fprintf(_LtDebugFile, "Arg[%d] : %s(%d):\n", i, al[i].name, num);
+		    for (j = 0; j < (int)num; j++)
 		    {
 			fprintf(_LtDebugFile, "\tItem %d '%s'\n", j,
 			    _LtDebugXmString2String(((XmString *)(al[i].value))[j]));
@@ -2190,11 +2221,11 @@ extern const char *
 _LtDebugFocusChange2String(XmFocusChange c)
 {
 	switch (c) {
-	case XmFOCUS_IN:	return	"XmFOCUS_IN";
-	case XmFOCUS_OUT:	return	"XmFOCUS_OUT";
-	case XmENTER:		return	"XmENTER";
-	case XmLEAVE:		return	"XmLEAVE";
-	default:		return	"???";
+	case XmFOCUS_IN:        return "XmFOCUS_IN";
+	case XmFOCUS_OUT:       return "XmFOCUS_OUT";
+	case XmENTER:           return "XmENTER";
+	case XmLEAVE:           return "XmLEAVE";
+	default:                return "???";
 	}
 }
 
@@ -2203,11 +2234,11 @@ extern const char *
 _LtDebugNavigationType2String(XmNavigationType nt)
 {
 	switch (nt) {
-	case XmNONE:			return "XmNONE";
-	case XmTAB_GROUP:		return "XmTAB_GROUP";
-	case XmSTICKY_TAB_GROUP:	return "XmSTICKY_TAB_GROUP";
-	case XmEXCLUSIVE_TAB_GROUP:	return "XmEXCLUSIVE_TAB_GROUP";
-	default:			return "???";
+	case XmNONE:                 return "XmNONE";
+	case XmTAB_GROUP:            return "XmTAB_GROUP";
+	case XmSTICKY_TAB_GROUP:     return "XmSTICKY_TAB_GROUP";
+	case XmEXCLUSIVE_TAB_GROUP:  return "XmEXCLUSIVE_TAB_GROUP";
+	default:                     return "???";
 	}
 }
 
@@ -2217,40 +2248,40 @@ _LtDebugEventType2String(int type)
 {
 	switch (type)
 	{
-	case KeyPress:		return("KeyPress");
-	case KeyRelease:	return("KeyRelease");
-	case ButtonPress:	return("ButtonPress");
-	case ButtonRelease:	return("ButtonRelease");
-	case KeymapNotify:	return("KeymapNotify");
-	case MotionNotify:	return("MotionNotify");
-	case EnterNotify:	return("EnterNotify");
-	case LeaveNotify:	return("LeaveNotify");
-	case FocusIn:		return("FocusIn");
-	case FocusOut:		return("FocusOut");
-	case Expose:		return("Expose");
-	case GraphicsExpose:	return("GraphicsExpose");
-	case NoExpose:		return("NoExpose");
-	case ColormapNotify:	return("ColormapNotify");
-	case PropertyNotify:	return("PropertyNotify");
-	case VisibilityNotify:	return("VisibilityNotify");
-	case ResizeRequest:	return("ResizeRequest");
-	case CirculateNotify:	return("CirculateNotify");
-	case ConfigureNotify:	return("ConfigureNotify");
-	case DestroyNotify:	return("DestroyNotify");
-	case GravityNotify:	return("GravityNotify");
-	case MapNotify:		return("MapNotify");
-	case ReparentNotify:	return("ReparentNotify");
-	case UnmapNotify:	return("UnmapNotify");
-	case CreateNotify:	return("CreateNotify");
-	case CirculateRequest:	return("CirculateRequest");
-	case ConfigureRequest:	return("ConfigureRequest");
-	case MapRequest:	return("MapRequest");
-	case MappingNotify:	return("MappingNotify");
-	case ClientMessage:	return("ClientMessage");
-	case SelectionClear:	return("SelectionClear");
-	case SelectionNotify:	return("SelectionNotify");
-	case SelectionRequest:	return("SelectionRequest");
-	default:		return("UNKNOWN");
+	case KeyPress:          return("KeyPress");
+	case KeyRelease:        return("KeyRelease");
+	case ButtonPress:       return("ButtonPress");
+	case ButtonRelease:     return("ButtonRelease");
+	case KeymapNotify:      return("KeymapNotify");
+	case MotionNotify:      return("MotionNotify");
+	case EnterNotify:       return("EnterNotify");
+	case LeaveNotify:       return("LeaveNotify");
+	case FocusIn:           return("FocusIn");
+	case FocusOut:          return("FocusOut");
+	case Expose:            return("Expose");
+	case GraphicsExpose:    return("GraphicsExpose");
+	case NoExpose:          return("NoExpose");
+	case ColormapNotify:    return("ColormapNotify");
+	case PropertyNotify:    return("PropertyNotify");
+	case VisibilityNotify:  return("VisibilityNotify");
+	case ResizeRequest:     return("ResizeRequest");
+	case CirculateNotify:   return("CirculateNotify");
+	case ConfigureNotify:   return("ConfigureNotify");
+	case DestroyNotify:     return("DestroyNotify");
+	case GravityNotify:     return("GravityNotify");
+	case MapNotify:         return("MapNotify");
+	case ReparentNotify:    return("ReparentNotify");
+	case UnmapNotify:       return("UnmapNotify");
+	case CreateNotify:      return("CreateNotify");
+	case CirculateRequest:  return("CirculateRequest");
+	case ConfigureRequest:  return("ConfigureRequest");
+	case MapRequest:        return("MapRequest");
+	case MappingNotify:     return("MappingNotify");
+	case ClientMessage:     return("ClientMessage");
+	case SelectionClear:    return("SelectionClear");
+	case SelectionNotify:   return("SelectionNotify");
+	case SelectionRequest:  return("SelectionRequest");
+	default:                return("UNKNOWN");
 	}
 }
 
@@ -2260,11 +2291,11 @@ _LtDebugFocusMode2String(int type)
 {
 	switch (type)
 	{
-	case NotifyNormal:		return("NotifyNormal");
-	case NotifyGrab:		return("NotifyGrab");
-	case NotifyUngrab:		return("NotifyUngrab");
-	case NotifyWhileGrabbed:	return("NotifyWhileGrabbed");
-	default:			return("UNKNOWN");
+	case NotifyNormal:        return("NotifyNormal");
+	case NotifyGrab:	        return("NotifyGrab");
+	case NotifyUngrab:        return("NotifyUngrab");
+	case NotifyWhileGrabbed:  return("NotifyWhileGrabbed");
+	default:                  return("UNKNOWN");
 	}
 }
 
@@ -2274,14 +2305,50 @@ _LtDebugFocusDetail2String(int type)
 {
 	switch (type)
 	{
-	case NotifyAncestor:		return("NotifyAncestor");
-	case NotifyDetailNone:		return("NotifyDetailNone");
-	case NotifyInferior:		return("NotifyInferior");
-	case NotifyNonlinear:		return("NotifyNonlinear");
-	case NotifyNonlinearVirtual:	return("NotifyNonlinearVirtual");
-	case NotifyPointer:		return("NotifyPointer");
-	case NotifyPointerRoot:		return("NotifyPointerRoot");
-	case NotifyVirtual:		return("NotifyVirtual");
-	default:			return("UNKNOWN");
+	case NotifyAncestor:          return("NotifyAncestor");
+	case NotifyDetailNone:        return("NotifyDetailNone");
+	case NotifyInferior:          return("NotifyInferior");
+	case NotifyNonlinear:         return("NotifyNonlinear");
+	case NotifyNonlinearVirtual:  return("NotifyNonlinearVirtual");
+	case NotifyPointer:           return("NotifyPointer");
+	case NotifyPointerRoot:       return("NotifyPointerRoot");
+	case NotifyVirtual:           return("NotifyVirtual");
+	default:                      return("UNKNOWN");
 	}
 }
+
+extern void
+_LtDebugAction(const char *fn, Widget w, const String action,
+		const String *params, const Cardinal *num_params)
+{
+#ifndef LESSTIF_PRODUCTION
+
+	if (_LtDebugInit() && ValidateSource(fn)) {
+  		int	i;
+
+		if (w) {
+			if (__LtDebugPrintWidgetID()) {
+				fprintf(_LtDebugFile, "%s %s [%p]: ",
+					w->core.widget_class->core_class.class_name,
+					XtName(w), w);
+	    		} else {
+				fprintf(_LtDebugFile, "%s %s: ",
+					w->core.widget_class->core_class.class_name, XtName(w));
+	    		}
+		} else {
+			fprintf(_LtDebugFile, "(null widget): ");
+		}
+
+		fprintf(_LtDebugFile, "Action %s(", action);
+		if (*num_params) {
+			fprintf(_LtDebugFile, "%s", params[0]);
+		}
+		for (i=1; i<(int)*num_params; i++) {
+			fprintf(_LtDebugFile, ", %s", params[i]);
+		}
+		fprintf(_LtDebugFile, ")\n");
+
+		fflush(_LtDebugFile);
+	}
+#endif /* !LESSTIF_PRODUCTION */
+}
