@@ -1,11 +1,11 @@
 /**
  *
- * $Id: DialogS.c,v 1.26 2000/09/22 20:35:11 amai Exp $
+ * $Id: DialogS.c,v 1.30 2001/07/27 18:51:55 dannybackx Exp $
  *
  * derived from Xt Vendor class.c 
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2000 LessTif Development Team
+ * Copyright (C) 1995-2001 LessTif Development Team
  * Copyright 1989 Massachusetts Institute of Technology
  *
  * This file is part of the GNU LessTif Library.
@@ -26,7 +26,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: DialogS.c,v 1.26 2000/09/22 20:35:11 amai Exp $";
+static const char rcsid[] = "$Id: DialogS.c,v 1.30 2001/07/27 18:51:55 dannybackx Exp $";
 
 /*
  * This controls questionable behavior.  It will go away
@@ -252,9 +252,9 @@ WidgetClass xmDialogShellExtObjectClass = (WidgetClass)&xmDialogShellExtClassRec
 static void 
 class_initialize(void)
 {
-    int ncom, i, j, addon;
+    int ncom, addon;
     XtResourceList combined, shells;
-    Cardinal nshells;
+    Cardinal nshells, i, j;
 
     _XmDialogSCoreClassExtRec.record_type = XmQmotif;
 
@@ -290,7 +290,7 @@ class_initialize(void)
 	}
     }
 
-    XtFree((XtPointer)shells);
+    XtFree((char *)shells);
 
     xmDialogShellExtClassRec.object_class.resources = combined;
     xmDialogShellExtClassRec.object_class.num_resources = nshells + addon;
@@ -336,11 +336,12 @@ initialize(Widget request,
     XtRealizeWidget(new_w);
 }
 
+
 static Widget
 GetChild(Widget w)
 {
     CompositeWidget cw = (CompositeWidget)w;
-    int i;
+    Cardinal i;
     extern WidgetClass xmVendorShellExtObjectClass;	/* FIX ME */
 
     /*
@@ -367,7 +368,7 @@ change_managed(Widget w)
 
     child = GetChild(w);
 
-    DEBUGOUT(XdbDebug2(__FILE__, w, child, "ChangeManaged\n"));
+    DEBUGOUT(_LtDebug2(__FILE__, w, child, "ChangeManaged\n"));
 
     /* not doing this was why popup dialogs wouldn't take focus */
     XtSetKeyboardFocus(w, child);
@@ -376,10 +377,10 @@ change_managed(Widget w)
     {
 	Boolean InitialPlacement = False;
 
-	DEBUGOUT(XdbDebug2(__FILE__, w, child, "... was not managed\n"));
+	DEBUGOUT(_LtDebug2(__FILE__, w, child, "... was not managed\n"));
 	if (!XtIsRealized(child))
 	{
-	    DEBUGOUT(XdbDebug(__FILE__, child, "... Realizing\n"));
+	    DEBUGOUT(_LtDebug(__FILE__, child, "... Realizing\n"));
 
 	    XtRealizeWidget(child);
 
@@ -396,13 +397,13 @@ change_managed(Widget w)
 	/* Dialog's child should be at 0,0 */
 	if (XtX(child) != 0 || XtY(child) != 0)
 	{
-	    DEBUGOUT(XdbDebug2(__FILE__, w, child,
+	    DEBUGOUT(_LtDebug2(__FILE__, w, child,
 		    "Child position %d,%d set to 0,0\n",
 		    XtX(child), XtY(child)));
 	    _XmMoveObject(child, 0, 0);
 	}
 
-	DEBUGOUT(XdbDebug2(__FILE__, w, child, "Shell size %d %d %d %d\n",
+	DEBUGOUT(_LtDebug2(__FILE__, w, child, "Shell size %d %d %d %d\n",
 			   XtWidth(child), XtHeight(child),
 			   XtX(w), XtY(w)));
 
@@ -417,7 +418,7 @@ change_managed(Widget w)
 	    px = XtX(p) + (XtWidth(p) - XtWidth(child)) / 2;
 	    py = XtY(p) + (XtHeight(p) - XtHeight(child)) / 2;
 
-	    DEBUGOUT(XdbDebug(__FILE__, w, "def. pos. %d %d\n", px, py));
+	    DEBUGOUT(_LtDebug(__FILE__, w, "def. pos. %d %d\n", px, py));
 
 	    if (px < 0)
 	    {
@@ -437,11 +438,11 @@ change_managed(Widget w)
 
 	if (CoreMappedWhenManaged(w))
 	{
-	    DEBUGOUT(XdbDebug(__FILE__, w, "XtPopup\n"));
+	    DEBUGOUT(_LtDebug(__FILE__, w, "XtPopup\n"));
 
 	    XtPopup(w, XtGrabNone);
 
-	    DEBUGOUT(XdbDebug2(__FILE__, w, child,
+	    DEBUGOUT(_LtDebug2(__FILE__, w, child,
 			       "Mapping shell, just to be sure\n"));
 
 	    XtMapWidget(w);
@@ -449,7 +450,7 @@ change_managed(Widget w)
     }
     else
     {
-	DEBUGOUT(XdbDebug(__FILE__, (Widget)w, "XtPopDown\n"));
+	DEBUGOUT(_LtDebug(__FILE__, (Widget)w, "XtPopDown\n"));
 	XtPopdown((Widget)w);
 
 	/* rws 1 Jun 1997
@@ -459,7 +460,7 @@ change_managed(Widget w)
 	 * MLM: enabled this again, but moved it to *after* the popdown.  This
 	 * fixes certain cases (like nedit->open->ok, with no file selected).
 	 */
-	DEBUGOUT(XdbDebug(__FILE__, w, "XtUnmapWidget\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "XtUnmapWidget\n"));
 	if (XmIsBulletinBoard(child))
 		_XmBulletinBoardUnmap(child);
 
@@ -472,7 +473,7 @@ insert_child(Widget w)
 {
     CompositeWidget p = (CompositeWidget)XtParent(w);
 
-    DEBUGOUT(XdbDebug2(__FILE__, (Widget)p, w, "insert_child\n"));
+    DEBUGOUT(_LtDebug2(__FILE__, (Widget)p, w, "insert_child\n"));
 
 #define superclass (&transientShellClassRec)
     (*superclass->composite_class.insert_child) (w);
@@ -512,8 +513,8 @@ delete_child(Widget w)
 {
     Widget s = XtParent(w);
 
-    DEBUGOUT(XdbDebug2(__FILE__, s, w, "delete_child\n"));
-    DEBUGOUT(XdbDebug2("RWS", s, w,"%s:delete_child(%d)\n",
+    DEBUGOUT(_LtDebug2(__FILE__, s, w, "delete_child\n"));
+    DEBUGOUT(_LtDebug2("RWS", s, w,"%s:delete_child(%d)\n",
     	__FILE__, __LINE__
     	));
 
@@ -530,10 +531,10 @@ delete_child(Widget w)
     if (XtIsManaged(w) || MGR_NumChildren(s) == 1)
     {
 #if 1
-	DEBUGOUT(XdbDebug(__FILE__, s, "XtUnmapWidget\n"));
+	DEBUGOUT(_LtDebug(__FILE__, s, "XtUnmapWidget\n"));
 	XtUnmapWidget(s);
 #else
-	DEBUGOUT(XdbDebug(__FILE__, s, "XtPopdown\n"));
+	DEBUGOUT(_LtDebug(__FILE__, s, "XtPopdown\n"));
 	XtPopdown(s);
 #endif
     }
@@ -547,15 +548,15 @@ static void
 WmProtocolHandler(Widget w, XtPointer client, XtPointer call)
 {
     XmVendorShellExtObject ve = (XmVendorShellExtObject)client;
-    int i;
+    Cardinal i;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "Dialog's WmProtocolHandler\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "Dialog's WmProtocolHandler\n"));
 
     switch (VSEP_DeleteResponse(ve))
     {
     case XmDESTROY:
 	XtDestroyWidget(w);
-	DEBUGOUT(XdbDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "WmProtocolHandler(DeleteResponse XmDESTROY)\n"));
 	break;
 
@@ -565,7 +566,7 @@ WmProtocolHandler(Widget w, XtPointer client, XtPointer call)
 	{
 	    if (XtIsManaged(MGR_Children(w)[i]))
 	    {
-		DEBUGOUT(XdbDebug2(__FILE__, w, MGR_Children(w)[i],
+		DEBUGOUT(_LtDebug2(__FILE__, w, MGR_Children(w)[i],
 				   "XtUnmanageChild(child)\n"));
 		XtUnmanageChild(MGR_Children(w)[i]);
 		return;
@@ -574,7 +575,7 @@ WmProtocolHandler(Widget w, XtPointer client, XtPointer call)
 	break;
 
     case XmDO_NOTHING:
-	DEBUGOUT(XdbDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "WmProtocolHandler(DeleteResponse XmNO_NOTHING)\n"));
 	return;
     }
@@ -652,12 +653,12 @@ StructureNotifyHandler(Widget w, XtPointer closure,
     switch (event->type)
     {
     case ConfigureNotify:
-	DEBUGOUT(XdbDebug(__FILE__, w, "CONFIGURE NOTIFY: layout %d %d %d %d\n",
+	DEBUGOUT(_LtDebug(__FILE__, w, "CONFIGURE NOTIFY: layout %d %d %d %d\n",
 			  cev->x, cev->y, cev->width, cev->height));
 	break;
 
     case MapNotify:
-	DEBUGOUT(XdbDebug(__FILE__, w, "MAP NOTIFY: window %08x\n",
+	DEBUGOUT(_LtDebug(__FILE__, w, "MAP NOTIFY: window %08x\n",
 			  mev->window));
 	/* rws 22 Sep 1998
 	   This is causing nedit's File->Open to un-map as soon as it is
@@ -674,17 +675,17 @@ StructureNotifyHandler(Widget w, XtPointer closure,
 	break;
 
     case UnmapNotify:
-	DEBUGOUT(XdbDebug(__FILE__, w, "UNMAP NOTIFY: window %08x\n",
+	DEBUGOUT(_LtDebug(__FILE__, w, "UNMAP NOTIFY: window %08x\n",
 			  uev->window));
 	break;
 
     case ReparentNotify:
-	DEBUGOUT(XdbDebug(__FILE__, w, "REPARENT NOTIFY: window %08x\n",
+	DEBUGOUT(_LtDebug(__FILE__, w, "REPARENT NOTIFY: window %08x\n",
 			  rev->window));
 	break;
 
     default:
-	DEBUGOUT(XdbDebug(__FILE__, w, "Got UNKNOWN TYPE: %d\n",
+	DEBUGOUT(_LtDebug(__FILE__, w, "Got UNKNOWN TYPE: %d\n",
 			  event->type));
 	break;
     }
