@@ -1,9 +1,9 @@
 /**
  *
- * $Id: DrawnB.c,v 1.42 2000/09/23 15:05:23 amai Exp $
+ * $Id: DrawnB.c,v 1.45 2001/07/27 18:51:55 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2000 LessTif Development Team 
+ * Copyright (C) 1995-2001 LessTif Development Team 
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: DrawnB.c,v 1.42 2000/09/23 15:05:23 amai Exp $";
+static const char rcsid[] = "$Id: DrawnB.c,v 1.45 2001/07/27 18:51:55 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -260,8 +260,8 @@ WidgetClass xmDrawnButtonWidgetClass = (WidgetClass)&xmDrawnButtonClassRec;
 static void
 class_initialize(void)
 {
-    if (! XmeTraitSet(xmDrawnButtonWidgetClass, XmQTactivatable,
-		&_XmDrawnBTraitRec)) {
+    if (! XmeTraitSet((XtPointer)xmDrawnButtonWidgetClass, XmQTactivatable,
+		(XtPointer)&_XmDrawnBTraitRec)) {
 	_XmWarning(NULL,
 	    "XmDrawnButton ClassInitialize: XmeTraitSet failed\n");
     }
@@ -278,7 +278,7 @@ static void
 initialize(Widget request, Widget new_w,
 	   ArgList args, Cardinal *num_args)
 {
-    DEBUGOUT(XdbDebug(__FILE__, new_w,
+    DEBUGOUT(_LtDebug(__FILE__, new_w,
 		      "initialize: %i args\n"
 		      "\trequest X %5i Y %5i W %5i H %5i\n"
 		      "\t  new_w X %5i Y %5i W %5i H %5i\n",
@@ -287,7 +287,7 @@ initialize(Widget request, Widget new_w,
 		      XtWidth(request), XtHeight(request),
 		      XtX(new_w), XtY(new_w),
 		      XtWidth(new_w), XtHeight(new_w)));
-    DEBUGOUT(XdbPrintArgList(__FILE__, new_w, args, *num_args, False));
+    DEBUGOUT(_LtDebugPrintArgList(__FILE__, new_w, args, *num_args, False));
 
     /* check the RepType resources */
     if (!XmRepTypeValidValue(XmRepTypeGetId(XmRMultiClick),
@@ -333,7 +333,7 @@ set_values(Widget old, Widget request, Widget new_w,
 {
     Boolean refresh_needed = False;
 
-    DEBUGOUT(XdbDebug(__FILE__, new_w,
+    DEBUGOUT(_LtDebug(__FILE__, new_w,
 		      "set_values: %i args\n"
 		      "\t    old X %5i Y %5i W %5i H %5i\n"
 		      "\trequest X %5i Y %5i W %5i H %5i\n"
@@ -345,7 +345,7 @@ set_values(Widget old, Widget request, Widget new_w,
 		      XtWidth(request), XtHeight(request),
 		      XtX(new_w), XtY(new_w),
 		      XtWidth(new_w), XtHeight(new_w)));
-    DEBUGOUT(XdbPrintArgList(__FILE__, new_w, args, *num_args, False));
+    DEBUGOUT(_LtDebugPrintArgList(__FILE__, new_w, args, *num_args, False));
 
     /* check the RepType resources */
     if (!XmRepTypeValidValue(XmRepTypeGetId(XmRMultiClick),
@@ -386,7 +386,7 @@ expose(Widget w, XEvent *event, Region region)
 {
     XmDrawnButtonCallbackStruct cbs;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "Expose (%dx%d%+d%+d)\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "Expose (%dx%d%+d%+d)\n",
 		      XtWidth(w), XtHeight(w),XtX(w),XtY(w)));
 
 #define superclass (&xmLabelClassRec)
@@ -457,7 +457,7 @@ resize(Widget w)
 {
     XmDrawnButtonCallbackStruct cbs;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "Resize (%dx%d%+d%+d)\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "Resize (%dx%d%+d%+d)\n",
 		      XtWidth(w), XtHeight(w),XtX(w),XtY(w)));
 
 #define superclass (&xmLabelClassRec)
@@ -578,7 +578,7 @@ ArmTimeout(XtPointer data, XtIntervalId *id)
 {
     Widget w = (Widget)data;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "ArmTimeout\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "ArmTimeout\n"));
 
     DB_Timer(w) = 0;
 
@@ -594,7 +594,7 @@ ArmAndActivate(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
     XmDrawnButtonCallbackStruct cbs;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "ArmAndActivate\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "ArmAndActivate\n"));
 
     /* Arm, Activate, and Disarm now, but draw the disarmed state later */
 
@@ -674,7 +674,7 @@ LeaveWindow(Widget w, XEvent *event, String *params, Cardinal *num_params)
 static void
 MultiArm(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(XdbDebug(__FILE__, w, "MultiArm\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "MultiArm\n"));
 
     if (DB_MultiClick(w) == XmMULTICLICK_KEEP)
     {
@@ -688,7 +688,7 @@ MultiActivate(Widget w, XEvent *event, String *params, Cardinal *num_params)
     XButtonEvent *ev = (XButtonEvent *)event;
     XmDrawnButtonCallbackStruct cbs;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "DrawnB: MultiClick\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "DrawnB: MultiClick\n"));
 
     if (DB_MultiClick(w) == XmMULTICLICK_KEEP)
     {
