@@ -1,8 +1,9 @@
 /**
  *
- * $Id: DropTrans.c,v 1.10 1999/08/15 23:39:10 rwscott Exp $
+ * $Id: DropTrans.c,v 1.18 2001/07/27 18:51:55 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,13 +23,13 @@
  *
  **/
 
-static const char rcsid[] = "$Id: DropTrans.c,v 1.10 1999/08/15 23:39:10 rwscott Exp $";
+static const char rcsid[] = "$Id: DropTrans.c,v 1.18 2001/07/27 18:51:55 dannybackx Exp $";
 
 #include <LTconfig.h>
+
+#include <string.h>
+
 #include <XmI/XmI.h>
-
-#include <X11/Xfuncs.h>
-
 #include <Xm/XmP.h>
 #include <Xm/AtomMgr.h>
 #include <Xm/DropTransP.h>
@@ -36,7 +37,6 @@ static const char rcsid[] = "$Id: DropTrans.c,v 1.10 1999/08/15 23:39:10 rwscott
 #include <XmI/DragDropI.h>
 #include <XmI/AtomMgrI.h>
 #include <Xm/DisplayP.h>
-#include <string.h>
 
 #include <XmI/DebugUtil.h>
 
@@ -180,7 +180,7 @@ WidgetClass xmDropTransferObjectClass = (WidgetClass)&xmDropTransferClassRec;
 static void
 class_initialize()
 {
-    DEBUGOUT(XdbDebug(__FILE__, NULL, "DropTransfer class initialize\n"));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "DropTransfer class initialize\n"));
 
     _XmDropTransferObjectClassExtRec.record_type = XmQmotif;
 }
@@ -191,7 +191,7 @@ class_part_initialize(WidgetClass widget_class)
 {
     WidgetClass sc;
 
-    DEBUGOUT(XdbDebug(__FILE__, NULL, "DropTransfer class part initialize\n"));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "DropTransfer class part initialize\n"));
 
     _XmFastSubclassInit(widget_class, XmDROP_TRANSFER_BIT);
 
@@ -214,7 +214,17 @@ initialize(Widget request, Widget new_w,
 {
     XmDropTransferEntry entries;
 
-    DEBUGOUT(XdbDebug(__FILE__, new_w, "DropTransfer initialize\n"));
+    DEBUGOUT(_LtDebug(__FILE__, new_w,
+		      "%s:initialize(%d) - %i args\n"
+		      "\trequest X %5i Y %5i W %5i H %5i\n"
+		      "\t  new_w X %5i Y %5i W %5i H %5i\n",
+		      __FILE__, __LINE__,
+		      *num_args,
+		      XtX(request), XtY(request),
+		      XtWidth(request), XtHeight(request),
+		      XtX(new_w), XtY(new_w),
+		      XtWidth(new_w), XtHeight(new_w)));
+    DEBUGOUT(_LtDebugPrintArgList(__FILE__, new_w, args, *num_args, False));
 
     if (DT_NumDropTransfers(new_w) != 0)
     {
@@ -228,7 +238,7 @@ initialize(Widget request, Widget new_w,
 	entries = (XmDropTransferEntry)XtMalloc(DT_NumDropTransfers(new_w) *
 						sizeof(XmDropTransferEntryRec));
 
-	bcopy(DT_DropTransfers(new_w), entries,
+	memcpy(entries, DT_DropTransfers(new_w),
 	      DT_NumDropTransfers(new_w) * sizeof(XmDropTransferEntryRec));
 
 	DT_DropTransferLists(new_w)[0].transfer_list = entries;
@@ -258,9 +268,9 @@ static void
 destroy(Widget w)
 {
     Widget dc;
-    int i;
+    Cardinal i;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "DropTransfer destroy\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "DropTransfer destroy\n"));
 
     dc = XmGetDragContext(w, DT_Timestamp(w));
 
@@ -281,7 +291,20 @@ static Boolean
 set_values(Widget current, Widget request, Widget new_w,
 	   ArgList args, Cardinal *num_args)
 {
-    DEBUGOUT(XdbDebug(__FILE__, new_w, "DropTransfer set_values\n"));
+    DEBUGOUT(_LtDebug(__FILE__, new_w,
+		      "%s:set_values(%d) - %i args\n"
+		      "\t    old X %5i Y %5i W %5i H %5i\n"
+		      "\trequest X %5i Y %5i W %5i H %5i\n"
+		      "\t  new_w X %5i Y %5i W %5i H %5i\n",
+		      __FILE__, __LINE__,
+		      *num_args,
+		      XtX(current), XtY(current),
+		      XtWidth(current), XtHeight(current),
+		      XtX(request), XtY(request),
+		      XtWidth(request), XtHeight(request),
+		      XtX(new_w), XtY(new_w),
+		      XtWidth(new_w), XtHeight(new_w)));
+    DEBUGOUT(_LtDebugPrintArgList(__FILE__, new_w, args, *num_args, False));
 
     return True;
 }
@@ -291,7 +314,10 @@ entry_transfer(Widget dt, int which)
 {
     XmDropTransferList lst = &DT_DropTransferLists(dt)[which];
     Widget dc = DT_DragContext(dt);
-    int i;
+    Cardinal i;
+
+    DEBUGOUT(_LtDebug(__FILE__, dt, "%s:entry_transfer(%d)",
+    	__FILE__, __LINE__));
 
     DT_CurDropTransferList(dt) = which;
     DT_CurTargets(dt) = (Atom *)XtMalloc(lst->num_transfers * sizeof(Atom));
@@ -330,6 +356,9 @@ static void
 notified_callback(Widget w, XtPointer cd, Atom *select, Atom *type,
 		  XtPointer value, unsigned long *len, int *fmt)
 {
+    DEBUGOUT(_LtDebug(__FILE__, w, "%s:notified_callback(%d)\n",
+    	__FILE__, __LINE__));
+
     if (value != NULL)
     {
 	XtFree((char *)value);
@@ -343,6 +372,13 @@ terminate_transfer(Widget dt, Atom *select)
 {
     Atom how;
 
+    DEBUGOUT(_LtDebug(__FILE__, dt, "%s:terminate_transfer(%d) - drag context %s receiver info %s %s\n",
+    	__FILE__, __LINE__,
+    	DT_DragContext(dt) ? "Yes" : "No",
+    	DC_CurrReceiverInfo(DT_DragContext(dt)) ?  "Yes" : "No",
+    	XGetAtomName(XtDisplay(dt), *select)
+    	));
+
     if (DT_TransferStatus(dt) == XmTRANSFER_SUCCESS)
     {
 	how = XmInternAtom(XtDisplay(dt), _XA_XmTRANSFER_SUCCESS, False);
@@ -352,9 +388,12 @@ terminate_transfer(Widget dt, Atom *select)
 	how = XmInternAtom(XtDisplay(dt), _XA_XmTRANSFER_FAILURE, False);
     }
 
-    XtGetSelectionValue(DC_CurrReceiverInfo(DT_DragContext(dt))->shell,
+    if (DT_DragContext(dt) && DC_CurrReceiverInfo(DT_DragContext(dt)) && DC_CurrReceiverInfo(DT_DragContext(dt))->shell)
+    {
+	XtGetSelectionValue(DC_CurrReceiverInfo(DT_DragContext(dt))->shell,
 			*select, how, notified_callback, (XtPointer)dt,
 			DT_Timestamp(dt));
+    }
 }
 
 static void
@@ -364,6 +403,9 @@ select_callback(Widget w, XtPointer cd, Atom *select, Atom *type,
     Widget dt = (Widget)cd;
     XmDropTransferList lst;
 
+    DEBUGOUT(_LtDebug(__FILE__, dt, "%s:select_callback(%d)",
+    	__FILE__, __LINE__));
+
     lst = &DT_DropTransferLists(dt)[DT_CurDropTransferList(dt)];
 
     if (DT_TransferCallback(dt))
@@ -407,6 +449,9 @@ drop_timer(XtPointer cd, XtIntervalId *id)
     Widget dt = (Widget)cd;
     Atom select;
 
+    DEBUGOUT(_LtDebug(__FILE__, dt, "%s:drop_timer(%d)\n",
+    	__FILE__, __LINE__));
+
     if (DT_NumDropTransferLists(dt))
     {
 	entry_transfer(dt, 0);
@@ -425,6 +470,9 @@ start_drop_transfer(Widget refWidget,
 {
     Widget disp = XmGetXmDisplay(XtDisplay(refWidget)), dt;
 
+    DEBUGOUT(_LtDebug(__FILE__, refWidget, "%s:start_drop_transfer(%d)\n",
+    	__FILE__, __LINE__));
+
     dt = XtCreateWidget("drop_transfer",
 			Display_DropTransferClass(disp),
 			disp, args, argCount);
@@ -446,6 +494,9 @@ add_drop_transfer(Widget widget,
     XmDropTransferEntry entries;
     int idx;
 
+    DEBUGOUT(_LtDebug(__FILE__, widget, "%s:add_drop_transfer(%d)",
+    	__FILE__, __LINE__));
+
     idx = DT_NumDropTransferLists(widget);
     DT_NumDropTransferLists(widget)++;
 
@@ -456,7 +507,7 @@ add_drop_transfer(Widget widget,
 
     entries = (XmDropTransferEntry)XtMalloc(num_transfers *
 					    sizeof(XmDropTransferEntryRec));
-    bcopy(transfers, entries, num_transfers * sizeof(XmDropTransferEntryRec));
+    memcpy(entries, transfers, num_transfers * sizeof(XmDropTransferEntryRec));
 
     DT_DropTransferLists(widget)[idx].transfer_list = entries;
     DT_DropTransferLists(widget)[idx].num_transfers = num_transfers;
@@ -467,7 +518,8 @@ XmDropTransferAdd(Widget drop_transfer,
 		  XmDropTransferEntryRec *transfers,
 		  Cardinal num_transfers)
 {
-    DEBUGOUT(XdbDebug(__FILE__, drop_transfer, "XmDropTransferAdd()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, drop_transfer, "%s:XmDropTransferAdd(%d)",
+    	__FILE__, __LINE__));
 
     DTC_AddTransferProc(XtClass(drop_transfer)) (drop_transfer,
 						 transfers,
@@ -481,7 +533,10 @@ XmDropTransferStart(Widget widget,
 {
     Widget disp = XmGetXmDisplay(XtDisplay(widget));
 
-    DEBUGOUT(XdbDebug(__FILE__, widget, "XmDropTransferStart()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, widget, "%s:XmDropTransferStart(%d)\n",
+    	__FILE__, __LINE__));
+    DEBUGOUT(_LtDebugPrintArgList(__FILE__, widget, arglist, argcount, False));
+
 
     return DTC_StartTransferProc(Display_DropTransferClass(disp)) (widget,
 								   arglist,
