@@ -1,9 +1,9 @@
 /**
  *
- * $Id: FontList.c,v 1.21 2000/12/06 14:28:19 amai Exp $
+ * $Id: FontList.c,v 1.25 2001/07/27 18:51:56 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2000 LessTif Development Team
+ * Copyright (C) 1995-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: FontList.c,v 1.21 2000/12/06 14:28:19 amai Exp $";
+static const char rcsid[] = "$Id: FontList.c,v 1.25 2001/07/27 18:51:56 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -243,12 +243,12 @@ XmFontListEntryCreate(char *tag,
 extern void
 XmFontListEntryFree(XmFontListEntry *entry)
 {
-    DEBUGOUT(XdbDebug(__FILE__, NULL, "XmFontListEntryFree(0x%x)\n", entry));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "XmFontListEntryFree(0x%x)\n", entry));
 
     if (entry)
     {
 	XtFree((*entry)->tag);
-	XtFree((XtPointer)*entry);
+	XtFree((char *)*entry);
 
 	/* should we close the Font? */
     }
@@ -261,13 +261,13 @@ XmFontListEntryGetFont(XmFontListEntry entry,
 {
     if (entry == NULL)
     {
-	DEBUGOUT(XdbDebug(__FILE__, NULL, "XmFontListEntryGetFont(NULL)\n"));
+	DEBUGOUT(_LtDebug(__FILE__, NULL, "XmFontListEntryGetFont(NULL)\n"));
 	if (type_return)
 	    *type_return = XmFONT_IS_FONT;
 	return (XtPointer)NULL;
     }
 
-    DEBUGOUT(XdbDebug(__FILE__, NULL, "XmFontListEntryGetFont()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "XmFontListEntryGetFont()\n"));
 
     if (type_return)
     {
@@ -296,7 +296,7 @@ XmFontListEntryLoad(Display *display,
     Boolean success = False;
     char *p;
 
-    DEBUGOUT(XdbDebug(__FILE__, NULL, "XmFontListEntryLoad(%s, tag %s)\n",
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "XmFontListEntryLoad(%s, tag %s)\n",
 		      font_name, tag));
 
     /* Strip trailing semi-colon */
@@ -319,7 +319,7 @@ XmFontListEntryLoad(Display *display,
     fromString.addr = font_name;
     fromString.size = strlen(font_name) + 1;
 
-    cvtArg[0].addr = (XtPointer)&display;
+    cvtArg[0].addr = (XPointer)&display;
     cvtArg[0].size = sizeof(Display *);
 
     entry = (XmFontListEntry)XtMalloc(sizeof(struct _XmFontListRec));
@@ -328,7 +328,7 @@ XmFontListEntryLoad(Display *display,
     switch (type)
     {
     case XmFONT_IS_FONT:
-	toFont.addr = (XtPointer)&(entry->font);
+	toFont.addr = (XPointer)&(entry->font);
 	toFont.size = sizeof(XFontStruct *);
 
 	success = XtCallConverter(display, XtCvtStringToFontStruct, cvtArg,
@@ -336,11 +336,11 @@ XmFontListEntryLoad(Display *display,
 	break;
 
     case XmFONT_IS_FONTSET:
-	toFont.addr = (XtPointer)&(entry->font);
+	toFont.addr = (XPointer)&(entry->font);
 	toFont.size = sizeof(XFontSet);
 
 	/* XtCvtStringToFontSet needs 2 arguments : display and locale */
-	cvtArg[1].addr = (XtPointer)XtNewString(setlocale(LC_CTYPE, NULL))/*&"C"*/;	/* FIX ME */
+	cvtArg[1].addr = (XPointer)XtNewString(setlocale(LC_CTYPE, NULL))/*&"C"*/;	/* FIX ME */
 	cvtArg[1].size = sizeof(char *);
 
 	success = XtCallConverter(display, XtCvtStringToFontSet, cvtArg,
@@ -351,13 +351,13 @@ XmFontListEntryLoad(Display *display,
 
     if (!success || !entry->font)
     {
-	DEBUGOUT(XdbDebug(__FILE__, NULL, "XmFontListEntryLoad => NULL\n"));
-	XtFree((XtPointer)entry);
+	DEBUGOUT(_LtDebug(__FILE__, NULL, "XmFontListEntryLoad => NULL\n"));
+	XtFree((char *)entry);
 	return (XmFontListEntry)NULL;
     }
     else
     {
-	DEBUGOUT(XdbDebug(__FILE__, NULL, "XmFontListEntryLoad success!\n"));
+	DEBUGOUT(_LtDebug(__FILE__, NULL, "XmFontListEntryLoad success!\n"));
 	entry->tag = XtNewString(tag);
 	entry->type = type;
 	return entry;
@@ -373,7 +373,7 @@ XmFontListFree(XmFontList list)
 	return;
     }
 
-    DEBUGOUT(XdbDebug(__FILE__, NULL, "XmFontListFree(0x%X)\n", list));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "XmFontListFree(0x%X)\n", list));
 
     __XmFontListDealloc(list);
 }
@@ -382,7 +382,7 @@ XmFontListFree(XmFontList list)
 extern void
 XmFontListFreeFontContext(XmFontContext context)
 {
-    DEBUGOUT(XdbDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 		      "XmFontListFreeFontContext(0x%X)\n", context));
     XtFree((char *)context);
 }
