@@ -1,6 +1,6 @@
 /**
  *
- * $Id: Gadget.c,v 1.19 2001/07/27 18:51:56 dannybackx Exp $
+ * $Id: Gadget.c,v 1.20 2001/09/13 13:34:13 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
  * Copyright (C) 1995-2001 LessTif Development Team
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: Gadget.c,v 1.19 2001/07/27 18:51:56 dannybackx Exp $";
+static const char rcsid[] = "$Id: Gadget.c,v 1.20 2001/09/13 13:34:13 amai Exp $";
 
 #include <LTconfig.h>
 
@@ -238,6 +238,9 @@ static XmGadgetClassExtRec _XmGadgetClassExtRec = {
     /* size                      */ sizeof(XmGadgetClassExtRec),
     /* widget_baseline_proc      */ NULL,
     /* display_rect_proc         */ NULL,
+#if XmVERSION >= 2
+    /* margins_proc              */ NULL,
+#endif
 };
 
 XmGadgetClassRec xmGadgetClassRec = {
