@@ -1,9 +1,9 @@
 /**
  *
- * $Id: ImageCache.c,v 1.21 2000/11/07 20:33:28 amai Exp $
+ * $Id: ImageCache.c,v 1.26 2001/07/27 18:51:56 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2000 LessTif Development Team
+ * Copyright (C) 1995-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: ImageCache.c,v 1.21 2000/11/07 20:33:28 amai Exp $";
+static const char rcsid[] = "$Id: ImageCache.c,v 1.26 2001/07/27 18:51:56 dannybackx Exp $";
 
 /*
  * --aldi 97/01/11: changed to use the generic hashtable module.
@@ -73,11 +73,6 @@ static LTImageValue LTGetImageFromCache(char *image_name);
 static void LTSetupImageCache(void);
 static void LTSetupPixmapCache(void);
 
-Boolean LTAddPixmapToCache(char *pixmap_name, Pixmap pixmap, Screen *screen,
-			   Pixel foreground, Pixel background,
-			   int depth, int width, int height,
-			   int hot_x, int hot_y);
-void LTCreateSearchPath(void);
 
 /*
  * Various paths used when searching for pixmaps in XmGetPixmap below
@@ -166,7 +161,7 @@ _XmInstallImage(XImage *image, char *image_name, int hot_x, int hot_y)
     ImageValue->hot_x = hot_x;
     ImageValue->hot_y = hot_y;
     ImageValue->undeletable = False;
-    if (!LTHashTableAddItem(ImageCache,
+    if (!_LTHashTableAddItem(ImageCache,
 			    (LTHashItemID) image_name,
 			    (LTHashItemValue) ImageValue))
     {
@@ -200,7 +195,7 @@ LTImageIterator(LTHashTable ht,
 	    return LTHASH_BREAK;
 	}
 
-	LTHashTableRemoveItem(ht, id, NULL);
+	_LTHashTableRemoveItem(ht, id, NULL);
 
 	XtFree((char *)value);
 
@@ -227,7 +222,7 @@ XmUninstallImage(XImage *image)
 	return False;
     }
 
-    return LTHashTableForEachItem(ImageCache, LTImageIterator,
+    return _LTHashTableForEachItem(ImageCache, LTImageIterator,
 				  (XtPointer)image) != 0 ? True : False;
 }
 
@@ -256,7 +251,7 @@ XmGetPixmap(Screen *screen, char *image_name,
     p = XmGetPixmapByDepth(screen, image_name, foreground, background,
 			   DefaultDepthOfScreen(screen));
 
-    DEBUGOUT(XdbDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 		      "XmGetPixmap(%s, %d, %d) => 0x%x (depth %d)\n",
 		      image_name, foreground, background, p,
 		      DefaultDepthOfScreen(screen)));
@@ -321,7 +316,7 @@ XmGetPixmapByDepth(Screen *screen, char *image_name,
     PixmapDesc.background = background;
     PixmapDesc.depth = depth;
 
-    if (LTHashTableLookupItem(PixmapCache, (LTHashItemID) & PixmapDesc,
+    if (_LTHashTableLookupItem(PixmapCache, (LTHashItemID) & PixmapDesc,
 			      (LTHashItemValue *) & PixmapValue))
     {
 	/*
@@ -406,7 +401,7 @@ XmGetPixmapByDepth(Screen *screen, char *image_name,
 	XFreeGC(DisplayOfScreen(screen), gc);
 
 	/* add the pixmap to the cache */
-	LTAddPixmapToCache(image_name, new_pix, screen,
+	_LTAddPixmapToCache(image_name, new_pix, screen,
 			   foreground, background, depth,
 			   image->width, image->height,
 			   ImageDesc->hot_x, ImageDesc->hot_y);
@@ -418,7 +413,7 @@ XmGetPixmapByDepth(Screen *screen, char *image_name,
     /* make sure the search path is there */
     if (!_search_path)
     {
-	LTCreateSearchPath();
+	_LTCreateSearchPath();
     }
 
     if (image_name[0] == '/')	/* an absolute pathname */
@@ -450,7 +445,7 @@ XmGetPixmapByDepth(Screen *screen, char *image_name,
 	return XmUNSPECIFIED_PIXMAP;
     }
 
-    DEBUGOUT(XdbDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 		      "pathname found is %s\n", pathname_to_pixmap));
 
 
@@ -487,7 +482,7 @@ XmGetPixmapByDepth(Screen *screen, char *image_name,
 			       &xpm_attrib) == XpmSuccess)
     {
 	/* add the pixmap to the cache */
-	LTAddPixmapToCache(image_name, new_pix, screen,
+	_LTAddPixmapToCache(image_name, new_pix, screen,
 			   foreground, background, depth,
 			   xpm_attrib.width, xpm_attrib.height,
 			   xpm_attrib.x_hotspot, xpm_attrib.y_hotspot);
@@ -503,7 +498,7 @@ XmGetPixmapByDepth(Screen *screen, char *image_name,
 			       &xpm_attrib) == _LtXpmSuccess)
     {
 	/* add the pixmap to the cache */
-	LTAddPixmapToCache(image_name, new_pix, screen,
+	_LTAddPixmapToCache(image_name, new_pix, screen,
 			   foreground, background, depth,
 			   xpm_attrib.width, xpm_attrib.height,
 			   xpm_attrib.x_hotspot, xpm_attrib.y_hotspot);
@@ -536,7 +531,7 @@ XmGetPixmapByDepth(Screen *screen, char *image_name,
 	XFreeGC(DisplayOfScreen(screen), gc);
 
 	/* add the pixmap to the cache */
-	LTAddPixmapToCache(image_name, new_pix, screen,
+	_LTAddPixmapToCache(image_name, new_pix, screen,
 			   foreground, background, depth,
 			   bitmap_width, bitmap_height,
 			   0, 0 /* FIX ME! hot_x, hot_y! */ );
@@ -571,7 +566,7 @@ XmDestroyPixmap(Screen *screen, Pixmap pixmap)
     PixmapDesc.screen = screen;
     PixmapDesc.pixmap = pixmap;
 
-    if (!LTHashTableLookupItem(RevPixmapCache, (LTHashItemID) & PixmapDesc,
+    if (!_LTHashTableLookupItem(RevPixmapCache, (LTHashItemID) & PixmapDesc,
 			       (LTHashItemValue *) & CachedPixmap))
     {
 	return False;
@@ -582,12 +577,12 @@ XmDestroyPixmap(Screen *screen, Pixmap pixmap)
 	return True;
     }
 
-    if (LTHashTableRemoveItem(RevPixmapCache, (LTHashItemID) & PixmapDesc,
+    if (_LTHashTableRemoveItem(RevPixmapCache, (LTHashItemID) & PixmapDesc,
 			      (LTHashItemValue *) & CachedPixmap))
     {
 	ImageName = CachedPixmap->image_name;
 
-	LTHashTableRemoveItem(PixmapCache, (LTHashItemID) CachedPixmap,
+	_LTHashTableRemoveItem(PixmapCache, (LTHashItemID) CachedPixmap,
 			      NULL);
 	XtFree(ImageName);
 
@@ -617,10 +612,10 @@ _XmInstallPixmap(Pixmap pixmap, Screen *screen, char *image_name,
 		 Pixel foreground, Pixel background)
 {
     /*
-     * Let LTAddPixmapToCache() do the work. Also let it calculate the
+     * Let _LTAddPixmapToCache() do the work. Also let it calculate the
      * pixmap's depth and geometry.
      */
-    return LTAddPixmapToCache(image_name, pixmap, screen,
+    return _LTAddPixmapToCache(image_name, pixmap, screen,
 			      foreground, background,
 			      0, 0, 0, 0, 0);
 }
@@ -649,7 +644,7 @@ _XmGetPixmapData(Screen *screen, Pixmap pixmap,
 
     PixmapDesc.screen = screen;
     PixmapDesc.pixmap = pixmap;
-    if (!LTHashTableLookupItem(RevPixmapCache, (LTHashItemID) & PixmapDesc,
+    if (!_LTHashTableLookupItem(RevPixmapCache, (LTHashItemID) & PixmapDesc,
 			       (LTHashItemValue *) & CachedPixmap))
     {
 	return False;
@@ -838,7 +833,7 @@ LTSetupImageCache(void)
      * hot spot coordinates. Using the generic hash tables for this makes
      * this really easy.
      */
-    ImageCache = LTHashTableCreate(NULL, NULL, LTHASH_ID_STRING);
+    ImageCache = _LTHashTableCreate(NULL, NULL, LTHASH_ID_STRING);
 
     /*
      * Now we put the default images into the cache. I'm not using
@@ -872,7 +867,7 @@ LTSetupImageCache(void)
 	ImageValue->hot_x = 0;
 	ImageValue->hot_y = 0;
 	ImageValue->undeletable = True;
-	LTHashTableAddItem(ImageCache,
+	_LTHashTableAddItem(ImageCache,
 			   (LTHashItemID) DefaultImages[i].ImageName,
 			   (LTHashItemValue) ImageValue);
     }
@@ -957,10 +952,10 @@ LTRevPixmapCompare(LTHashItemID id1, LTHashItemID id2)
 static void
 LTSetupPixmapCache(void)
 {
-    PixmapCache = LTHashTableCreate(LTPixmapGetHash, LTPixmapCompare,
+    PixmapCache = _LTHashTableCreate(LTPixmapGetHash, LTPixmapCompare,
 				    sizeof(LTPixmapDescRec));
 
-    RevPixmapCache = LTHashTableCreate(LTRevPixmapGetHash, LTRevPixmapCompare,
+    RevPixmapCache = _LTHashTableCreate(LTRevPixmapGetHash, LTRevPixmapCompare,
 				       LTHASH_ID_NOCOPY);
 }
 
@@ -979,7 +974,7 @@ LTGetImageFromCache(char *image_name)
 	LTSetupImageCache();
     }
 
-    if (LTHashTableLookupItem(ImageCache,
+    if (_LTHashTableLookupItem(ImageCache,
 			      image_name, (LTHashItemValue *) & Image))
     {
 	return Image;
@@ -997,7 +992,7 @@ LTGetImageFromCache(char *image_name)
  * lost.
  */
 Boolean
-LTAddPixmapToCache(char *pixmap_name, Pixmap pixmap, Screen *screen,
+_LTAddPixmapToCache(const char *pixmap_name, Pixmap pixmap, Screen *screen,
 		   Pixel foreground, Pixel background,
 		   int depth,
 		   int width, int height, int hot_x, int hot_y)
@@ -1047,7 +1042,7 @@ LTAddPixmapToCache(char *pixmap_name, Pixmap pixmap, Screen *screen,
      * If there's already such an entry in the cache, then we'll silently
      * overwrite it (compatibility with _XmInstallPixmap()). Sigh.
      */
-    if (LTHashTableReplaceItemAndID(PixmapCache,
+    if (_LTHashTableReplaceItemAndID(PixmapCache,
 				    (LTHashItemID) PixmapDesc,
 				    (LTHashItemValue) PixmapDesc,
 				    (LTHashItemID *) OldPixmapDesc,
@@ -1057,7 +1052,7 @@ LTAddPixmapToCache(char *pixmap_name, Pixmap pixmap, Screen *screen,
 	XtFree((char *)OldPixmapDesc);
     }
 
-    LTHashTableReplaceItem(RevPixmapCache, (LTHashItemID) PixmapDesc,
+    _LTHashTableReplaceItem(RevPixmapCache, (LTHashItemID) PixmapDesc,
 			   (LTHashItemValue) PixmapDesc, NULL);
 
     return True;
@@ -1065,58 +1060,54 @@ LTAddPixmapToCache(char *pixmap_name, Pixmap pixmap, Screen *screen,
 
 
 extern void
-LTCreateSearchPath(void)
+_LTCreateSearchPath(void)
 {
-    char *XBMLANGPATH = XtNewString((String)getenv("XBMLANGPATH"));
-    char *XAPPLRESDIR = XtNewString((String)getenv("XAPPLRESDIR"));
-    char *HOME = _XmOSGetHomeDirName();		/* getenv(HOME) */
-    int HOME_length;
+    const char *XBMLANGPATH = getenv("XBMLANGPATH");
+    const char *XAPPLRESDIR = getenv("XAPPLRESDIR");
+    const char *HOME = _XmOSGetHomeDirName();
 
+    
     if (HOME == NULL) {
 	HOME = "";
-	HOME_length = 0;
-    } else
-	HOME_length = strlen(HOME);
-
+    }
     if (XBMLANGPATH)
     {
-	_search_path = XBMLANGPATH;
-
-	if (XAPPLRESDIR)
-	{
-	    XtFree(XAPPLRESDIR);
-	}
+      _search_path = XtNewString(XBMLANGPATH);
     }
     else if (XAPPLRESDIR)
     {
-	int XAPPLRESDIR_length = strlen(XAPPLRESDIR);
 
 	_search_path = (char *)XtMalloc(strlen(XAPPLRESDIR_set_pattern)
-					+ XAPPLRESDIR_length * 6
-					+ HOME_length * 2 + 1);
+					+ strlen(XAPPLRESDIR) * 6
+					+ strlen(HOME) * 2 + 1);
 
 	sprintf(_search_path, XAPPLRESDIR_set_pattern,
 		XAPPLRESDIR, XAPPLRESDIR, XAPPLRESDIR,
 		XAPPLRESDIR, XAPPLRESDIR, XAPPLRESDIR,
 		HOME, HOME);
 
-
     }
     else
     {				/* neither of them was set... */
 	_search_path = (char *)XtMalloc(strlen(nothing_set_pattern)
-					+ HOME_length * 7 + 1);
+					+ strlen(HOME) * 7 + 1);
 
 	sprintf(_search_path, nothing_set_pattern,
 		HOME, HOME, HOME, HOME, HOME, HOME, HOME);
     }
 
-    DEBUGOUT(XdbDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 		      "Using %s for search path\n", _search_path));
 }
 
 
 #if XmVERSION >= 2
+/*
+ * Get a scaled pixmap.
+ *
+ * If scaling_ratio == 0 then use print shell resolution,
+ * if scaling_ratio == 1 then don't scale.
+ */
 extern XtEnum 
 XmGetScaledPixmap(Widget widget,
                   String image_name,
@@ -1131,4 +1122,4 @@ XmGetScaledPixmap(Widget widget,
    _XmWarning(NULL, "XmGetScaledPixmap() is not yet implemented!");
    return 0;
 }
-#endif
+#endif /* #if XmVERSION >= 2 */
