@@ -1,9 +1,9 @@
 /**
  *
- * $Id: LTCvt.c,v 1.15 2000/09/27 12:26:58 amai Exp $
+ * $Id: LTCvt.c,v 1.22 2001/07/27 18:51:56 dannybackx Exp $
  *
- * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2000 LessTif Development Team
+ * Copyright  1995 Free Software Foundation, Inc.
+ * Copyright  1995-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: LTCvt.c,v 1.15 2000/09/27 12:26:58 amai Exp $";
+static const char rcsid[] = "$Id: LTCvt.c,v 1.22 2001/07/27 18:51:56 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -48,57 +48,35 @@ static const char rcsid[] = "$Id: LTCvt.c,v 1.15 2000/09/27 12:26:58 amai Exp $"
 
 static char *_search_path = NULL;
 
-extern void LTCreateSearchPath(void);
-extern Boolean LTAddPixmapToCache(char *pixmap_name, Pixmap pixmap,
-				  Screen *screen,
-				  Pixel foreground, Pixel background,
-				  int depth, int width, int height,
-				  int hot_x, int hot_y);
-
-
 /* Prototypes to ensure proper type for the definitions below: */
 static Boolean
-_XmNSECvtStringToBitmap
-(Display*, XrmValue*, Cardinal*, XrmValue*, XrmValue*, XtPointer*);
+_XmNSECvtStringToBitmap (Display*, XrmValue*, Cardinal*, XrmValue*, XrmValue*, XtPointer*);
 static Boolean
-_XmNSECvtStringToPixmap
-(Display*, XrmValue*, Cardinal*, XrmValue*, XrmValue*, XtPointer*);
+_XmNSECvtStringToPixmap (Display*, XrmValue*, Cardinal*, XrmValue*, XrmValue*, XtPointer*);
 static Boolean
-_XmNSECvtShapeStyleToString
-(Display*, XrmValue*, Cardinal*, XrmValue*, XrmValue*, XtPointer*);
+_XmNSECvtShapeStyleToString (Display*, XrmValue*, Cardinal*, XrmValue*, XrmValue*, XtPointer*);
 static Boolean
-_XmNSECvtBooleanToString
-(Display*, XrmValue*, Cardinal*, XrmValue*, XrmValue*, XtPointer*);
+_XmNSECvtBooleanToString (Display*, XrmValue*, Cardinal*, XrmValue*, XrmValue*, XtPointer*);
 static Boolean
-_XmNSECvtBoolToString
-(Display*, XrmValue*, Cardinal*, XrmValue*, XrmValue*, XtPointer*);
+_XmNSECvtBoolToString (Display*, XrmValue*, Cardinal*, XrmValue*, XrmValue*, XtPointer*);
 static Boolean
-_XmNSECvtAttachmentToString
-(Display*, XrmValue*, Cardinal*, XrmValue*, XrmValue*, XtPointer*);
+_XmNSECvtAttachmentToString (Display*, XrmValue*, Cardinal*, XrmValue*, XrmValue*, XtPointer*);
 static Boolean
-_XmNSECvtPositionToString
-(Display*, XrmValue*, Cardinal*, XrmValue*, XrmValue*, XtPointer*);
+_XmNSECvtPositionToString (Display*, XrmValue*, Cardinal*, XrmValue*, XrmValue*, XtPointer*);
 static Boolean
-_XmNSECvtCardinalToString
-(Display*, XrmValue*, Cardinal*, XrmValue*, XrmValue*, XtPointer*);
+_XmNSECvtCardinalToString (Display*, XrmValue*, Cardinal*, XrmValue*, XrmValue*, XtPointer*);
 static Boolean
-_XmNSECvtPixelToString
-(Display*, XrmValue*, Cardinal*, XrmValue*, XrmValue*, XtPointer*);
+_XmNSECvtPixelToString (Display*, XrmValue*, Cardinal*, XrmValue*, XrmValue*, XtPointer*);
 static Boolean
-_XmNSECvtColorToString
-(Display*, XrmValue*, Cardinal*, XrmValue*, XrmValue*, XtPointer*);
+_XmNSECvtColorToString (Display*, XrmValue*, Cardinal*, XrmValue*, XrmValue*, XtPointer*);
 static Boolean
-_XmNSECvtUnsignedCharToString
-(Display*, XrmValue*, Cardinal*, XrmValue*, XrmValue*, XtPointer*);
+_XmNSECvtUnsignedCharToString (Display*, XrmValue*, Cardinal*, XrmValue*, XrmValue*, XtPointer*);
 static Boolean
-_XmNSECvtDimensionToString
-(Display*, XrmValue*, Cardinal*, XrmValue*, XrmValue*, XtPointer*);
+_XmNSECvtDimensionToString (Display*, XrmValue*, Cardinal*, XrmValue*, XrmValue*, XtPointer*);
 static Boolean
-_XmNSECvtXmStringToString
-(Display*, XrmValue*, Cardinal*, XrmValue*, XrmValue*, XtPointer*);
+_XmNSECvtXmStringToString (Display*, XrmValue*, Cardinal*, XrmValue*, XrmValue*, XtPointer*);
 static Boolean
-_XmNSECvtWidgetToString
-(Display*, XrmValue*, Cardinal*, XrmValue*, XrmValue*, XtPointer*);
+_XmNSECvtWidgetToString (Display*, XrmValue*, Cardinal*, XrmValue*, XrmValue*, XtPointer*);
 
 
 /*
@@ -149,7 +127,7 @@ _XmNSEGetPixmap(Screen *screen, char *fname)
 
     if (_search_path == NULL)
     {
-	LTCreateSearchPath();
+	_LTCreateSearchPath();
     }
 
     /*
@@ -202,7 +180,7 @@ _XmNSEGetPixmap(Screen *screen, char *fname)
 			       &xpm_attrib) == _LtXpmSuccess)
 #endif
     {
-	LTAddPixmapToCache(fname, pmap, screen, 0, 0, 0, 0, 0, 0, 0);
+	_LTAddPixmapToCache(fname, pmap, screen, 0, 0, 0, 0, 0, 0, 0);
 	/* FIX ME! */
     }
     else
@@ -216,21 +194,6 @@ _XmNSEGetPixmap(Screen *screen, char *fname)
     return pmap;
 }
 
-
-static Boolean
-_XmNSECvtStringToBitmap(Display *dpy,
-		        XrmValue *args,
-		        Cardinal *num_args,
-		        XrmValue *from,
-		        XrmValue *to,
-		        XtPointer *converter_data)
-
-{
-fprintf(stderr, "_XmNSECvtStringToBitmap(from=%s) called\n",
-        (char *)from->addr);
-  return False;
-}
-
 /*
  * _XmNSECvtStringToPixmap is not part of the OSF/Motif API.
  * This routine is used to convert a string to a pixmap.
@@ -302,6 +265,70 @@ _XmNSECvtStringToPixmap(Display *dpy,
     return True;
 }
 
+/*
+ * _XmNSECvtStringToPixmap is not part of the OSF/Motif API.
+ * This routine is used to convert a string to a pixmap.
+ * This is done by calling the _XmNSEGetPixmap routine with the
+ * supplied string.  
+ */
+static Boolean
+_XmNSECvtStringToBitmap(Display *dpy,
+		        XrmValue *args,
+		        Cardinal *num_args,
+		        XrmValue *from,
+		        XrmValue *to,
+		        XtPointer *converter_data)
+{
+	static Pixmap _pmap;
+	Screen *screen;
+	char *name;
+
+	DEBUGOUT(_LtDebug(__FILE__, NULL, "_XmNSECvtStringToBitmap(from=%s) called\n",
+		(char *)from->addr));
+
+	if (_XmGetDefaultDisplay() == NULL) {
+		return False;
+	}
+
+	if (*num_args != 1) {
+		XtWarningMsg("wrongParameters", "cvtStringToBitmap", "XtToolkitError",
+			"String to Bitmap conversion needs screen argument",
+			(String *)NULL,
+			(Cardinal *)NULL);
+	}
+
+	/* get arguments */
+	screen = *((Screen **)args[0].addr);
+	name = (char *)from->addr;
+
+	/* over kill check */
+	if (name == NULL || strcmp(name, "None") == 0
+			|| strcmp(name, "XmUNSPECIFIED_PIXMAP") == 0) {
+		_pmap = XmUNSPECIFIED_PIXMAP;
+	} else {
+		fprintf(stderr, "_XmNSECvtStringToBitmap(from=%s) called\n",
+			(char *)from->addr);
+		_pmap = XmUNSPECIFIED_PIXMAP;		/* FIX ME */
+
+		return False;
+/*		_pmap = _XmNSEGetPixmap(screen, name);	*/
+	}
+
+	if (to->addr == NULL) {
+		to->addr = (XPointer)&_pmap;
+		to->size = sizeof(Pixmap);
+	} else {
+		if (to->size >= sizeof(Pixmap)) {
+			*((Pixmap *)to->addr) = _pmap;
+			to->size = sizeof(Pixmap);
+		} else {
+			XtDisplayStringConversionWarning(dpy, (char *)from->addr, XmRPixmap);
+		}
+	}
+
+	return True;
+}
+
 /* Begin stuff copied from X11/Xmu/Converters.h */
 #define XtRShapeStyle "ShapeStyle"
 #define XtERectangle "Rectangle"
@@ -328,6 +355,7 @@ typedef struct
     int size;
 } ConversionMap;
 
+
 static ConversionMap boolean_map[] =
 {
     {True, XtEtrue, sizeof(XtEtrue)},
@@ -338,6 +366,7 @@ static ConversionMap boolean_map[] =
     {False, XtEno, sizeof(XtEno)},
 };
 
+
 static ConversionMap shape_style_map[] =
 {
     {XmuShapeRectangle, XtERectangle, sizeof(XtERectangle)},
@@ -363,7 +392,7 @@ static ConversionMap shape_style_map[] =
 		strcpy((char *) toVal->addr, value);	\
 	    }							\
 	    else {						\
-		toVal->addr = (XtPointer)value;			\
+		toVal->addr = (XPointer)value;			\
 	    }							\
 	    toVal->size = size; 				\
 	    return True;					\
@@ -385,6 +414,7 @@ static ConversionMap shape_style_map[] =
 	    return True;					\
 	}
 
+
 static void
 XtDisplayConversionWarning(String type, XtPointer from, String to)
 {
@@ -398,6 +428,7 @@ XtDisplayConversionWarning(String type, XtPointer from, String to)
 		 params, &num_params);
 }
 
+
 static Boolean
 _XmNSECvtShapeStyleToString(Display *dpy, XrmValue *args, Cardinal *numArgs,
 			    XrmValue *fromVal, XrmValue *toVal,
@@ -415,10 +446,11 @@ _XmNSECvtShapeStyleToString(Display *dpy, XrmValue *args, Cardinal *numArgs,
 	}
     }
 
-    XtDisplayConversionWarning(XtRShapeStyle, (XtPointer)*i, XtRString);
+    XtDisplayConversionWarning(XtRShapeStyle, (XtPointer)(long)*i, XtRString);
     return False;
 }
 
+
 static Boolean
 _XmNSECvtBooleanToString(Display *dpy, XrmValue *args, Cardinal *numArgs,
 			 XrmValue *fromVal, XrmValue *toVal, XtPointer *data)
@@ -439,6 +471,7 @@ _XmNSECvtBooleanToString(Display *dpy, XrmValue *args, Cardinal *numArgs,
     return False;
 }
 
+
 static Boolean
 _XmNSECvtBoolToString(Display *dpy, XrmValue *args, Cardinal *numArgs,
 		      XrmValue *fromVal, XrmValue *toVal, XtPointer *data)
@@ -459,6 +492,7 @@ _XmNSECvtBoolToString(Display *dpy, XrmValue *args, Cardinal *numArgs,
     return False;
 }
 
+
 static Boolean
 _XmNSECvtAttachmentToString(Display *dpy, XrmValue *args, Cardinal *numArgs,
 			  XrmValue *fromVal, XrmValue *toVal, XtPointer *data)
@@ -475,11 +509,12 @@ _XmNSECvtAttachmentToString(Display *dpy, XrmValue *args, Cardinal *numArgs,
     }
 
     /* buffer must not be freed! */
-    buffer = XdbAttachment2String(*(Position *)fromVal->addr);
+    buffer = _LtDebugAttachment2String(*(Position *)fromVal->addr);
     size = strlen(buffer);
     string_convert_done(buffer);
 }
 
+
 static Boolean
 _XmNSECvtPositionToString(Display *dpy, XrmValue *args, Cardinal *numArgs,
 			  XrmValue *fromVal, XrmValue *toVal, XtPointer *data)
@@ -500,6 +535,7 @@ _XmNSECvtPositionToString(Display *dpy, XrmValue *args, Cardinal *numArgs,
     string_convert_done(buffer);
 }
 
+
 static Boolean
 _XmNSECvtIntToString(Display *dpy, XrmValue *args, Cardinal *numArgs,
 		     XrmValue *fromVal, XrmValue *toVal, XtPointer *data)
@@ -520,6 +556,7 @@ _XmNSECvtIntToString(Display *dpy, XrmValue *args, Cardinal *numArgs,
     string_convert_done(buffer);
 }
 
+
 static Boolean
 _XmNSECvtCardinalToString(Display *dpy, XrmValue *args, Cardinal *numArgs,
 			  XrmValue *fromVal, XrmValue *toVal, XtPointer *data)
@@ -540,6 +577,7 @@ _XmNSECvtCardinalToString(Display *dpy, XrmValue *args, Cardinal *numArgs,
     string_convert_done(buffer);
 }
 
+
 static Boolean
 _XmNSECvtPixelToString(Display *dpy, XrmValue *args, Cardinal *numArgs,
 		       XrmValue *fromVal, XrmValue *toVal, XtPointer *data)
@@ -560,6 +598,7 @@ _XmNSECvtPixelToString(Display *dpy, XrmValue *args, Cardinal *numArgs,
     string_convert_done(buffer);
 }
 
+
 static Boolean
 _XmNSECvtColorToString(Display *dpy, XrmValue *args, Cardinal *numArgs,
 		       XrmValue *fromVal, XrmValue *toVal, XtPointer *data)
@@ -581,6 +620,7 @@ _XmNSECvtColorToString(Display *dpy, XrmValue *args, Cardinal *numArgs,
     string_convert_done(buffer);
 }
 
+
 static Boolean
 _XmNSECvtUnsignedCharToString(Display *dpy, XrmValue *args, Cardinal *numArgs,
 			      XrmValue *fromVal, XrmValue *toVal,
@@ -603,6 +643,7 @@ _XmNSECvtUnsignedCharToString(Display *dpy, XrmValue *args, Cardinal *numArgs,
     string_convert_done(buffer);
 }
 
+
 static Boolean
 _XmNSECvtDimensionToString(Display *dpy, XrmValue *args, Cardinal *numArgs,
 			   XrmValue *fromVal, XrmValue *toVal, XtPointer *data)
@@ -623,6 +664,7 @@ _XmNSECvtDimensionToString(Display *dpy, XrmValue *args, Cardinal *numArgs,
     string_convert_done(buffer);
 }
 
+
 static Boolean
 _XmNSECvtXmStringToString(Display *dpy, XrmValue *args, Cardinal *numArgs,
 			  XrmValue *fromVal, XrmValue *toVal, XtPointer *data)
@@ -630,7 +672,7 @@ _XmNSECvtXmStringToString(Display *dpy, XrmValue *args, Cardinal *numArgs,
     int size;
     char *s;
 
-    DEBUGOUT(XdbDebug(__FILE__, NULL, "_XmNSECvtXmStringToString\n"));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "_XmNSECvtXmStringToString\n"));
 
     if (*numArgs != 0)
     {
@@ -650,6 +692,7 @@ _XmNSECvtXmStringToString(Display *dpy, XrmValue *args, Cardinal *numArgs,
        return False;		/* Conversion failed */
 }
 
+
 static Boolean
 _XmNSECvtWidgetToString(Display *dpy, XrmValue *args, Cardinal *numArgs,
 			  XrmValue *fromVal, XrmValue *toVal, XtPointer *data)
@@ -658,7 +701,7 @@ _XmNSECvtWidgetToString(Display *dpy, XrmValue *args, Cardinal *numArgs,
     Widget w;
     static char *s = NULL; /* amai: a small(?) memory leak - see below */
 
-    DEBUGOUT(XdbDebug(__FILE__, NULL, "_XmNSECvtWidgetToString\n"));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "_XmNSECvtWidgetToString\n"));
 
     if (*numArgs != 0)
     {
@@ -676,6 +719,7 @@ _XmNSECvtWidgetToString(Display *dpy, XrmValue *args, Cardinal *numArgs,
     string_convert_done(s);
 }
 
+
 /* this is needed for the string to pixmap converters */
 static XtConvertArgRec args[] =
 {
@@ -686,10 +730,11 @@ static XtConvertArgRec args[] =
     }
 };
 
+
 /*
  * register nonstandard extensions, if any
  */
-void
+extern void
 _XmRegisterNSEConverters(void)
 {
     XtSetTypeConverter(XmRString,	/* source type */
@@ -699,6 +744,17 @@ _XmRegisterNSEConverters(void)
 		       XtNumber(args),	/* number of args for converter */
 		       XtCacheNone,	/* caching instructions */
 		       NULL);		/* destructor function */
+
+/* Danny FIX ME should I do this ? */
+    XtSetTypeConverter(XmRString,	/* source type */
+		       XmRBitmap,	/* target type */
+		       _XmNSECvtStringToBitmap,	/* converter routine */
+		       args,		/* args for converter routine */
+		       XtNumber(args),	/* number of args for converter */
+		       XtCacheNone,	/* caching instructions */
+		       NULL);		/* destructor function */
+/* End Danny */
+
 #if 0
 /* amai: see thread about DragIcon/Ishmail */
     XtSetTypeConverter(XmRString,
