@@ -1,11 +1,11 @@
 /**
- * $Id: LTglob.c,v 1.19 2000/10/14 19:08:53 amai Exp $
+ * $Id: LTglob.c,v 1.28 2001/07/27 18:51:56 dannybackx Exp $
  *
  * derived from GNU libc glob.c
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
  * Copyright (C) 1991, 1992, 1993 Free Software Foundation, Inc.
- * Copyright (C) 1995-2000 LessTif Development Team
+ * Copyright (C) 1995-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -25,19 +25,15 @@
  *
  **/
 
-static const char rcsid[] = "$Id: LTglob.c,v 1.19 2000/10/14 19:08:53 amai Exp $";
-
-#if defined (_AIX) && !defined (__GNUC__)
-#pragma alloca
-#endif
+static const char rcsid[] = "$Id: LTglob.c,v 1.28 2001/07/27 18:51:56 dannybackx Exp $";
 
 #include <LTconfig.h>
 
-#include <stdlib.h>      /* -> qsort() */
+#include <stdlib.h>
 #include <string.h>
+#include <ctype.h>
 #include <errno.h>
 #include <stddef.h>
-
 #ifdef HAVE_SYS_TYPES_H
 #include <sys/types.h>
 #endif
@@ -85,21 +81,10 @@ static const char rcsid[] = "$Id: LTglob.c,v 1.19 2000/10/14 19:08:53 amai Exp $
 #define REAL_DIR_ENTRY(dp) (dp->d_ino != 0)
 #endif /* POSIX */
 
-#if !defined(__alloca)
-#ifdef	__GNUC__
-#undef	alloca
-#define	alloca(n)	__builtin_alloca (n)
-#else /* Not GCC.  */
-#if	defined (sparc) || defined (HAVE_ALLOCA_H)
-#include <alloca.h>
-#else /* Not sparc or HAVE_ALLOCA_H.  */
-#ifndef	_AIX
-extern char *alloca(size_t size_to_allocate);
-#endif /* Not _AIX.  */
-#endif /* sparc or HAVE_ALLOCA_H.  */
-#endif /* GCC.  */
-#define	__alloca	alloca
-#endif
+#include "LTglob.h"
+
+#include <XmI/DebugUtil.h>
+
 
 /*
    rws 5 Nov 1998
@@ -122,26 +107,6 @@ extern char *alloca(size_t size_to_allocate);
 #endif
 
 
-/* Some system header files erroneously define these.
-   We want our own definitions from <fnmatch.h> to take precedence.  */
-#undef	FNM_PATHNAME
-#undef	FNM_NOESCAPE
-#undef	FNM_PERIOD
-#include "LTfnmatch.h"
-
-/* Some system header files erroneously define these.
-   We want our own definitions from <glob.h> to take precedence.  */
-#undef	GLOB_ERR
-#undef	GLOB_MARK
-#undef	GLOB_NOSORT
-#undef	GLOB_DOOFFS
-#undef	GLOB_NOCHECK
-#undef	GLOB_APPEND
-#undef	GLOB_NOESCAPE
-#undef	GLOB_PERIOD
-#include "LTglob.h"
-
-
 #if 1
 /* amai: We don't use external hooks. If you want to do so -
    also change <LTglob.h> */
@@ -154,14 +119,178 @@ const char *(*__glob_readdir_hook) (void * stream);
 void (*__glob_closedir_hook) (void * stream);
 #endif /* */
 
+/* just for convenience: */
+typedef int (* errfunc_t)(const char *, int);
+
 static int glob_pattern_p (const char *pattern, int quote);
 static int glob_in_dir (const char *pattern, const char *directory,
-                        int flags,
-				int (*errfunc) (const char *, int),
-				glob_t *pglob);
+                        int flags, errfunc_t errfunc, glob_t *pglob);
 static int prefix_array (const char *prefix, char **array, size_t n);
 static int collated_compare (const void *, const void *);
 
+
+
+
+/* Match STRING against the filename pattern PATTERN, returning zero if
+   it matches, nonzero if not.
+   Derived from GNU libc fnmatch.c  */
+static int
+_Lesstif_fnmatch(const char *pattern,
+		 const char *string,
+		 int flags)
+{
+    register const char *p = pattern, *n = string;
+    register char c;
+
+/* Note that this evalutes C many times.  */
+#define FOLD(c)	((flags & FNM_CASEFOLD) && isupper (c) ? tolower (c) : (c))
+
+    while ((c = *p++) != '\0')
+    {
+	c = FOLD(c);
+
+	switch (c)
+	{
+	case '?':
+	    if (*n == '\0')
+		return FNM_NOMATCH;
+	    else if ((flags & FNM_FILE_NAME) && *n == '/')
+		return FNM_NOMATCH;
+	    else if ((flags & FNM_PERIOD) && *n == '.' &&
+		     (n == string || ((flags & FNM_FILE_NAME) && n[-1] == '/')))
+		return FNM_NOMATCH;
+	    break;
+
+	case '\\':
+	    if (!(flags & FNM_NOESCAPE))
+	    {
+		c = *p++;
+		c = FOLD(c);
+	    }
+	    if (FOLD(*n) != c)
+		return FNM_NOMATCH;
+	    break;
+
+	case '*':
+	    if ((flags & FNM_PERIOD) && *n == '.' &&
+		(n == string || ((flags & FNM_FILE_NAME) && n[-1] == '/')))
+		return FNM_NOMATCH;
+
+	    for (c = *p++; c == '?' || c == '*'; c = *p++, ++n)
+		if (((flags & FNM_FILE_NAME) && *n == '/') ||
+		    (c == '?' && *n == '\0'))
+		    return FNM_NOMATCH;
+
+	    if (c == '\0')
+		return 0;
+
+	    {
+		char c1 = (!(flags & FNM_NOESCAPE) && c == '\\') ? *p : c;
+		c1 = FOLD(c1);
+		for (--p; *n != '\0'; ++n)
+		    if ((c == '[' || FOLD(*n) == c1) &&
+			_Lesstif_fnmatch(p, n, flags & ~FNM_PERIOD) == 0)
+			return 0;
+		return FNM_NOMATCH;
+	    }
+
+	case '[':
+	    {
+		/* Nonzero if the sense of the character class is inverted.  */
+		register int c_not;
+
+		if (*n == '\0')
+		    return FNM_NOMATCH;
+
+		if ((flags & FNM_PERIOD) && *n == '.' &&
+		    (n == string || ((flags & FNM_FILE_NAME) && n[-1] == '/')))
+		    return FNM_NOMATCH;
+
+		c_not = (*p == '!' || *p == '^');
+		if (c_not)
+		    ++p;
+
+		c = *p++;
+		for (;;)
+		{
+		    register char cstart = c, cend = c;
+
+		    if (!(flags & FNM_NOESCAPE) && c == '\\')
+			cstart = cend = *p++;
+
+		    cstart = cend = FOLD(cstart);
+
+		    if (c == '\0')
+			/* [ (unterminated) loses.  */
+			return FNM_NOMATCH;
+
+		    c = *p++;
+		    c = FOLD(c);
+
+		    if ((flags & FNM_FILE_NAME) && c == '/')
+			/* [/] can never match.  */
+			return FNM_NOMATCH;
+
+		    if (c == '-' && *p != ']')
+		    {
+			cend = *p++;
+			if (!(flags & FNM_NOESCAPE) && cend == '\\')
+			    cend = *p++;
+			if (cend == '\0')
+			    return FNM_NOMATCH;
+			cend = FOLD(cend);
+
+			c = *p++;
+		    }
+
+		    if (FOLD(*n) >= cstart && FOLD(*n) <= cend)
+			goto matched;
+
+		    if (c == ']')
+			break;
+		}
+		if (!c_not)
+		    return FNM_NOMATCH;
+		break;
+
+	      matched:;
+		/* Skip the rest of the [...] that already matched.  */
+		while (c != ']')
+		{
+		    if (c == '\0')
+			/* [... (unterminated) loses.  */
+			return FNM_NOMATCH;
+
+		    c = *p++;
+		    if (!(flags & FNM_NOESCAPE) && c == '\\')
+			/* XXX 1003.2d11 is unclear if this is right.  */
+			++p;
+		}
+		if (c_not)
+		    return FNM_NOMATCH;
+	    }
+	    break;
+
+	default:
+	    if (c != FOLD(*n))
+		return FNM_NOMATCH;
+	}
+
+	++n;
+    }
+
+    if (*n == '\0')
+	return 0;
+
+    if ((flags & FNM_LEADING_DIR) && *n == '/')
+	/* The FNM_LEADING_DIR flag says that "foo*" matches "foobar/frobozz".  */
+	return 0;
+
+    return FNM_NOMATCH;
+} /* _Lesstif_fnmatch() */
+
+
+
 /* Do glob searching for PATTERN, placing results in PGLOB.
    The bits defined above may be set in FLAGS.
    If a directory cannot be opened or read and ERRFUNC is not nil,
@@ -172,12 +301,11 @@ static int collated_compare (const void *, const void *);
    Otherwise, `glob' returns zero.
  */
 int
- _Lesstif_glob(const char *pattern, int flags,
-	       int (*errfunc) (const char *, int),
-	       glob_t *pglob)
+_Lesstif_glob(const char *pattern, int flags,
+	      errfunc_t errfunc, glob_t *pglob)
 {
-    const char *filename;
     char *dirname;
+    const char *filename;
     size_t dirlen;
     int status;
     int oldcount;
@@ -188,25 +316,30 @@ int
 	return -1;
     }
 
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
+		      "_Lesstif_glob(%s, %i)\n", pattern, flags));
+
     /* Find the filename.  */
     filename = strrchr(pattern, '/');
     if (filename == NULL)
     {
+        dirname=XtMalloc(2);
 	filename = pattern;
-	dirname = (char *)".";
+	strcpy(dirname, ".");
 	dirlen = 0;
     }
     else if (filename == pattern)
     {
 	/* "/pattern".  */
-	dirname = (char *)"/";
+        dirname=XtMalloc(2);
+	strcpy(dirname, "/");
 	dirlen = 1;
 	++filename;
     }
     else
     {
 	dirlen = filename - pattern;
-	dirname = (char *)__alloca(dirlen + 1);
+	dirname = XtMalloc(dirlen + 1);
 	memcpy(dirname, pattern, dirlen);
 	dirname[dirlen] = '\0';
 	++filename;
@@ -219,6 +352,7 @@ int
 	if (val == 0)
 	    pglob->gl_flags = (pglob->gl_flags & ~GLOB_MARK) |
 		(flags & GLOB_MARK);
+	XtFree(dirname);
 	return val;
     }
 
@@ -238,12 +372,16 @@ int
 	glob_t dirs;
 	register int i;
 
+        DEBUGOUT(_LtDebug(__FILE__, NULL,
+		      "glob_pattern(%s, !(flags & GLOB_NOESCAPE))!=NULL\n", dirname));
 	status = _Lesstif_glob(dirname,
 			 ((flags & (GLOB_ERR | GLOB_NOCHECK | GLOB_NOESCAPE)) |
 			  GLOB_NOSORT),
-			       errfunc, &dirs);
-	if (status != 0)
+			  errfunc, &dirs);
+	if (status != 0) {
+     	    XtFree(dirname);
 	    return status;
+        }
 
 	/* We have successfully globbed the preceding directory name.
 	   For each name we found, call glob_in_dir on it and FILENAME,
@@ -252,20 +390,6 @@ int
 	{
 	    int oldcount;
 
-#ifdef	SHELL
-	    {
-		/* Make globbing interruptible in the bash shell. */
-		extern int interrupt_state;
-
-		if (interrupt_state)
-		{
-		    _Lesstif_globfree(&dirs);
-		    _Lesstif_globfree(&files);
-		    return GLOB_ABEND;
-		}
-	    }
-#endif /* SHELL.  */
-
 	    oldcount = pglob->gl_pathc;
 	    status = glob_in_dir(filename, dirs.gl_pathv[i],
 				 (flags | GLOB_APPEND) & ~GLOB_NOCHECK,
@@ -278,6 +402,7 @@ int
 	    {
 		_Lesstif_globfree(&dirs);
 		_Lesstif_globfree(pglob);
+		XtFree(dirname);
 		return status;
 	    }
 
@@ -288,6 +413,7 @@ int
 	    {
 		_Lesstif_globfree(&dirs);
 		_Lesstif_globfree(pglob);
+		XtFree(dirname);
 		return GLOB_NOSPACE;
 	    }
 	}
@@ -301,8 +427,10 @@ int
 	    {
 		size_t len = strlen(pattern) + 1;
 		char *patcopy = (char *)XtMalloc(len);
-		if (patcopy == NULL)
+		if (patcopy == NULL) {
+		    XtFree(dirname);
 		    return GLOB_NOSPACE;
+		}
 		memcpy(patcopy, pattern, len);
 
 		pglob->gl_pathv =
@@ -315,6 +443,7 @@ int
 		if (pglob->gl_pathv == NULL)
 		{
 		    XtFree(patcopy);
+		    XtFree(dirname);
 		    return GLOB_NOSPACE;
 		}
 
@@ -326,15 +455,22 @@ int
 		pglob->gl_pathv[pglob->gl_pathc] = NULL;
 		pglob->gl_flags = flags;
 	    }
-	    else
+	    else {
+	        XtFree(dirname);
 		return GLOB_NOMATCH;
+	    }
 	}
-    }
+    } /* if (glob_pattern_p(dirname, !(flags & GLOB_NOESCAPE))) */
     else
     {
+        DEBUGOUT(_LtDebug(__FILE__, NULL,
+		      "glob_pattern(%s, !(flags & GLOB_NOESCAPE))=NULL\n", dirname));
+
 	status = glob_in_dir(filename, dirname, flags, errfunc, pglob);
-	if (status != 0)
+	if (status != 0) {
+ 	    XtFree(dirname);
 	    return status;
+	}
 
 	if (dirlen > 0)
 	{
@@ -344,10 +480,11 @@ int
 			     pglob->gl_pathc - oldcount))
 	    {
 		_Lesstif_globfree(pglob);
+		XtFree(dirname);
 		return GLOB_NOSPACE;
 	    }
 	}
-    }
+    } /* else */
 
     if (!(flags & GLOB_NOSORT))
 	/* Sort the vector.  */
@@ -364,14 +501,17 @@ int
 	   order (`"./" > "../"' but `"." < ".."'). */
 	int i;
 	struct stat st;
+
+        DEBUGOUT(_LtDebug(__FILE__, NULL,
+		      "_Lesstif_glob(): GLOB_NOSORT\n"));
 	for (i = oldcount; i < pglob->gl_pathc; ++i)
 	    if (LTstat(pglob->gl_pathv[i], &st) == 0 &&
 		S_ISDIR(st.st_mode))
 		strcat(pglob->gl_pathv[i], "/");
     }
-
+    XtFree(dirname);
     return 0;
-}
+} /* _Lesstif_glob() */
 
 
 /* Free storage allocated in PGLOB by a previous `glob' call.  */
@@ -381,10 +521,11 @@ _Lesstif_globfree(register glob_t *pglob)
     if (pglob->gl_pathv != NULL)
     {
 	register int i;
+
 	for (i = 0; i < pglob->gl_pathc; ++i)
 	    if (pglob->gl_pathv[i] != NULL)
-		XtFree((void *) pglob->gl_pathv[i]);
-	XtFree((void *) pglob->gl_pathv);
+		XtFree((char *) pglob->gl_pathv[i]);
+	XtFree((char *) pglob->gl_pathv);
     }
 }
 
@@ -434,14 +575,14 @@ prefix_array(const char *dirname, char **array, size_t n)
 	if (new_w == NULL)
 	{
 	    while (i > 0)
-		XtFree((void *) array[--i]);
+		XtFree((char *) array[--i]);
 	    return 1;
 	}
 
 	memcpy(new_w, dirname, dirlen);
 	new_w[dirlen] = '/';
 	memcpy(&new_w[dirlen + 1], array[i], eltlen);
-	XtFree((void *) array[i]);
+	XtFree((char *) array[i]);
 	array[i] = new_w;
     }
 
@@ -457,6 +598,8 @@ glob_pattern_p(const char *pattern, int quote)
     register const char *p;
     int open = 0;
 
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
+		      "glob_pattern_p(%s, %i)\n", pattern, quote));
     for (p = pattern; *p != '\0'; ++p)
 	switch (*p)
 	{
@@ -480,7 +623,7 @@ glob_pattern_p(const char *pattern, int quote)
 	}
 
     return 0;
-}
+} /* glob_pattern_p() */
 
 
 /* Like `glob', but PATTERN is a final pathname component,
@@ -490,11 +633,9 @@ glob_pattern_p(const char *pattern, int quote)
  */
 static int
 glob_in_dir(const char *pattern, const char *directory, int flags,
-	    int (*errfunc) (const char *, int),
-	    glob_t *pglob)
+	    errfunc_t errfunc, glob_t *pglob)
 {
-    void * stream;
-
+    void *stream;
     struct globlink
     {
 	struct globlink *next;
@@ -503,6 +644,10 @@ glob_in_dir(const char *pattern, const char *directory, int flags,
     struct globlink *names = NULL;
     size_t nfound = 0;
 
+
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
+		      "glob_in_dir(%s, %s, %i,)\n",
+		      pattern, directory, flags));    
     if (!glob_pattern_p(pattern, !(flags & GLOB_NOESCAPE)))
     {
 	stream = NULL;
@@ -553,7 +698,8 @@ glob_in_dir(const char *pattern, const char *directory, int flags,
 			    ((flags & GLOB_NOESCAPE) ? FNM_NOESCAPE : 0)) == 0)
 		{
 		    struct globlink *new_w
-		    = (struct globlink *)__alloca(sizeof(struct globlink));
+		    = (struct globlink *)XtMalloc(sizeof(struct globlink));
+
 		    if (len == 0)
 			len = strlen(name);
 		    new_w->name
@@ -573,7 +719,7 @@ glob_in_dir(const char *pattern, const char *directory, int flags,
     {
 	size_t len = strlen(pattern);
 	nfound = 1;
-	names = (struct globlink *)__alloca(sizeof(struct globlink));
+	names = (struct globlink *)XtMalloc(sizeof(struct globlink));
 	names->next = NULL;
 	names->name = (char *)XtMalloc(len + 1);
 	if (names->name == NULL)
@@ -595,8 +741,12 @@ glob_in_dir(const char *pattern, const char *directory, int flags,
 	while (pglob->gl_pathc < pglob->gl_offs)
 	    pglob->gl_pathv[pglob->gl_pathc++] = NULL;
 
-    for (; names != NULL; names = names->next)
+    while (names != NULL) {
+	struct globlink *next = names->next;
 	pglob->gl_pathv[pglob->gl_pathc++] = names->name;
+	XtFree((char *)names);
+	names = next;
+    }
     pglob->gl_pathv[pglob->gl_pathc] = NULL;
 
     pglob->gl_flags = flags;
@@ -604,28 +754,32 @@ glob_in_dir(const char *pattern, const char *directory, int flags,
     if (stream != NULL)
     {
 	int save = errno;
+
 	if (__glob_closedir_hook)
 	    (*__glob_closedir_hook) (stream);
 	else
-	    (void)closedir((DIR *) stream);
+	    closedir((DIR *) stream);
 	errno = save;
     }
+
     return nfound == 0 ? GLOB_NOMATCH : 0;
 
   memory_error:
     {
 	int save = errno;
+
 	if (__glob_closedir_hook)
 	    (*__glob_closedir_hook) (stream);
 	else
-	    (void)closedir((DIR *) stream);
+	    closedir((DIR *) stream);
 	errno = save;
     }
     while (names != NULL)
     {
 	if (names->name != NULL)
-	    XtFree((void *) names->name);
+	    XtFree((char *) names->name);
 	names = names->next;
     }
+    if (names) XtFree((char *)names);
     return GLOB_NOSPACE;
-}
+} /* glob_in_dir() */
