@@ -1,8 +1,9 @@
 /**
  *
- * $Id: LabelG.c,v 1.90 1999/09/19 16:34:11 rwscott Exp $
+ * $Id: LabelG.c,v 1.101 2001/09/13 13:34:13 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,9 +23,12 @@
  *
  **/
 
-static const char rcsid[] = "$Id: LabelG.c,v 1.90 1999/09/19 16:34:11 rwscott Exp $";
+static const char rcsid[] = "$Id: LabelG.c,v 1.101 2001/09/13 13:34:13 amai Exp $";
 
 #include <LTconfig.h>
+
+#include <string.h>
+
 #include <XmI/XmI.h>
 
 #include <Xm/XmP.h>
@@ -40,7 +44,6 @@ static const char rcsid[] = "$Id: LabelG.c,v 1.90 1999/09/19 16:34:11 rwscott Ex
 #include <Xm/ScreenP.h>
 #include <Xm/DragIconP.h>
 #include <XmI/AtomMgrI.h>
-#include <X11/Xfuncs.h>
 
 #include <XmI/DebugUtil.h>
 
@@ -51,18 +54,12 @@ static const char rcsid[] = "$Id: LabelG.c,v 1.90 1999/09/19 16:34:11 rwscott Ex
 /* Forward Declarations */
 
 static void class_initialize(void);
-
 static void class_part_initialize(WidgetClass w_class);
-
 static void initialize(Widget request, Widget new_w,
 		       ArgList args, Cardinal *num_args);
-
 static void destroy(Widget w);
-
 static void resize(Widget w);
-
 static void expose(Widget w, XEvent *event, Region region);
-
 static XtGeometryResult query_geometry(Widget w,
 				       XtWidgetGeometry *proposed,
 				       XtWidgetGeometry *answer);
@@ -72,10 +69,8 @@ static void get_values_hook(Widget w, ArgList args, Cardinal *num_args);
 #endif
 
 static void input_dispatch(Widget gadget, XEvent *event, Mask event_mask);
-
 static Boolean set_values(Widget current, Widget request, Widget new_w,
 			  ArgList args, Cardinal *num_args);
-
 static void secondary_object_create(Widget request, Widget new_w,
 				    ArgList args, Cardinal *num_args);
 
@@ -86,39 +81,28 @@ static void initialize_prehook(Widget request, Widget new_w,
 
 static void initialize_posthook(Widget request, Widget new_w,
 				ArgList args, Cardinal *num_args);
-
 static Boolean set_values_prehook(Widget old, Widget request, Widget new_w,
 				  ArgList args, Cardinal *num_args);
-
 static Boolean set_values_posthook(Widget old, Widget request, Widget new_w,
 				   ArgList args, Cardinal *num_args);
-
 static void get_values_prehook(Widget new_w, ArgList args, Cardinal *num_args);
-
 static void get_values_posthook(Widget new_w, ArgList args, Cardinal *num_args);
-
 static Cardinal get_sec_res_data(WidgetClass wc,
 				 XmSecondaryResourceData **data);
-
 static Boolean widget_baseline(Widget w, Dimension **baselines,
 			       int *nbaselines);
-
 static Boolean widget_display_rect(Widget w, XRectangle *rect);
-
+static void widget_margins (Widget w, XmBaselineMargins *margins);
 static void set_override_callback(Widget w);
-
 static void export_label_string(Widget w, int offset, XtArgVal *value);
-
 static void drag_drop_finish(Widget w,
 			     XtPointer client_data,
 			     XtPointer call_data);
-
 static Boolean drag_convert_proc(Widget w, Atom *selection,
 				 Atom *target, Atom *type_return,
 				 XtPointer *value_return,
 				 unsigned long *length_return,
 				 int *format_return);
-
 static void preferred_size(Widget w, Dimension *width, Dimension *height);
 
 /*
@@ -350,7 +334,6 @@ static XmSyntheticResource syn_resources[] =
     }
 };
 
-/* *INDENT-OFF* */
 static XmBaseClassExtRec _XmLabelGRectClassExtRec = {
     /* next_extension            */ NULL,
     /* record_type               */ NULLQUARK,
@@ -396,6 +379,10 @@ static XmGadgetClassExtRec _XmLabelGadgetClassExtRec = {
     /* size                      */ sizeof(XmGadgetClassExtRec),
     /* widget_baseline           */ widget_baseline,
     /* widget_display_rect       */ widget_display_rect,
+#if XmVERSION >= 2
+    /* margins_proc              */ widget_margins,
+#endif
+
 };
 
 XmLabelGadgetClassRec xmLabelGadgetClassRec = {
@@ -453,7 +440,6 @@ XmLabelGadgetClassRec xmLabelGadgetClassRec = {
 	/* extension           */ NULL
     },
 };
-/* *INDENT-ON* */
 
 
 WidgetClass xmLabelGadgetClass = (WidgetClass)&xmLabelGadgetClassRec;
@@ -470,9 +456,9 @@ secondary_object_create(Widget request,
     XmBaseClassExt *bce;
     XtPointer nsec, rsec;
     XmWidgetExtData ed;
-    int size;
+    Cardinal size;
 
-    DEBUGOUT(XdbDebug(__FILE__, new_w,
+    DEBUGOUT(_LtDebug(__FILE__, new_w,
 		      "LabelGCacheRec %s being initialized.\n", XtName(new_w)));
 
     bce = _XmGetBaseClassExtPtr(XtClass(new_w), XmQmotif);
@@ -501,7 +487,7 @@ secondary_object_create(Widget request,
     ed->widget = (Widget)nsec;
     ed->reqWidget = (Widget)rsec;
 
-    bcopy(nsec, rsec, size);
+    memcpy(rsec, nsec, size);
     ((XmExtRec *)rsec)->object.self = (Widget)rsec;
 
     _XmPushWidgetExtData(new_w, ed, XmCACHE_EXTENSION);
@@ -513,7 +499,7 @@ secondary_object_create(Widget request,
 int
 _XmLabelCacheCompare(XtPointer A, XtPointer B)
 {
-    return !bcmp(((XmLabelGCacheObjPart *)A),
+    return !memcmp(((XmLabelGCacheObjPart *)A),
 		 ((XmLabelGCacheObjPart *)B),
 		 sizeof(XmLabelGCacheObjPart));
 }
@@ -534,9 +520,17 @@ _XmCalcLabelGDimensions(Widget w)
     }
     else
     {
-	_XmLabelGetPixmapSize(w, (XtIsSensitive(w)
-				  ? LabG_Pixmap(w)
-				  : LabG_PixmapInsensitive(w)),
+    Pixmap mypm;
+
+	mypm = XtIsSensitive(w) ? LabG_Pixmap(w) : LabG_PixmapInsensitive(w);
+#if XmVERSION > 1
+	if (mypm == XmUNSPECIFIED_PIXMAP)
+	{
+	    mypm = LabG_Pixmap(w);
+	}
+#endif
+
+	_XmLabelGetPixmapSize(w, mypm,
 			      &LabG_TextRect_width(w),
 			      &LabG_TextRect_height(w));
     }
@@ -575,7 +569,7 @@ _XmAssignLabG_MarginHeight(XmLabelGadget lw, Dimension value)
 {
     XmBaseClassExt *bce;
     XmWidgetExtData ed;
-    int size;
+    Cardinal size;
     XtPointer nsec;
 
     if ((ed = _XmGetWidgetExtData((Widget)lw, XmCACHE_EXTENSION)) != NULL)
@@ -599,9 +593,9 @@ _XmAssignLabG_MarginHeight(XmLabelGadget lw, Dimension value)
     ExtObj_LogicalParent(nsec) = (Widget)lw;
     ExtObj_ExtensionType(nsec) = XmCACHE_EXTENSION;
 
-    bcopy(LabG_Cache((Widget)lw),
-	  &((XmLabelGCacheObject)nsec)->label_cache,
-	  sizeof(XmLabelGCacheObjPart));
+    memcpy(&((XmLabelGCacheObject)nsec)->label_cache,
+           LabG_Cache((Widget)lw),
+	   sizeof(XmLabelGCacheObjPart));
 
     ed = (XmWidgetExtData)XtMalloc(sizeof(XmWidgetExtDataRec));
     ed->widget = (Widget)nsec;
@@ -620,7 +614,7 @@ _XmAssignLabG_MarginWidth(XmLabelGadget lw, Dimension value)
 {
     XmBaseClassExt *bce;
     XmWidgetExtData ed;
-    int size;
+    Cardinal size;
     XtPointer nsec;
 
     if ((ed = _XmGetWidgetExtData((Widget)lw, XmCACHE_EXTENSION)) != NULL)
@@ -644,9 +638,9 @@ _XmAssignLabG_MarginWidth(XmLabelGadget lw, Dimension value)
     ExtObj_LogicalParent(nsec) = (Widget)lw;
     ExtObj_ExtensionType(nsec) = XmCACHE_EXTENSION;
 
-    bcopy(LabG_Cache((Widget)lw),
-	  &((XmLabelGCacheObject)nsec)->label_cache,
-	  sizeof(XmLabelGCacheObjPart));
+    memcpy(&((XmLabelGCacheObject)nsec)->label_cache,
+           LabG_Cache((Widget)lw),
+	   sizeof(XmLabelGCacheObjPart));
 
     ed = (XmWidgetExtData)XtMalloc(sizeof(XmWidgetExtDataRec));
     ed->widget = (Widget)nsec;
@@ -663,7 +657,7 @@ _XmAssignLabG_MarginLeft(XmLabelGadget lw, Dimension value)
 {
     XmBaseClassExt *bce;
     XmWidgetExtData ed;
-    int size;
+    Cardinal size;
     XtPointer nsec;
 
     if ((ed = _XmGetWidgetExtData((Widget)lw, XmCACHE_EXTENSION)) != NULL)
@@ -687,9 +681,9 @@ _XmAssignLabG_MarginLeft(XmLabelGadget lw, Dimension value)
     ExtObj_LogicalParent(nsec) = (Widget)lw;
     ExtObj_ExtensionType(nsec) = XmCACHE_EXTENSION;
 
-    bcopy(LabG_Cache((Widget)lw),
-	  &((XmLabelGCacheObject)nsec)->label_cache,
-	  sizeof(XmLabelGCacheObjPart));
+    memcpy(&((XmLabelGCacheObject)nsec)->label_cache,
+           LabG_Cache((Widget)lw),
+	   sizeof(XmLabelGCacheObjPart));
 
     ed = (XmWidgetExtData)XtMalloc(sizeof(XmWidgetExtDataRec));
     ed->widget = (Widget)nsec;
@@ -706,7 +700,7 @@ _XmAssignLabG_MarginRight(XmLabelGadget lw, Dimension value)
 {
     XmBaseClassExt *bce;
     XmWidgetExtData ed;
-    int size;
+    Cardinal size;
     XtPointer nsec;
 
     if ((ed = _XmGetWidgetExtData((Widget)lw, XmCACHE_EXTENSION)) != NULL)
@@ -730,9 +724,9 @@ _XmAssignLabG_MarginRight(XmLabelGadget lw, Dimension value)
     ExtObj_LogicalParent(nsec) = (Widget)lw;
     ExtObj_ExtensionType(nsec) = XmCACHE_EXTENSION;
 
-    bcopy(LabG_Cache((Widget)lw),
-	  &((XmLabelGCacheObject)nsec)->label_cache,
-	  sizeof(XmLabelGCacheObjPart));
+    memcpy(&((XmLabelGCacheObject)nsec)->label_cache,
+           LabG_Cache((Widget)lw),
+	   sizeof(XmLabelGCacheObjPart));
 
     ed = (XmWidgetExtData)XtMalloc(sizeof(XmWidgetExtDataRec));
     ed->widget = (Widget)nsec;
@@ -749,7 +743,7 @@ _XmAssignLabG_MarginTop(XmLabelGadget lw, Dimension value)
 {
     XmBaseClassExt *bce;
     XmWidgetExtData ed;
-    int size;
+    Cardinal size;
     XtPointer nsec;
 
     if ((ed = _XmGetWidgetExtData((Widget)lw, XmCACHE_EXTENSION)) != NULL)
@@ -773,9 +767,9 @@ _XmAssignLabG_MarginTop(XmLabelGadget lw, Dimension value)
     ExtObj_LogicalParent(nsec) = (Widget)lw;
     ExtObj_ExtensionType(nsec) = XmCACHE_EXTENSION;
 
-    bcopy(LabG_Cache((Widget)lw),
-	  &((XmLabelGCacheObject)nsec)->label_cache,
-	  sizeof(XmLabelGCacheObjPart));
+    memcpy(&((XmLabelGCacheObject)nsec)->label_cache,
+           LabG_Cache((Widget)lw),
+	   sizeof(XmLabelGCacheObjPart));
 
     ed = (XmWidgetExtData)XtMalloc(sizeof(XmWidgetExtDataRec));
     ed->widget = (Widget)nsec;
@@ -792,7 +786,7 @@ _XmAssignLabG_MarginBottom(XmLabelGadget lw, Dimension value)
 {
     XmBaseClassExt *bce;
     XmWidgetExtData ed;
-    int size;
+    Cardinal size;
     XtPointer nsec;
 
     if ((ed = _XmGetWidgetExtData((Widget)lw, XmCACHE_EXTENSION)) != NULL)
@@ -816,9 +810,9 @@ _XmAssignLabG_MarginBottom(XmLabelGadget lw, Dimension value)
     ExtObj_LogicalParent(nsec) = (Widget)lw;
     ExtObj_ExtensionType(nsec) = XmCACHE_EXTENSION;
 
-    bcopy(LabG_Cache((Widget)lw),
-	  &((XmLabelGCacheObject)nsec)->label_cache,
-	  sizeof(XmLabelGCacheObjPart));
+    memcpy(&((XmLabelGCacheObject)nsec)->label_cache,
+           LabG_Cache((Widget)lw),
+	   sizeof(XmLabelGCacheObjPart));
 
     ed = (XmWidgetExtData)XtMalloc(sizeof(XmWidgetExtDataRec));
     ed->widget = (Widget)nsec;
@@ -839,17 +833,77 @@ drag_convert_proc(Widget w, Atom *selection,
 {
     Atom COMPOUND_TEXT;
     Atom MOTIF_DROP;
+    Widget source;
+    char *ct, *text;
+    XmString label;
+    Atom TEXT;
+    int len;
 
+    _XmObjectLock(w);
     COMPOUND_TEXT = XmInternAtom(XtDisplay(w), _XA_COMPOUND_TEXT, False);
     MOTIF_DROP = XmInternAtom(XtDisplay(w), _XA_MOTIF_DROP, False);
+    TEXT = XmInternAtom(XtDisplay(w), _XA_TEXT, False);
 
     if (*selection != MOTIF_DROP)
     {
+	_XmObjectUnlock(w);
 	return False;
     }
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "We're dealing with a motif drop\n"));
-    return False;
+    DEBUGOUT(_LtDebug(__FILE__, w, "We're dealing with a motif drop\n"));
+
+    XtVaGetValues(w,
+    	XmNsourceWidget, &source,
+    	NULL);
+    XtVaGetValues(source,
+    	XmNlabelString, &label,
+    	NULL);
+
+    ct = XmCvtXmStringToCT(label);
+    XmStringFree(label);
+    text = XtNewString(ct);
+    len = strlen(text);
+
+    if (*target == XA_STRING){
+        *length_return = len;
+        *value_return = text;
+        *type_return = XA_STRING;
+    }
+    else if (*target == COMPOUND_TEXT || *target == TEXT){
+
+	    XTextProperty prop;
+	    char *buf;
+	    int ret;
+
+	    buf = XtMalloc(len + 1);
+            strncpy(buf, text, len);
+	    buf[len] = '\0';
+
+	    ret = XmbTextListToTextProperty(XtDisplay(w), &buf, 1,
+	    			XCompoundTextStyle, &prop);
+		
+	    XtFree(buf);
+	    if (ret != 0){
+	    	*length_return = 0;
+	    	*value_return  = NULL;
+	    }
+	    else{
+	    	buf = XtMalloc(prop.nitems + 1);
+		strncpy(buf, prop.value, prop.nitems);
+		buf[prop.nitems] = '\0';
+	    	*length_return = prop.nitems;
+	    	*value_return  = buf;
+	    }
+	   *type_return = COMPOUND_TEXT;
+
+    }
+    else
+	return False;
+
+    *format_return = 8;
+
+    _XmObjectUnlock(w);
+    return True;
 }
 
 static void
@@ -861,28 +915,30 @@ void
 _XmProcessDrag(Widget w, XEvent *event,
 	       String *params, Cardinal *num_params)
 {
-    Atom export_target;
+    Atom export_target[3];
     Arg args[10];
     int n = 0;
     Widget dc;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "Processing a drag-drop request\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "Processing a drag-drop request\n"));
 
     if (LabG_IsPixmap(w))
     {
-	export_target = XmInternAtom(XtDisplay(w),
+	export_target[0] = XmInternAtom(XtDisplay(w),
 				     _XA_PIXMAP,
 				     False);
+        XtSetArg(args[n], XmNexportTargets, export_target); n++;
+        XtSetArg(args[n], XmNnumExportTargets, 1); n++;
     }
     else
     {
-	export_target = XmInternAtom(XtDisplay(w),
-				     _XA_COMPOUND_TEXT,
-				     False);
+	export_target[0] = XmInternAtom(XtDisplay(w), _XA_COMPOUND_TEXT, False);
+	export_target[1] = XmInternAtom(XtDisplay(w), _XA_TEXT, False);
+	export_target[2] = XA_STRING;
+        XtSetArg(args[n], XmNexportTargets, export_target); n++;
+        XtSetArg(args[n], XmNnumExportTargets, 3); n++;
     }
 
-    XtSetArg(args[n], XmNexportTargets, &export_target); n++;
-    XtSetArg(args[n], XmNnumExportTargets, 1); n++;
     XtSetArg(args[n], XmNdragOperations, XmDROP_COPY); n++;
     XtSetArg(args[n], XmNconvertProc, drag_convert_proc); n++;
     XtSetArg(args[n], XmNclientData, w); n++;
@@ -1000,7 +1056,7 @@ CreateInsensitiveGC(Widget w)
     values.graphics_exposures = False;
     values.foreground = XmParentForeground(w);
     values.background = XmParentBackground(w);
-    values.fill_style = FillOpaqueStippled;
+    values.fill_style = FillStippled;
     values.ts_x_origin = values.ts_y_origin = 0;
     values.stipple = XmGetPixmapByDepth(XtScreen(w), "50_foreground", 1, 0, 1);
 
@@ -1012,7 +1068,7 @@ static void
 initialize_prehook(Widget request, Widget new_w,
 		   ArgList args, Cardinal *num_args)
 {
-    DEBUGOUT(XdbDebug(__FILE__, new_w, "LabelG InitializePrehook\n"));
+    DEBUGOUT(_LtDebug(__FILE__, new_w, "LabelG InitializePrehook\n"));
 }
 #endif
 
@@ -1024,7 +1080,7 @@ initialize_posthook(Widget request,
 {
     XmWidgetExtData ext;
 
-    DEBUGOUT(XdbDebug(__FILE__, new_w, "LabelG InitializePosthook\n"));
+    DEBUGOUT(_LtDebug(__FILE__, new_w, "LabelG InitializePosthook\n"));
 
     /* don't let the null fool you */
     LabG_Cache(new_w) = (XmLabelGCacheObjPart *)
@@ -1044,7 +1100,7 @@ initialize(Widget request, Widget new_w,
 {
     XmString xmstring;
 
-    DEBUGOUT(XdbDebug(__FILE__, new_w,
+    DEBUGOUT(_LtDebug(__FILE__, new_w,
 		      "%s:initialize(%d) - %i args\n"
 		      "\trequest X %5i Y %5i W %5i H %5i\n"
 		      "\t  new_w X %5i Y %5i W %5i H %5i\n",
@@ -1054,7 +1110,7 @@ initialize(Widget request, Widget new_w,
 		      XtWidth(request), XtHeight(request),
 		      XtX(new_w), XtY(new_w),
 		      XtWidth(new_w), XtHeight(new_w)));
-    DEBUGOUT(XdbPrintArgList(__FILE__, new_w, args, *num_args, False));
+    DEBUGOUT(_LtDebugPrintArgList(__FILE__, new_w, args, *num_args, False));
 
     LabG_SkipCallback(new_w) = False;
 
@@ -1237,7 +1293,7 @@ resize(Widget w)
 	    {
 		_XmAssignLabG_MarginRight((XmLabelGadget)w,
 		    LABEL_ACC_PAD + LabG_AccTextRect(w).width);
-		DEBUGOUT(XdbDebug(__FILE__, w,
+		DEBUGOUT(_LtDebug(__FILE__, w,
 				  "resize: set right margin to %d\n",
 				  LabG_MarginRight(w)));
 		_XmReCacheLabG(w);
@@ -1250,7 +1306,7 @@ resize(Widget w)
 	    {
 		_XmAssignLabG_MarginLeft((XmLabelGadget)w,
 		    LABEL_ACC_PAD + LabG_AccTextRect(w).width);
-		DEBUGOUT(XdbDebug(__FILE__, w,
+		DEBUGOUT(_LtDebug(__FILE__, w,
 				  "resize: set left margin to %d\n",
 				  LabG_MarginLeft(w)));
 		_XmReCacheLabG(w);
@@ -1334,7 +1390,7 @@ set_values_prehook(Widget old, Widget request, Widget new_w,
 {
     XmBaseClassExt *bce;
     XmWidgetExtData ed;
-    int size;
+    Cardinal size;
     XtPointer nsec, rsec;
 
     bce = _XmGetBaseClassExtPtr(XtClass(new_w), XmQmotif);
@@ -1354,9 +1410,9 @@ set_values_prehook(Widget old, Widget request, Widget new_w,
     ExtObj_LogicalParent(nsec) = new_w;
     ExtObj_ExtensionType(nsec) = XmCACHE_EXTENSION;
 
-    bcopy(LabG_Cache(new_w),
-	  &((XmLabelGCacheObject)nsec)->label_cache,
-	  sizeof(XmLabelGCacheObjPart));
+    memcpy(&((XmLabelGCacheObject)nsec)->label_cache,
+           LabG_Cache(new_w),
+	   sizeof(XmLabelGCacheObjPart));
 
     ed = (XmWidgetExtData)XtMalloc(sizeof(XmWidgetExtDataRec));
     ed->widget = (Widget)nsec;
@@ -1371,7 +1427,7 @@ set_values_prehook(Widget old, Widget request, Widget new_w,
 		   (*bce)->secondaryObjectClass->core_class.num_resources,
 		   args, *num_args);
 
-    bcopy(nsec, rsec, size);
+    memcpy(rsec, nsec, size);
     ((XmExtRec *)rsec)->object.self = (Widget)rsec;
 
     LabG_Cache(new_w) = &(((XmLabelGCacheObject)nsec)->label_cache);
@@ -1425,7 +1481,7 @@ set_values(Widget old, Widget request, Widget new_w,
     Boolean refresh_needed = False, relayout_needed = False,
 	recalc_needed = False;
 
-    DEBUGOUT(XdbDebug(__FILE__, new_w, "LabelGadget SetValues %d %d\n",
+    DEBUGOUT(_LtDebug(__FILE__, new_w, "LabelGadget SetValues %d %d\n",
 		      LabG_MarginRight(new_w), LabG_MarginRight(old)));
 
     /* Silently discard accelerator for non-menu labels and cascades */
@@ -1686,7 +1742,7 @@ get_values_prehook(Widget new_w, ArgList args, Cardinal *num_args)
 {
     XmBaseClassExt *bce;
     XmWidgetExtData ed;
-    int size;
+    Cardinal size;
     XtPointer nsec;
 
     bce = _XmGetBaseClassExtPtr(XtClass(new_w), XmQmotif);
@@ -1694,9 +1750,9 @@ get_values_prehook(Widget new_w, ArgList args, Cardinal *num_args)
 
     nsec = _XmExtObjAlloc(size);
 
-    bcopy(LabG_Cache(new_w),
-	  &((XmLabelGCacheObject)nsec)->label_cache,
-	  sizeof(XmLabelGCacheObjPart));
+    memcpy(&((XmLabelGCacheObject)nsec)->label_cache,
+           LabG_Cache(new_w),
+	   sizeof(XmLabelGCacheObjPart));
 
     /*
      * don't do this and ResInd will blow up.
@@ -1741,7 +1797,7 @@ get_values_posthook(Widget new_w, ArgList args, Cardinal *num_args)
 static void
 get_values_hook(Widget w, ArgList args, Cardinal *num_args)
 {
-    DEBUGOUT(XdbDebug(__FILE__, w, "LabelG: GetValuesHook\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "LabelG: GetValuesHook\n"));
 }
 #endif
 
@@ -1822,11 +1878,11 @@ expose(Widget w,
 	- ((G_ShadowThickness(w) + G_HighlightThickness(w)) << 1)
 	- LabG_MarginTop(w) - LabG_MarginBottom(w);
 
-    DEBUGOUT(XdbDebug(__FILE__, w,
+    DEBUGOUT(_LtDebug(__FILE__, w,
              "Expose: cliprect %d %d %dx%d\n",
             cliprect.x, cliprect.y,
              cliprect.width, cliprect.height));
-    DEBUGOUT(XdbDebug(__FILE__, w,
+    DEBUGOUT(_LtDebug(__FILE__, w,
              "Expose: acctextrect %d %d %dx%d\n",
             LabG_AccTextRect(w).x, LabG_AccTextRect(w).y,
              LabG_AccTextRect(w).width, LabG_AccTextRect(w).height));
@@ -1873,6 +1929,12 @@ expose(Widget w,
 	mypm = XtSensitive(w)
 	    ? LabG_Pixmap(w)
 	    : LabG_PixmapInsensitive(w);
+#if XmVERSION > 1
+	if (mypm == XmUNSPECIFIED_PIXMAP)
+	{
+	    mypm = LabG_Pixmap(w);
+	}
+#endif
 	cliprect.x -= XtX(w);
 	cliprect.y -= XtY(w);
 	if (mypm > XmUNSPECIFIED_PIXMAP &&
@@ -1903,6 +1965,63 @@ expose(Widget w,
 		cliprect.height = (LabG_TextRect_y(w)
 				   + LabG_TextRect_height(w)) - cliprect.y;
 	    }
+#if XmVERSION > 1
+	    {
+		unsigned int tmp, tmpw, tmph;
+		int tmpx, tmpy;
+		unsigned Depth;
+		Window tmpwin;
+
+		/* rws 4 Mar 2000
+		   According to the comments in label/test12, this does not
+		   happen. We should be adding the pixmap to our pixmap
+		   cache, and getting the info from there instead of a
+		   round trip server query.
+		 */
+		/* rws 10 Mar 2000
+		   Apparently a Motif 2 thing.
+		 */
+		XGetGeometry(XtDisplayOfObject(w),
+			     mypm,
+			     &tmpwin,
+			     &tmpx, &tmpy,
+			     &tmpw, &tmph,
+			     &tmp, &Depth);
+
+		if (Depth == 1)
+		{
+		    XCopyPlane(XtDisplay(w),
+			  mypm,
+			  XtWindow(w),
+			  myGC,
+			  cliprect.x - LabG_TextRect_x(w),
+			  cliprect.y - LabG_TextRect_y(w),
+			  cliprect.width, cliprect.height,
+			  cliprect.x + XtX(w), cliprect.y + XtY(w),
+			  1);
+		}
+		else if (Depth > 1)
+		{
+		    XCopyArea(XtDisplay(w),
+			  mypm,
+			  XtWindow(w),
+			  myGC,
+			  cliprect.x - LabG_TextRect_x(w),
+			  cliprect.y - LabG_TextRect_y(w),
+			  cliprect.width, cliprect.height,
+			  cliprect.x + XtX(w), cliprect.y + XtY(w));
+		}
+	    }
+	    if (!XtSensitive(w) && LabG_PixmapInsensitive(w) == XmUNSPECIFIED_PIXMAP)
+	    {
+	    	/* label/test14 */
+	    	XFillRectangle(XtDisplay(w), XtWindow(w),
+	    		myGC,
+		  cliprect.x,
+		  cliprect.y,
+		  cliprect.width, cliprect.height);
+	    }
+#else
 	    XCopyArea(XtDisplay(w),
 		      mypm,
 		      XtWindow(w),
@@ -1911,6 +2030,7 @@ expose(Widget w,
 		      cliprect.y - LabG_TextRect_y(w),
 		      cliprect.width, cliprect.height,
 		      cliprect.x + XtX(w), cliprect.y + XtY(w));
+#endif
 	}
     }
 }
@@ -1983,7 +2103,7 @@ query_geometry(Widget w, XtWidgetGeometry *proposed, XtWidgetGeometry *answer)
     a.width = XtWidth(w);
     a.height = XtHeight(w);
     a.request_mode = CWWidth | CWHeight;
-    DEBUGOUT(XdbDebug(__FILE__, w,
+    DEBUGOUT(_LtDebug(__FILE__, w,
 		      "LabelGadget queried for size: reporting %d %d %08x\n",
 		      XtWidth(w), XtHeight(w), answer));
 
@@ -2079,6 +2199,15 @@ widget_display_rect(Widget w, XRectangle *rect)
     return True;
 }
 
+
+#if XmVERSION >= 2
+static void
+widget_margins (Widget w, XmBaselineMargins *margins)
+{
+ /* FIX ME */
+}
+#endif
+
 /* FIX ME: there has to be more to this, doesn't there? */
 static void
 set_override_callback(Widget w)
@@ -2104,11 +2233,11 @@ input_dispatch(Widget gadget,
     switch (event_mask)
     {
     case XmHELP_EVENT:
-	DEBUGOUT(XdbDebug(__FILE__, gadget, "LabelGadget got help event\n"));
+	DEBUGOUT(_LtDebug(__FILE__, gadget, "LabelGadget got help event\n"));
 	break;
 
     case XmBDRAG_EVENT:
-	DEBUGOUT(XdbDebug(__FILE__, gadget, "LabelGadget got bdrag event\n"));
+	DEBUGOUT(_LtDebug(__FILE__, gadget, "LabelGadget got bdrag event\n"));
 	_XmProcessDrag(gadget, event, NULL, NULL);
 	break;
     }
