@@ -1,8 +1,9 @@
 /**
  *
- * $Id: MapEvent.c,v 1.13 1999/02/02 18:23:17 gritton Exp $
+ * $Id: MapEvent.c,v 1.20 2001/09/13 12:28:20 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: MapEvent.c,v 1.13 1999/02/02 18:23:17 gritton Exp $";
+static const char rcsid[] = "$Id: MapEvent.c,v 1.20 2001/09/13 12:28:20 amai Exp $";
 
 /*
  * this code borrows heavily from TMparse.c.  The copyright there is as follows:
@@ -49,23 +50,20 @@ static const char rcsid[] = "$Id: MapEvent.c,v 1.13 1999/02/02 18:23:17 gritton
  * SOFTWARE.
  */
 #include <LTconfig.h>
+
+#include <ctype.h>
+#include <stdlib.h>
+#include <string.h>
+
 #include <XmI/XmI.h>
-
 #include <Xm/XmP.h>
 
-#include <XmI/DebugUtil.h>
-
 #define XK_MISCELLANY
 #define XK_LATIN1
 #include <X11/keysymdef.h>
-#include <X11/Xfuncs.h>
 
-#include <ctype.h>
-#include <stdlib.h>
+#include <XmI/DebugUtil.h>
 
-#ifdef HAVE_STRINGS_H
-#include <strings.h>
-#endif
 
 #define COLON	':'
 
@@ -709,7 +707,7 @@ FetchModifierToken(String str, XrmQuark *token_return)
     if (start != str)
     {
 	char modStr[100];
-	bcopy(start, modStr, str-start);
+	memcpy(modStr, start, str-start);
 	modStr[str-start] = '\0';
 	*token_return = XrmStringToQuark(modStr);
 
@@ -845,7 +843,7 @@ ParseXtEventType(String str, EventPtr event, Cardinal *tmEventP, Boolean *error)
     char eventTypeStr[100];
 
     ScanAlphanumeric(str);
-    bcopy(start, eventTypeStr, str-start);
+    memcpy(eventTypeStr, start, str-start);
     eventTypeStr[str-start] = '\0';
     *tmEventP = LookupTMEventType(eventTypeStr,error);
     if (*error) 
@@ -1074,7 +1072,7 @@ ParseKeySym(String str, XP closure, EventPtr event, Boolean *error)
 	    str++;
 	}
 
-	bcopy(start, keySymName, str-start);
+	memcpy(keySymName, start, str-start);
 
 	keySymName[str-start] = '\0';
 
@@ -1117,7 +1115,7 @@ ParseTable(String str, XP closure, EventPtr event, Boolean *error)
 	return str;
     }
 
-    bcopy(start, tableSymName, str-start);
+    memcpy(tableSymName, start, str-start);
     tableSymName[str-start] = '\0';
 
     if (!_XtLookupTableSym((NameValueTable)closure, tableSymName, 
@@ -1174,7 +1172,7 @@ ParseAtom(String str, XP closure, EventPtr event, Boolean *error)
 	    return str;
 	}
 
-	bcopy(start, atomName, str-start);
+	memcpy(atomName, start, str-start);
 	atomName[str-start] = '\0';
 	event->event.eventCode = XrmStringToQuark(atomName);
     }
@@ -1610,13 +1608,13 @@ ParseRepeat(String str, int *reps, Boolean *plus, Boolean *error)
     {
 	String start = str;
 	char repStr[7];
-	int len;
+	size_t len;
 
 	ScanNumeric(str);
 	len = (str - start);
-	if (len < sizeof repStr)
+	if (len < sizeof(repStr))
 	{
-	    bcopy(start, repStr, len);
+	    memcpy(repStr, start, len);
 	    repStr[len] = '\0';
 	    *reps = StrToNum(repStr);
 	}
@@ -1670,8 +1668,8 @@ ParseEventSeq(String str, EventSeqPtr *eventSeqP, Boolean *error)
 
     while ( *str != '\0' && *str != '\n')
     {
-	static Event	nullEvent = {0, 0,0L, 0, 0L, 0L,FALSE};
-	EventPtr	event;
+	static Event nullEvent = {0, 0, (LateBindingsPtr)NULL, 0, 0L, 0L, FALSE};
+	EventPtr     event;
 
 	ScanWhitespace(str);
 
@@ -1771,7 +1769,7 @@ ParseEventSeq(String str, EventSeqPtr *eventSeqP, Boolean *error)
 static void
 PrintLateBindings(LateBindingsPtr late)
 {
-    DEBUGOUT(XdbDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 		      "LateBindings: knot: %d pair: %d, ref: %d KeySym %04x\n",
 		      late->knot, late->pair, late->ref_count, late->keysym));
 }
@@ -1779,15 +1777,15 @@ PrintLateBindings(LateBindingsPtr late)
 static void
 PrintEvent(Event *event)
 {
-    DEBUGOUT(XdbDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 		      "Event: modifiers: %08x modMask: %08x late: %p\n",
 		      event->modifiers, event->modifierMask,
 		      event->lateModifiers));
-    DEBUGOUT(XdbDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 		      "       eventType: %08x eventCode: %08x codeMask: %08x\n",
 		      event->eventType, event->eventCode,
 		      event->eventCodeMask));
-    DEBUGOUT(XdbDebug(__FILE__, NULL, "       standard: %d\n",
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "       standard: %d\n",
 		      event->standard));
 
     if (event->lateModifiers)
@@ -1801,7 +1799,7 @@ PrintEventSeq(EventSeqPtr evs)
 {
     EventSeqPtr tmp;
 
-    DEBUGOUT(XdbDebug(__FILE__, NULL, "EventSequence:\n"));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "EventSequence:\n"));
     for (tmp = evs; tmp != NULL; tmp = tmp->next)
     {
 	PrintEvent(&evs->event);
@@ -1912,7 +1910,7 @@ _XmMapBtnEvent(String str, int *eventType,
 
     _XmTransParseInit();
 
-    DEBUGOUT(XdbDebug(__FILE__, NULL, "MAP KEY: %s\n", str));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "MAP KEY: %s\n", str));
 
     ParseEventSeq(str, &evs, &err);
 
@@ -1965,13 +1963,13 @@ _XmMapKeyEvent(String str, int *eventType,
 
     _XmTransParseInit();
 
-    DEBUGOUT(XdbDebug(__FILE__, NULL, "MAP KEY: %s\n", str));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "MAP KEY: %s\n", str));
 
     ParseEventSeq(str, &evs, &err);
 
     if (evs == NULL)
     {
-    	DEBUGOUT(XdbDebug(__FILE__, NULL, "MapKey got NULL sequence:\n"));
+    	DEBUGOUT(_LtDebug(__FILE__, NULL, "MapKey got NULL sequence:\n"));
 	FreeEventSeq(evs);
 
 	return False;
@@ -1985,7 +1983,7 @@ _XmMapKeyEvent(String str, int *eventType,
     err = SetLateModifier(_XmGetDefaultDisplay(), evs);
     if (err)
     {
-    	DEBUGOUT(XdbDebug(__FILE__, NULL, "MapKey got err sequence:\n"));
+    	DEBUGOUT(_LtDebug(__FILE__, NULL, "MapKey got err sequence:\n"));
 	FreeEventSeq(evs);
 
 	return False;
