@@ -1,9 +1,9 @@
 /**
  * 
- * $Id: MenuShell.c,v 1.82 2000/09/23 15:05:24 amai Exp $
+ * $Id: MenuShell.c,v 1.87 2001/07/27 18:51:56 dannybackx Exp $
  *
  * Copyright (C) 1996 Free Software Foundation, Inc.
- * Copyright (C) 1996-2000 LessTif Development Team
+ * Copyright (C) 1996-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: MenuShell.c,v 1.82 2000/09/23 15:05:24 amai Exp $";
+static const char rcsid[] = "$Id: MenuShell.c,v 1.87 2001/07/27 18:51:56 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -44,14 +44,10 @@ static const char rcsid[] = "$Id: MenuShell.c,v 1.82 2000/09/23 15:05:24 amai Ex
 
 /* Forward Declarations */
 static void class_initialize(void);
-
 static void class_part_initialize(WidgetClass w_class);
-
 static void initialize(Widget request, Widget new_w,
 		       ArgList args, Cardinal *num_args);
-
 static void destroy(Widget w);
-
 static void realize(Widget w, XtValueMask *value_mask,
 		    XSetWindowAttributes *attributes);
 
@@ -60,15 +56,12 @@ static void expose(Widget w, XEvent *event, Region region);
 #endif
 
 static void resize(Widget w);
-
 static Boolean set_values(Widget current, Widget request, Widget new_w,
 			  ArgList args, Cardinal *num_args);
-
 static XtGeometryResult geometry_manager(Widget w,
 					 XtWidgetGeometry *request,
 					 XtWidgetGeometry *reply);
 static void change_managed(Widget w);
-
 static void insert_child(Widget w);
 
 #define Offset(field) XtOffsetOf(XmMenuShellRec, menu_shell.field)
@@ -95,19 +88,14 @@ static XtResource resources[] =
 
 static void MenuShellPopdownDone(Widget w, XEvent *event,
 				 String *params, Cardinal *num_params);
-
 static void MenuShellPopdownOne(Widget w, XEvent *event,
 				String *params, Cardinal *num_params);
-
 static void MenuShellPopdownEveryone(Widget w, XEvent *event,
 				     String *params, Cardinal *num_params);
-
 static void _XmXtMenuPopup(Widget widget, XEvent *event,
 			   String *params, Cardinal *num_params);
-
 static void _XmXtMenuPopdown(Widget widget, XEvent *event,
 			     String *params, Cardinal *num_params);
-
 static void MenuShellPopupSharedMenuPane(Widget w, Widget w2, XEvent *event);
 
 static XtActionsRec actions[] =
@@ -119,7 +107,7 @@ static XtActionsRec actions[] =
     {"ClearTraversal", _XmClearTraversal},
 };
 
-/* *INDENT-OFF* */
+
 static XmBaseClassExtRec _XmMenuSCoreClassExtRec = {
     /* next_extension            */ NULL,
     /* record_type               */ NULLQUARK,                             
@@ -146,6 +134,7 @@ static XmBaseClassExtRec _XmMenuSCoreClassExtRec = {
     /* wrapper_data              */ NULL
 };
 
+
 XmMenuShellClassRec xmMenuShellClassRec = {
     /* Core class part */
     {
@@ -207,10 +196,11 @@ XmMenuShellClassRec xmMenuShellClassRec = {
 	/* extension           */ NULL,
     },
 };
-/* *INDENT-ON* */
+
 
 WidgetClass xmMenuShellWidgetClass = (WidgetClass)&xmMenuShellClassRec;
 
+
 static void
 class_initialize(void)
 {
@@ -219,17 +209,19 @@ class_initialize(void)
     _XmMenuSCoreClassExtRec.record_type = XmQmotif;
 }
 
+
 static void
 class_part_initialize(WidgetClass widget_class)
 {
     _XmFastSubclassInit(widget_class, XmMENU_SHELL_BIT);
 }
 
+
 static void
 initialize(Widget request, Widget new_w,
 	   ArgList args, Cardinal *num_args)
 {
-    DEBUGOUT(XdbDebug(__FILE__, new_w,
+    DEBUGOUT(_LtDebug(__FILE__, new_w,
 		      "%s:initialize(%d) - %i args\n"
 		      "\trequest X %5i Y %5i W %5i H %5i\n"
 		      "\t  new_w X %5i Y %5i W %5i H %5i\n",
@@ -239,7 +231,7 @@ initialize(Widget request, Widget new_w,
 		      XtWidth(request), XtHeight(request),
 		      XtX(new_w), XtY(new_w),
 		      XtWidth(new_w), XtHeight(new_w)));
-    DEBUGOUT(XdbPrintArgList(__FILE__, new_w, args, *num_args, False));
+    DEBUGOUT(_LtDebugPrintArgList(__FILE__, new_w, args, *num_args, False));
 
     if (MS_DefaultFontList(new_w) != NULL)
     {
@@ -295,7 +287,7 @@ initialize(Widget request, Widget new_w,
 
     if (XtWidth(new_w) == 0 || XtHeight(new_w) == 0)
     {
-	DEBUGOUT(XdbDebug(__FILE__, new_w,
+	DEBUGOUT(_LtDebug(__FILE__, new_w,
 			  "Initialize: dimensions %d %d changed to 1x1",
 			  XtWidth(new_w), XtHeight(new_w)));
 
@@ -313,7 +305,7 @@ initialize(Widget request, Widget new_w,
 static void
 destroy(Widget w)
 {
-    DEBUGOUT(XdbDebug(__FILE__, w, "Destroy\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "Destroy\n"));
     _XmDestroyFocusData(MS_FocusData(w));
 
     XmFontListFree(MS_DefaultFontList(w));
@@ -324,7 +316,7 @@ destroy(Widget w)
 static void
 resize(Widget w)
 {
-    DEBUGOUT(XdbDebug(__FILE__, w, "Resize -- (%d, %d)\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "Resize -- (%d, %d)\n",
 		      XtWidth(w), XtHeight(w)));
 }
 
@@ -358,7 +350,7 @@ realize(Widget w,
     (*superclass->core_class.realize) (w, value_mask, attributes);
 #undef superclass
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "Realize (size %dx%d)\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "Realize (size %dx%d)\n",
 		      XtWidth(w), XtHeight(w)));
 }
 
@@ -366,7 +358,7 @@ realize(Widget w,
 static void
 expose(Widget w, XEvent *event, Region region)
 {
-    DEBUGOUT(XdbDebug(__FILE__, w, "Expose\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "Expose\n"));
 }
 #endif
 
@@ -374,7 +366,7 @@ static Boolean
 set_values(Widget current, Widget request, Widget new_w,
 	   ArgList args, Cardinal *num_args)
 {
-    DEBUGOUT(XdbDebug(__FILE__, new_w, "SetValues\n"));
+    DEBUGOUT(_LtDebug(__FILE__, new_w, "SetValues\n"));
 
     if (MS_DefaultFontList(new_w) != MS_DefaultFontList(current))
     {
@@ -406,9 +398,9 @@ geometry_manager(Widget w,
     XtWidgetGeometry wants;
     Widget ms = XtParent(w);
 
-    DEBUGOUT(XdbDebug2(__FILE__, ms, w,
+    DEBUGOUT(_LtDebug2(__FILE__, ms, w,
 		       "geometry_manager: request %s, allow_shell_resize %s\n",
-		       XdbWidgetGeometry2String(request),
+		       _LtDebugWidgetGeometry2String(request),
 		       ((XmMenuShellWidget)ms)->shell.allow_shell_resize
 		       ? "True"
 		       : "False"));
@@ -418,9 +410,9 @@ geometry_manager(Widget w,
 	return XtGeometryYes;
     }
 
-    DEBUGOUT(XdbDebug(__FILE__, ms,
+    DEBUGOUT(_LtDebug(__FILE__, ms,
 		      "geometry_manager: %s\n",
-		      XdbWidgetGeometry2String(request)));
+		      _LtDebugWidgetGeometry2String(request)));
 
     wants = *request;
 
@@ -428,7 +420,7 @@ geometry_manager(Widget w,
 
     if (res == XtGeometryNo)
     {
-	DEBUGOUT(XdbDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "XtGeometryNo returned... THIS SHOULD NOT HAPPEN\n"));
     }
     *reply = wants;
@@ -442,7 +434,7 @@ geometry_manager(Widget w,
 	XtHeight(w) = wants.height;
     }
 
-    DEBUGOUT(XdbDebug(__FILE__, w,
+    DEBUGOUT(_LtDebug(__FILE__, w,
 		      "geometry_manager: size %dx%d => Yes\n",
 		      reply->width, reply->height));
 
@@ -454,16 +446,16 @@ change_managed(Widget w)
 {
     XtWidgetGeometry geo;
     Widget child;
-    int i;
+    Cardinal i;
 
-    DEBUGOUT(XdbDebug(__FILE__, w,
+    DEBUGOUT(_LtDebug(__FILE__, w,
 		      "ChangeManaged: trying to find child to manage\n"));
 
     /* FIX ME: isn't having no managed children perfectly valid ? */
     child = NULL;
     for (i = 0; i < MGR_NumChildren(w); i++)
     {
-	DEBUGOUT(XdbDebug2(__FILE__, w,
+	DEBUGOUT(_LtDebug2(__FILE__, w,
 			   MGR_Children(w)[i], "ChangeManaged [%d] %s\n",
 			   i,
 			   XtIsManaged(MGR_Children(w)[i])
@@ -524,7 +516,7 @@ change_managed(Widget w)
 
     if (!child)
     {
-	DEBUGOUT(XdbDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "change_managed: no managed children so we must"
 			  " be popping down\n"));
 
@@ -532,13 +524,13 @@ change_managed(Widget w)
 	{
 	    if (MS_PrivateShell(w))
 	    {
-		DEBUGOUT(XdbDebug(__FILE__, w, "  PrivateShell\n"));
+		DEBUGOUT(_LtDebug(__FILE__, w, "  PrivateShell\n"));
 
 		_XmXtMenuPopdown(w, NULL, NULL, NULL);
 	    }
 	    else
 	    {
-		DEBUGOUT(XdbDebug(__FILE__, w, "  public shell\n"));
+		DEBUGOUT(_LtDebug(__FILE__, w, "  public shell\n"));
 		_XmRemoveGrab(w);
 
 		XtUnmapWidget(w);
@@ -566,7 +558,7 @@ change_managed(Widget w)
     /* FIX ME: should look at the flags */
     _XmResizeObject(w, geo.width, geo.height, 0);
 
-    DEBUGOUT(XdbDebug2(__FILE__, w, child,
+    DEBUGOUT(_LtDebug2(__FILE__, w, child,
 		       "ChangeManaged width %d height %d\n",
 		       XtWidth(w), XtHeight(w)));
 
@@ -580,7 +572,7 @@ change_managed(Widget w)
     {
 	XmMenuState state = _XmGetMenuState(child);
 
-	DEBUGOUT(XdbDebug2(__FILE__, w, child, "Popping up\n"));
+	DEBUGOUT(_LtDebug2(__FILE__, w, child, "Popping up\n"));
 
 	_XmPostPopupMenu(child,
 			 (XEvent *)&state->RC_ButtonEventStatus.event);
@@ -594,23 +586,23 @@ change_managed(Widget w)
 	 */
 	if (RC_Type(child) == XmMENU_PULLDOWN)
 	{
-	    DEBUGOUT(XdbDebug(__FILE__, child, "Pulldown posting\n"));
+	    DEBUGOUT(_LtDebug(__FILE__, child, "Pulldown posting\n"));
 
 	    if (RC_CascadeBtn(child))
 	    {
-	        DEBUGOUT(XdbDebug(__FILE__, child, "Child is cascade\n"));
+	        DEBUGOUT(_LtDebug(__FILE__, child, "Child is cascade\n"));
 		if (XtIsManaged(child))
 		{
-	            DEBUGOUT(XdbDebug(__FILE__, w, "Popping up\n"));
+	            DEBUGOUT(_LtDebug(__FILE__, w, "Popping up\n"));
 
 		    if (MS_PrivateShell(w))
 		    {
-			DEBUGOUT(XdbDebug(__FILE__, w, "Popping up private shell\n"));
+			DEBUGOUT(_LtDebug(__FILE__, w, "Popping up private shell\n"));
 			MSClass_PopupSharedMenuPane(w)(w, child, NULL);
 		    }
 		    else
 		    {
-			DEBUGOUT(XdbDebug(__FILE__, w, "Popping up public shell\n"));
+			DEBUGOUT(_LtDebug(__FILE__, w, "Popping up public shell\n"));
 		    	XtManageChild(child);
 			XMapRaised(XtDisplay(w), XtWindow(w));
 			XtCallCallbacks(w, XmNpopupCallback, NULL);
@@ -624,16 +616,16 @@ change_managed(Widget w)
 		}
 		else
 		{
-	            DEBUGOUT(XdbDebug(__FILE__, w, "Popping down\n"));
+	            DEBUGOUT(_LtDebug(__FILE__, w, "Popping down\n"));
 
 		    if (MS_PrivateShell(w))
 		    {
-			DEBUGOUT(XdbDebug(__FILE__, w, "  PrivateShell\n"));
+			DEBUGOUT(_LtDebug(__FILE__, w, "  PrivateShell\n"));
 			_XmXtMenuPopdown(w, NULL, NULL, NULL);
 		    }
 		    else
 		    {
-			DEBUGOUT(XdbDebug(__FILE__, w, "  public shell\n"));
+			DEBUGOUT(_LtDebug(__FILE__, w, "  public shell\n"));
 			if (RC_Type(child) == XmMENU_POPUP || RC_Type(child) == XmMENU_OPTION)
 			{
 			    _XmRemoveGrab(w);
@@ -647,13 +639,13 @@ change_managed(Widget w)
 	    }
 	    else
 	    {
-		DEBUGOUT(XdbDebug(__FILE__, w, "Not cascade\n"));
+		DEBUGOUT(_LtDebug(__FILE__, w, "Not cascade\n"));
 		/* Not attached to a cascade button. */
 		if (XtIsManaged(child))
 		{
 		    /* Probably the user managed the pulldown after creation. */
 		    /* FIX ME: Motif 2.0 does issue a warning here. */
-		    DEBUGOUT(XdbDebug(__FILE__, child,
+		    DEBUGOUT(_LtDebug(__FILE__, child,
 				      "Unmanaging in change_managed...\n"));
 		    XtUnmanageChild(child);
 		}
@@ -695,6 +687,7 @@ insert_child(Widget w)
     }
 }
 
+
 static void
 MenuShellPopdownDone(Widget w, XEvent *event,
 		     String *params, Cardinal *num_params)
@@ -702,17 +695,16 @@ MenuShellPopdownDone(Widget w, XEvent *event,
     Cardinal numparams = 0;
     Widget rc, toplevelrc;
     Widget menu_shell = NULL;
-    int i;
-    extern Boolean _XmMenuGetInPMMode(Widget);
+    Cardinal i;
     XmMenuState state = _XmGetMenuState(w);
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "MenuShellPopdownDone()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "MenuShellPopdownDone()\n"));
 
     /* make sure the trigger event here hasn't already been processed */
     if (_XmMenuGetInPMMode(w) && event && event->type == ButtonRelease &&
 	event->xbutton.time <= state->RC_ButtonEventStatus.time)
     {
-      DEBUGOUT(XdbDebug(__FILE__, w, "MenuShellPopdownDone(): exiting b/c already processed\n"));
+      DEBUGOUT(_LtDebug(__FILE__, w, "MenuShellPopdownDone(): exiting b/c already processed\n"));
 	return;
     }
 
@@ -731,7 +723,7 @@ MenuShellPopdownDone(Widget w, XEvent *event,
 	event->xbutton.time <= state->RC_ButtonEventStatus.time
 				+ XtGetMultiClickTime(XtDisplay(w)))
     {
-      DEBUGOUT(XdbDebug(__FILE__, w, "MenuShellPopdownDone(): exiting b/c user too fast\n"));
+      DEBUGOUT(_LtDebug(__FILE__, w, "MenuShellPopdownDone(): exiting b/c user too fast\n"));
 	return;
     }
 #endif
@@ -740,7 +732,7 @@ MenuShellPopdownDone(Widget w, XEvent *event,
     assert(XmIsMenuShell(w));
 
     if (MGR_NumChildren(w) == 0) {
-      DEBUGOUT(XdbDebug(__FILE__, w, "MenuShellPopdownDone(): exiting b/c no children\n"));
+      DEBUGOUT(_LtDebug(__FILE__, w, "MenuShellPopdownDone(): exiting b/c no children\n"));
 	return;
     }
     /* Find a child that is managed */
@@ -756,11 +748,11 @@ MenuShellPopdownDone(Widget w, XEvent *event,
 
     if (!rc)
     {
-	DEBUGOUT(XdbDebug(__FILE__, w, "MenuShellPopdownDone - NO RC\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "MenuShellPopdownDone - NO RC\n"));
 	return;
     }
 
-    DEBUGOUT(XdbDebug2(__FILE__, w, rc,
+    DEBUGOUT(_LtDebug2(__FILE__, w, rc,
 		       "MenuShellPopdownDone - found RC %s, posted: %s\n",
 			XtName(rc), RC_PopupPosted(rc) ? XtName(RC_PopupPosted(rc)) : "NULL"));
 
@@ -768,7 +760,7 @@ MenuShellPopdownDone(Widget w, XEvent *event,
 
     if (!toplevelrc)
     {
-	DEBUGOUT(XdbDebug2(__FILE__, w, rc, "No toplevelrc\n"));
+	DEBUGOUT(_LtDebug2(__FILE__, w, rc, "No toplevelrc\n"));
 
 #if 0
 	/*
@@ -790,7 +782,7 @@ MenuShellPopdownDone(Widget w, XEvent *event,
 	}
 	else
 	{
-	    DEBUGOUT(XdbDebug2(__FILE__, w, rc,
+	    DEBUGOUT(_LtDebug2(__FILE__, w, rc,
 			       "No posted menu\n"));
 	    return;
 	}
@@ -806,14 +798,14 @@ MenuShellPopdownDone(Widget w, XEvent *event,
 
 	if (Shell_PoppedUp(menu_shell))
 	{
-	    DEBUGOUT(XdbDebug(__FILE__, w,
+	    DEBUGOUT(_LtDebug(__FILE__, w,
 		      "calling PopdownEveryone on toplevel menushell\n"));
 
 	    MSClass_PopdownEveryone(menu_shell)(menu_shell, event, params, &numparams);
 	}
 	else
 	{
-	    DEBUGOUT(XdbDebug(__FILE__, w,
+	    DEBUGOUT(_LtDebug(__FILE__, w,
 		      "MenuShellPopdownDone - MenuShell is not popped up, must have been an accelerator\n"));
 	    return;
 	}
@@ -834,11 +826,27 @@ MenuShellPopdownDone(Widget w, XEvent *event,
 	}
 	else
 	{
-	    DEBUGOUT(XdbDebug(__FILE__, rc, "Unmanaging...\n"));
+	    DEBUGOUT(_LtDebug(__FILE__, rc, "Unmanaging...\n"));
+	    {
+	    Widget realpar;
+
+		if (XtIsShell(XtParent(rc)))
+		{
+		    realpar = XtParent(XtParent(rc));
+		}
+		else
+		{
+		    realpar = XtParent(rc);
+		}
+		DEBUGOUT(_LtDebug("EMACS", realpar, "%s:%s(%d) - UNGRAB %i %i\n", __FILE__, "MenuShellPopdownDone" , __LINE__,
+			      RC_PostButton(rc), RC_PostModifiers(rc)));
+		XtUngrabButton(realpar,
+			       RC_PostButton(rc), RC_PostModifiers(rc));
+	    }
 	    XtUnmanageChild(rc);
 	    if (_XmIsActiveTearOff(rc))
 	    {
-		DEBUGOUT(XdbDebug(__FILE__, rc, "Unmanaging... ActiveTearOff\n"));
+		DEBUGOUT(_LtDebug(__FILE__, rc, "Unmanaging... ActiveTearOff\n"));
 		XtManageChild(rc);
 	    }
 	}
@@ -851,7 +859,7 @@ MenuShellPopdownDone(Widget w, XEvent *event,
     {
 	Widget tmp = RC_LastSelectToplevel(rc);
 
-	DEBUGOUT(XdbDebug(__FILE__, tmp,
+	DEBUGOUT(_LtDebug(__FILE__, tmp,
 			  "  calling menuDisarm on lastSelectTopLevel\n"));
 	RCClass_MenuProcs(XtClass(tmp))(XmMENU_DISARM, tmp, NULL);
     }
@@ -861,7 +869,7 @@ MenuShellPopdownDone(Widget w, XEvent *event,
     {
 	Widget tmp = XtParent(menu_shell);
 
-	DEBUGOUT(XdbDebug(__FILE__, tmp,
+	DEBUGOUT(_LtDebug(__FILE__, tmp,
 			  "  calling menuDisarm on XtParent(menu_shell)\n"));
 
 	RCClass_MenuProcs(XtClass(tmp))(XmMENU_DISARM, tmp, NULL);
@@ -872,27 +880,28 @@ MenuShellPopdownDone(Widget w, XEvent *event,
     _XmSetInDragMode(w, False);
 }
 
+
 static void
 MenuShellPopdownOne(Widget w, XEvent *event,
 		    String *params, Cardinal *num_params)
 {
     Widget rc = NULL;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "MenuShellPopdownOne()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "MenuShellPopdownOne()\n"));
 
     /* must be a menu shell here. */
     assert(XmIsMenuShell(w));
 
     if (MGR_NumChildren(w) == 0)
     {
-	DEBUGOUT(XdbDebug(__FILE__, w, "MenuShellPopdownOne: no children\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "MenuShellPopdownOne: no children\n"));
 	return;
     }
 
     if (MS_PrivateShell(w) && XmIsRowColumn(XtParent(w)) &&
 	XmIsMenuBar(XtParent(w)))
     {
-	DEBUGOUT(XdbDebug(__FILE__, w, "MenuShellPopdownOne: parent %s\n",
+	DEBUGOUT(_LtDebug(__FILE__, w, "MenuShellPopdownOne: parent %s\n",
 			  XtName(XtParent(w))));
 	rc = RC_PopupPosted(XtParent(w));
     }
@@ -903,16 +912,16 @@ MenuShellPopdownOne(Widget w, XEvent *event,
 
     if (!rc || !XmIsRowColumn(rc))
     {
-	DEBUGOUT(XdbDebug(__FILE__, w, "MenuShellPopdownOne: no RC\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "MenuShellPopdownOne: no RC\n"));
 	return;
     }
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "  Child menu pane is %s\n", XtName(rc)));
+    DEBUGOUT(_LtDebug(__FILE__, w, "  Child menu pane is %s\n", XtName(rc)));
 
     /* unhighlight the cascade button that popped us up. */
     if (RC_CascadeBtn(rc))
     {
-	DEBUGOUT(XdbDebug(__FILE__, w, "  Removing myself from the cascade\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "  Removing myself from the cascade\n"));
 
 	/* disarm the cascade button that pulled us down. */
 	if (XmIsPrimitive(RC_CascadeBtn(rc)))
@@ -931,17 +940,17 @@ MenuShellPopdownOne(Widget w, XEvent *event,
 	RC_CascadeBtn(rc) = NULL;
     }
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "  Popping down\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "  Popping down\n"));
 
     if (MS_PrivateShell(w))
     {
-	DEBUGOUT(XdbDebug(__FILE__, w, "  PrivateShell\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "  PrivateShell\n"));
 
 	_XmXtMenuPopdown(w, NULL, NULL, NULL);
     }
     else
     {
-	DEBUGOUT(XdbDebug(__FILE__, w, "  public shell\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "  public shell\n"));
 	if (RC_Type(rc) == XmMENU_POPUP || RC_Type(rc) == XmMENU_OPTION)
 	{
 	    _XmRemoveGrab(w);
@@ -954,17 +963,18 @@ MenuShellPopdownOne(Widget w, XEvent *event,
 	_XmCallRowColumnUnmapCallback(rc, event);
 }
 
+
 static void
 MenuShellPopdownEveryone(Widget w, XEvent *event,
 			 String *params, Cardinal *num_params)
 {
-    int i;
+    Cardinal i;
     Widget rc;
 
     /* must be a menu shell here. */
     assert(XmIsMenuShell(w));
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "Popping down everyone - %i kids\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "Popping down everyone - %i kids\n",
     		MGR_NumChildren(w)));
 
     if (MGR_NumChildren(w) == 0)
@@ -976,7 +986,7 @@ MenuShellPopdownEveryone(Widget w, XEvent *event,
     {
 	rc = MGR_Children(w)[i];
 
-	DEBUGOUT(XdbDebug2(__FILE__, w, rc,"child %i\n", i));
+	DEBUGOUT(_LtDebug2(__FILE__, w, rc,"child %i\n", i));
 	if (!rc)
 	{
 	    continue;
@@ -994,18 +1004,18 @@ MenuShellPopdownEveryone(Widget w, XEvent *event,
 
 	    if (XmIsMenuShell(shell))
 	    {
-		DEBUGOUT(XdbDebug(__FILE__, shell,
+		DEBUGOUT(_LtDebug(__FILE__, shell,
 			  "  recursing in PopdownEveryone.\n"));
 		MenuShellPopdownEveryone(shell, event, params, num_params);
 	    }
 	}
-	DEBUGOUT(XdbDebug(__FILE__, w, "  calling popdownOne.\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "  calling popdownOne.\n"));
 
 	MenuShellPopdownOne(XtParent(rc), event, params, num_params);
 #if 0
 	_XmCallRowColumnUnmapCallback(rc, event);
 #endif
-	DEBUGOUT(XdbDebug2(__FILE__, w, rc,"child %i parent %s\n", 
+	DEBUGOUT(_LtDebug2(__FILE__, w, rc,"child %i parent %s\n", 
 			i,
 			XtName(XtParent(rc))));
     }
@@ -1020,10 +1030,11 @@ MenuShellPopdownEveryone(Widget w, XEvent *event,
     }
 }
 
+
 static void
 MenuShellPopupSharedMenuPane(Widget w, Widget w2, XEvent *event)
 {
-    DEBUGOUT(XdbDebug(__FILE__, w, "Popping up shared pane\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "Popping up shared pane\n"));
 
     /* must be a menu shell here. */
     assert(XmIsMenuShell(w));
@@ -1043,7 +1054,7 @@ MenuShellPopupSharedMenuPane(Widget w, Widget w2, XEvent *event)
     Shell_PoppedUp(w) = True;
  
 #ifdef USE_FOCUS
-    DEBUGOUT(XdbDebug(__FILE__, w,
+    DEBUGOUT(_LtDebug(__FILE__, w,
 		      "FOCUS SET: %s %s\n", XtName(w), XtName(w2)));
 
     _XmMenuFocus(w2, XmMENU_FOCUS_SET, CurrentTime);
@@ -1054,6 +1065,7 @@ MenuShellPopupSharedMenuPane(Widget w, Widget w2, XEvent *event)
     _XmAddGrab(w, False, False);
 }
 
+
 static void
 _XmXtMenuPopup(Widget widget, XEvent *event,
 	       String *params, Cardinal *num_params)
@@ -1083,11 +1095,12 @@ _XmXtMenuPopup(Widget widget, XEvent *event,
     XAllowEvents(XtDisplay(widget), SyncPointer, CurrentTime);
 }
 
+
 static void
 _XmXtMenuPopdown(Widget widget, XEvent *event,
 		 String *params, Cardinal *num_params)
 {
-    DEBUGOUT(XdbDebug(__FILE__, widget, "_XmXtMenuPopdown()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, widget, "_XmXtMenuPopdown()\n"));
     if (MS_PrivateShell(widget))
     {
         XtUnmapWidget(widget);
@@ -1096,7 +1109,7 @@ _XmXtMenuPopdown(Widget widget, XEvent *event,
 
 #ifdef USE_FOCUS
 #if 0
-	DEBUGOUT(XdbDebug(__FILE__, widget,
+	DEBUGOUT(_LtDebug(__FILE__, widget,
 			  "RESTORE: %s\n", XtName(widget)));
 
         _XmMenuFocus(widget, XmMENU_FOCUS_RESTORE, CurrentTime);
@@ -1107,25 +1120,28 @@ _XmXtMenuPopdown(Widget widget, XEvent *event,
     }
 }
 
-void
+
+extern void
 _XmEnterRowColumn(Widget widget, XtPointer closure,
 		  XEvent *event, Boolean *cont)
 {
-    DEBUGOUT(XdbDebug(__FILE__, widget,
+    DEBUGOUT(_LtDebug(__FILE__, widget,
 		      "_XmEnterRowColumn(not implemented)\n"));
 }
 
-void
+
+extern void
 _XmClearTraversal(Widget wid, XEvent *event,
 		  String *params, Cardinal *num_params)
 {
-    DEBUGOUT(XdbDebug(__FILE__, wid,
+    DEBUGOUT(_LtDebug(__FILE__, wid,
 		      "_XmClearTraversal(not implemented)\n"));
 
     XAllowEvents(XtDisplay(wid), SyncPointer, CurrentTime);
 }
 
-void
+
+extern void
 _XmSetLastManagedMenuTime(Widget wid,
 			  Time newTime)
 {
@@ -1135,7 +1151,7 @@ _XmSetLastManagedMenuTime(Widget wid,
 }
 
 
-Widget
+extern Widget
 XmCreateMenuShell(Widget parent, char *name, ArgList arglist, Cardinal argcount)
 {
     while (parent && !XtIsComposite(parent))
