@@ -1,8 +1,9 @@
 /**
  *
- * $Id: Primitive.c,v 1.42 1999/08/15 17:17:10 rwscott Exp $
+ * $Id: Primitive.c,v 1.47 2001/07/27 18:51:56 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,9 +23,10 @@
  *
  **/
 
-static const char rcsid[] = "$Id: Primitive.c,v 1.42 1999/08/15 17:17:10 rwscott Exp $";
+static const char rcsid[] = "$Id: Primitive.c,v 1.47 2001/07/27 18:51:56 dannybackx Exp $";
 
 #include <LTconfig.h>
+
 #include <XmI/XmI.h>
 
 #include <Xm/XmP.h>
@@ -34,14 +36,14 @@ static const char rcsid[] = "$Id: Primitive.c,v 1.42 1999/08/15 17:17:10 rwscott
 #include <Xm/ManagerP.h>
 #include <Xm/TransltnsP.h>
 #include <Xm/VirtKeysP.h>
-
-#include <XmI/DebugUtil.h>
-
 #if XmVERSION > 1
 /* Includes for 2.0 features */
 #include <XmI/DirectionI.h>
 #endif
 
+#include <XmI/DebugUtil.h>
+
+
 /* Forward Declarations */
 
 static void class_initialize(void);
@@ -188,8 +190,6 @@ static XtResource resources[] =
 	XmRImmediate, (XtPointer)NULL
     }
 
-#if LESSTIF_BACK_COMPAT
-#else
 #if XmVERSION > 1
     ,{
 	XmNconvertCallback, XmCCallback, XmRCallback,
@@ -207,7 +207,6 @@ static XtResource resources[] =
 	XmRCallProc, (XtPointer)_XmDirectionDefault
     }
 #endif
-#endif
 
 };
 
@@ -283,7 +282,7 @@ static XtActionsRec actions[] =
     {"NextTabGroup", _XmTraversePrevTabGroup},
 };
 
-/* *INDENT-OFF* */
+
 static XmBaseClassExtRec _XmPrimitiveCoreClassExtRec = {
     /* next_extension            */ NULL,
     /* record_type               */ NULLQUARK,
@@ -367,7 +366,6 @@ XmPrimitiveClassRec xmPrimitiveClassRec = {
 	/* extension             */ (XtPointer)&_XmPrimClassExtRec
     }
 };
-/* *INDENT-ON* */
 
 WidgetClass xmPrimitiveWidgetClass = (WidgetClass)&xmPrimitiveClassRec;
 
@@ -653,7 +651,7 @@ realize(Widget w,
 {
     int i;
 
-    DEBUGOUT(XdbDebug(__FILE__, w,
+    DEBUGOUT(_LtDebug(__FILE__, w,
 		      "Realize wid before create %d ht %d bw %d\n",
 		      XtWidth(w), XtHeight(w), XtBorderWidth(w)));
 
@@ -684,7 +682,7 @@ realize(Widget w,
 	XtRealizeWidget(w->core.popup_list[i]);
     }
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "Realize wid %d ht %d bw %d\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "Realize wid %d ht %d bw %d\n",
 		      XtWidth(w), XtHeight(w), XtBorderWidth(w)));
 }
 
@@ -738,7 +736,7 @@ set_values(Widget old, Widget request, Widget new_w,
     /* Debug print */
     if (Prim_Foreground(old) != Prim_Foreground(new_w))
     {
-	DEBUGOUT(XdbDebug(__FILE__, new_w,
+	DEBUGOUT(_LtDebug(__FILE__, new_w,
 			  "Primitive SetValues: Foreground changed\n"));
 	need_refresh = True;
     }
@@ -811,7 +809,7 @@ focus_change(Widget w, XmFocusChange change)
 {
     XmPrimitiveWidgetClass pc = (XmPrimitiveWidgetClass)XtClass(w);
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "Primitive Focus Change (%s)\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "Primitive Focus Change (%s)\n",
 		      (change == XmENTER) ? "XmENTER" :
 		      (change == XmFOCUS_IN) ? "XmFOCUS_IN" :
 		      (change == XmLEAVE) ? "XmLEAVE" :
@@ -868,22 +866,22 @@ widget_navigable(Widget w)
 	    Prim_NavigationType(w) == XmEXCLUSIVE_TAB_GROUP ||
 	    (Prim_NavigationType(w) == XmTAB_GROUP && !_XmShellIsExclusive(w)))
 	{
-	    DEBUGOUT(XdbDebug(__FILE__, w,
+	    DEBUGOUT(_LtDebug(__FILE__, w,
 			      "PrimitiveWidgetNavigable => XmTAB_NAVIGABLE\n"));
 
 	    return XmTAB_NAVIGABLE;
 	}
 
-	DEBUGOUT(XdbDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "PrimitiveWidgetNavigable => XmCONTROL_NAVIGABLE\n"));
 
 	return XmCONTROL_NAVIGABLE;
     }
 
-    DEBUGOUT(XdbDebug(__FILE__, w,
+    DEBUGOUT(_LtDebug(__FILE__, w,
 	   "PrimitiveWidgetNavigable (sens %s TravOn %s) => XmNOT_NAVIGABLE\n",
-		      XdbBoolean2String(XtSensitive(w)),
-		      XdbBoolean2String(Prim_TraversalOn(w))));
+		      _LtDebugBoolean2String(XtSensitive(w)),
+		      _LtDebugBoolean2String(Prim_TraversalOn(w))));
 
     return XmNOT_NAVIGABLE;
 }
@@ -891,7 +889,7 @@ widget_navigable(Widget w)
 static void
 primitive_border_unhighlight(Widget w)
 {
-    DEBUGOUT(XdbDebug(__FILE__, w, "PrimitiveBorderUnhighlight\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "PrimitiveBorderUnhighlight\n"));
 
     if (!XtIsRealized(w))
     {
@@ -927,7 +925,7 @@ primitive_border_unhighlight(Widget w)
 static void
 primitive_border_highlight(Widget w)
 {
-    DEBUGOUT(XdbDebug(__FILE__, w, "PrimitiveBorderHighlight\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "PrimitiveBorderHighlight\n"));
 
     if (!XtIsRealized(w))
     {
@@ -959,8 +957,8 @@ _XmTraverseLeft(Widget w, XEvent *event, String *params, Cardinal *num_params)
 void
 _XmTraverseRight(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(XdbDebug(__FILE__, w, "XmProcessTraversal(TRAVERSE_RIGHT)\n"));
-    DEBUGOUT(XdbDebug(__FILE__, w,
+    DEBUGOUT(_LtDebug(__FILE__, w, "XmProcessTraversal(TRAVERSE_RIGHT)\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w,
 		       "event type: %d code %08x\n",
 		       event->type, event->xkey.keycode));
 
@@ -970,7 +968,7 @@ _XmTraverseRight(Widget w, XEvent *event, String *params, Cardinal *num_params)
 void
 _XmTraverseNext(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(XdbDebug(__FILE__, w, "XmProcessTraversal(TRAVERSE_NEXT)\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "XmProcessTraversal(TRAVERSE_NEXT)\n"));
 
     XmProcessTraversal(w, XmTRAVERSE_NEXT);
 }
@@ -978,7 +976,7 @@ _XmTraverseNext(Widget w, XEvent *event, String *params, Cardinal *num_params)
 void
 _XmTraversePrev(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
-    DEBUGOUT(XdbDebug(__FILE__, w, "XmProcessTraversal(TRAVERSE_PREV)\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "XmProcessTraversal(TRAVERSE_PREV)\n"));
 
     XmProcessTraversal(w, XmTRAVERSE_PREV);
 }
@@ -1062,7 +1060,7 @@ _XmPrimitiveHelp(Widget w, XEvent *event,
     Widget cur = w;
     XmAnyCallbackStruct cbs;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "_XmPrimitiveHelp\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "_XmPrimitiveHelp\n"));
 
     cbs.reason = XmCR_HELP;
     cbs.event = event;
@@ -1071,7 +1069,7 @@ _XmPrimitiveHelp(Widget w, XEvent *event,
     {
 	if (XtHasCallbacks(cur, XmNhelpCallback) == XtCallbackHasSome)
 	{
-	    DEBUGOUT(XdbDebug(__FILE__, cur,
+	    DEBUGOUT(_LtDebug(__FILE__, cur,
 			      "_XmPrimitiveHelp ... calling !!\n"));
 
 	    XtCallCallbacks(cur, XmNhelpCallback, (XtPointer)&cbs);
@@ -1079,7 +1077,7 @@ _XmPrimitiveHelp(Widget w, XEvent *event,
 	    return;
 	}
 
-	DEBUGOUT(XdbDebug(__FILE__, cur, "_XmPrimitiveHelp ... no luck\n"));
+	DEBUGOUT(_LtDebug(__FILE__, cur, "_XmPrimitiveHelp ... no luck\n"));
 	cur = XtParent(cur);
     }
 }
@@ -1107,7 +1105,7 @@ _XmPrimitiveHighlightPixmapDefault(Widget w, int offset, XrmValue *value)
 {
     static Pixmap pixmap;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "_XmPrimitiveHighlightPixmapDefault\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "_XmPrimitiveHighlightPixmapDefault\n"));
 
     pixmap = XmUNSPECIFIED_PIXMAP;
 
@@ -1128,7 +1126,7 @@ _XmPrimitiveTopShadowPixmapDefault(Widget w, int offset, XrmValue *value)
 {
     static Pixmap pixmap;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "_XmPrimitiveTopShadowPixmapDefault\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "_XmPrimitiveTopShadowPixmapDefault\n"));
 
     pixmap = XmUNSPECIFIED_PIXMAP;
 
@@ -1202,7 +1200,7 @@ XmResolveAllPartOffsets( WidgetClass w_class,
     Cardinal			num_resources;
     ConstraintWidgetClass	superclass, thisclass, tmp;
 
-    DEBUGOUT(XdbDebug0(__FILE__, NULL,
+    DEBUGOUT(_LtDebug0(__FILE__, NULL,
 		       "\nXmResolveAllPartOffsets(`%s')\n",
 		       w_class->core_class.class_name));
 
@@ -1250,7 +1248,7 @@ XmResolveAllPartOffsets( WidgetClass w_class,
 	bfIsConstraint = False;
     }
 
-    DEBUGOUT(XdbDebug0(__FILE__, NULL,
+    DEBUGOUT(_LtDebug0(__FILE__, NULL,
 		       "\twidget class:`%s' is %s a Constraint type.\n",
 		       thisclass->core_class.class_name,
 		       (bfIsConstraint ? "" : "NOT" )));
@@ -1281,7 +1279,7 @@ XmResolveAllPartOffsets( WidgetClass w_class,
 	array_size++;
     }
 
-    DEBUGOUT(XdbDebug0(__FILE__, NULL, "\tarray size:%d\n", array_size));
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, "\tarray size:%d\n", array_size));
 
     /*
      * Allocate an array based upon the number of superclass
@@ -1320,7 +1318,7 @@ XmResolveAllPartOffsets( WidgetClass w_class,
      */
 
 
-    DEBUGOUT(XdbDebug0(__FILE__, NULL, "\n\t--- Calculate Core offsets ---\n"));
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, "\n\t--- Calculate Core offsets ---\n"));
 
     for ( tmp = (ConstraintWidgetClass)thisclass->core_class.superclass,
 	      k = array_size - 1;
@@ -1329,7 +1327,7 @@ XmResolveAllPartOffsets( WidgetClass w_class,
     {
 	offset[k] = tmp->core_class.widget_size;
 
-	DEBUGOUT(XdbDebug0(__FILE__, NULL, "\t  offset[%2d] = %-6d `%s'\n",
+	DEBUGOUT(_LtDebug0(__FILE__, NULL, "\t  offset[%2d] = %-6d `%s'\n",
 			   k, offset[k], tmp->core_class.class_name));
     }
 
@@ -1350,7 +1348,7 @@ XmResolveAllPartOffsets( WidgetClass w_class,
 	 *    xmBulletinBoardClass->constraint_class.constraint_size'
 	 */
 
-	DEBUGOUT(XdbDebug0(__FILE__, NULL,
+	DEBUGOUT(_LtDebug0(__FILE__, NULL,
 			   "\n\t--- Calculate Constraint offsets ---\n"));
 
 	for ( tmp = (ConstraintWidgetClass)thisclass->core_class.superclass,
@@ -1360,7 +1358,7 @@ XmResolveAllPartOffsets( WidgetClass w_class,
 	{
 	    constraint_offset[k] = tmp->constraint_class.constraint_size;
 
-	    DEBUGOUT(XdbDebug0(__FILE__, NULL, "\t  offset[%2d] = %-6d `%s'\n",
+	    DEBUGOUT(_LtDebug0(__FILE__, NULL, "\t  offset[%2d] = %-6d `%s'\n",
 			       k, constraint_offset[k],
 			       tmp->core_class.class_name));
 	}
@@ -1371,7 +1369,7 @@ XmResolveAllPartOffsets( WidgetClass w_class,
      * list to be real offsets.
      */
 
-    DEBUGOUT(XdbDebug0(__FILE__, NULL, "\n\t--- Core Final ---\n"));
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, "\n\t--- Core Final ---\n"));
 
     resources = (XmPartResource*)thisclass->core_class.resources;
     num_resources = thisclass->core_class.num_resources;
@@ -1381,7 +1379,7 @@ XmResolveAllPartOffsets( WidgetClass w_class,
 	int	true_offset =  resources[j].resource_offset &  XmOFFSETMASK;
 	resources[j].resource_offset = offset[widget_index] + true_offset;
 
-	DEBUGOUT(XdbDebug0(__FILE__, NULL,
+	DEBUGOUT(_LtDebug0(__FILE__, NULL,
 			   "\t  [%2d] windex:%-3d true_offset:%-3d"
 			   " real_offset: %-3d\n",
 			   j, widget_index, true_offset,
@@ -1395,7 +1393,7 @@ XmResolveAllPartOffsets( WidgetClass w_class,
 	 * constraint resource list to be real offsets.
 	 */
 
-	DEBUGOUT(XdbDebug0(__FILE__, NULL, "\n\t--- Constraint Final ---\n"));
+	DEBUGOUT(_LtDebug0(__FILE__, NULL, "\n\t--- Constraint Final ---\n"));
 
 	resources = (XmPartResource*)thisclass->constraint_class.resources;
 	num_resources = thisclass->constraint_class.num_resources;
@@ -1408,7 +1406,7 @@ XmResolveAllPartOffsets( WidgetClass w_class,
 	    resources[j].resource_offset = constraint_offset[widget_index] +
 						true_offset;
 
-	    DEBUGOUT(XdbDebug0(__FILE__, NULL,
+	    DEBUGOUT(_LtDebug0(__FILE__, NULL,
 			       "\t  [%2d] windex:%-3d true_offset:%-3d "
 			       "real_offset: %-3d\n",
 			       j, widget_index, true_offset,
@@ -1422,17 +1420,17 @@ XmResolveAllPartOffsets( WidgetClass w_class,
 	/* Release constraint offset that were allocated,
 	 * silly caller supplied a NULL referenced parameter
 	 */
-	XtFree((void*)constraint_offset);
+	XtFree((char *)constraint_offset);
     }
     if ( !offset_return && offset )
     {
 	/* Release offsets that were allocated,
 	 * silly caller supplied a NULL referenced parameter
 	 */
-	XtFree((void*)offset);
+	XtFree((char *)offset);
     }
 
-    DEBUGOUT(XdbDebug0(__FILE__, NULL,
+    DEBUGOUT(_LtDebug0(__FILE__, NULL,
 		       "END OF XmResolveAllPartOffsets(`%s')\n\n",
 		       w_class->core_class.class_name));
 }
