@@ -1,6 +1,6 @@
 /**
  *
- * $Id: PushBG.c,v 1.87 2001/07/27 18:51:57 dannybackx Exp $
+ * $Id: PushBG.c,v 1.89 2001/09/13 13:34:13 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
  * Copyright (C) 1995-2001 LessTif Development Team
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: PushBG.c,v 1.87 2001/07/27 18:51:57 dannybackx Exp $";
+static const char rcsid[] = "$Id: PushBG.c,v 1.89 2001/09/13 13:34:13 amai Exp $";
 
 #include <LTconfig.h>
 
@@ -55,6 +55,7 @@ static const char rcsid[] = "$Id: PushBG.c,v 1.87 2001/07/27 18:51:57 dannybackx
 #if XmVERSION > 1
 #include <Xm/TraitP.h>
 #include <Xm/ActivatableT.h>
+#include <Xm/ContItemT.h>
 
 void _XmPushBG_TraitAddCallback(Widget, XtCallbackProc, XtPointer, Boolean);
 
@@ -62,6 +63,15 @@ static XmActivatableTraitRec _XmPushBGTraitRec = {
 	/* version	*/	0,
 	/* cb		*/	_XmPushBG_TraitAddCallback
 };
+
+static void _XmPushBG_ContainerItemGetValues(Widget w, XmContainerItemData d);
+static void _XmPushBG_ContainerItemSetValues(Widget w, XmContainerItemData d);
+
+static XmContainerItemTraitRec _XmPushBG_ContainerItemTrait = {
+        /* version */           0,
+        /* setvalues */         _XmPushBG_ContainerItemGetValues,
+        /* getvalues */         _XmPushBG_ContainerItemSetValues
+};
 #endif
 
 #ifndef XmUNSPECIFIED
@@ -347,6 +357,9 @@ static XmGadgetClassExtRec _XmPushBGadgetClassExtRec = {
     /* size                      */ sizeof(XmGadgetClassExtRec),
     /* widget_baseline_proc      */ XmInheritBaselineProc,
     /* display_rect_proc         */ XmInheritDisplayRectProc,
+#if XmVERSION >= 2
+    /* margins_proc              */ XmInheritMarginsProc,
+#endif
 };
 
 XmPushButtonGadgetClassRec xmPushButtonGadgetClassRec = {
@@ -521,11 +534,15 @@ class_initialize(void)
     xmPushButtonGCacheObjClassRec.object_class.num_resources = ncom;
 
 #if XmVERSION > 1
-    if (! XmeTraitSet((XtPointer)xmPushButtonGadgetClass, XmQTactivatable,
-		(XtPointer)&_XmPushBGTraitRec)) {
-	_XmWarning(NULL,
-	    "XmPushButtonGadget ClassInitialize: XmeTraitSet failed\n");
-    }
+	if (! XmeTraitSet((XtPointer)xmPushButtonGadgetClass, XmQTactivatable,
+			(XtPointer)&_XmPushBGTraitRec)) {
+		_XmWarning(NULL, "XmPushButtonGadget ClassInitialize: XmeTraitSet failed\n");
+	}
+	if (! XmeTraitSet((XtPointer)xmPushButtonGadgetClass, XmQTcontainerItem,
+			(XtPointer)&_XmPushBG_ContainerItemTrait)) {
+		_XmWarning(NULL, "XmPushButtonGadget ClassInitialize: XmeTraitSet failed\n");
+	}
+
 #endif
 }
 
@@ -1886,4 +1903,17 @@ void _XmPushBG_TraitAddCallback(Widget w,
     else
 	XtRemoveCallback(w, XmNactivateCallback, cb, cbp);
 }
+
+/*
+ * Trait functions for ContainerItem
+ */
+static void _XmPushBG_ContainerItemGetValues(Widget w, XmContainerItemData d)
+{
+	DEBUGOUT(_LtDebug(__FILE__, w, "_XmPushBG_ContainerItemGetValues()\n"));
+}
+
+static void _XmPushBG_ContainerItemSetValues(Widget w, XmContainerItemData d)
+{       
+	DEBUGOUT(_LtDebug(__FILE__, w, "_XmPushBG_ContainerItemSetValues()\n"));
+}
 #endif
