@@ -1,8 +1,9 @@
 /**
  *
- * $Id: ResConvert.c,v 1.53 1999/10/26 09:25:10 amai Exp $
+ * $Id: ResConvert.c,v 1.79 2001/09/07 09:52:30 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,22 +23,15 @@
  *
  **/
 
-static const char rcsid[] = "$Id: ResConvert.c,v 1.53 1999/10/26 09:25:10 amai Exp $";
+static const char rcsid[] = "$Id: ResConvert.c,v 1.79 2001/09/07 09:52:30 amai Exp $";
 
 #include <LTconfig.h>
 
 #include <stdio.h>
 #include <stdlib.h>
-#ifdef __STDC__
 #include <stdarg.h>
-#else
-#include <varargs.h>
-#endif
 #include <ctype.h>
-
-#ifdef HAVE_STRING_H
 #include <string.h>
-#endif
 
 #include <XmI/XmI.h>
 #include <Xm/XmP.h>
@@ -48,15 +42,11 @@ static const char rcsid[] = "$Id: ResConvert.c,v 1.53 1999/10/26 09:25:10 amai E
 #include <Xm/VendorSEP.h>
 #include <Xm/ExtObjectP.h>
 #include <Xm/XmosP.h>
-#include <X11/Xfuncs.h>
-
-#include <XmI/DebugUtil.h>
 
 #include "LTmisc.h"
 
-#ifndef XmUNSPECIFIED
-#define XmUNSPECIFIED (~0)
-#endif
+#include <XmI/DebugUtil.h>
+
 
 enum
 {
@@ -114,9 +104,24 @@ static Boolean _XmCvtStringToTabList(Display *display, XrmValue *args,
 static Boolean _XmCvtStringToRenderTable(Display *display, XrmValue *args,
 		       Cardinal *num_args, XrmValue *from, XrmValue *to,
 		       XtPointer *converter_data);
+#endif /* XmVERSION > 1 */
+
+
+/*
+   xmUseVersion is used for a sanity check by developers.  It is used within
+   a M*tif applications to ensure the version of the (shared) M*tif library
+   being used corresponds to the M*tif toolkit header the application was
+   compiled against.  8/3/98, pgw@ma.ultranet.com
+   amai: it seems that at least OM 2.1 initializes this number
+         immediately, instead of waiting for XmRegisterConverters()
+	 to be called. We try to stay as compatible as possible here ...
+ */
+#if XmVersion < 2001
+int xmUseVersion = 0;
+#else
+int xmUseVersion = XmVersion;
 #endif
 
-int	xmUseVersion = 0;
 
 /* please be careful if you're editting these arrays, as
  * the strings have to be in the _same_ order as the
@@ -285,6 +290,11 @@ static char *unit_types[] =
     "100th_font_units"
 };
 
+/*
+ * These are the values of XmNdialogType for XmMessageBox
+ *	This is the value type XmRDialogType.
+ *	The class of this resource is XmCDialogType.
+ */
 static char *dialog_types[] =
 {
     "dialog_template",
@@ -296,6 +306,19 @@ static char *dialog_types[] =
     "dialog_working"
 };
 
+/*
+ * These are the values of XmNdialogType for XmSelectionBox
+ *	This is the value type XmRSelectionType.
+ *	The class of this resource is (also) XmCDialogType
+ */
+static char *selection_dialog_types[] = {
+	"dialog_work_area",
+	"dialog_prompt",
+	"dialog_selection",
+	"dialog_command",
+	"dialog_file_selection",
+};
+
 static char *dialog_styles[] =
 {
     "dialog_modeless",
@@ -340,7 +363,6 @@ static char *row_column_types[] =
     "menu_popup",
     "menu_option"
 };
-
 static unsigned char row_column_type_values[] =
 {
     XmWORK_AREA,
@@ -359,7 +381,6 @@ static char *indicator_types[] =
     "one_of_many_diamond"
 #endif
 };
-
 static unsigned char indicator_type_values[] =
 {
     XmN_OF_MANY,
@@ -532,12 +553,13 @@ static char *spb_arrow_layouts[] =
 
 static unsigned char spb_arrow_layout_values[] =
 {
-    XmARROWS_BEGINNING,
     XmARROWS_END,
-    XmARROWS_SPLIT
+    XmARROWS_BEGINNING,
+    XmARROWS_SPLIT,
+    XmARROWS_FLAT_END,
+    XmARROWS_FLAT_BEGINNING
 };
 
-#if XmVERSION > 1
 /* Notebook */
 static char *nb_child_types[] =
 {
@@ -558,7 +580,6 @@ static unsigned char nb_child_type_values[] =
     XmSTATUS_AREA, 
     XmPAGE_SCROLLER
 };
-#endif
 
 static char *indicator_on[] =
 {
@@ -596,9 +617,10 @@ static unsigned char indicator_on_values[] =
     XmINDICATOR_FILL,		/* yes */
 };
 
-#endif
+#endif /* XmVERSION > 1 */
 
-void
+
+extern void
 XmRegisterConverters(void)
 {
     /* don't really know the difference between the two, so
@@ -607,7 +629,8 @@ XmRegisterConverters(void)
     _XmRegisterConverters();
 }
 
-void
+
+extern void
 _XmRegisterConverters(void)
 {
     static Boolean first = True;
@@ -645,10 +668,6 @@ _XmRegisterConverters(void)
 	    0
 	}};
 
-#ifdef NONSTANDARD_CONVERTERS
-    extern void _XmRegisterNSEConverters(void);
-#endif
-
     if (first)
     {
 	first = False;
@@ -658,13 +677,10 @@ _XmRegisterConverters(void)
 	return;
     }
 
-    /*
-       xmUseVersion is used for a santity check by developers.  It is used within
-       a M*tif applications to ensure the version of the (shared) M*tif library
-       being used corresponds to the M*tif toolkit header the application was
-       compiled against.  8/3/98, pgw@ma.ultranet.com
-     */
+/* See comment at declaration at beginning of this file */
+#if XmVersion < 2001
     xmUseVersion = XmVersion;
+#endif
 
 #define REPTYPE_REGISTER(reptype,array) \
     XmRepTypeRegister((reptype), \
@@ -696,7 +712,7 @@ _XmRegisterConverters(void)
     REPTYPE_REGISTER(XmRDragReceiverProtocolStyle, protocol_styles);
     REPTYPE_REGISTER(XmRUnitType, unit_types);
     REPTYPE_REGISTER(XmRDialogType, dialog_types);
-    REPTYPE_REGISTER(XmRSelectionType, dialog_types);
+    REPTYPE_REGISTER(XmRSelectionType, selection_dialog_types);
     REPTYPE_REGISTER(XmRDialogStyle, dialog_styles);
     REPTYPE_REGISTER(XmRSeparatorType, separator_types);
     REPTYPE_REGISTER(XmRResizePolicy, resize_policies);
@@ -728,7 +744,7 @@ _XmRegisterConverters(void)
                                 indicator_type_values);
 
 #if XmVERSION > 1
-/* Motif 2.0 */
+/* Motif 2.x */
     REPTYPE_REGISTER(XmRToggleMode, toggle_mode);
     REPTYPE_REGISTER_WITH_VALUES(XmRArrowLayout,
                 spb_arrow_layouts, spb_arrow_layout_values);
@@ -738,7 +754,9 @@ _XmRegisterConverters(void)
                 indicator_on, indicator_on_values);
     REPTYPE_REGISTER_WITH_VALUES(XmRNotebookChildType,
                 nb_child_types, nb_child_type_values);
-#endif
+
+    XmRepTypeInstallTearOffModelConverter();
+#endif /* XmVERSION > 1 */
 
 #undef REPTYPE_REGISTER
 #undef REPTYPE_REGISTER_WITH_VALUES
@@ -991,132 +1009,182 @@ _XmRegisterConverters(void)
 #endif
 }
 
+
 /*
  * error convenience
  */
 void
-#ifdef __STDC__
-_XmError(Widget w, char *fmt,...)
+_XmError(Widget w, const char *fmt, ...)
 {
     va_list arg_list;
-    char buf[256];
+    char buf[1024];
+    int charsleft=sizeof(buf);
 
     va_start(arg_list, fmt);
+#ifdef HAVE_VSNPRINTF
+    charsleft -= vsnprintf(buf, sizeof(buf),
+                           fmt, arg_list);
 #else
-_XmError(w, fmt, va_alist)
-     Widget w;
-     char *fmt;
-     va_dcl
-{
-    char buf[256];
-    va_list arg_list;
-
-    va_start(arg_list);
+    charsleft -= vsprintf(buf,
+                          fmt, arg_list);
+    /* one might add a catch here ... */
 #endif
+    va_end(arg_list);
     if (w)
     {
-	vsprintf(buf, fmt, arg_list);
-	va_end(arg_list);
-
 	XtAppError(XtWidgetToApplicationContext(w), buf);
     }
     else
     {
-	vsprintf(buf, fmt, arg_list);
-	va_end(arg_list);
-
 	XtError(buf);
     }
 }
 
+
 /*
  * Warning convenience
  *
- * Added XdbDebug stuff here to be able to avoid infinite loops in applications
+ * Added _LtDebug stuff here to be able to avoid infinite loops in applications
  * that redirect stderr to a scrolledText. ML suffers from this, due to LessTif
- * bugs of cource :-(
+ * bugs of course :-(
  */
-void
-#ifdef __STDC__
-_XmWarning(Widget w, char *fmt,...)
+static void
+_LtWarning(Widget w, const char *fmt, va_list arg_list)
 {
-    va_list arg_list;
-    char buf[256];
+ /* Somewhere it's pointed out that we shouldn't exceed 1024 characters here.
+    Let's reserve two chars for \n\000
+    If we don't have (v)snprintf() we have a vulnerable piece of
+    code here ...  */
+#define BUFLEN 1026
+    char buf[BUFLEN]="";
+    int charsleft=BUFLEN;
+    static Boolean redirect=False;
+#ifndef	LESSTIF_PRODUCTION
+    static Boolean init=False;
 
-    va_start(arg_list, fmt);
-#else
-_XmWarning(Widget w, fmt, va_list)
-     Widget w;
-     char *fmt;
-     va_dcl
-{
-    char buf[256];
 
-    va_start(arg_list);
-#endif
+    if (!init) {
+    	if (getenv("DEBUG_REDIRECT_XMWARNING"))
+	   redirect = True;
+	init=True;
+    }
+#endif /* !LESSTIF_PRODUCTION */
+
     if (w)
     {
-	sprintf(buf, "\n    Name: %s\n    Class: %s\n    ",
-		XtName(w), XtClass(w)->core_class.class_name);
+#ifdef HAVE_SNPRINTF
+	charsleft -= snprintf(buf, charsleft,
+    	                      "\n    Name: %s\n    Class: %s\n    ",
+		              XtName(w), XtClass(w)->core_class.class_name);
+#else
+	charsleft -= sprintf(buf,
+	                     "\n    Name: %s\n    Class: %s\n    ",
+		             XtName(w), XtClass(w)->core_class.class_name);
+        /* one might add a catch here ... */
+#endif
 
-	vsprintf(buf + strlen(buf), fmt, arg_list);
-	va_end(arg_list);
+#ifdef HAVE_VSNPRINTF
+	charsleft -= vsnprintf(buf + strlen(buf), charsleft,
+	                       fmt, arg_list);
+#else
+	charsleft -= vsprintf(buf + strlen(buf),
+	                      fmt, arg_list);
+        /* one might add a catch here ... */
+#endif
 
 	strcat(buf, "\n");
 
-#ifdef	LESSTIF_PRODUCTION
-	XtAppWarning(XtWidgetToApplicationContext(w), buf);
-#else
-	if (getenv("DEBUG_REDIRECT_XMWARNING"))
+	if (redirect)
 	{
-	    XdbPrintString(buf);
+	    _LtDebugPrintString(buf);
 	}
 	else
 	{
 	    XtAppWarning(XtWidgetToApplicationContext(w), buf);
 	}
-#endif
     }
     else
     {
-	buf[0] = '\0';
-	vsprintf(buf + strlen(buf), fmt, arg_list);
-	va_end(arg_list);
-
-#ifdef	LESSTIF_PRODUCTION
-	XtWarning(buf);
+#ifdef HAVE_VSNPRINTF
+	charsleft -= vsnprintf(buf + strlen(buf), charsleft,
+	          fmt, arg_list);
 #else
-	if (getenv("DEBUG_REDIRECT_XMWARNING"))
+	charsleft -= vsprintf(buf + strlen(buf),
+	         fmt, arg_list);
+#endif
+
+	if (redirect)
 	{
-	    XdbPrintString(buf);
+	    _LtDebugPrintString(buf);
 	}
 	else
 	{
 	    XtWarning(buf);
 	}
-#endif
-    }
+    } /* if(w) */
 }
 
-char *
+/*
+ * Warning convenience
+ *
+ * Added _LtDebug stuff here to be able to avoid infinite loops in applications
+ * that redirect stderr to a scrolledText. ML suffers from this, due to LessTif
+ * bugs of course :-(
+ */
+
+/* unshadow for the Motif 2.x build */
+#if XmVERSION >= 2
+#ifdef _XmWarning
+#undef _XmWarning
+#endif
+#endif
+
+extern void
+_XmWarning(Widget w, const char *fmt, ...)
+{
+    va_list arg_list;
+
+    va_start(arg_list, fmt);
+    _LtWarning(w, fmt, arg_list);
+    va_end(arg_list);
+}
+
+
+#if XmVERSION >= 2
+extern void
+XmeWarning(Widget w, const char *fmt, ...)
+{
+    va_list arg_list;
+
+    va_start(arg_list, fmt);
+    _LtWarning(w, fmt, arg_list);
+    va_end(arg_list);
+}
+#endif
+
+
+extern char *
 XmRegisterSegmentEncoding(char *fontlist_tag, char *ct_encoding)
 {
     return NULL;
 }
 
-char *
+
+extern char *
 XmMapSegmentEncoding(char *fontlist_tag)
 {
     return NULL;
 }
 
-XmString
+
+extern XmString
 XmCvtCTToXmString(char *text)
 {
     return XmStringCreate(text, XmFONTLIST_DEFAULT_TAG);
 }
 
-Boolean
+
+extern Boolean
 XmCvtTextToXmString(Display *display, XrmValuePtr args,
 		    Cardinal *num_args, XrmValue *from_val, XrmValue *to_val,
 		    XtPointer *converter_data)
@@ -1124,7 +1192,8 @@ XmCvtTextToXmString(Display *display, XrmValuePtr args,
     return False;
 }
 
-char *
+
+extern char *
 XmCvtXmStringToCT(XmString string)
 {
     char *text = (char *)NULL;
@@ -1134,7 +1203,7 @@ XmCvtXmStringToCT(XmString string)
     XmStringDirection direction;
     Boolean separator;
 
-    DEBUGOUT(XdbDebug(__FILE__, NULL, "XmCvtXmStringToCT\n"));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "XmCvtXmStringToCT\n"));
 
     if (XmStringInitContext(&context, string) == True)
     {
@@ -1175,7 +1244,7 @@ XmCvtXmStringToCT(XmString string)
     return text;
 }
 
-Boolean
+extern Boolean
 XmCvtXmStringToText(Display *display, XrmValuePtr args,
 		    Cardinal *num_args, XrmValue *from_val, XrmValue *to_val,
 		    XtPointer *converter_data)
@@ -1238,20 +1307,21 @@ XmCvtXmStringToText(Display *display, XrmValuePtr args,
     to_val->addr = value;
     to_val->size = strlen(value);  /* FIXME: should this be sizeof(value)? */
 
-    DEBUGOUT(XdbDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 		      "XmCvtXmStringToText(%p) => %s\n",
 		      from_val->addr, to_val->addr));
 
     return True;
 }
 
+
 /*
  * Compare two strings to see if they're equivalent. This one is used
  * whenever comparing motif constants with resource string values. The
  * motif constants must have the Xm prefix stripped off and must be
  * in lower case.
  */
-Boolean
+extern Boolean
 _XmStringsAreEqual(char *in_str,
 		   char *text_str)
 {
@@ -1272,17 +1342,24 @@ _XmStringsAreEqual(char *in_str,
     return *text_str ? False : True;
 }
 
+
 /*
  * Fixed this thing to make a COPY of the fontlist it returns.
  * Danny 16/4/1996
  */
-XmFontList
+extern XmFontList
 _XmGetDefaultFontList(Widget w,
 		      unsigned char fontListType)
 {
+#if 1
+    XmFontList labelFontList = NULL;
+    XmFontList buttonFontList = NULL;
+    XmFontList textFontList = NULL;
+#else
     static XmFontList labelFontList = NULL;
     static XmFontList buttonFontList = NULL;
     static XmFontList textFontList = NULL;
+#endif
     Widget par = w;
     XmFontList fontlist;
     XmVendorShellExtObject ve = NULL;
@@ -1326,6 +1403,7 @@ _XmGetDefaultFontList(Widget w,
 							   XmFONT_IS_FONT,
 						       XmFONTLIST_DEFAULT_TAG);
 	    textFontList = XmFontListAppendEntry(NULL, newEntry);
+            XmFontListEntryFree(&newEntry);
 	}
 
 	if (textFontList == NULL) {
@@ -1333,7 +1411,6 @@ _XmGetDefaultFontList(Widget w,
 	}
 
 	return XmFontListCopy(textFontList);
-	break;
 
     case XmBUTTON_FONTLIST:
 	while ((par = XtParent(par)) != NULL)
@@ -1358,8 +1435,9 @@ _XmGetDefaultFontList(Widget w,
 		}
 	    }
 	}
-	if (fontlist)
-	    return XmFontListCopy(fontlist);
+	if (fontlist) {
+		return XmFontListCopy(fontlist);
+	}
 
 	if (!buttonFontList)
 	{
@@ -1368,6 +1446,7 @@ _XmGetDefaultFontList(Widget w,
 							   XmFONT_IS_FONT,
 						       XmFONTLIST_DEFAULT_TAG);
 	    buttonFontList = XmFontListAppendEntry(NULL, newEntry);
+            XmFontListEntryFree(&newEntry);
 	}
 
 	if (buttonFontList == NULL) {
@@ -1375,7 +1454,6 @@ _XmGetDefaultFontList(Widget w,
 	}
 
 	return XmFontListCopy(buttonFontList);
-	break;
 
     default:
     case XmLABEL_FONTLIST:
@@ -1414,6 +1492,7 @@ _XmGetDefaultFontList(Widget w,
 							   XmFONT_IS_FONT,
 						       XmFONTLIST_DEFAULT_TAG);
 	    labelFontList = XmFontListAppendEntry(NULL, newEntry);
+            XmFontListEntryFree(&newEntry);
 	}
 
 	if (labelFontList == NULL) {
@@ -1422,19 +1501,19 @@ _XmGetDefaultFontList(Widget w,
 
 	return XmFontListCopy(labelFontList);
 
-	break;
     }
 }
 
 /* resource converters, of various types */
 
-char *
+extern char *
 _XmConvertCSToString(XmString cs)
 {
     return NULL;
 }
 
-Boolean
+
+extern Boolean
 _XmCvtXmStringToCT(XrmValue *from,
 		   XrmValue *to)
 {
@@ -1467,7 +1546,7 @@ _XmCvtStringToXmString(Display *display,
     {
 	if (to->addr == NULL)
 	{
-	    to->addr = (XtPointer)&newString;
+	    to->addr = (XPointer)&newString;
 	    to->size = sizeof(XmString);
 	}
 	else
@@ -1490,7 +1569,7 @@ _XmCvtStringToXmString(Display *display,
 					 XmRXmString);
     }
 
-    DEBUGOUT(XdbDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 		      "_XmCvtStringToXmString(%s) => %p\n",
 		      from->addr, to->addr));
 
@@ -1515,9 +1594,10 @@ __XmFontListResourceAddEntry(Display *display,
 			     XmFontList oldFontList)
 {
     XmFontList newFontList;
+    XmFontListEntry newEntry;
     char *eq, *end, *fn, *ft, *tag, *font, *semi, *colon;
 
-    DEBUGOUT(XdbDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 		      "__XmFontListResourceAddEntry(%s)\n", full_entry));
 
     eq = strchr(full_entry, (int)'=');
@@ -1566,11 +1646,9 @@ __XmFontListResourceAddEntry(Display *display,
 	    *end = 0;
 	}
 
-	newFontList = XmFontListAppendEntry(oldFontList,
-					    XmFontListEntryLoad(display,
-								font,
-								XmFONT_IS_FONT,
-								tag));
+        newEntry = XmFontListEntryLoad(display,
+                                       font, XmFONT_IS_FONT, tag);
+	newFontList = XmFontListAppendEntry(oldFontList, newEntry);
 
 	XtFree(ft);
 	XtFree(fn);
@@ -1617,11 +1695,9 @@ __XmFontListResourceAddEntry(Display *display,
 	{
 	    *colon = '\0';
 	}
-	newFontList = XmFontListAppendEntry(oldFontList,
-					    XmFontListEntryLoad(display,
-								fn,
-							      XmFONT_IS_FONTSET,
-								tag));
+	newEntry = XmFontListEntryLoad(display,
+                                       fn, XmFONT_IS_FONTSET, tag);
+	newFontList = XmFontListAppendEntry(oldFontList, newEntry);
 
 	XtFree(fn);
 
@@ -1647,10 +1723,9 @@ __XmFontListResourceAddEntry(Display *display,
 	end++;
 	*end = 0;
     }
-    newFontList = XmFontListAppendEntry(oldFontList,
-					XmFontListEntryLoad(display, full_entry,
-							    XmFONT_IS_FONT,
-						      XmFONTLIST_DEFAULT_TAG));
+    newEntry = XmFontListEntryLoad(display,
+                                   full_entry, XmFONT_IS_FONT, XmFONTLIST_DEFAULT_TAG);
+    newFontList = XmFontListAppendEntry(oldFontList, newEntry);
     XtFree(fn);
     return newFontList;
 }
@@ -1758,7 +1833,7 @@ _XmCvtStringToXmFontList(Display *display,
     {
 	if (to->addr == NULL)
 	{
-	    to->addr = (XtPointer)&newFontList;
+	    to->addr = (XPointer)&newFontList;
 	    to->size = sizeof(XmFontList);
 	}
 	else
@@ -1874,17 +1949,13 @@ _XmCvtStringToCardinal(Display *display,
 		    (String *)NULL, (Cardinal *)NULL);
 	}
 
-#ifdef	HAVE_STRTOUL
 	value = strtoul((char *)from->addr, &end, 10);
-#else
-	value = (Cardinal)strtol((char *)from->addr, &end, 10);
-#endif
 
 	if (*end == '\0')
 	{
 		if (to->addr == NULL)
 		{
-			to->addr = (XtPointer)&value;
+			to->addr = (XPointer)&value;
 			to->size = sizeof(Cardinal);
 		}
 		else
@@ -1924,7 +1995,7 @@ _XmCvtStringToKeySym(Display *d, XrmValue *args, Cardinal *nargs,
     {
 	if (to->addr == NULL)
 	{
-	    to->addr = (XtPointer)&k;
+	    to->addr = (XPointer)&k;
 	    to->size = sizeof(k);
 	    return True;
 	}
@@ -1940,7 +2011,7 @@ _XmCvtStringToKeySym(Display *d, XrmValue *args, Cardinal *nargs,
 	    {
 		XtDisplayStringConversionWarning(d, (char *)from->addr,
 						 XmRKeySym);
-		DEBUGOUT(XdbDebug(__FILE__, NULL,
+		DEBUGOUT(_LtDebug(__FILE__, NULL,
 				  "_XmCvtStringToKeySym fail at line %d\n",
 				  __LINE__));
 		return False;
@@ -1950,11 +2021,12 @@ _XmCvtStringToKeySym(Display *d, XrmValue *args, Cardinal *nargs,
 
     XtDisplayStringConversionWarning(d, (char *)from->addr, XmRKeySym);
 
-    DEBUGOUT(XdbDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 		      "_XmCvtStringToKeySym fail at line %d\n", __LINE__));
     return False;
 }
 
+
 static Boolean
 _XmCvtStringToResIndPosition(Display *display,
 			     XrmValue *args,
@@ -1972,14 +2044,14 @@ _XmCvtStringToResIndPosition(Display *display,
 		     (String *)NULL, (Cardinal *)NULL);
 
     pos = (Position)_XmConvertUnits(*(Screen **)args[0].addr,
-				    (int)*(XtPointer *)args[1].addr,
+				    (int)(long)*(XtPointer *)args[1].addr,
 				    *(unsigned char *)args[2].addr,
 				    atoi(from->addr),
 				    XmPIXELS);
 
     if (to->addr == NULL)
     {
-	to->addr = (XtPointer)&pos;
+	to->addr = (XPointer)&pos;
 	to->size = sizeof pos;
     }
     else
@@ -1987,7 +2059,7 @@ _XmCvtStringToResIndPosition(Display *display,
 	if (to->size < sizeof pos)
 	{
 	    XtDisplayStringConversionWarning(display, (char *)from->addr,
-		(int)*(XtPointer *)args[1].addr == XmHORIZONTAL
+		(int)(long)*(XtPointer *)args[1].addr == XmHORIZONTAL
 		? XmRHorizontalPosition : XmRVerticalPosition);
 	    return False;
 	}
@@ -1998,6 +2070,7 @@ _XmCvtStringToResIndPosition(Display *display,
     return True;
 }
 
+
 static Boolean
 _XmCvtStringToResIndDimension(Display *display,
 			      XrmValue *args,
@@ -2015,14 +2088,14 @@ _XmCvtStringToResIndDimension(Display *display,
 		     (String *)NULL, (Cardinal *)NULL);
 
     dim = (Dimension)_XmConvertUnits(*(Screen **)args[0].addr,
-				     (int)*(XtPointer *)args[1].addr,
+				     (int)(long)*(XtPointer *)args[1].addr,
 				     *(unsigned char *)args[2].addr,
 				     atoi(from->addr),
 				     XmPIXELS);
 
     if (to->addr == NULL)
     {
-	to->addr = (XtPointer)&dim;
+	to->addr = (XPointer)&dim;
 	to->size = sizeof dim;
     }
     else
@@ -2030,7 +2103,7 @@ _XmCvtStringToResIndDimension(Display *display,
 	if (to->size < sizeof dim)
 	{
 	    XtDisplayStringConversionWarning(display, (char *)from->addr,
-		(int)*(XtPointer *)args[1].addr == XmHORIZONTAL
+		(int)(long)*(XtPointer *)args[1].addr == XmHORIZONTAL
 		? XmRHorizontalDimension : XmRVerticalDimension);
 	    return False;
 	}
@@ -2041,6 +2114,7 @@ _XmCvtStringToResIndDimension(Display *display,
     return True;
 }
 
+
 static Boolean
 _XmCvtStringToResIndInt(Display *display,
 			XrmValue *args,
@@ -2058,14 +2132,14 @@ _XmCvtStringToResIndInt(Display *display,
 		     (String *)NULL, (Cardinal *)NULL);
 
     pos = _XmConvertUnits(*(Screen **)args[0].addr,
-			  (int)*(XtPointer *)args[1].addr,
+			  (int)(long)*(XtPointer *)args[1].addr,
 			  *(unsigned char *)args[2].addr,
 			  atoi(from->addr),
 			  XmPIXELS);
 
     if (to->addr == NULL)
     {
-	to->addr = (XtPointer)&pos;
+	to->addr = (XPointer)&pos;
 	to->size = sizeof pos;
     }
     else
@@ -2073,7 +2147,7 @@ _XmCvtStringToResIndInt(Display *display,
 	if (to->size < sizeof pos)
 	{
 	    XtDisplayStringConversionWarning(display, (char *)from->addr,
-		(int)*(XtPointer *)args[1].addr == XmHORIZONTAL
+		(int)(long)*(XtPointer *)args[1].addr == XmHORIZONTAL
 		? XmRHorizontalInt : XmRVerticalInt);
 	    return False;
 	}
@@ -2084,6 +2158,7 @@ _XmCvtStringToResIndInt(Display *display,
     return True;
 }
 
+
 static Boolean
 _XmCvtStringToWidget(	Display *display,
 			XrmValue *args,
@@ -2112,7 +2187,7 @@ _XmCvtStringToWidget(	Display *display,
 
 	if (to->addr == NULL)
 	{
-	    to->addr = (XtPointer)&child;
+	    to->addr = (XPointer)&child;
 	    to->size = sizeof(Widget);
 	}
 	else
@@ -2138,6 +2213,7 @@ _XmCvtStringToWidget(	Display *display,
     return True;
 }
 
+
 static Boolean
 _XmCvtStringToWindow(Display *display,
 		     XrmValue *args,
@@ -2164,6 +2240,7 @@ _XmCvtStringToWindow(Display *display,
     return True;
 }
 
+
 static Boolean
 _XmCvtStringToBooleanDimension( Display *display,
 				XrmValue *args,
@@ -2189,7 +2266,7 @@ _XmCvtStringToBooleanDimension( Display *display,
 	if (isdigit(str[0])) {
 	    preval = atoi(from->addr);
 	    value = (Dimension)_XmConvertUnits(*(Screen **)args[0].addr,
-					       (int)*(XtPointer *)args[1].addr,
+					       (int)(long)*(XtPointer *)args[1].addr,
 					       *(unsigned char *)args[2].addr,
 					       preval,
 					       XmPIXELS);
@@ -2211,7 +2288,7 @@ _XmCvtStringToBooleanDimension( Display *display,
 	}
 
 	if (to->addr == NULL) {
-	    to->addr = (XtPointer)&value;
+	    to->addr = (XPointer)&value;
 	    to->size = sizeof(value);
 	} else {
 	    if (to->size >= sizeof(value)) {
@@ -2231,6 +2308,7 @@ _XmCvtStringToBooleanDimension( Display *display,
     return True;
 }
 
+
 static Boolean
 _XmCvtStringToChar( Display *display,
 		    XrmValue *args,
@@ -2257,6 +2335,7 @@ _XmCvtStringToChar( Display *display,
     return True;
 }
 
+
 static Boolean
 _XmCvtStringToTextPosition( Display *display,
 			    XrmValue *args,
@@ -2269,7 +2348,7 @@ _XmCvtStringToTextPosition( Display *display,
 
     tp = atol( from->addr);
     if (to->addr == NULL) {
-	to->addr = (XtPointer)&tp;
+	to->addr = (XPointer)&tp;
 	to->size = sizeof tp;
     } else {
 	if (to->size < sizeof tp) {
@@ -2284,6 +2363,7 @@ _XmCvtStringToTextPosition( Display *display,
     return True;
 }
 
+
 static Boolean
 _XmCvtStringToTopItemPosition( Display *display,
 			       XrmValue *args,
@@ -2296,7 +2376,7 @@ _XmCvtStringToTopItemPosition( Display *display,
 
     tip = atoi( from->addr);
     if (to->addr == NULL) {
-	to->addr = (XtPointer)&tip;
+	to->addr = (XPointer)&tip;
 	to->size = sizeof tip;
     } else {
 	if (to->size < sizeof tip) {
@@ -2311,6 +2391,7 @@ _XmCvtStringToTopItemPosition( Display *display,
     return True;
 }
 
+
 /* Converter for various tables of comma-separated strings,
  * with those strings converted each in their own way.
  */
@@ -2336,7 +2417,7 @@ _XmCvtStringToSomeTable( Display *display,
     nitems = 0;
     item = NULL;
     escaped = anyescaped = False;
-    tabtype = (int)*(XtPointer *)args[0].addr;
+    tabtype = (int)(long)*(XtPointer *)args[0].addr;
     for (p = from->addr;; p++)
     {
 	if (escaped)
@@ -2428,7 +2509,7 @@ _XmCvtStringToSomeTable( Display *display,
 
 	    case ST_XM_STRING_TABLE:
 		table[nitems] =
-		    XmStringCreateLtoR(str, XmFONTLIST_DEFAULT_TAG);
+		    (XtPointer)XmStringCreateLtoR(str, XmFONTLIST_DEFAULT_TAG);
 		XtFree(str);
 	    }
 
@@ -2497,7 +2578,7 @@ _XmCvtStringToSomeTable( Display *display,
     }
 
     if (to->addr == NULL) {
-	to->addr = (XtPointer)&table;
+	to->addr = (XPointer)&table;
 	to->size = sizeof table;
     } else {
 	if (to->size < sizeof table) {
@@ -2515,6 +2596,7 @@ _XmCvtStringToSomeTable( Display *display,
     return True;
 }
 
+
 static void
 destroy_font_list(XtAppContext app, XrmValue *to,
 		  XtPointer converer_data, XrmValue *args,
@@ -2523,6 +2605,7 @@ destroy_font_list(XtAppContext app, XrmValue *to,
     XmFontListFree(*(XmFontList *)to->addr);
 }
 
+
 static void
 destroy_table(XtAppContext app, XrmValue *to,
 	      XtPointer converer_data, XrmValue *args,
@@ -2531,6 +2614,7 @@ destroy_table(XtAppContext app, XrmValue *to,
     XtFree(*(char **)to->addr);
 }
 
+
 static void
 destroy_string_table(XtAppContext app, XrmValue *to,
 		     XtPointer converer_data, XrmValue *args,
@@ -2544,6 +2628,7 @@ destroy_string_table(XtAppContext app, XrmValue *to,
     XtFree((char *)table);
 }
 
+
 static void
 destroy_xm_string_table(XtAppContext app, XrmValue *to,
 		     XtPointer converer_data, XrmValue *args,
@@ -2557,6 +2642,7 @@ destroy_xm_string_table(XtAppContext app, XrmValue *to,
     XtFree((char *)table);
 }
 
+
 static void
 get_unit_type(Widget w, Cardinal *size, XrmValue *val)
 {
@@ -2567,18 +2653,20 @@ get_unit_type(Widget w, Cardinal *size, XrmValue *val)
     ut = _XmGetUnitType(w);
 }
 
-#if	XmVERSION > 1
+
+#if XmVERSION > 1
 /*
  * XmConvertStringToUnits converts a string specification value and returns
  * the converted value as the return value from the function. This function
  * uses the specified screen's resolution to compute the number of units for
  * the string specification.
  */
-int
+extern int
 XmConvertStringToUnits(Screen *screen, String spec, int orientation,
 	int to_type, XtEnum *parse_error)
 {
 	/* FIX ME not implemented yet */
+        _XmWarning(NULL, "XmConvertStringToUnits() is not implemented yet!\n");
 
 	if (screen == NULL)
 		return 0;
@@ -2604,6 +2692,7 @@ XmConvertStringToUnits(Screen *screen, String spec, int orientation,
     return 0;
 }
 
+
 static Boolean
 _XmCvtStringToTabList(Display *display,
 		       XrmValue *args,
@@ -2615,14 +2704,46 @@ _XmCvtStringToTabList(Display *display,
 	return False;
 }
 
+
 static Boolean
 _XmCvtStringToRenderTable(Display *display,
-		       XrmValue *args,
-		       Cardinal *num_args,
-		       XrmValue *from,
-		       XrmValue *to,
-		       XtPointer *converter_data)
+                          XrmValue *args,
+                          Cardinal *num_args,
+                          XrmValue *from,
+                          XrmValue *to,
+                          XtPointer *converter_data)
 {
+
 	return False;
 }
-#endif
+
+
+extern unsigned int
+XmCvtXmStringToByteStream(XmString string,
+                          unsigned char **prop_return)
+{
+        _XmWarning(NULL, "XmConvertStringToUnits() is not implemented yet!\n");
+	return 0;
+}
+
+
+
+extern XmString 
+XmCvtByteStreamToXmString(unsigned char *property)
+{
+      _XmWarning(NULL, "XmCvtByteStreamToXmString() is not implemented yet!\n");
+      return NULL;
+}
+
+
+extern int
+XmCvtXmStringTableToTextProperty (Display *display,
+                                  XmStringTable string_table,
+                                  int count,
+                                  XmICCEncodingStyle style,
+                                  XTextProperty *text_prop_return)
+{
+        _XmWarning(NULL, "XmCvtXmStringTableToTextProperty() is not implemented yet!\n");
+	return 0;
+}				      
+#endif /* XmVERSION > 1 */
