@@ -1,8 +1,9 @@
 /**
  *
- * $Id: Scale.c,v 1.36 1999/05/11 14:07:40 strauman Exp $
+ * $Id: Scale.c,v 1.49 2001/09/21 08:55:14 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,11 +23,16 @@
  *
  **/
 
-static const char rcsid[] = "$Id: Scale.c,v 1.36 1999/05/11 14:07:40 strauman Exp $";
+static const char rcsid[] = "$Id: Scale.c,v 1.49 2001/09/21 08:55:14 amai Exp $";
 
 #include <LTconfig.h>
-#include <XmI/XmI.h>
 
+#include <stdlib.h>
+#include <stdio.h>
+#include <limits.h>
+#include <math.h>
+
+#include <XmI/XmI.h>
 #include <Xm/XmP.h>
 #include <Xm/ScaleP.h>
 #include <Xm/LabelGP.h>
@@ -36,12 +42,8 @@ static const char rcsid[] = "$Id: Scale.c,v 1.36 1999/05/11 14:07:40 strauman Ex
 #include <Xm/VendorSP.h>
 #include <Xm/VendorSEP.h>
 
-#include <stdio.h>
-#include <limits.h>
-
 #include <XmI/DebugUtil.h>
 
-/* Forward Declarations */
 
 #define USE_LAYOUT	1
 
@@ -49,7 +51,7 @@ static const char rcsid[] = "$Id: Scale.c,v 1.36 1999/05/11 14:07:40 strauman Ex
 #define CHILD_SB	1
 
 /* FIX ME/BUGS
- *   - higlight
+ *   - highlight
  */
 
 /*
@@ -76,32 +78,22 @@ static const char rcsid[] = "$Id: Scale.c,v 1.36 1999/05/11 14:07:40 strauman Ex
 #define Scale_ShadowThickness(x) MGR_ShadowThickness(x)
 
 static void class_initialize(void);
-
 static void class_part_initialize(WidgetClass w_class);
-
 static void initialize(Widget request, Widget new_w,
 		       ArgList args, Cardinal *num_args);
-
 static void destroy(Widget w);
-
 static void realize(Widget w, XtValueMask *value_mask,
 		    XSetWindowAttributes *attributes);
-
 static Boolean set_values(Widget current, Widget request, Widget new_w,
 			  ArgList args, Cardinal *num_args);
-
 static XtGeometryResult query_geometry(Widget w,
 				       XtWidgetGeometry *request,
 				       XtWidgetGeometry *reply);
-
 static XtGeometryResult geometry_manager(Widget w,
 					 XtWidgetGeometry *request,
 					 XtWidgetGeometry *reply);
-
 static void expose(Widget w, XEvent *event, Region region);
-
 static void resize(Widget w);
-
 static void change_managed(Widget w);
 
 #if 0
@@ -111,36 +103,28 @@ static void insert_child(Widget w);
 static XmKidGeometry _XmScalePreferredSize(Widget scale, Widget child,
 					   XtWidgetGeometry *childgeom,
 					   Dimension *w, Dimension *ht);
-
 static XtGeometryResult _XmScaleGeomRequest(Widget scale,
 					    Dimension *wd, Dimension *ht);
-
 static void _XmScaleLayout(Widget scale, XmKidGeometry boxes,
 			   Widget child, XtWidgetGeometry *childgeom,
 			   Dimension curw, Dimension curh);
-
 static void _XmScaleConfigureChildren(Widget scale,
 				      Widget child,
 				      XmKidGeometry boxes);
-
 static int _XmScaleConvertWidthToSliderSize(Widget w);
-
 static int _XmScaleConvertSCBValueToScaleValue(Widget w, int value);
-
 static int _XmScaleConvertScaleValueToSCBValue(Widget w);
-
+static void _XmScaleConvertScaleIncrementToSCBIncrements(Widget w,
+							 int* inc,
+							 int* page_inc);
 static void _ScaleValueChanged(Widget sb, XtPointer cd, XtPointer data);
-
 static void _ScaleDrag(Widget sb, XtPointer cd, XtPointer data);
-
 static void computeValueSize(Widget w);
-
 static void showValue(Widget w, int scb_value, int scale_value);
 
 #if 0
 static void GetFocus(Widget w, XEvent *event,
 		     String *params, Cardinal *num_params);
-
 static void LoseFocus(Widget w, XEvent *event,
 		      String *params, Cardinal *num_params);
 #endif
@@ -203,7 +187,7 @@ static XtResource resources[] =
     {
 	XmNdecimalPoints, XmCDecimalPoints, XmRShort,
 	sizeof(short), Offset(decimal_points),
-	XmRImmediate, (XtPointer)0
+	XmRImmediate, (XtPointer)(short)0
     },
     {
 	XmNscaleWidth, XmCScaleWidth, XmRHorizontalDimension,
@@ -238,7 +222,7 @@ static XtResource resources[] =
 #if XmVERSION > 1
     {
 	XmNeditable, XmCEditable, XmRBoolean,
-	sizeof(int), Offset(editable),
+	sizeof(Boolean), Offset(editable),
 	XmRImmediate, (XtPointer)True
     },
 #endif
@@ -279,7 +263,7 @@ static XtActionsRec actions[] =
     {"FocusOut", LoseFocus}
 };
 #endif
-/* *INDENT-OFF* */
+
 static XmBaseClassExtRec _XmScaleCoreClassExtRec = {
     /* next_extension            */ NULL,
     /* record_type               */ NULLQUARK,                             
@@ -386,17 +370,19 @@ XmScaleClassRec xmScaleClassRec =
 	/* extension */ NULL,
     },
 };
-/* *INDENT-ON* */
+
 
 
 WidgetClass xmScaleWidgetClass = (WidgetClass)&xmScaleClassRec;
 
+
 static void
 class_initialize(void)
 {
     _XmScaleCoreClassExtRec.record_type = XmQmotif;
 }
 
+
 static void
 class_part_initialize(WidgetClass widget_class)
 {
@@ -427,6 +413,7 @@ class_part_initialize(WidgetClass widget_class)
     _XmFastSubclassInit(widget_class, XmSCALE_BIT);
 }
 
+
 static void
 CreateForegroundGC(Widget w)
 {
@@ -447,6 +434,7 @@ CreateForegroundGC(Widget w)
     Scale_ForegroundGC(w) = XtGetGC(w, mask, &values);
 }
 
+
 static void
 initialize(Widget request, Widget new_w,
 	   ArgList args, Cardinal *num_args)
@@ -460,7 +448,7 @@ initialize(Widget request, Widget new_w,
     Dimension wd, ht;
     */
 
-    DEBUGOUT(XdbDebug(__FILE__, new_w,
+    DEBUGOUT(_LtDebug(__FILE__, new_w,
 		      "%s:initialize(%d) - %i args\n"
 		      "\trequest X %5i Y %5i W %5i H %5i\n"
 		      "\t  new_w X %5i Y %5i W %5i H %5i\n",
@@ -470,8 +458,22 @@ initialize(Widget request, Widget new_w,
 		      XtWidth(request), XtHeight(request),
 		      XtX(new_w), XtY(new_w),
 		      XtWidth(new_w), XtHeight(new_w)));
-    DEBUGOUT(XdbPrintArgList(__FILE__, new_w, args, *num_args, False));
+    DEBUGOUT(_LtDebugPrintArgList(__FILE__, new_w, args, *num_args, False));
 
+    if (Scale_ScaleWidth(new_w) == 0)
+    {
+    	/* rws 22 Dec 1999
+    	   scale/test18 scale/test16
+    	 */
+	if (Scale_Orientation(new_w) == XmHORIZONTAL)
+	{
+	    Scale_ScaleWidth(new_w) = XtWidth(request);
+    	}
+    	else
+	{
+	    Scale_ScaleWidth(new_w) = XtHeight(request);
+    	}
+    }
     if (Scale_Value(new_w) == INT_MAX)
     {
 	if (Scale_Minimum(new_w) >= 0)
@@ -538,7 +540,7 @@ initialize(Widget request, Widget new_w,
     XtSetArg(argl[argc], XmNhighlightOnEnter,
 	     Scale_HighlightOnEnter(new_w)); argc++;
 	/* T. Straumann:  M*TIF enforces 0 borderWidth for scrollBar */
-	XtSetArg(argl[argc], XmNborderWidth, 0); argc++;
+    XtSetArg(argl[argc], XmNborderWidth, 0); argc++;
 
     sb = XmCreateScrollBar(new_w, "Scrollbar", argl, argc);
 
@@ -569,24 +571,27 @@ initialize(Widget request, Widget new_w,
 #if 0
     wd = ht = 0;
     boxes = _XmScalePreferredSize(new_w, NULL, NULL, &wd, &ht);
-
     _XmScaleGeomRequest(new_w, &wd, &ht);
-
     _XmScaleLayout(new_w, boxes, NULL, NULL, wd, ht);
-
     _XmScaleConfigureChildren(new_w, NULL, boxes);
-
     XtFree((char *)boxes);
 #endif
 }
 
+
 static void
 destroy(Widget w)
 {
+
+    if (Scale_Title(w))
+     {
+         XmStringFree(Scale_Title(w));
+     }
     XmFontListFree(Scale_FontList(w));
     XtDestroyGC(Scale_ForegroundGC(w));
 }
 
+
 /*
  * called when the user changes a resource
  */
@@ -598,12 +603,12 @@ set_values(Widget old, Widget request, Widget new_w,
 	   ArgList args, Cardinal *num_args)
 {
     Boolean refresh = False;
-    Arg argl[6];
+    Arg argl[8];
     int argc;
     Widget sb, lab;
     int resize = False;
 
-    DEBUGOUT(XdbDebug(__FILE__, new_w, "XmScale set_values()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, new_w, "XmScale set_values()\n"));
 
     sb = ((XmScaleWidget)new_w)->composite.children[CHILD_SB];
     lab = ((XmScaleWidget)new_w)->composite.children[CHILD_LAB];
@@ -632,7 +637,6 @@ set_values(Widget old, Widget request, Widget new_w,
 	}
 
 	XtReleaseGC(new_w, Scale_ForegroundGC(new_w));
-
 	CreateForegroundGC(new_w);
 
 	refresh = True;
@@ -670,22 +674,25 @@ set_values(Widget old, Widget request, Widget new_w,
 	Scale_Value(new_w) != Scale_Value(old))
     {
 	int newval;
+	int inc, page_inc;
+
+
+	newval = _XmScaleConvertScaleValueToSCBValue(new_w);
+	_XmScaleConvertScaleIncrementToSCBIncrements(new_w, &inc, &page_inc);
 
 	argc = 0;
 	XtSetArg(argl[argc], XmNorientation, Scale_Orientation(new_w)); argc++;
 	XtSetArg(argl[argc], XmNprocessingDirection,
 		 Scale_ProcessingDirection(new_w)); argc++;
-
-	newval = _XmScaleConvertScaleValueToSCBValue(new_w);
-
 	XtSetArg(argl[argc], XmNvalue, newval); argc++;
+	XtSetArg(argl[argc], XmNincrement, inc); argc++;
+	XtSetArg(argl[argc], XmNpageIncrement, page_inc); argc++;
 	XtSetArg(argl[argc], XmNshadowThickness,
 		 Scale_ShadowThickness(new_w)); argc++;
 	XtSetArg(argl[argc], XmNhighlightThickness,
 		 Scale_HighlightThickness(new_w)); argc++;
 	XtSetArg(argl[argc], XmNhighlightOnEnter,
 		 Scale_HighlightOnEnter(new_w)); argc++;
-
 	XtSetValues(sb, argl, argc);
 
 	refresh = True;
@@ -707,8 +714,12 @@ set_values(Widget old, Widget request, Widget new_w,
 	Scale_ScaleHeight(new_w) != Scale_ScaleHeight(old))
     {
 	argc = 0;
-	XtSetArg(argl[argc], XmNwidth, Scale_ScaleWidth(new_w)); argc++;
-	XtSetArg(argl[argc], XmNheight, Scale_ScaleHeight(new_w)); argc++;
+	if (Scale_ScaleWidth(new_w) != Scale_ScaleWidth(old) ) {
+	    XtSetArg(argl[argc], XmNwidth, Scale_ScaleWidth(new_w)); argc++;
+	}
+	if ( Scale_ScaleHeight(new_w) != Scale_ScaleHeight(old) ) {
+	    XtSetArg(argl[argc], XmNheight, Scale_ScaleHeight(new_w)); argc++;
+	}
 
 	XtSetValues(sb, argl, argc);
        
@@ -766,9 +777,7 @@ set_values(Widget old, Widget request, Widget new_w,
     boxes = _XmScalePreferredSize(new_w, NULL, NULL, &wd, &ht);
 
     _XmScaleGeomRequest(new_w, &wd, &ht);
-
     _XmScaleLayout(new_w, boxes, NULL, NULL, wd, ht);
-
     _XmScaleConfigureChildren(new_w, NULL, boxes);
 
     XtFree((char *)boxes);
@@ -777,12 +786,13 @@ set_values(Widget old, Widget request, Widget new_w,
     return refresh;
 }
 
+
 static void
 expose(Widget w,
        XEvent *event,
        Region region)
 {
-    DEBUGOUT(XdbDebug(__FILE__, w, "XmScale expose()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "XmScale expose()\n"));
 
     _XmRedisplayGadgets(w, event, region);
 
@@ -794,6 +804,7 @@ expose(Widget w,
     }
 }
 
+
 /*
  * called when our parent wants to find out how we would like to look.  It
  * doesn't have to honor our preference, though.
@@ -808,12 +819,10 @@ query_geometry(Widget w, XtWidgetGeometry *request, XtWidgetGeometry *reply)
 
 #define Wants(x)	((wants.request_mode & x) == x)
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "XmScale %s QueryGeometry\n", XtName(w)));
+    DEBUGOUT(_LtDebug(__FILE__, w, "XmScale %s QueryGeometry\n", XtName(w)));
 
     wants = *request;
-
     *reply = *request;
-
     reply->request_mode = 0;
 
     if (Wants(CWWidth))
@@ -858,7 +867,7 @@ query_geometry(Widget w, XtWidgetGeometry *request, XtWidgetGeometry *reply)
     XtWidgetGeometry wants;
     Dimension wd, ht;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "XmScale %s QueryGeometry\n", XtName(w)));
+    DEBUGOUT(_LtDebug(__FILE__, w, "XmScale %s QueryGeometry\n", XtName(w)));
 
     wants = *request;
 
@@ -871,6 +880,7 @@ query_geometry(Widget w, XtWidgetGeometry *request, XtWidgetGeometry *reply)
 #endif
 }
 
+
 /*
  * called when our parent is resizing us.  We have no choice but to obey.
  */
@@ -880,7 +890,7 @@ resize(Widget w)
     XmKidGeometry boxes;
     Dimension wd, ht;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "Scale %s Resize: x %d y %d w %d h %d\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "Scale %s Resize: x %d y %d w %d h %d\n",
 		      XtName(w), XtX(w), XtY(w), XtWidth(w), XtHeight(w)));
 
     Scale_SliderSize(w) = _XmScaleConvertWidthToSliderSize(w);
@@ -896,6 +906,7 @@ resize(Widget w)
     XtFree((char *)boxes);
 }
 
+
 /*
  * called when one of our children wants to change.  We control whether
  * the child can, or not
@@ -909,7 +920,7 @@ geometry_manager(Widget w, XtWidgetGeometry *request, XtWidgetGeometry *reply)
     XmKidGeometry boxes;
     XtWidgetGeometry wants;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "XmScale geometry_manager()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "XmScale geometry_manager()\n"));
 
     wants = *request;
 
@@ -932,8 +943,7 @@ geometry_manager(Widget w, XtWidgetGeometry *request, XtWidgetGeometry *reply)
     _XmScaleGeomRequest(XtParent(w), &wd, &ht);
 
     *reply = *request;
-
-    reply->request_mode = CWWidth|CWHeight;
+    reply->request_mode &= CWWidth|CWHeight;
 
     if (Wants(CWWidth) && Wants(CWHeight) &&
 	wants.width == reply->width && wants.height == reply->height)
@@ -957,10 +967,19 @@ geometry_manager(Widget w, XtWidgetGeometry *request, XtWidgetGeometry *reply)
 	return XtGeometryYes;
     }
 
+    if (Wants(CWWidth) && wants.width == reply->width)
+    {
+    	reply->request_mode &= ~CWWidth;
+    }
+    if (Wants(CWHeight) && wants.height == reply->height)
+    {
+    	reply->request_mode &= ~CWHeight;
+    }
     return XtGeometryAlmost;
 #undef Wants
 }
 
+
 /*
  * called when our Window is allocated.  We may want to change our layout,
  * and we can ask our parent to allow this
@@ -974,7 +993,7 @@ realize(Widget w, XtValueMask *value_mask, XSetWindowAttributes *attributes)
     XmKidGeometry boxes;
     */
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "XmScale realize()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "XmScale realize()\n"));
 
 #define superclass (&xmManagerClassRec)
     (*superclass->core_class.realize) (w, value_mask, attributes);
@@ -987,15 +1006,14 @@ realize(Widget w, XtValueMask *value_mask, XSetWindowAttributes *attributes)
     pht = ht;
 
     _XmScaleGeomRequest(w, &wd, &ht);
-
     _XmScaleLayout(w, boxes, NULL, NULL, pwd, pht);
-
     _XmScaleConfigureChildren(w, NULL, boxes);
 
     XtFree((char *)boxes);
 #endif
 }
 
+
 /*
  * one of our children has become managed or unmanaged.  We need to relayout
  */
@@ -1005,7 +1023,7 @@ change_managed(Widget w)
     Dimension wd, ht;
     XmKidGeometry boxes;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "XmScale change_managed()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "XmScale change_managed()\n"));
 
     wd = ht = 0;
     boxes = _XmScalePreferredSize(w, NULL, NULL, &wd, &ht);
@@ -1021,6 +1039,7 @@ change_managed(Widget w)
     _XmNavigChangeManaged(w);
 }
 
+
 #if 0
 /*
  * a child has been added
@@ -1032,13 +1051,14 @@ insert_child(Widget w)
     (*superclass->composite_class.insert_child) (w);
 #undef  superclass
 
-    DEBUGOUT(XdbDebug(__FILE__, w,
+    DEBUGOUT(_LtDebug(__FILE__, w,
 		      "Scale %s: insert child %s\n",
 		      XtName(XtParent(w)), XtName(w)));
 }
 #endif
 
-Widget
+
+extern Widget
 XmCreateScale(Widget parent,
 	      char *name,
 	      Arg *arglist,
@@ -1051,14 +1071,16 @@ XmCreateScale(Widget parent,
 			  argcount);
 }
 
-void
+
+extern void
 XmScaleGetValue(Widget widget,
 		int *value_return)
 {
     *value_return = Scale_Value(widget);
 }
 
-void
+
+extern void
 XmScaleSetValue(Widget widget,
 		int value)
 {
@@ -1085,6 +1107,7 @@ XmScaleSetValue(Widget widget,
     }
 }
 
+
 static void
 valueToString(Widget w, char *buf)
 {
@@ -1642,6 +1665,7 @@ printf("COMPUTED %d %d : %d %d\n", curw, cury, incw, inch);
     return boxes;
 }
 
+
 /*
  * if we can, change our size to match
  */
@@ -1655,7 +1679,7 @@ _XmScaleGeomRequest(Widget scale, Dimension *wd, Dimension *ht)
     request.width = *wd;
     request.height = *ht;
 
-    DEBUGOUT(XdbDebug(__FILE__, scale, "_XmScaleGeomRequest(ing) (%d %d)\n",
+    DEBUGOUT(_LtDebug(__FILE__, scale, "_XmScaleGeomRequest(ing) (%d %d)\n",
 		      *wd, *ht));
 
     result = _XmMakeGeometryRequest(scale, &request);
@@ -1671,12 +1695,13 @@ _XmScaleGeomRequest(Widget scale, Dimension *wd, Dimension *ht)
 	*ht = XtHeight(scale);
     }
 
-    DEBUGOUT(XdbDebug(__FILE__, scale, "_XmScaleLayout (%d %d) => %s\n",
-		      *wd, *ht, XdbGeometryResult2String(result)));
+    DEBUGOUT(_LtDebug(__FILE__, scale, "_XmScaleLayout (%d %d) => %s\n",
+		      *wd, *ht, _LtDebugGeometryResult2String(result)));
 
     return result;
 }
 
+
 static void
 _XmScaleLayout(Widget scale, XmKidGeometry boxes,
 	       Widget child, XtWidgetGeometry *childgeom,
@@ -1725,12 +1750,12 @@ _XmScaleLayout(Widget scale, XmKidGeometry boxes,
 	{
 	    for (i = 2; i < num_children; i++)
 	    {
-		boxes[i].box.width = (Dimension)((float)boxes[i].box.width /
-						 (float)curw *
-						 (float)XtWidth(scale));
+		boxes[i].box.width = (Dimension)((double)boxes[i].box.width /
+						 (double)curw *
+						 (double)XtWidth(scale));
 	    }
 	}
-#endif
+#endif /* 0 */
 
 	if ((delta = XtHeight(scale) - curh))
 	{
@@ -1818,11 +1843,11 @@ _XmScaleLayout(Widget scale, XmKidGeometry boxes,
 	if (XtWidth(scale) > curw)
 	{
 	    for (i = 2; i < num_children; i++)
-		boxes[i].box.height = (Dimension)((float)boxes[i].box.height /
-						  (float)curw *
-						  (float)XtWidth(scale));
+		boxes[i].box.height = (Dimension)((double)boxes[i].box.height /
+						  (double)curw *
+						  (double)XtWidth(scale));
 	}
-#endif
+#endif /* 0 */
 
 	if ((delta = XtWidth(scale) - curw))
 	{
@@ -1887,11 +1912,7 @@ _XmScaleConfigureChildren(Widget scale, Widget child, XmKidGeometry boxes)
     _XmSetKidGeo(boxes, child);
 
     Scale_SliderSize(scale) = _XmScaleConvertWidthToSliderSize(scale);
-    inc = (int)((float)(SCB_MAX - SCB_MIN - Scale_SliderSize(scale)) /
-		(float)(Scale_Maximum(scale) - Scale_Minimum(scale)) +
-		0.5);
-    inc = _XmMax(inc, 1);	/* FIX ME */
-    p_inc = inc * Scale_ScaleMultiple(scale);
+    _XmScaleConvertScaleIncrementToSCBIncrements(scale, &inc, &p_inc);
 
     XmScrollBarSetValues(boxes[CHILD_SB].kid,
 			 _XmScaleConvertScaleValueToSCBValue(scale),
@@ -1899,6 +1920,7 @@ _XmScaleConfigureChildren(Widget scale, Widget child, XmKidGeometry boxes)
 			 inc, p_inc, False);
 }
 
+
 static void
 computeValueSize(Widget w)
 {
@@ -1938,6 +1960,7 @@ computeValueSize(Widget w)
         Scale_FontStruct(w)->max_bounds.descent;
 }
 
+
 static void
 showValue(Widget w, int scb_value, int scale_value)
 {
@@ -2012,6 +2035,7 @@ showValue(Widget w, int scb_value, int scale_value)
     }
 }
 
+
 static void
 _ScaleValueChanged(Widget sb, XtPointer cd, XtPointer data)
 {
@@ -2039,6 +2063,7 @@ _ScaleValueChanged(Widget sb, XtPointer cd, XtPointer data)
     }
 }
 
+
 static void
 _ScaleDrag(Widget sb, XtPointer cd, XtPointer data)
 {
@@ -2047,7 +2072,7 @@ _ScaleDrag(Widget sb, XtPointer cd, XtPointer data)
     int scale_value;
 
 #if XmVERSION > 1
-    if (! Scale_Editable(sb))
+    if (! Scale_Editable(XtParent(sb)))
 	return;
 #endif
 
@@ -2070,13 +2095,14 @@ _ScaleDrag(Widget sb, XtPointer cd, XtPointer data)
     }
 }
 
+
 #if 0
 static void
 GetFocus(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
     XmScrollBarWidget sb;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "GetFocus\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "GetFocus\n"));
 
     sb = (XmScrollBarWidget)(((XmScaleWidget)w)->composite.children[CHILD_SB]);
 
@@ -2084,19 +2110,21 @@ GetFocus(Widget w, XEvent *event, String *params, Cardinal *num_params)
 		     params, *num_params);
 }
 
+
 static void
 LoseFocus(Widget w, XEvent *event, String *params, Cardinal *num_params)
 {
     XmScrollBarWidget sb;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "LoseFocus\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "LoseFocus\n"));
 
     sb = (XmScrollBarWidget)(((XmScaleWidget)w)->composite.children[CHILD_SB]);
 
     XtCallActionProc((Widget)sb, "PrimitiveFocusOut", event,
 		     params, *num_params);
 }
-#endif
+#endif /* 0 */
+
 
 static int
 _XmScaleConvertWidthToSliderSize(Widget w)
@@ -2127,9 +2155,9 @@ _XmScaleConvertWidthToSliderSize(Widget w)
 	    if (XtWidth(sb) == 2 * (ht + st))
 	    {
 		/* Note: M*tif 1.2.2 SIGFPE's on this -- PvH */
-		ret = (int)((float)(SCB_MAX - SCB_MIN) /
-			    (float)(Scale_Maximum(w) - Scale_Minimum(w)) *
-			    (float)HSLIDERSIZE);
+		ret = (int)((double)(SCB_MAX - SCB_MIN) /
+			    (double)(Scale_Maximum(w) - Scale_Minimum(w)) *
+			    (double)HSLIDERSIZE);
 	    }
 	    else if (XtWidth(sb) < HSLIDERSIZE)
 	    {
@@ -2169,29 +2197,62 @@ _XmScaleConvertWidthToSliderSize(Widget w)
     return ret;
 }
 
+
 static int
 _XmScaleConvertSCBValueToScaleValue(Widget w, int value)
 {
+    double roundarg;
+    int result;
+
+    DEBUGOUT(_LtDebug(__FILE__, w, "_XmScaleConvertSCBValueToScaleValue(,%i)\n",
+                       value));
     if ((SCB_MAX - SCB_MIN - Scale_SliderSize(w)) == 0)
     {
 	return Scale_Minimum(w);
     }
 
-    return (int)((float)(Scale_Maximum(w) - Scale_Minimum(w)) 
-		* (float)value 
-		/ (float)(SCB_MAX - SCB_MIN - Scale_SliderSize(w))
-		+ (float)Scale_Minimum(w) );
+    roundarg = (double)(Scale_Maximum(w) - Scale_Minimum(w)) 
+	     * (double)value 
+	     / (double)(SCB_MAX - SCB_MIN - Scale_SliderSize(w))
+	     + (double)Scale_Minimum(w);
+
+    result = (int)(roundarg + 0.5);
+
+    return result;
 }
 
+
 static int
 _XmScaleConvertScaleValueToSCBValue(Widget w)
 {
-    return (int)((float)(Scale_Value(w) - Scale_Minimum(w)) 
-		* (float)(SCB_MAX - SCB_MIN - Scale_SliderSize(w))
-		/ (float)(Scale_Maximum(w) - Scale_Minimum(w)) 
-		);
+
+    double roundarg;
+    int result;
+
+    DEBUGOUT(_LtDebug(__FILE__, w, "_XmScaleConvertScaleValueToSCBValue()\n"));
+    roundarg = (double)(Scale_Value(w) - Scale_Minimum(w)) 
+	     * (double)(SCB_MAX - SCB_MIN - Scale_SliderSize(w))
+	     / (double)(Scale_Maximum(w) - Scale_Minimum(w));
+    /* amai: is this the correct formula? 
+             looks like the old one in _XmScaleConvertSCBValueToScaleValue() */
+    result = (int)(roundarg);
+    return result;
 }
 
+
+static void
+_XmScaleConvertScaleIncrementToSCBIncrements(Widget w,
+					 int* inc,
+					 int* page_inc)
+{
+    *inc = (int)((double)(SCB_MAX - SCB_MIN - Scale_SliderSize(w)) /
+		 (double)(Scale_Maximum(w) - Scale_Minimum(w)) +
+		 0.5);
+    *inc = _XmMax(*inc, 1);	/* FIX ME */
+    *page_inc = *inc * Scale_ScaleMultiple(w);
+}
+
+
 static void
 _XmScaleProcessingDirectionDefault(Widget w, int offset, XrmValue *val)
 {
@@ -2207,6 +2268,5 @@ _XmScaleProcessingDirectionDefault(Widget w, int offset, XrmValue *val)
 	direction = XmMAX_ON_RIGHT;	/* FIX ME */
     }
 
-    val->addr = (XtPointer)&direction;
+    val->addr = (XPointer)&direction;
 }
-
