@@ -1,6 +1,6 @@
 /*
  *
- * $Id: ScrolledW.c,v 1.121 2000/11/15 15:03:24 amai Exp $
+ * $Id: ScrolledW.c,v 1.126 2001/07/27 18:51:57 dannybackx Exp $
  *
  * Copyright (C) 1996 Free Software Foundation, Inc.
  * Copyright (C) 1996-2000 LessTif Development Team
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: ScrolledW.c,v 1.121 2000/11/15 15:03:24 amai Exp $";
+static const char rcsid[] = "$Id: ScrolledW.c,v 1.126 2001/07/27 18:51:57 dannybackx Exp $";
 
 /*
  * Current status of changes in layout (Danny 18/4/1997) :
@@ -462,7 +462,7 @@ static void
 initialize(Widget request, Widget new_w,
 	   ArgList args, Cardinal *num_args)
 {
-    DEBUGOUT(XdbDebug(__FILE__, new_w,
+    DEBUGOUT(_LtDebug(__FILE__, new_w,
 		      "%s:initialize: %i args\n"
 		      "\trequest X %5i Y %5i W %5i H %5i\n"
 		      "\t  new_w X %5i Y %5i W %5i H %5i\n",
@@ -471,7 +471,7 @@ initialize(Widget request, Widget new_w,
 		      XtWidth(request), XtHeight(request),
 		      XtX(new_w), XtY(new_w),
 		      XtWidth(new_w), XtHeight(new_w)));
-    DEBUGOUT(XdbPrintArgList(__FILE__, new_w, args, *num_args, False));
+    DEBUGOUT(_LtDebugPrintArgList(__FILE__, new_w, args, *num_args, False));
 
     if (SW_ScrollBarPolicy(new_w) == (unsigned char)XmUNSPECIFIED)
     {
@@ -737,7 +737,7 @@ set_values(Widget old, Widget request, Widget new_w,
 {
     Boolean r = False;		/* Must I be redisplayed ? */
 
-    DEBUGOUT(XdbDebug(__FILE__, new_w,
+    DEBUGOUT(_LtDebug(__FILE__, new_w,
 		      "set_values: %i args\n"
 		      "\t    old X %5i Y %5i W %5i H %5i\n"
 		      "\trequest X %5i Y %5i W %5i H %5i\n"
@@ -749,7 +749,7 @@ set_values(Widget old, Widget request, Widget new_w,
 		      XtWidth(request), XtHeight(request),
 		      XtX(new_w), XtY(new_w),
 		      XtWidth(new_w), XtHeight(new_w)));
-    DEBUGOUT(XdbPrintArgList(__FILE__, new_w, args, *num_args, False));
+    DEBUGOUT(_LtDebugPrintArgList(__FILE__, new_w, args, *num_args, False));
 
 #define	NE(x)	(x(new_w) != x(old))
 
@@ -814,7 +814,7 @@ set_values(Widget old, Widget request, Widget new_w,
 
     if (NE(SW_WorkWindow))
     {
-	DEBUGOUT(XdbDebug0(__FILE__, new_w,
+	DEBUGOUT(_LtDebug0(__FILE__, new_w,
 			   "Work Window changed: from %s to %s.\n",
 			   SW_WorkWindow(old) != NULL
 				? XtName(SW_WorkWindow(old))
@@ -822,7 +822,7 @@ set_values(Widget old, Widget request, Widget new_w,
 			   SW_WorkWindow(new_w) != NULL
 				? XtName(SW_WorkWindow(new_w))
 				: "(null)"));
-	DEBUGOUT(XdbDebug0(__FILE__, new_w,
+	DEBUGOUT(_LtDebug0(__FILE__, new_w,
 			   "Work Window was: %dx%d now %dx%d.\n",
 			   SW_WorkWindow(old) != NULL
 				? XtWidth(SW_WorkWindow(old))
@@ -836,7 +836,7 @@ set_values(Widget old, Widget request, Widget new_w,
 			   SW_WorkWindow(new_w) != NULL
 				? XtHeight(SW_WorkWindow(new_w))
 				: 0));
-	DEBUGOUT(XdbDebug0(__FILE__, new_w, "... SW_VisualPolicy %s",
+	DEBUGOUT(_LtDebug0(__FILE__, new_w, "... SW_VisualPolicy %s",
 			   (SW_VisualPolicy(new_w) == XmCONSTANT)
 				? "XmCONSTANT"
 				: (SW_VisualPolicy(new_w) == XmVARIABLE)
@@ -845,13 +845,13 @@ set_values(Widget old, Widget request, Widget new_w,
 					   XmRESIZE_IF_POSSIBLE)
 						? "XmRESIZE_IF_POSSIBLE"
 						: "???"));
-	DEBUGOUT(XdbDebug0(__FILE__, new_w, " SW_ScrollBarPolicy %s",
+	DEBUGOUT(_LtDebug0(__FILE__, new_w, " SW_ScrollBarPolicy %s",
 			   (SW_ScrollBarPolicy(new_w) == XmSTATIC)
 			   ? "XmSTATIC"
 			   : (SW_ScrollBarPolicy(new_w) == XmAS_NEEDED)
 			   ? "XmAS_NEEDED"
 			   : "???"));
-	DEBUGOUT(XdbDebug0(__FILE__, new_w, " SW_ScrollPolicy %s\n",
+	DEBUGOUT(_LtDebug0(__FILE__, new_w, " SW_ScrollPolicy %s\n",
 			   (SW_ScrollPolicy(new_w) == XmAPPLICATION_DEFINED)
 			   ? "XmAPPLICATION_DEFINED"
 			   : (SW_ScrollPolicy(new_w) == XmAUTOMATIC)
@@ -912,7 +912,7 @@ resize(Widget w)
 {
     XmSWValues vals;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "Resize: x %d y %d w %d h %d\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "Resize: x %d y %d w %d h %d\n",
 		      XtX(w), XtY(w), XtWidth(w), XtHeight(w)));
 
     SW_FromResize(w) = True;
@@ -987,7 +987,7 @@ realize(Widget w, Mask *value_mask, XSetWindowAttributes *attributes)
     XmSWValues vals;
     */
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "%s:realize(%d) - %dx%d\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "%s:realize(%d) - %dx%d\n",
     	__FILE__, __LINE__,
     	XtWidth(w), XtHeight(w)));
 
@@ -1044,8 +1044,8 @@ query_geometry(Widget w,
     XtWidgetGeometry wants;
 
 #if 0
-    DEBUGOUT(XdbDebug(__FILE__, w, "query_geometry(%s)\n",
-		      XdbWidgetGeometry2String(intended)));
+    DEBUGOUT(_LtDebug(__FILE__, w, "query_geometry(%s)\n",
+		      _LtDebugWidgetGeometry2String(intended)));
 
     wants = *intended;
 
@@ -1059,15 +1059,15 @@ query_geometry(Widget w,
 	preferred->height = vals.SwH;
     }
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "query_geometry: I want %s\n",
-		      XdbWidgetGeometry2String(preferred)));
+    DEBUGOUT(_LtDebug(__FILE__, w, "query_geometry: I want %s\n",
+		      _LtDebugWidgetGeometry2String(preferred)));
 
     if (((wants.request_mode & CWWidth) &&
 	wants.width == preferred->width) &&
         ((intended->request_mode & CWHeight) &&
 	wants.height == preferred->height))
     {
-	DEBUGOUT(XdbDebug(__FILE__, w, "query_geometry => NO (w %d)\n",
+	DEBUGOUT(_LtDebug(__FILE__, w, "query_geometry => NO (w %d)\n",
 			  preferred->width));
 
 	return XtGeometryNo;	/* Something's different */
@@ -1076,7 +1076,7 @@ query_geometry(Widget w,
     if ((wants.request_mode & CWWidth) &&
 	wants.width != preferred->width)
     {
-	DEBUGOUT(XdbDebug(__FILE__, w, "query_geometry => ALMOST (w %d)\n",
+	DEBUGOUT(_LtDebug(__FILE__, w, "query_geometry => ALMOST (w %d)\n",
 			  preferred->width));
 
 	return XtGeometryAlmost;	/* Something's different */
@@ -1085,18 +1085,18 @@ query_geometry(Widget w,
     if ((wants.request_mode & CWHeight) &&
 	wants.height != preferred->height)
     {
-	DEBUGOUT(XdbDebug(__FILE__, w, "query_geometry => ALMOST (h %d)\n",
+	DEBUGOUT(_LtDebug(__FILE__, w, "query_geometry => ALMOST (h %d)\n",
 			  preferred->height));
 
 	return XtGeometryAlmost;	/* Something's different */
     }
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "query_geometry => YES\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "query_geometry => YES\n"));
 
     return XtGeometryYes;	/* I'm happy */
 #else
-    DEBUGOUT(XdbDebug(__FILE__, w, "query_geometry(%s)\n",
-		      XdbWidgetGeometry2String(intended)));
+    DEBUGOUT(_LtDebug(__FILE__, w, "query_geometry(%s)\n",
+		      _LtDebugWidgetGeometry2String(intended)));
 
     wants = *intended;
 
@@ -1126,8 +1126,8 @@ geometry_manager(Widget w, XtWidgetGeometry *desired, XtWidgetGeometry *allowed)
     XmSWValues vals;
 	XtGeometryResult rval;
 
-    DEBUGOUT(XdbDebug2(__FILE__, sw, w, "geometry_manager (request %s)\n",
-		       XdbWidgetGeometry2String(desired)));
+    DEBUGOUT(_LtDebug2(__FILE__, sw, w, "geometry_manager (request %s)\n",
+		       _LtDebugWidgetGeometry2String(desired)));
 
     /* Whoa, nelly.  Not if we control what you do. */
     if (w == (Widget)SW_HSB(sw) || w == (Widget)SW_VSB(sw))
@@ -1148,10 +1148,10 @@ geometry_manager(Widget w, XtWidgetGeometry *desired, XtWidgetGeometry *allowed)
      */
     if (SW_ScrollPolicy(sw) == XmAUTOMATIC && w == (Widget)SW_ClipWindow(sw))
     {
-	DEBUGOUT(XdbDebug2(__FILE__, sw, w,
+	DEBUGOUT(_LtDebug2(__FILE__, sw, w,
 			   "BEGIN AUTOMATIC FAKE\n\n"));
 
-	DEBUGOUT(XdbDebug2(__FILE__, sw, w,
+	DEBUGOUT(_LtDebug2(__FILE__, sw, w,
 			   "geometry_manager: resize WorkWindow: %d %d\n",
 			   wants.width, wants.height));
 
@@ -1190,7 +1190,7 @@ geometry_manager(Widget w, XtWidgetGeometry *desired, XtWidgetGeometry *allowed)
 	_XmRepositionScrolledWindow(w, NULL, NULL);
 #endif
 
-	DEBUGOUT(XdbDebug2(__FILE__, sw, w, "END AUTOMATIC FAKE\n"));
+	DEBUGOUT(_LtDebug2(__FILE__, sw, w, "END AUTOMATIC FAKE\n"));
 
 	return XtGeometryNo;
     }
@@ -1227,7 +1227,7 @@ geometry_manager(Widget w, XtWidgetGeometry *desired, XtWidgetGeometry *allowed)
 		   "not implemented (child %s, class %s)",
 		   XtName(w), XtClass(w)->core_class.class_name);
 
-	DEBUGOUT(XdbDebug2(__FILE__, sw, w,
+	DEBUGOUT(_LtDebug2(__FILE__, sw, w,
 		   "geometry_manager QueryOnly not implemented ! (=> YES)\n"));
 
 	return XtGeometryYes;
@@ -1239,38 +1239,42 @@ geometry_manager(Widget w, XtWidgetGeometry *desired, XtWidgetGeometry *allowed)
 	 */
     if ( (Wants(CWX) || Wants(CWY)) && !(Wants(CWWidth) || Wants(CWHeight) || Wants(CWBorderWidth)))
     {
-	DEBUGOUT(XdbDebug2(__FILE__, sw, w, "GeometryManager => No 2\n"));
+	DEBUGOUT(_LtDebug2(__FILE__, sw, w, "GeometryManager => No 2\n"));
 	return XtGeometryNo;
     }
 
     if (Wants((CWWidth|CWHeight)) == (CWWidth|CWHeight) &&
 	wants.width == desired->width && wants.height == desired->height)
     {
-	DEBUGOUT(XdbDebug2(__FILE__, sw, w, "GeometryManager => Yes-1 %s\n",
-		XdbWidgetGeometry2String(allowed)));
+	wants.request_mode &= ~CWWidth;
+	wants.request_mode &= ~CWHeight;
+	DEBUGOUT(_LtDebug2(__FILE__, sw, w, "GeometryManager => Yes-1 %s\n",
+		_LtDebugWidgetGeometry2String(allowed)));
     }
     else if (Wants((CWWidth|CWHeight)) == CWWidth &&
 	wants.width == desired->width)
     {
-	DEBUGOUT(XdbDebug2(__FILE__, sw, w, "GeometryManager => Yes-2 %s\n",
-		XdbWidgetGeometry2String(allowed)));
+	wants.request_mode &= ~CWWidth;
+	DEBUGOUT(_LtDebug2(__FILE__, sw, w, "GeometryManager => Yes-2 %s\n",
+		_LtDebugWidgetGeometry2String(allowed)));
     }
     else if (Wants((CWWidth|CWHeight)) == CWHeight &&
 	wants.height == desired->height)
     {
-	DEBUGOUT(XdbDebug2(__FILE__, sw, w, "GeometryManager => Yes-3 %s\n",
-		XdbWidgetGeometry2String(allowed)));
+	wants.request_mode &= ~CWHeight;
+	DEBUGOUT(_LtDebug2(__FILE__, sw, w, "GeometryManager => Yes-3 %s\n",
+		_LtDebugWidgetGeometry2String(allowed)));
     }
 	else if (rval == XtGeometryYes)
 	{
 	/* T. Straumann: change in border width only */
-	DEBUGOUT(XdbDebug2(__FILE__, sw, w, "GeometryManager => Yes-4 %s\n",
-		XdbWidgetGeometry2String(allowed)));
+	DEBUGOUT(_LtDebug2(__FILE__, sw, w, "GeometryManager => Yes-4 %s\n",
+		_LtDebugWidgetGeometry2String(allowed)));
 	}
 	else
 	{
-    DEBUGOUT(XdbDebug2(__FILE__, sw, w, "GeometryManager -> Almost %s\n",
-		XdbWidgetGeometry2String(allowed)));
+    DEBUGOUT(_LtDebug2(__FILE__, sw, w, "GeometryManager -> Almost %s\n",
+		_LtDebugWidgetGeometry2String(allowed)));
 	}
 
 
@@ -1293,7 +1297,7 @@ geometry_manager(Widget w, XtWidgetGeometry *desired, XtWidgetGeometry *allowed)
     }
     else
     {
-	DEBUGOUT(XdbDebug2(__FILE__, sw, w, "GeometryManager => No 1\n"));
+	DEBUGOUT(_LtDebug2(__FILE__, sw, w, "GeometryManager => No 1\n"));
 	return XtGeometryNo;
     }
 	}
@@ -1306,7 +1310,7 @@ change_managed(Widget w)
 {
     XmSWValues vals;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "%s:change_managed(%d)\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "%s:change_managed(%d)\n",
 			  __FILE__, __LINE__));
     if (True || XtIsManaged(w))
     {
@@ -1320,14 +1324,14 @@ change_managed(Widget w)
 	    _XmScrolledWConfigureChildren(w, NULL, NULL, &vals);
 	}
 
-	DEBUGOUT(XdbDebug(__FILE__, w, "change_managed: size %d %d\n",
+	DEBUGOUT(_LtDebug(__FILE__, w, "change_managed: size %d %d\n",
 			  XtWidth(w), XtHeight(w)));
     }
     else
     {
 	if (SW_ScrollBarPolicy(w) != XmSTATIC)
 	{
-	    DEBUGOUT(XdbDebug(__FILE__, w, "change_managed: unmanaging sb's\n"));
+	    DEBUGOUT(_LtDebug(__FILE__, w, "change_managed: unmanaging sb's\n"));
 
 	    if (SW_HSB(w) && XtIsManaged((Widget)SW_HSB(w)))
 	    {
@@ -1446,7 +1450,7 @@ insert_child(Widget w)
      */
     else if (SW_VisualPolicy(sw) == XmCONSTANT)
     {
-	DEBUGOUT(XdbDebug2(__FILE__, (Widget)sw, (Widget)w, "Reparented to %s\n",
+	DEBUGOUT(_LtDebug2(__FILE__, (Widget)sw, (Widget)w, "Reparented to %s\n",
 			   XtName(SW_ClipWindow(sw))));
 
 	XtParent(w) = (Widget)SW_ClipWindow(sw);
@@ -1461,7 +1465,7 @@ insert_child(Widget w)
     }
     else if (SW_WorkWindow(sw) == NULL)
     {
-	DEBUGOUT(XdbDebug2(__FILE__, (Widget)sw, w, "Child is Work Window\n"));
+	DEBUGOUT(_LtDebug2(__FILE__, (Widget)sw, w, "Child is Work Window\n"));
 
 	(*superclass->composite_class.insert_child) (w);
 
@@ -1469,7 +1473,7 @@ insert_child(Widget w)
     }
     else
     {
-	DEBUGOUT(XdbDebug2(__FILE__, (Widget)sw, w, "Child is goofy\n"));
+	DEBUGOUT(_LtDebug2(__FILE__, (Widget)sw, w, "Child is goofy\n"));
 
 	(*superclass->composite_class.insert_child) (w);
     }
@@ -1492,11 +1496,11 @@ delete_child(Widget w)
     }
     else if ((Widget)SW_VSB(sw) == w)
     {
-	SW_VSB(w) = NULL;
+	SW_VSB(sw) = NULL;
     }
     else if ((Widget)SW_HSB(sw) == w)
     {
-	SW_HSB(w) = NULL;
+	SW_HSB(sw) = NULL;
     }
 
 #define superclass (&xmManagerClassRec)
@@ -1544,7 +1548,7 @@ _XmRepositionScrolledWindow(Widget w, XtPointer client, XtPointer call)
 	SW_HSBValue(sw) = 0;
     }
 
-    DEBUGOUT(XdbDebug2(__FILE__, sw, w, "Hor %d Vert %d\n", h, v));
+    DEBUGOUT(_LtDebug2(__FILE__, sw, w, "Hor %d Vert %d\n", h, v));
 
     /*
      * Position the work window
@@ -1607,10 +1611,10 @@ _XmFixupScrollBars(Widget w, Dimension ww, Dimension wh)
     /*
      * otherwise, fixup the scrollbars.
      */
-    DEBUGOUT(XdbDebug(__FILE__, w,
+    DEBUGOUT(_LtDebug(__FILE__, w,
 		      "FixupScrollBars Widths : Work %d Clip %d\n",
 		      ww, SW_CWWidth(w)));
-    DEBUGOUT(XdbDebug(__FILE__, w,
+    DEBUGOUT(_LtDebug(__FILE__, w,
 		      "FixupScrollBars Heights : Work %d Clip %d\n",
 		      wh, SW_CWHeight(w)));
 
@@ -1661,7 +1665,7 @@ _XmFixupScrollBars(Widget w, Dimension ww, Dimension wh)
 	SW_HSBMaximum(w) = max;
 	SW_HSBSliderSize(w) = percent;
 
-	DEBUGOUT(XdbDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "FixupScrollBars HSB min %d max %d percent %d\n",
 			  min, max, percent));
     }
@@ -1712,7 +1716,7 @@ _XmFixupScrollBars(Widget w, Dimension ww, Dimension wh)
 	SW_VSBMaximum(w) = max;
 	SW_VSBSliderSize(w) = percent;
 
-	DEBUGOUT(XdbDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "FixupScrollBars VSB min %d max %d percent %d value %d\n",
 			  min, max, percent, value));
     }
@@ -1806,29 +1810,26 @@ _XmScrolledWPreferredSize(Widget w, Widget child, XtWidgetGeometry *childgeom,
 			  XmSWValues *vals)
 {
     /* Print out how we're called */
-    if (XdbInDebug(__FILE__, w))
-    {
-	DEBUGOUT(XdbDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "XmScrolledWPreferredSize [size %d %d]\n",
 			  XtWidth(w), XtHeight(w)));
-	DEBUGOUT(XdbDebug0(__FILE__, w, "... SW_VisualPolicy %s",
+	DEBUGOUT(_LtDebug0(__FILE__, w, "... SW_VisualPolicy %s",
 			   (SW_VisualPolicy(w) == XmCONSTANT) ? "XmCONSTANT" :
 			   (SW_VisualPolicy(w) == XmVARIABLE) ? "XmVARIABLE" :
 			   (SW_VisualPolicy(w) == XmRESIZE_IF_POSSIBLE)
 			   ? "XmRESIZE_IF_POSSIBLE" : "???"));
-	DEBUGOUT(XdbDebug0(__FILE__, w, " SW_ScrollBarPolicy %s",
+	DEBUGOUT(_LtDebug0(__FILE__, w, " SW_ScrollBarPolicy %s",
 			   (SW_ScrollBarPolicy(w) == XmSTATIC)
 			   ? "XmSTATIC"
 			   : (SW_ScrollBarPolicy(w) == XmAS_NEEDED)
 			   ? "XmAS_NEEDED"
 			   : "???"));
-	DEBUGOUT(XdbDebug0(__FILE__, w, " SW_ScrollPolicy %s\n",
+	DEBUGOUT(_LtDebug0(__FILE__, w, " SW_ScrollPolicy %s\n",
 			   (SW_ScrollPolicy(w) == XmAPPLICATION_DEFINED)
 			   ? "XmAPPLICATION_DEFINED"
 			   : (SW_ScrollPolicy(w) == XmAUTOMATIC)
 			   ? "XmAUTOMATIC"
 			   : "???"));
-    }
 
     if (childgeom)
     {
@@ -1895,7 +1896,7 @@ _XmScrolledWPreferredSize(Widget w, Widget child, XtWidgetGeometry *childgeom,
 	    vals->WorkH = XtHeight(SW_WorkWindow(w)) + 2 * XtBorderWidth(SW_WorkWindow(w));
 	}
 
-	DEBUGOUT(XdbDebug2(__FILE__, w, (Widget)SW_WorkWindow(w),
+	DEBUGOUT(_LtDebug2(__FILE__, w, (Widget)SW_WorkWindow(w),
 			   "WorkWindow queried geo is W %d H %d X %d Y %d\n",
 			   vals->WorkW, vals->WorkH, vals->WorkX, vals->WorkY));
     }
@@ -2042,7 +2043,7 @@ _XmScrolledWPreferredSize(Widget w, Widget child, XtWidgetGeometry *childgeom,
 					? (SW_Spacing(w) + vals->VsbW)
 					: 0);
 
-	    DEBUGOUT(XdbDebug2(__FILE__, w, SW_WorkWindow(w),
+	    DEBUGOUT(_LtDebug2(__FILE__, w, SW_WorkWindow(w),
 			       "Grow WorkW %d -> %d\n",
 			       xx, vals->WorkW));
 	}
@@ -2057,7 +2058,7 @@ _XmScrolledWPreferredSize(Widget w, Widget child, XtWidgetGeometry *childgeom,
 					? (SW_Spacing(w) + vals->HsbH)
 					: 0);
 
-	    DEBUGOUT(XdbDebug2(__FILE__, w, SW_WorkWindow(w),
+	    DEBUGOUT(_LtDebug2(__FILE__, w, SW_WorkWindow(w),
 			       "Grow WorkH %d -> %d\n",
 			       xx, vals->WorkH));
 	}
@@ -2089,7 +2090,7 @@ _XmScrolledWPreferredSize(Widget w, Widget child, XtWidgetGeometry *childgeom,
 			2 * (SW_MarginWidth(w) + MGR_ShadowThickness(w)) +
 			(vals->ShowVSB ? (SW_Spacing(w) + vals->VsbW) : 0);
 
-		DEBUGOUT(XdbDebug2(__FILE__, w, SW_WorkWindow(w),
+		DEBUGOUT(_LtDebug2(__FILE__, w, SW_WorkWindow(w),
 				   "Grow SwW %d -> %d\n",
 				   xx, vals->SwW));
 	    }
@@ -2108,7 +2109,7 @@ _XmScrolledWPreferredSize(Widget w, Widget child, XtWidgetGeometry *childgeom,
 			2 * (SW_MarginHeight(w) + MGR_ShadowThickness(w)) +
 			(vals->ShowHSB ? (SW_Spacing(w) + vals->HsbH) : 0);
 
-		DEBUGOUT(XdbDebug2(__FILE__, w, SW_WorkWindow(w),
+		DEBUGOUT(_LtDebug2(__FILE__, w, SW_WorkWindow(w),
 				   "Grow SwH %d -> %d\n",
 				   xx, vals->SwH));
 	    }
@@ -2217,16 +2218,16 @@ _XmScrolledWGeomRequest(Widget w, XmSWValues *vals)
     }
 #endif
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "Request geo %s from parent %s %s\n",
-		      XdbWidgetGeometry2String(&request),
+    DEBUGOUT(_LtDebug(__FILE__, w, "Request geo %s from parent %s %s\n",
+		      _LtDebugWidgetGeometry2String(&request),
 		      XtName(XtParent(w)),
 		      XtClass(XtParent(w))->core_class.class_name));
 
     res = _XmMakeGeometryRequest(w, &request);
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "==> Got %s %s\n",
-		      XdbGeometryResult2String(res),
-		      XdbWidgetGeometry2String(&request)));
+    DEBUGOUT(_LtDebug(__FILE__, w, "==> Got %s %s\n",
+		      _LtDebugGeometryResult2String(res),
+		      _LtDebugWidgetGeometry2String(&request)));
 
     if (res == XtGeometryYes || res == XtGeometryDone)
     {
@@ -2447,29 +2448,29 @@ _XmScrolledWLayout(Widget w, Widget child, XtWidgetGeometry *childgeom,
 	SetMinimum((Widget)SW_VSB(w));
     }
 
-    DEBUGOUT(XdbDebug0(__FILE__, w, "##############################\n"));
-    DEBUGOUT(XdbDebug2(__FILE__, w, (Widget)SW_ClipWindow(w),
+    DEBUGOUT(_LtDebug0(__FILE__, w, "##############################\n"));
+    DEBUGOUT(_LtDebug2(__FILE__, w, (Widget)SW_ClipWindow(w),
 		       "Clip @ x %d y %d w %d h %d\n",
 		       vals->ClipX, vals->ClipY, vals->ClipW, vals->ClipH));
-    DEBUGOUT(XdbDebug0(__FILE__, w,
+    DEBUGOUT(_LtDebug0(__FILE__, w,
 		       "HSB @ x %d y %d w %d h %d\n",
 		       vals->HsbX, vals->HsbY, vals->HsbW, vals->HsbH));
-    DEBUGOUT(XdbDebug0(__FILE__, w,
+    DEBUGOUT(_LtDebug0(__FILE__, w,
 		       "VSB @ x %d y %d w %d h %d\n",
 		       vals->VsbX, vals->VsbY, vals->VsbW, vals->VsbH));
-    DEBUGOUT(XdbDebug0(__FILE__, w,
+    DEBUGOUT(_LtDebug0(__FILE__, w,
 		       "HasHSB %s ShowHSB %s HasVSB %s ShowVSB %s\n",
 		       vals->HasHSB ? "True" : "False",
 		       vals->ShowHSB ? "True" : "False",
 		       vals->HasVSB ? "True" : "False",
 		       vals->ShowVSB ? "True" : "False"));
-    DEBUGOUT(XdbDebug0(__FILE__, w,
+    DEBUGOUT(_LtDebug0(__FILE__, w,
 	      "MarginWidth %d MarginHeight %d ShadowThickness %d Spacing %d\n",
 		       SW_MarginWidth(w), SW_MarginHeight(w),
 		       MGR_ShadowThickness(w), SW_Spacing(w)));
-    DEBUGOUT(XdbDebug0(__FILE__, w,
+    DEBUGOUT(_LtDebug0(__FILE__, w,
 		       "SwW %d SwH %d\n", vals->SwW, vals->SwH));
-    DEBUGOUT(XdbDebug0(__FILE__, w, "##############################\n"));
+    DEBUGOUT(_LtDebug0(__FILE__, w, "##############################\n"));
 
     if (SW_ScrollPolicy(w) == XmAPPLICATION_DEFINED)
     {
@@ -2560,8 +2561,8 @@ _XmScrolledWLayout(Widget w, Widget child, XtWidgetGeometry *childgeom,
 	    childgeom->height = vals->VsbH;
 	}
 
-	DEBUGOUT(XdbDebug2(__FILE__, w, child, "feedback => %s\n",
-			   XdbWidgetGeometry2String(childgeom)));
+	DEBUGOUT(_LtDebug2(__FILE__, w, child, "feedback => %s\n",
+			   _LtDebugWidgetGeometry2String(childgeom)));
     }
 }
 
@@ -2569,7 +2570,7 @@ void
 _XmConfigureScrollBars(Widget w, Widget child, XtWidgetGeometry *childgeom,
 		    XmSWValues *vals)
 {
-    DEBUGOUT(XdbDebug(__FILE__, w, "%s:_XmConfigureScrollBars(%d)\n",
+    DEBUGOUT(_LtDebug(__FILE__, w, "%s:_XmConfigureScrollBars(%d)\n",
     	__FILE__, __LINE__));
     /* Don't display scrollbars unless the child is managed */
     if (SW_WorkWindow(w) && ! XtIsManaged(SW_WorkWindow(w)))
@@ -2618,7 +2619,7 @@ _XmConfigureScrollBars(Widget w, Widget child, XtWidgetGeometry *childgeom,
 	{
 	    if (XtIsManaged(SW_VSB(w)) && !vals->ShowVSB)
 	    {
-		DEBUGOUT(XdbDebug2(__FILE__, w, (Widget)SW_VSB(w),
+		DEBUGOUT(_LtDebug2(__FILE__, w, (Widget)SW_VSB(w),
 				   "Unmanaging VSB\n"));
 
 		vals->VsbX = vals->SwW;
@@ -2657,7 +2658,7 @@ _XmConfigureScrollBars(Widget w, Widget child, XtWidgetGeometry *childgeom,
 	{
 	    if (vals->ShowVSB && !XtIsManaged(SW_VSB(w)))
 	    {
-		DEBUGOUT(XdbDebug2(__FILE__, w, (Widget)SW_VSB(w),
+		DEBUGOUT(_LtDebug2(__FILE__, w, (Widget)SW_VSB(w),
 				   "Managing VSB\n"));
 
 		if (True || XtIsRealized(w))
@@ -2679,7 +2680,7 @@ _XmConfigureScrollBars(Widget w, Widget child, XtWidgetGeometry *childgeom,
 	{
 	    if (XtIsManaged(SW_HSB(w)) && !vals->ShowHSB)
 	    {
-		DEBUGOUT(XdbDebug2(__FILE__, w, (Widget)SW_HSB(w),
+		DEBUGOUT(_LtDebug2(__FILE__, w, (Widget)SW_HSB(w),
 				   "Unmanaging HSB\n"));
 
 		vals->HsbY = vals->SwH;
@@ -2718,7 +2719,7 @@ _XmConfigureScrollBars(Widget w, Widget child, XtWidgetGeometry *childgeom,
 	{
 	    if (vals->ShowHSB && !XtIsManaged(SW_HSB(w)))
 	    {
-		DEBUGOUT(XdbDebug2(__FILE__, w, (Widget)SW_HSB(w),
+		DEBUGOUT(_LtDebug2(__FILE__, w, (Widget)SW_HSB(w),
 				   "Managing HSB\n"));
 
 		if (True || XtIsRealized(w))
@@ -2740,22 +2741,22 @@ _XmScrolledWConfigureChildren(Widget w, Widget child,
 			      XtWidgetGeometry *childgeom,
 			      XmSWValues *vals)
 {
-    if (XdbInDebug(__FILE__, w))
+    if (_LtDebugInDebug(__FILE__, w))
     {
-	DEBUGOUT(XdbDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, w,
 			  "_XmScrolledWConfigureChildren: Sw %dx%d\n",
 			  vals->SwW, vals->SwH));
-	DEBUGOUT(XdbDebug0(__FILE__, w,
+	DEBUGOUT(_LtDebug0(__FILE__, w,
 			   "\t\tX\tY\tW\tH\n\tWork\t%d\t%d\t%d\t%d\n",
 			   vals->WorkX, vals->WorkY, vals->WorkW, vals->WorkH));
-	DEBUGOUT(XdbDebug0(__FILE__, w,
+	DEBUGOUT(_LtDebug0(__FILE__, w,
 			   "\tClip\t%d\t%d\t%d\t%d\n",
 			   vals->ClipX, vals->ClipY, vals->ClipW, vals->ClipH));
-	DEBUGOUT(XdbDebug0(__FILE__, w,
+	DEBUGOUT(_LtDebug0(__FILE__, w,
 			   "\tHsb\t%d\t%d\t%d\t%d\t%3s managed\n",
 			   vals->HsbX, vals->HsbY, vals->HsbW, vals->HsbH,
 			   (vals->ShowHSB && vals->HasHSB) ? "" : "not"));
-	DEBUGOUT(XdbDebug0(__FILE__, w,
+	DEBUGOUT(_LtDebug0(__FILE__, w,
 			   "\tVsb\t%d\t%d\t%d\t%d\t%3s managed\n",
 			   vals->VsbX, vals->VsbY, vals->VsbW, vals->VsbH,
 			   (vals->ShowVSB && vals->HasVSB) ? "" : "not"));
@@ -3106,7 +3107,7 @@ XmScrolledWindowSetAreas(Widget widget,
 			 Widget v_scrollbar,
 			 Widget work_region)
 {
-    DEBUGOUT(XdbDebug(__FILE__, widget, "XmScrolledWindowSetAreas() - %s %s %s\n",
+    DEBUGOUT(_LtDebug(__FILE__, widget, "XmScrolledWindowSetAreas() - %s %s %s\n",
 		      h_scrollbar ? XtName(h_scrollbar) : "NULL",
 		      v_scrollbar ? XtName(v_scrollbar) : "NULL",
 		      work_region ? XtName(work_region) : "NULL"));
