@@ -1,8 +1,9 @@
 /**
  *
- * $Id: Shadow.c,v 1.18 1999/03/14 06:10:59 gritton Exp $
+ * $Id: Shadow.c,v 1.20 2001/01/25 14:28:35 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2001 LessTif Development Team 
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,18 +23,19 @@
  *
  **/
 
-static const char rcsid[] = "$Id: Shadow.c,v 1.18 1999/03/14 06:10:59 gritton Exp $";
+static const char rcsid[] = "$Id: Shadow.c,v 1.20 2001/01/25 14:28:35 amai Exp $";
 
 #include <LTconfig.h>
-#include <XmI/XmI.h>
 
+#include <XmI/XmI.h>
 #include <Xm/XmP.h>
 #include <Xm/PrimitiveP.h>
 #include <Xm/ManagerP.h>
 
 #include <XmI/DebugUtil.h>
 
-void
+
+extern void
 _XmClearBorder(Display *display,
 	       Window win,
 	       Position x, Position y,
@@ -69,7 +71,8 @@ _XmClearBorder(Display *display,
 	       False);
 }
 
-void
+
+extern void
 _XmDrawShadows(Display *display,
 	       Drawable d,
 	       GC top_gc,
@@ -219,7 +222,8 @@ _XmDrawShadows(Display *display,
     }
 }
 
-void
+
+extern void
 _XmDrawShadow(Display *display,
 	      Drawable d,
 	      GC top_gc,
@@ -242,7 +246,8 @@ _XmDrawShadow(Display *display,
 #define DA_SHADOW_1	True
 /* #define DA_SHADOW_1	XmVERSION > 1 */
 
-void
+
+extern void
 _XmDrawArrow(Display *display,
 	     Drawable d,
 	     GC top_gc,
@@ -524,7 +529,8 @@ _XmDrawArrow(Display *display,
         XtFree((char *) top);
 }
 
-void
+
+extern void
 _XmDrawDiamond(Display *display,
 	       Drawable d,
 	       GC top_gc,
@@ -653,7 +659,8 @@ _XmDrawDiamond(Display *display,
 
 }
 
-void
+
+extern void
 _XmDrawSeparator(Display *display,
 		 Drawable d,
 		 GC top_gc,
@@ -868,7 +875,8 @@ _XmDrawSeparator(Display *display,
     }
 }
 
-void
+
+extern void
 _XmDrawSimpleHighlight(Display *display,
 		       Drawable d,
 		       GC gc,
@@ -899,7 +907,8 @@ _XmDrawSimpleHighlight(Display *display,
     XFillRectangles(display, d, gc, rects, 4);
 }
 
-void
+
+extern void
 _XmDrawHighlight(Display *display,
 		 Drawable d,
 		 GC gc,
@@ -954,7 +963,7 @@ _XmDrawHighlight(Display *display,
  *
  * Looks like they just call the methods ...
  */
-void
+extern void
 _XmHighlightBorder(Widget w)
 {
     if (XmIsGadget(w))
@@ -971,7 +980,8 @@ _XmHighlightBorder(Widget w)
     }
 }
 
-void
+
+extern void
 _XmUnhighlightBorder(Widget w)
 {
     if (XmIsGadget(w))
@@ -988,11 +998,12 @@ _XmUnhighlightBorder(Widget w)
     }
 }
 
+
 /* Backward compatibility for ToggleButton.  They're not used now, and are
  * in fact insufficient for 2.0's detailShadowThickness.
  */
 
-void
+extern void
 _XmDrawSquareButton(Widget w,
 		    int x, int y, int size,
 		    GC top_gc, GC bottom_gc, GC select_gc,
@@ -1010,7 +1021,8 @@ _XmDrawSquareButton(Widget w,
 		       size - (delta << 1), size - (delta << 1));
 }
 
-void
+
+extern void
 _XmDrawDiamondButton(Widget w,
 		     int x, int y, int size,
 		     GC top_gc, GC bottom_gc, GC select_gc,
