@@ -1,8 +1,9 @@
 /**
  *
- * $Id: Simple.c,v 1.21 1999/08/14 12:17:14 danny Exp $
+ * $Id: Simple.c,v 1.26 2001/05/14 19:46:10 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,14 +23,14 @@
  *
  **/
 
-static const char rcsid[] = "$Id: Simple.c,v 1.21 1999/08/14 12:17:14 danny Exp $";
-
-#include <stdio.h>
+static const char rcsid[] = "$Id: Simple.c,v 1.26 2001/05/14 19:46:10 amai Exp $";
 
 #include <LTconfig.h>
-#include <XmI/XmI.h>
 
-#include <X11/Xfuncs.h>
+#include <stdio.h>
+#include <string.h>
+
+#include <XmI/XmI.h>
 #include <Xm/XmP.h>
 #include <Xm/RowColumnP.h>
 #include <Xm/CascadeBG.h>
@@ -41,6 +42,7 @@ static const char rcsid[] = "$Id: Simple.c,v 1.21 1999/08/14 12:17:14 danny Exp
 
 #include <XmI/DebugUtil.h>
 
+
 /* For the prototype police */
 extern Widget _XmCreateSimpleGadget(char *name, Widget parent, int def_type,
 				    XmSimpleMenu data, int which,
@@ -255,7 +257,7 @@ XmCreateSimpleCheckBox(Widget parent,
     }
 #endif
 
-    bzero((void *)&data, sizeof(XmSimpleMenuRec));
+    memset((void *)&data, 0, sizeof(XmSimpleMenuRec));
 
     n = 0;
     XtSetArg(myArgList[n], XmNrowColumnType, XmWORK_AREA);
@@ -311,7 +313,7 @@ XmCreateSimpleMenuBar(Widget parent,
     }
 #endif
 
-    bzero((void *)&data, sizeof(XmSimpleMenuRec));
+    memset((void *)&data, 0, sizeof(XmSimpleMenuRec));
 
     n = 0;
     XtSetArg(myArgList[n], XmNrowColumnType, XmMENU_BAR);
@@ -369,7 +371,7 @@ XmCreateSimpleOptionMenu(Widget parent,
     }
 #endif
 
-    bzero((void *)&data, sizeof(XmSimpleMenuRec));
+    memset((void *)&data, 0, sizeof(XmSimpleMenuRec));
 
     XtGetSubresources(parent, (XtPointer)&data, name, XmCSimpleOptionMenu,
 		      simple_resources, XtNumber(simple_resources),
@@ -429,7 +431,7 @@ XmCreateSimpleOptionMenu(Widget parent,
 		tmp = _XmCreateSimpleGadget(buf, RC_OptionSubMenu(rc),
 				      data.button_type[i],
 				      &data, i, bcnt - 1, arglist, argcount);
-		if (data.button_set == bcnt)
+		if (data.button_type[i] == XmPUSHBUTTON && data.button_set == bcnt - 1)
 		{
 		    XtVaSetValues(rc,
 			    XmNmenuHistory, tmp,
@@ -497,7 +499,7 @@ XmCreateSimplePopupMenu(Widget parent,
     }
 #endif
 
-    bzero((void *)&data, sizeof(XmSimpleMenuRec));
+    memset((void *)&data, 0, sizeof(XmSimpleMenuRec));
 
     rc = XmCreatePopupMenu(parent, name, arglist, argcount);
 
@@ -570,7 +572,7 @@ XmCreateSimplePulldownMenu(Widget parent,
     }
 #endif
 
-    bzero((void *)&data, sizeof(XmSimpleMenuRec));
+    memset((void *)&data, 0, sizeof(XmSimpleMenuRec));
 
     rc = XmCreatePulldownMenu(parent, name, arglist, argcount);
 
@@ -709,7 +711,7 @@ XmCreateSimpleRadioBox(Widget parent,
     }
 #endif
 
-    bzero((void *)&data, sizeof(XmSimpleMenuRec));
+    memset((void *)&data, 0, sizeof(XmSimpleMenuRec));
 
     n = 0;
     XtSetArg(myArgList[n], XmNrowColumnType, XmWORK_AREA); n++;
