@@ -1,8 +1,9 @@
 /**
  *
- * $Id: ToggleBG.c,v 1.68 1999/09/11 04:28:36 gritton Exp $
+ * $Id: ToggleBG.c,v 1.82 2001/12/07 08:08:05 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright  1995, 1996, 1997, 1998, 1999, 2000, 2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,9 +23,13 @@
  *
  **/
 
-static const char rcsid[] = "$Id: ToggleBG.c,v 1.68 1999/09/11 04:28:36 gritton Exp $";
+static const char rcsid[] = "$Id: ToggleBG.c,v 1.82 2001/12/07 08:08:05 amai Exp $";
 
 #include <LTconfig.h>
+
+#include <stdarg.h>
+#include <string.h>
+
 #include <XmI/XmI.h>
 
 #include <Xm/XmP.h>
@@ -36,18 +41,12 @@ static const char rcsid[] = "$Id: ToggleBG.c,v 1.68 1999/09/11 04:28:36 gritton
 #include <Xm/MenuShell.h>
 #include <Xm/MenuUtilP.h>
 #include <Xm/CacheP.h>
-#include <X11/Xfuncs.h>
 #include <X11/ShellP.h>
 #include <Xm/ToggleBP.h>
 
-#ifndef __STDC__
-#include <varargs.h>
-#else
-#include <stdarg.h>
-#endif
-
 #include <XmI/DebugUtil.h>
 
+
 /* Some M*tif versions (e.g. 1.2.6 on Solaris 2.6) leave less room above and
  * below the indicator than others (e.g. 1.2.5 on HP-UX 10, my reference).
  */
@@ -179,7 +178,7 @@ static XtResource cache_resources[] =
 	sizeof(Pixmap), Offset(insen_pixmap),
 	XmRImmediate, (XtPointer)XmUNSPECIFIED_PIXMAP
     },
-#if XmVERSION == 1 || LESSTIF_BACK_COMPAT
+#if XmVERSION == 1
     {
 	XmNindicatorOn, XmCIndicatorOn, XmRBoolean,
 	sizeof(Boolean), Offset(ind_on),
@@ -202,7 +201,14 @@ static XtResource cache_resources[] =
 	XmNselectColor, XmCSelectColor, XmRPixel,
 	sizeof(Pixel), Offset(select_color),
 	XmRCallProc, (XtPointer)_XmSelectColorDefault
+    },
+#if XmVERSION > 1
+    {
+	XmNunselectColor, XmCUnselectColor, XmRPixel,
+	sizeof(Pixel), Offset(unselect_color),
+	XmRImmediate, (XtPointer)NULL		/* FIX ME must be dynamic */
     }
+#endif
 };
 
 static XmSyntheticResource cache_syn_resources[] =
@@ -218,7 +224,7 @@ static XmSyntheticResource cache_syn_resources[] =
 	_XmFromVerticalPixels, _XmToVerticalPixels
     }
 };
-/* *INDENT-OFF* */
+
 XmToggleButtonGCacheObjClassRec xmToggleButtonGCacheObjClassRec = {
     /* Object class part */
     {
@@ -384,6 +390,9 @@ static XmGadgetClassExtRec _XmToggleBGadgetClassExtRec = {
     /* size                      */ sizeof(XmGadgetClassExtRec),
     /* widget_baseline_proc      */ XmInheritBaselineProc,
     /* display_rect_proc         */ XmInheritDisplayRectProc,
+#if XmVERSION >= 2
+    /* margins_proc              */ XmInheritMarginsProc,
+#endif
 };
 
 XmToggleButtonGadgetClassRec xmToggleButtonGadgetClassRec = {
@@ -449,7 +458,6 @@ XmToggleButtonGadgetClassRec xmToggleButtonGadgetClassRec = {
 	/* extension */ NULL
     },
 };
-/* *INDENT-ON* */
 
 
 WidgetClass xmToggleButtonGadgetClass = (WidgetClass)&xmToggleButtonGadgetClassRec;
@@ -471,9 +479,9 @@ secondary_object_create(Widget request,
     XmBaseClassExt *bce;
     XtPointer nsec, rsec;
     XmWidgetExtData ed;
-    int size;
+    Cardinal size;
 
-    DEBUGOUT(XdbDebug(__FILE__, new_w,
+    DEBUGOUT(_LtDebug(__FILE__, new_w,
 		      "ToggleButtonGCacheRec %s being initialized.\n",
 		      XtName(new_w)));
 
@@ -503,7 +511,7 @@ secondary_object_create(Widget request,
     ed->widget = (Widget)nsec;
     ed->reqWidget = (Widget)rsec;
 
-    bcopy(nsec, rsec, size);
+    memcpy(rsec, nsec, size);
     ((XmExtRec *)rsec)->object.self = (Widget)rsec;
 
     _XmPushWidgetExtData(new_w, ed, XmCACHE_EXTENSION);
@@ -518,7 +526,7 @@ secondary_object_create(Widget request,
 int
 _XmToggleBCacheCompare(XtPointer A, XtPointer B)
 {
-    return !bcmp(((XmToggleButtonGCacheObjPart *)A),
+    return !memcmp(((XmToggleButtonGCacheObjPart *)A),
 		 ((XmToggleButtonGCacheObjPart *)B),
 		 sizeof(XmToggleButtonGCacheObjPart));
 }
@@ -556,10 +564,10 @@ class_initialize(void)
 			     &labels, &nlabels);
 
     combined = (XtResourceList)XtMalloc(sizeof(XtResource) * ncom);
-    bcopy(labels, combined, nlabels * sizeof(XtResource));
-    bcopy(cache_resources,
-	  &combined[nlabels],
-	  XtNumber(cache_resources) * sizeof(XtResource));
+    memcpy(combined, labels, nlabels * sizeof(XtResource));
+    memcpy(&combined[nlabels],
+           cache_resources,
+	   XtNumber(cache_resources) * sizeof(XtResource));
     XtFree((char *)labels);
 
     xmToggleButtonGCacheObjClassRec.object_class.resources = combined;
@@ -631,7 +639,7 @@ initialize_posthook(Widget request, Widget new_w,
 {
     XmWidgetExtData ext;
 
-    DEBUGOUT(XdbDebug(__FILE__, new_w, "ToggleBG InitializePosthook\n"));
+    DEBUGOUT(_LtDebug(__FILE__, new_w, "ToggleBG InitializePosthook\n"));
 
     /* don't let the null fool you */
     LabG_Cache(new_w) = (XmLabelGCacheObjPart *)
@@ -836,7 +844,7 @@ set_values_prehook(Widget old, Widget request, Widget new_w,
 {
     XmBaseClassExt *bce;
     XmWidgetExtData ed;
-    int size;
+    Cardinal size;
     XtPointer nsec, rsec;
 
     bce = _XmGetBaseClassExtPtr(XtClass(new_w), XmQmotif);
@@ -855,12 +863,12 @@ set_values_prehook(Widget old, Widget request, Widget new_w,
     ExtObj_LogicalParent(nsec) = new_w;
     ExtObj_ExtensionType(nsec) = XmCACHE_EXTENSION;
 
-    bcopy(LabG_Cache(new_w),
-	  &((XmLabelGCacheObject)nsec)->label_cache,
-	  sizeof(XmLabelGCacheObjPart));
-    bcopy(TBG_Cache(new_w),
-	  &((XmToggleButtonGCacheObject)nsec)->toggle_cache,
-	  sizeof(XmToggleButtonGCacheObjPart));
+    memcpy(&((XmLabelGCacheObject)nsec)->label_cache,
+           LabG_Cache(new_w),
+	   sizeof(XmLabelGCacheObjPart));
+    memcpy(&((XmToggleButtonGCacheObject)nsec)->toggle_cache,
+           TBG_Cache(new_w),
+	   sizeof(XmToggleButtonGCacheObjPart));
 
     ed = (XmWidgetExtData)XtMalloc(sizeof(XmWidgetExtDataRec));
     ed->widget = (Widget)nsec;
@@ -875,7 +883,7 @@ set_values_prehook(Widget old, Widget request, Widget new_w,
 		   (*bce)->secondaryObjectClass->core_class.num_resources,
 		   args, *num_args);
 
-    bcopy(nsec, rsec, size);
+    memcpy(rsec, nsec, size);
 
     LabG_Cache(new_w) = &(((XmToggleButtonGCacheObject)nsec)->label_cache);
     LabG_Cache(request) = &(((XmToggleButtonGCacheObject)rsec)->label_cache);
@@ -941,7 +949,7 @@ set_values(Widget old, Widget request, Widget new_w,
 {
     Boolean refresh_needed = False;
 
-    DEBUGOUT(XdbDebug(__FILE__, new_w, "ToggleBG set_values\n"));
+    DEBUGOUT(_LtDebug(__FILE__, new_w, "ToggleBG set_values\n"));
 
     if (TBG_IndType(old) != TBG_IndType(new_w) &&
 	!XmRepTypeValidValue(XmRepTypeGetId(XmRIndicatorType),
@@ -1182,7 +1190,7 @@ get_values_prehook(Widget new_w, ArgList args, Cardinal *num_args)
 {
     XmBaseClassExt *bce;
     XmWidgetExtData ed;
-    int size;
+    Cardinal size;
     XtPointer nsec;
 
     bce = _XmGetBaseClassExtPtr(XtClass(new_w), XmQmotif);
@@ -1190,12 +1198,12 @@ get_values_prehook(Widget new_w, ArgList args, Cardinal *num_args)
 
     nsec = _XmExtObjAlloc(size);
 
-    bcopy(LabG_Cache(new_w),
-	  &((XmLabelGCacheObject)nsec)->label_cache,
-	  sizeof(XmLabelGCacheObjPart));
-    bcopy(TBG_Cache(new_w),
-	  &((XmToggleButtonGCacheObject)nsec)->toggle_cache,
-	  sizeof(XmToggleButtonGCacheObjPart));
+    memcpy(&((XmLabelGCacheObject)nsec)->label_cache,
+           LabG_Cache(new_w),
+	   sizeof(XmLabelGCacheObjPart));
+    memcpy(&((XmToggleButtonGCacheObject)nsec)->toggle_cache,
+           TBG_Cache(new_w),
+	   sizeof(XmToggleButtonGCacheObjPart));
 
     /*
      * don't do this and ResInd will blow up.
@@ -1274,7 +1282,7 @@ resize(Widget w)
 static void
 expose(Widget w, XEvent *event, Region region)
 {
-    DEBUGOUT(XdbDebug(__FILE__, w, "ToggleBG Expose\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "ToggleBG Expose\n"));
     draw_toggle(w, event, region, True, 0);
 }
 
@@ -1335,6 +1343,8 @@ Select(Widget w, XEvent *event, String *params, Cardinal *num_params)
 	{
 	    RC_MenuMenuCallback(w, &cbs);
 	}
+	/* Menu callback might cancel the set (radioAlwaysOne). */
+	cbs.set = TBG_Set(w);
 	if (!LabG_SkipCallback(w) && TBG_ValueChangedCallback(w))
 	{
 	    XFlush(XtDisplay(w));
@@ -1478,7 +1488,7 @@ ButtonDown(Widget w, XEvent *event, String *params, Cardinal *num_params)
 	RC_MenuShellPopdown(w, event, &poppedUp);
     }
     {
-	int i;
+	Cardinal i;
 	Widget menu = XtParent(w);
 
 	for (i = 0; i < MGR_NumChildren(menu); i++)
@@ -1621,7 +1631,7 @@ input_dispatch(Widget gadget, XEvent *event, Mask event_mask)
     {
     case XmARM_EVENT:
     case XmMULTI_ARM_EVENT:
-	DEBUGOUT(XdbDebug(__FILE__, gadget,
+	DEBUGOUT(_LtDebug(__FILE__, gadget,
 			  "ToggleButtonGadget got arm event\n"));
 	if (IN_MENU(gadget))
 	{
@@ -1635,7 +1645,7 @@ input_dispatch(Widget gadget, XEvent *event, Mask event_mask)
 
     case XmACTIVATE_EVENT:
     case XmMULTI_ACTIVATE_EVENT:
-	DEBUGOUT(XdbDebug(__FILE__, gadget,
+	DEBUGOUT(_LtDebug(__FILE__, gadget,
 			  "ToggleButtonGadget got activate event\n"));
 	if (IN_MENU(gadget))
 	{
@@ -1649,19 +1659,19 @@ input_dispatch(Widget gadget, XEvent *event, Mask event_mask)
 	break;
 
     case XmENTER_EVENT:
-	DEBUGOUT(XdbDebug(__FILE__, gadget,
+	DEBUGOUT(_LtDebug(__FILE__, gadget,
 			  "ToggleButtonGadget enter window\n"));
 	EnterWindow(gadget, event, NULL, &num_params);
 	break;
 
     case XmLEAVE_EVENT:
-	DEBUGOUT(XdbDebug(__FILE__, gadget,
+	DEBUGOUT(_LtDebug(__FILE__, gadget,
 			  "ToggleButtonGadget leave window\n"));
 	LeaveWindow(gadget, event, NULL, &num_params);
 	break;
 
     case XmMOTION_EVENT:
-	DEBUGOUT(XdbDebug(__FILE__, gadget,
+	DEBUGOUT(_LtDebug(__FILE__, gadget,
 			  "ToggleButtonGadget motion event\n"));
 	break;
 
@@ -1686,7 +1696,6 @@ input_dispatch(Widget gadget, XEvent *event, Mask event_mask)
     }
 }
 
-#ifdef __STDC__
 static void
 MenuProcEntry(int proc, Widget w,...)
 {
@@ -1696,19 +1705,6 @@ MenuProcEntry(int proc, Widget w,...)
     */
 
     va_start(arg_list, w);
-#else
-MenuProcEntry(proc, w, va_alist)
-     int proc;
-     Widget w;
-     va_dcl
-{
-    va_list arglist;
-    /*
-    Cardinal num_params = 0;
-    */
-
-    va_start(arglist);
-#endif
 
     switch (proc)
     {
@@ -2253,6 +2249,8 @@ XmToggleButtonGadgetSetState(Widget w, Boolean state, Boolean notify)
 	    {
 		RC_MenuMenuCallback(w, &cbs);
 	    }
+	    /* Menu callback might cancel the set (radioAlwaysOne). */
+	    cbs.set = TBG_Set(w);
 	    if (!LabG_SkipCallback(w) && TBG_ValueChangedCallback(w))
 	    {
 		XFlush(XtDisplay(w));
