@@ -1,9 +1,9 @@
 /**
  *
- * $Id: Visual.c,v 1.31 2000/09/22 20:35:13 amai Exp $
+ * $Id: Visual.c,v 1.35 2001/07/27 18:51:58 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2000 LessTif Development Team
+ * Copyright (C) 1995-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: Visual.c,v 1.31 2000/09/22 20:35:13 amai Exp $";
+static const char rcsid[] = "$Id: Visual.c,v 1.35 2001/07/27 18:51:58 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -312,7 +312,7 @@ _XmAddBackgroundToColorCache(Screen *screen, Colormap color_map,
 
     if (!XAllocColor(DisplayOfScreen(screen), color_map, &cd.background))
     {
-	DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:_XmAddBackgroundToColorCache(%d) - Could not allocate color\n",
+	DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:_XmAddBackgroundToColorCache(%d) - Could not allocate color\n",
 			   __FILE__,__LINE__));
 	color_fail_warn();
 	cd.background.pixel =
@@ -394,7 +394,7 @@ _XmAccessColorData(XmColorData *cd, unsigned char which)
 			     cd->color_map,
 			     &cd->foreground))
 	    {
-		DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:_XmAccessColorData(%d) - Could not allocate XmFOREGROUND\n",
+		DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:_XmAccessColorData(%d) - Could not allocate XmFOREGROUND\n",
 				   __FILE__,__LINE__));
 		color_fail_warn();
 		cd->foreground.pixel = black_or_white(cd, XmFOREGROUND);
@@ -409,7 +409,7 @@ _XmAccessColorData(XmColorData *cd, unsigned char which)
 			     cd->color_map,
 			     &cd->top_shadow))
 	    {
-		DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:_XmAccessColorData(%d) - Could not allocate XmTOP_SHADOW\n",
+		DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:_XmAccessColorData(%d) - Could not allocate XmTOP_SHADOW\n",
 				   __FILE__,__LINE__));
 		color_fail_warn();
 		cd->top_shadow.pixel = black_or_white(cd, XmTOP_SHADOW);
@@ -424,7 +424,7 @@ _XmAccessColorData(XmColorData *cd, unsigned char which)
 			     cd->color_map,
 			     &cd->bottom_shadow))
 	    {
-		DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:_XmAccessColorData(%d) - Could not allocate XmBOTTOM_SHADOW\n",
+		DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:_XmAccessColorData(%d) - Could not allocate XmBOTTOM_SHADOW\n",
 				   __FILE__,__LINE__));
 		color_fail_warn();
 		cd->bottom_shadow.pixel = black_or_white(cd, XmBOTTOM_SHADOW);
@@ -439,7 +439,7 @@ _XmAccessColorData(XmColorData *cd, unsigned char which)
 			     cd->color_map,
 			     &cd->select))
 	    {
-		DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:_XmAccessColorData(%d) - Could not allocate XmSELECT\n",
+		DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:_XmAccessColorData(%d) - Could not allocate XmSELECT\n",
 				   __FILE__,__LINE__));
 		color_fail_warn();
 		cd->select.pixel = black_or_white(cd, XmSELECT);
@@ -1163,7 +1163,7 @@ CvtStringToBackgroundPixmap(Display *display,
 {
     static Pixmap buf;
 
-    DEBUGOUT(XdbDebug(__FILE__, NULL,
+    DEBUGOUT(_LtDebug(__FILE__, NULL,
 		      "CvtStringToBackgroundPixmap: %s\n",
 		      fromVal->addr));
 
@@ -1191,7 +1191,7 @@ CvtStringToBackgroundPixmap(Display *display,
     else
     {
 	buf = XmUNSPECIFIED_PIXMAP;
-	toVal->addr = (XtPointer)&buf;
+	toVal->addr = (XPointer)&buf;
 	toVal->size = sizeof(Pixmap);
 
 	return True;
@@ -1199,7 +1199,7 @@ CvtStringToBackgroundPixmap(Display *display,
 }
 
 static void
-BuildPixmap(int ncargs, char *which,
+BuildPixmap(Cardinal ncargs, char *which,
 	    XrmValuePtr args, Cardinal *num_args,
 	    XrmValuePtr fromVal, XrmValuePtr toVal)
 {
@@ -1242,7 +1242,7 @@ static void
 _XmCvtStringToPrimForegroundPixmap(XrmValuePtr args, Cardinal *num_args,
 				   XrmValuePtr fromVal, XrmValuePtr toVal)
 {
-    DEBUGOUT(XdbDebug(__FILE__, NULL, "_XmCvtStringToPrimForegroundPixmap\n"));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "_XmCvtStringToPrimForegroundPixmap\n"));
 
     BuildPixmap(XtNumber(PrimForegroundPixmapArgs),
 		"_XmCvtStringToPrimForegroundPixmap",
@@ -1253,7 +1253,7 @@ static void
 _XmCvtStringToPrimHighlightPixmap(XrmValuePtr args, Cardinal *num_args,
 				  XrmValuePtr fromVal, XrmValuePtr toVal)
 {
-    DEBUGOUT(XdbDebug(__FILE__, NULL, "_XmCvtStringToPrimHighlightPixmap\n"));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "_XmCvtStringToPrimHighlightPixmap\n"));
 
     BuildPixmap(XtNumber(PrimHighlightPixmapArgs),
 		"_XmCvtStringToPrimHighlightPixmap",
@@ -1264,7 +1264,7 @@ static void
 _XmCvtStringToPrimTopShadowPixmap(XrmValuePtr args, Cardinal *num_args,
 				  XrmValuePtr fromVal, XrmValuePtr toVal)
 {
-    DEBUGOUT(XdbDebug(__FILE__, NULL, "_XmCvtStringToPrimTopShadowPixmap\n"));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "_XmCvtStringToPrimTopShadowPixmap\n"));
 
     BuildPixmap(XtNumber(PrimTopShadowPixmapArgs),
 		"_XmCvtStringToPrimTopShadowPixmap",
@@ -1275,7 +1275,7 @@ static void
 _XmCvtStringToPrimBottomShadowPixmap(XrmValuePtr args, Cardinal *num_args,
 				     XrmValuePtr fromVal, XrmValuePtr toVal)
 {
-    DEBUGOUT(XdbDebug(__FILE__, NULL, "_XmCvtStringToPrimBottomShadowPixmap\n"));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "_XmCvtStringToPrimBottomShadowPixmap\n"));
 
     BuildPixmap(XtNumber(PrimBottomShadowPixmapArgs),
 		"_XmCvtStringToPrimBottomShadowPixmap",
@@ -1286,7 +1286,7 @@ static void
 _XmCvtStringToManForegroundPixmap(XrmValuePtr args, Cardinal *num_args,
 				  XrmValuePtr fromVal, XrmValuePtr toVal)
 {
-    DEBUGOUT(XdbDebug(__FILE__, NULL, "_XmCvtStringToManForegroundPixmap\n"));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "_XmCvtStringToManForegroundPixmap\n"));
 
     BuildPixmap(XtNumber(ManForegroundPixmapArgs),
 		"_XmCvtStringToManForegroundPixmap",
@@ -1297,7 +1297,7 @@ static void
 _XmCvtStringToManHighlightPixmap(XrmValuePtr args, Cardinal *num_args,
 				 XrmValuePtr fromVal, XrmValuePtr toVal)
 {
-    DEBUGOUT(XdbDebug(__FILE__, NULL, "_XmCvtStringToManHighlightPixmap\n"));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "_XmCvtStringToManHighlightPixmap\n"));
 
     BuildPixmap(XtNumber(ManHighlightPixmapArgs),
 		"_XmCvtStringToManHighlightPixmap",
@@ -1308,7 +1308,7 @@ static void
 _XmCvtStringToManTopShadowPixmap(XrmValuePtr args, Cardinal *num_args,
 				 XrmValuePtr fromVal, XrmValuePtr toVal)
 {
-    DEBUGOUT(XdbDebug(__FILE__, NULL, "_XmCvtStringToManTopShadowPixmap\n"));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "_XmCvtStringToManTopShadowPixmap\n"));
 
     BuildPixmap(XtNumber(ManTopShadowPixmapArgs),
 		"_XmCvtStringToManTopShadowPixmap",
@@ -1319,7 +1319,7 @@ static void
 _XmCvtStringToManBottomShadowPixmap(XrmValuePtr args, Cardinal *num_args,
 				    XrmValuePtr fromVal, XrmValuePtr toVal)
 {
-    DEBUGOUT(XdbDebug(__FILE__, NULL, "_XmCvtStringToManBottomShadowPixmap\n"));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "_XmCvtStringToManBottomShadowPixmap\n"));
 
     BuildPixmap(XtNumber(ManBottomShadowPixmapArgs),
 		"_XmCvtStringToManBottomShadowPixmap",
@@ -1334,7 +1334,7 @@ _XmCvtStringToGadgetPixmap(XrmValuePtr args, Cardinal *num_args,
     Cardinal pnargs = 4;
     Widget parent;
 
-    DEBUGOUT(XdbDebug(__FILE__, NULL, "_XmCvtStringToGadgetPixmap\n"));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "_XmCvtStringToGadgetPixmap\n"));
 
     parent = *((Widget *)args[0].addr);
 
@@ -1352,7 +1352,7 @@ _XmRegisterPixmapConverters(void)
 {
     static Boolean inited = False;
   
-    DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:_XmRegisterPixmapConverters(%d)\n",
+    DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:_XmRegisterPixmapConverters(%d)\n",
 	__FILE__, __LINE__));
 
     if (inited)
@@ -1450,7 +1450,7 @@ _XmWhitePixel(Screen *screen, Colormap colormap, XColor whitecolor)
     }
     else
     {
-	DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:_XmWhitePixel(%d) - Could not allocate white color\n",
+	DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:_XmWhitePixel(%d) - Could not allocate white color\n",
 			   __FILE__,__LINE__));
 	color_fail_warn();
 	last_pixel = WhitePixelOfScreen(screen);
@@ -1481,7 +1481,7 @@ _XmBlackPixel(Screen *screen, Colormap colormap, XColor blackcolor)
     }
     else
     {
-	DEBUGOUT(XdbDebug0(__FILE__, NULL, "%s:_XmBlackPixel(%d) - Could not allocate black color\n",
+	DEBUGOUT(_LtDebug0(__FILE__, NULL, "%s:_XmBlackPixel(%d) - Could not allocate black color\n",
 			   __FILE__,__LINE__));
 	color_fail_warn();
 	last_pixel = BlackPixelOfScreen(screen);
