@@ -1,6 +1,6 @@
 /*
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm/XmString.c,v 1.70 2001/07/27 18:51:58 dannybackx Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm/XmString.c,v 1.72 2001/10/29 09:00:37 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
  * Copyright (C) 1995-2001 LessTif Development Team
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm/XmString.c,v 1.70 2001/07/27 18:51:58 dannybackx Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm/XmString.c,v 1.72 2001/10/29 09:00:37 amai Exp $";
 
 /*
  * ** Danny had added a flag here, but I think the behavior he added is always
@@ -45,11 +45,11 @@ static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm/XmString.c
 
 #include <LTconfig.h>
 
-#include <limits.h>
-#include <stdio.h>
-#include <locale.h>
 #include <stdlib.h>
 #include <string.h>
+#include <stdio.h>
+/* #include <locale.h> */
+#include <limits.h>
 
 #include <XmI/XmI.h>
 #include <XmI/MacrosI.h>
@@ -72,8 +72,12 @@ static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm/XmString.c
  */
 #define XmSTRING_HEADER_SIZE	(ASN1_HEADER_SIZE * 2)
 
-/* don't need this in a production build */
-#ifndef LESSTIF_PRODUCTION
+/* We don't need this in a production build */
+#ifdef LESSTIF_PRODUCTION
+#ifdef XMSTRING_DEBUG
+#undef XMSTRING_DEBUG
+#endif
+#else
 #ifndef XMSTRING_DEBUG
 #define XMSTRING_DEBUG
 #endif
@@ -429,7 +433,7 @@ __XmStringComponentCopy(struct __XmStringComponentRec *dest,
 static _XmString
 __XmStringFromASN1(XmString string)
 {
-    unsigned i, nlen, nlength, length;
+    unsigned i, nlen, length;
     struct __XmStringExtRec *str = (struct __XmStringExtRec *)string;
     unsigned char *next;
     char *charset;
@@ -477,11 +481,7 @@ __XmStringFromASN1(XmString string)
 
     next = &str->data[i];
 
-    if (length < 0)
-    {
-	return NULL;
-    }
-    else if (length == 0)
+    if (length <= 0)
     {
 	return NULL;
     }
