@@ -1,9 +1,9 @@
 /**
  *
- * $Id: misc.c,v 1.17 2000/10/09 11:56:32 amai Exp $
+ * $Id: misc.c,v 1.22 2001/09/09 09:21:02 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2000 LessTif Development Team
+ * Copyright (C) 1995-2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -30,6 +30,10 @@
 
 #include <LTconfig.h>
 
+#include <stdlib.h>
+#include <string.h>
+#include <ctype.h>
+
 #include <X11/Intrinsic.h>
 #if XtSpecificationRelease < 6
 #include <X11/IntrinsicP.h>
@@ -37,8 +41,11 @@
 
 #include <XmI/XmI.h>
 #include <Xm/XmP.h>
+
 #include "LTmisc.h"
 
+#include <XmI/DebugUtil.h>
+
 
 /* ******************* LessTif internal stuff ******************* */
 
@@ -83,6 +90,7 @@ static unsigned char odd_stipple_bits[] =
     0x55, 0xaa, 0x55, 0xaa, 0x55, 0xaa, 0x55, 0xaa
  };
 
+
 void
 _XmInstallStippleImages(Widget w)
 {
@@ -98,6 +106,7 @@ _XmInstallStippleImages(Widget w)
     XmInstallImage(odd_stipple_image, XmODD_STIPPLE_IMAGE);
 }
 
+
 /*
  * Below are some functions to deal with a multi-threaded environment.
  * Use these instead of the Xt stuff, to ensure that we can still cope
@@ -117,6 +126,7 @@ _XmAppLock(XtAppContext appc)
 #endif
 }
 
+
 void
 _XmAppUnlock(XtAppContext appc)
 {
@@ -125,6 +135,7 @@ _XmAppUnlock(XtAppContext appc)
 #endif
 }
 
+
 void
 _XmProcessLock(void)
 {
@@ -133,6 +144,7 @@ _XmProcessLock(void)
 #endif
 }
 
+
 void
 _XmProcessUnlock(void)
 {
@@ -141,6 +153,7 @@ _XmProcessUnlock(void)
 #endif
 }
 
+
 /*
  * These are utility functions so you don't need to type so much.
  * Just pass a widget or gadget.
@@ -157,6 +170,7 @@ _XmObjectLock(Widget w)
 #endif
 }
 
+
 void
 _XmObjectUnlock(Widget w)
 {
@@ -169,27 +183,30 @@ _XmObjectUnlock(Widget w)
 #endif
 }
 
-/* ***** Fallbacks for non-ANSI stuff ***** */
+
+/* ***** A couple of Fallbacks for non-ANSI stuff ***** */
 /*       
-         This might a crucial thing: if upon build-time the decision
-         is made to build these implementations they might hurt 
-	 later on another system or after a system update.
-	 While the implementations may not be perfect we ensure
-	 that their signatures are conforming to the relevant
-	 standards, i.e. Single UNIX Specification V2 and the
-	 upcoming joint version of "Posix.1 & SUSV3".
+       This might a crucial thing: if upon build-time the decision
+       is made to build these implementations they might hurt 
+       later on another system or after a system update.
+       While the implementations may not be perfect we ensure
+       that their signatures are conforming to the relevant
+       standards, i.e. Single UNIX Specification V2 and the
+       upcoming joint version of "Posix.1 & SUSV3".
 	 
-         The following hacks _should_ therefore conform to the docs
+       The following hacks _should_ therefore conform to the docs
 	 e.g. from
          http://www.opengroup.org/onlinepubs/007908799
      
-         Any deviation is not by intention (but a lack of time and
-         proper testing ...
+       Any deviation is not by intention, but a lack of time and
+       proper testing ...
+       amai, 20010326: move them "out the way" by using
+                       a prefix
 */
 
 #ifndef HAVE_STRCASECMP
-int
-strcasecmp(const char *s1, const char *s2)
+extern int
+_Lt_strcasecmp(const char *s1, const char *s2)
 {
     int c1, c2;
 
@@ -209,13 +226,13 @@ strcasecmp(const char *s1, const char *s2)
 #endif
 
 #ifndef HAVE_STRNCASECMP
-int
-strncasecmp(const char *s1, const char *s2, int count)
+extern int
+_Lt_strncasecmp(const char *s1, const char *s2, size_t count)
 {
     int c1, c2;
     int i = 0;
 
-    while (*s1 && *s2 && i < count)
+    while (*s1 && *s2 && i < (int)count)
     {
 	c1 = tolower(*s1);
 	c2 = tolower(*s2);
@@ -232,13 +249,14 @@ strncasecmp(const char *s1, const char *s2, int count)
 #endif
 
 
-/* The following hacks for basename() and dirname() _should_
-   be conforming to SUS V2 as of 
-     http://www.opengroup.org/onlinepubs/007908799/xsh/basename.html
+/* amai:
+   The following hacks for basename() and dirname() _should_
+   be conforming to Single UNIX Specification (SUS) V2 as of 
+      http://www.opengroup.org/onlinepubs/007908799/xsh/basename.html
    and
-     http://www.opengroup.org/onlinepubs/007908799/xsh/dirname.html
+      http://www.opengroup.org/onlinepubs/007908799/xsh/dirname.html
      
-   Any deviation is not by intention (but a lack of time and
+   Any deviation is not by intention, but due a lack of time and
    proper testing ...
 */
 
@@ -246,22 +264,17 @@ strncasecmp(const char *s1, const char *s2, int count)
 
 #ifndef HAVE_BASENAME
 extern char *
-basename(char *inpath) {
+_Lt_basename(char *inpath) {
 
   char *ptr;
   static char *path=NULL; /* limit memory leak to one entry */
 
   if (path)
-    free(path);
-  if (!inpath) {
-    path=(char*)malloc(2);
-    strcpy(path, ".");
-    return path;
-  }
-  if (!*inpath) {
-    path=(char*)malloc(2);
-    strcpy(path, ".");
-    return path;
+     free(path);
+  if (!inpath || !*inpath) {
+     path=(char*)malloc(2);
+     strcpy(path, ".");
+     return path;
   }
 
   /* Make a local copy */  
@@ -271,14 +284,14 @@ basename(char *inpath) {
   /* limit trailing '/' chars */
   ptr=path+strlen(path)-1;
   while( (ptr>path) && (*ptr==cDIRSEP) ) {
-    *ptr='\0';
-    ptr--;
+     *ptr='\0';
+     ptr--;
   }
 
   /* look up what's left */
   ptr = strrchr(path, cDIRSEP);
   if (!ptr)
-    return path;
+     return path;
 
   if (*(ptr+1))
   {
@@ -289,30 +302,24 @@ basename(char *inpath) {
     /* "/" only */
     return ptr;
   }
-
 } /* basename() */
 #endif /* !HAVE_BASENAME */
 
 
 #ifndef HAVE_DIRNAME
 extern char *
-dirname(char *inpath) {
+_Lt_dirname(char *inpath) {
 
   char *ptr;
   static char *path=NULL; /* limit memory leak to one entry */
 
 
   if (path)
-    free(path);  
-  if (!inpath) {
-    path=(char*)malloc(2);
-    strcpy(path, ".");
-    return path;
-  }
-  if (!*inpath) {
-    path=(char*)malloc(2);
-    strcpy(path, ".");
-    return path;
+     free(path);  
+  if (!inpath || !*inpath) {
+     path=(char*)malloc(2);
+     strcpy(path, ".");
+     return path;
   }
 
   /* Make a local copy */  
@@ -321,14 +328,14 @@ dirname(char *inpath) {
 
   ptr = strrchr(path, cDIRSEP);
   if (!ptr) {
-    strcpy(path, ".");
-    return path;
+     strcpy(path, ".");
+     return path;
   }
 
   /* 'eat' trailing '/' characters */
   while( (ptr>path) && (*ptr==cDIRSEP) ) {
-    *ptr='\0';
-    ptr--;
+     *ptr='\0';
+     ptr--;
   }
   ptr=strrchr(path, cDIRSEP);
   if (ptr)
@@ -338,4 +345,3 @@ dirname(char *inpath) {
 
 } /* dirname() */ 
 #endif /* !HAVE_DIRNAME */
-
