@@ -1,5 +1,5 @@
 /*
- * LessTif ID : $Id: xdnd.c,v 1.5 1999/09/03 00:17:41 rwscott Exp $
+ * LessTif ID : $Id: xdnd.c,v 1.7 2001/07/27 18:51:58 dannybackx Exp $
  *
  * This file is maintained by Paul Sheer.
  * Integration with LessTif should be outside this source, so Paul can
@@ -300,7 +300,7 @@ int xdnd_is_dnd_aware (DndClass * dnd, Window window, int *version, Atom * typel
 			&count, &remaining, &data);
 
     if (actual != XA_ATOM || format != 32 || count == 0 || !data) {
-        DEBUGOUT(XdbDebug(__FILE__, NULL, "XGetWindowProperty failed in xdnd_is_dnd_aware - XdndAware = %ld", dnd->XdndAware));
+        DEBUGOUT(_LtDebug(__FILE__, NULL, "XGetWindowProperty failed in xdnd_is_dnd_aware - XdndAware = %ld", dnd->XdndAware));
 
 	if (data)
 	    XFree (data);
@@ -308,7 +308,7 @@ int xdnd_is_dnd_aware (DndClass * dnd, Window window, int *version, Atom * typel
     }
     types = (Atom *) data;
     *version = dnd->version < types[0] ? dnd->version : types[0];	/* minimum */
-    DEBUGOUT(XdbDebug(__FILE__, NULL,"Using XDND version %d", *version)); 
+    DEBUGOUT(_LtDebug(__FILE__, NULL,"Using XDND version %d", *version)); 
     if (count > 1) {
 	result = 0;
 	for (t = typelist; *t; t++) {
@@ -352,7 +352,7 @@ void xdnd_get_type_list (DndClass * dnd, Window window, Atom ** typelist)
     if (type != XA_ATOM || format != 32 || count == 0 || !data) {
 	if (data)
 	    XFree (data);
-        DEBUGOUT(XdbDebug(__FILE__, NULL, "XGetWindowProperty failed in xdnd_get_type_list - dnd->XdndTypeList = %ld", dnd->XdndTypeList));
+        DEBUGOUT(_LtDebug(__FILE__, NULL, "XGetWindowProperty failed in xdnd_get_type_list - dnd->XdndTypeList = %ld", dnd->XdndTypeList));
 	return;
     }
     *typelist = malloc ((count + 1) * sizeof (Atom));
@@ -625,7 +625,7 @@ void xdnd_send_finished (DndClass * dnd, Window window, Window from, int error)
 int xdnd_convert_selection (DndClass * dnd, Window window, Window requester, Atom type)
 {
     if (window != XGetSelectionOwner (dnd->display, dnd->XdndSelection)) {
-        DEBUGOUT(XdbDebug(__FILE__, NULL,"xdnd_convert_selection(): XGetSelectionOwner failed"));
+        DEBUGOUT(_LtDebug(__FILE__, NULL,"xdnd_convert_selection(): XGetSelectionOwner failed"));
 	return 1;
     }
     XConvertSelection (dnd->display, dnd->XdndSelection, type,
@@ -637,7 +637,7 @@ int xdnd_convert_selection (DndClass * dnd, Window window, Window requester, Ato
 int xdnd_set_selection_owner (DndClass * dnd, Window window, Atom type)
 {
     if (!XSetSelectionOwner (dnd->display, dnd->XdndSelection, window, CurrentTime)) {
-        DEBUGOUT(XdbDebug(__FILE__, NULL, "xdnd_set_selection_owner(): XSetSelectionOwner failed"));
+        DEBUGOUT(_LtDebug(__FILE__, NULL, "xdnd_set_selection_owner(): XSetSelectionOwner failed"));
 	return 1;
     }
     return 0;
@@ -646,9 +646,9 @@ int xdnd_set_selection_owner (DndClass * dnd, Window window, Atom type)
 void xdnd_selection_send (DndClass * dnd, XSelectionRequestEvent * request, unsigned char *data, int length)
 {
     XEvent xevent;
-    DEBUGOUT(XdbDebug(__FILE__, NULL, "      requestor = %ld", request->requestor));
-    DEBUGOUT(XdbDebug(__FILE__, NULL, "      property = %ld", request->property));
-    DEBUGOUT(XdbDebug(__FILE__, NULL, "      length = %d", length));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "      requestor = %ld", request->requestor));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "      property = %ld", request->property));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "      length = %d", length));
     XChangeProperty (dnd->display, request->requestor, request->property,
 		     request->target, 8, PropModeReplace, data, length);
     xevent.xselection.type = SelectionNotify;
@@ -729,7 +729,7 @@ Atom xdnd_drag (DndClass * dnd, Window from, Atom action, Atom * typelist)
     do {
 	XNextEvent (dnd->display, &xevent);
 	if (xevent.type == ButtonRelease) {
-            DEBUGOUT(XdbDebug(__FILE__, NULL, "button release - no motion"));
+            DEBUGOUT(_LtDebug(__FILE__, NULL, "button release - no motion"));
 	    XSendEvent (dnd->display, xevent.xany.window, 0, ButtonReleaseMask, &xevent);
 	    return 0;
 	}
@@ -752,7 +752,7 @@ Atom xdnd_drag (DndClass * dnd, Window from, Atom action, Atom * typelist)
 	}
     }
 
-    DEBUGOUT(XdbDebug(__FILE__, NULL, "moved 5 pixels - going to drag"));
+    DEBUGOUT(_LtDebug(__FILE__, NULL, "moved 5 pixels - going to drag"));
 
     n = array_length (typelist);
     if (n > XDND_THREE)
@@ -773,7 +773,7 @@ Atom xdnd_drag (DndClass * dnd, Window from, Atom action, Atom * typelist)
 		      ButtonMotionMask | PointerMotionMask | ButtonPressMask | ButtonReleaseMask,
 		      GrabModeAsync, GrabModeAsync, None,
 		      cursor->cursor, CurrentTime) != GrabSuccess)
-        DEBUGOUT(XdbDebug(__FILE__, NULL, "Unable to grab pointer"));
+        DEBUGOUT(_LtDebug(__FILE__, NULL, "Unable to grab pointer"));
 
     while (xevent.xany.type != ButtonRelease) {
 	XAllowEvents (dnd->display, SyncPointer, CurrentTime);
@@ -791,7 +791,7 @@ Atom xdnd_drag (DndClass * dnd, Window from, Atom action, Atom * typelist)
 	    break;
 	case ButtonRelease:
 /* done, but must send a leave event */
-            DEBUGOUT(XdbDebug(__FILE__, NULL, "ButtonRelease - exiting event loop"));
+            DEBUGOUT(_LtDebug(__FILE__, NULL, "ButtonRelease - exiting event loop"));
 	    break;
 	case MotionNotify:
 	    memcpy (&xevent_temp, &xevent, sizeof (xevent));
@@ -812,8 +812,8 @@ Atom xdnd_drag (DndClass * dnd, Window from, Atom action, Atom * typelist)
 	  found_descendent:
 /* last_window is just for debug purposes */
 	    if (last_window != xevent.xmotion.subwindow) {
-                DEBUGOUT(XdbDebug(__FILE__, NULL, "window crossing to %ld", xevent.xmotion.subwindow));
-                DEBUGOUT(XdbDebug(__FILE__, NULL, "  current window is %ld", over_window));
+                DEBUGOUT(_LtDebug(__FILE__, NULL, "window crossing to %ld", xevent.xmotion.subwindow));
+                DEBUGOUT(_LtDebug(__FILE__, NULL, "  current window is %ld", over_window));
 	    }
 	    dnd_aware = 0;
 /* is the new window dnd aware? if not stay in the old window */
@@ -827,34 +827,34 @@ Atom xdnd_drag (DndClass * dnd, Window from, Atom action, Atom * typelist)
 		xevent.xany.window = over_window;
 		if (over_window) {
 		    if (dnd->stage == XDND_DRAG_STAGE_ENTERED) {
-                        DEBUGOUT(XdbDebug(__FILE__, NULL, "got leave at right stage"));
+                        DEBUGOUT(_LtDebug(__FILE__, NULL, "got leave at right stage"));
 			dnd->stage = XDND_DRAG_STAGE_DRAGGING;
 			if (dnd->internal_drag) {
-                            DEBUGOUT(XdbDebug(__FILE__, NULL, "  our own widget"));
+                            DEBUGOUT(_LtDebug(__FILE__, NULL, "  our own widget"));
 			    if (dnd->widget_apply_leave)
 				(*dnd->widget_apply_leave) (dnd, xevent.xany.window);
 			} else {
-                            DEBUGOUT(XdbDebug(__FILE__, NULL, "  not our widget - sending XdndLeave"));
+                            DEBUGOUT(_LtDebug(__FILE__, NULL, "  not our widget - sending XdndLeave"));
 			    xdnd_send_leave (dnd, xevent.xany.window, from);
 			}
 			dnd->internal_drag = 0;
 			dnd->dropper_window = 0;
 			dnd->ready_to_drop = 0;
 		    } else {
-			DEBUGOUT(XdbDebug(__FILE__, NULL, "got leave at wrong stage - ignoring"));
+			DEBUGOUT(_LtDebug(__FILE__, NULL, "got leave at wrong stage - ignoring"));
 		    }
 		}
 /* entering window we are currently over */
 		over_window = xevent.xmotion.subwindow;
 		if (dnd_aware) {
-		    DEBUGOUT(XdbDebug(__FILE__, NULL, "  is dnd aware"));
+		    DEBUGOUT(_LtDebug(__FILE__, NULL, "  is dnd aware"));
 		    dnd->stage = XDND_DRAG_STAGE_ENTERED;
 		    if (dnd->widget_exists && (*dnd->widget_exists) (dnd, over_window))
 			dnd->internal_drag = 1;
 		    if (dnd->internal_drag) {
-			DEBUGOUT(XdbDebug(__FILE__, NULL, "    our own widget"));
+			DEBUGOUT(_LtDebug(__FILE__, NULL, "    our own widget"));
 		    } else {
-			DEBUGOUT(XdbDebug(__FILE__, NULL, "    not our widget - sending XdndEnter"));
+			DEBUGOUT(_LtDebug(__FILE__, NULL, "    not our widget - sending XdndEnter"));
 			xdnd_send_enter (dnd, over_window, from, typelist);
 		    }
 		    dnd->want_position = 1;
@@ -870,13 +870,13 @@ Atom xdnd_drag (DndClass * dnd, Window from, Atom action, Atom * typelist)
 /* got here, so we are just moving `inside' the same window */
 		if (dnd->stage == XDND_DRAG_STAGE_ENTERED) {
 		    dnd->supported_action = dnd->XdndActionCopy;
-		    DEBUGOUT(XdbDebug(__FILE__, NULL, "got motion at right stage"));
+		    DEBUGOUT(_LtDebug(__FILE__, NULL, "got motion at right stage"));
 		    dnd->x = xevent.xmotion.x_root;
 		    dnd->y = xevent.xmotion.y_root;
 		    if (dnd->want_position && outside_rectangle (dnd->x, dnd->y, &dnd->rectangle)) {
-			DEBUGOUT(XdbDebug(__FILE__, NULL, "  want position and outside rectangle"));
+			DEBUGOUT(_LtDebug(__FILE__, NULL, "  want position and outside rectangle"));
 			if (dnd->internal_drag) {
-			    DEBUGOUT(XdbDebug(__FILE__, NULL, "    our own widget"));
+			    DEBUGOUT(_LtDebug(__FILE__, NULL, "    our own widget"));
 			    dnd->ready_to_drop = (*dnd->widget_apply_position) (dnd, over_window, from,
 										action, dnd->x, dnd->y, xevent.xmotion.time, typelist,
 										&dnd->want_position, &dnd->supported_action, &dnd->desired_type, &dnd->rectangle);
@@ -885,25 +885,25 @@ Atom xdnd_drag (DndClass * dnd, Window from, Atom action, Atom * typelist)
 				dnd->want_position = 1;
 				dnd->rectangle.width = dnd->rectangle.height = 0;
 			    }
-			    DEBUGOUT(XdbDebug(__FILE__, NULL, "      return action=%ld", dnd->supported_action));
+			    DEBUGOUT(_LtDebug(__FILE__, NULL, "      return action=%ld", dnd->supported_action));
 			} else {
-			    DEBUGOUT(XdbDebug(__FILE__, NULL, "    not our own widget - sending XdndPosition"));
+			    DEBUGOUT(_LtDebug(__FILE__, NULL, "    not our own widget - sending XdndPosition"));
 			    xdnd_send_position (dnd, over_window, from, action, dnd->x, dnd->y, xevent.xmotion.time);
 			}
 		    } else {
-			DEBUGOUT(XdbDebug(__FILE__, NULL, "  doesn't want position or inside rectangle"));
-			DEBUGOUT(XdbDebug(__FILE__, NULL, "    rectangle = (x=%d, y=%d, w=%d, h=%d), (x,y)=(%d,%d) want_position=%d\n", dnd->rectangle.x, dnd->rectangle.y, dnd->rectangle.width, dnd->rectangle.height, dnd->x, dnd->y, dnd->want_position));
+			DEBUGOUT(_LtDebug(__FILE__, NULL, "  doesn't want position or inside rectangle"));
+			DEBUGOUT(_LtDebug(__FILE__, NULL, "    rectangle = (x=%d, y=%d, w=%d, h=%d), (x,y)=(%d,%d) want_position=%d\n", dnd->rectangle.x, dnd->rectangle.y, dnd->rectangle.width, dnd->rectangle.height, dnd->x, dnd->y, dnd->want_position));
 		    }
 		}
 	    }
 	    last_window = xevent.xmotion.subwindow;
 	    break;
 	case ClientMessage:
-	    DEBUGOUT(XdbDebug(__FILE__, NULL, "ClientMessage recieved"));
+	    DEBUGOUT(_LtDebug(__FILE__, NULL, "ClientMessage recieved"));
 	    if (xevent.xclient.message_type == dnd->XdndStatus && !dnd->internal_drag) {
-		DEBUGOUT(XdbDebug(__FILE__, NULL, "  XdndStatus recieved"));
+		DEBUGOUT(_LtDebug(__FILE__, NULL, "  XdndStatus recieved"));
 		if (dnd->stage == XDND_DRAG_STAGE_ENTERED && XDND_STATUS_TARGET_WIN (&xevent) == dnd->dropper_window) {
-		    DEBUGOUT(XdbDebug(__FILE__, NULL, "    XdndStatus stage correct, dropper window correct"));
+		    DEBUGOUT(_LtDebug(__FILE__, NULL, "    XdndStatus stage correct, dropper window correct"));
 		    dnd->want_position = XDND_STATUS_WANT_POSITION (&xevent);
 		    dnd->ready_to_drop = XDND_STATUS_WILL_ACCEPT (&xevent);
 		    dnd->rectangle.x = XDND_STATUS_RECT_X (&xevent);
@@ -913,15 +913,15 @@ Atom xdnd_drag (DndClass * dnd, Window from, Atom action, Atom * typelist)
 		    dnd->supported_action = dnd->XdndActionCopy;
 		    if (dnd_version_at_least (dnd->dragging_version, 2))
 			dnd->supported_action = XDND_STATUS_ACTION (&xevent);
-		    DEBUGOUT(XdbDebug(__FILE__, NULL, "      return action=%ld", dnd->supported_action));
+		    DEBUGOUT(_LtDebug(__FILE__, NULL, "      return action=%ld", dnd->supported_action));
 		    /* if not ready, keep sending positions, this check is repeated above for internal widgets */
 		    if (!dnd->ready_to_drop) {
 			dnd->want_position = 1;
 			dnd->rectangle.width = dnd->rectangle.height = 0;
 		    }
-		    DEBUGOUT(XdbDebug(__FILE__, NULL, "      rectangle = (x=%d, y=%d, w=%d, h=%d), want_position=%d\n", dnd->rectangle.x, dnd->rectangle.y, dnd->rectangle.width, dnd->rectangle.height, dnd->want_position));
+		    DEBUGOUT(_LtDebug(__FILE__, NULL, "      rectangle = (x=%d, y=%d, w=%d, h=%d), want_position=%d\n", dnd->rectangle.x, dnd->rectangle.y, dnd->rectangle.width, dnd->rectangle.height, dnd->want_position));
 		} else {
-		    DEBUGOUT(XdbDebug(__FILE__, NULL, "    XdndStatus stage incorrect or dropper window incorrect"));
+		    DEBUGOUT(_LtDebug(__FILE__, NULL, "    XdndStatus stage incorrect or dropper window incorrect"));
 		}
 	    }
 	    break;
@@ -929,11 +929,11 @@ Atom xdnd_drag (DndClass * dnd, Window from, Atom action, Atom * typelist)
 /* the target widget MAY request data, so wait for SelectionRequest */
 		int length = 0;
 		unsigned char *data = 0;
-		DEBUGOUT(XdbDebug(__FILE__, NULL, "SelectionRequest - getting widget data"));
+		DEBUGOUT(_LtDebug(__FILE__, NULL, "SelectionRequest - getting widget data"));
 
 		(*dnd->widget_get_data) (dnd, from, &data, &length, xevent.xselectionrequest.target);
 		if (data) {
-		    DEBUGOUT(XdbDebug(__FILE__, NULL, "  sending selection"));
+		    DEBUGOUT(_LtDebug(__FILE__, NULL, "  sending selection"));
 		    xdnd_selection_send (dnd, &xevent.xselectionrequest, data, length);
 		    xdnd_xfree (data);
 		}
@@ -944,7 +944,7 @@ Atom xdnd_drag (DndClass * dnd, Window from, Atom action, Atom * typelist)
 
     if (dnd->ready_to_drop) {
 	Time time;
-	DEBUGOUT(XdbDebug(__FILE__, NULL, "ready_to_drop - sending XdndDrop"));
+	DEBUGOUT(_LtDebug(__FILE__, NULL, "ready_to_drop - sending XdndDrop"));
 	time = xevent.xbutton.time;
 	if (dnd->internal_drag) {
 /* we are dealing with our own widget, no need to send drop events, just put the data straight */
@@ -955,13 +955,13 @@ Atom xdnd_drag (DndClass * dnd, Window from, Atom action, Atom * typelist)
 		if (data) {
 		    if (!(*dnd->widget_insert_drop) (dnd, data, length, 0, dnd->dropper_window, from, dnd->desired_type)) {
 			result = dnd->supported_action;		/* success - so return action to caller */
-			DEBUGOUT(XdbDebug(__FILE__, NULL, "  inserted data into widget - success"));
+			DEBUGOUT(_LtDebug(__FILE__, NULL, "  inserted data into widget - success"));
 		    } else {
-			DEBUGOUT(XdbDebug(__FILE__, NULL, "  inserted data into widget - failed"));
+			DEBUGOUT(_LtDebug(__FILE__, NULL, "  inserted data into widget - failed"));
 		    }
 		    xdnd_xfree (data);
 		} else {
-		    DEBUGOUT(XdbDebug(__FILE__, NULL, "  got data from widget, but data is null"));
+		    DEBUGOUT(_LtDebug(__FILE__, NULL, "  got data from widget, but data is null"));
 		}
 	    }
 	} else {
@@ -973,9 +973,9 @@ Atom xdnd_drag (DndClass * dnd, Window from, Atom action, Atom * typelist)
 		XAllowEvents (dnd->display, SyncPointer, CurrentTime);
 		XNextEvent (dnd->display, &xevent);
 		if (xevent.type == ClientMessage && xevent.xclient.message_type == dnd->XdndFinished) {
-		    DEBUGOUT(XdbDebug(__FILE__, NULL, "XdndFinished"));
+		    DEBUGOUT(_LtDebug(__FILE__, NULL, "XdndFinished"));
 		    if (XDND_FINISHED_TARGET_WIN (&xevent) == dnd->dropper_window) {
-			DEBUGOUT(XdbDebug(__FILE__, NULL, "  source correct - exiting event loop, action=%ld", dnd->supported_action));
+			DEBUGOUT(_LtDebug(__FILE__, NULL, "  source correct - exiting event loop, action=%ld", dnd->supported_action));
 			result = dnd->supported_action;		/* success - so return action to caller */
 			break;
 		    }
@@ -984,7 +984,7 @@ Atom xdnd_drag (DndClass * dnd, Window from, Atom action, Atom * typelist)
 			(*dnd->handle_expose_events) (dnd, &xevent);
 		} else if (xevent.type == MotionNotify) {
 		    if (xevent.xmotion.time > time + (dnd->time_out ? dnd->time_out * 1000 : 10000)) {	/* allow a ten second timeout as default */
-			DEBUGOUT(XdbDebug(__FILE__, NULL, "timeout - exiting event loop"));
+			DEBUGOUT(_LtDebug(__FILE__, NULL, "timeout - exiting event loop"));
 			break;
 		    }
 		} else if (xevent.type == SelectionRequest && xevent.xselectionrequest.selection == dnd->XdndSelection) {
@@ -992,10 +992,10 @@ Atom xdnd_drag (DndClass * dnd, Window from, Atom action, Atom * typelist)
 		    int length = 0;
 		    unsigned char *data = 0;
 
-		    DEBUGOUT(XdbDebug(__FILE__, NULL, "SelectionRequest - getting widget data"));
+		    DEBUGOUT(_LtDebug(__FILE__, NULL, "SelectionRequest - getting widget data"));
 		    (*dnd->widget_get_data) (dnd, from, &data, &length, xevent.xselectionrequest.target);
 		    if (data) {
-			DEBUGOUT(XdbDebug(__FILE__, NULL, "  sending selection"));
+			DEBUGOUT(_LtDebug(__FILE__, NULL, "  sending selection"));
 			xdnd_selection_send (dnd, &xevent.xselectionrequest, data, length);
 			xdnd_xfree (data);
 		    }
@@ -1005,7 +1005,7 @@ Atom xdnd_drag (DndClass * dnd, Window from, Atom action, Atom * typelist)
 		}
 	    }
     } else {
-	DEBUGOUT(XdbDebug(__FILE__, NULL, "not ready_to_drop - ungrabbing pointer"));
+	DEBUGOUT(_LtDebug(__FILE__, NULL, "not ready_to_drop - ungrabbing pointer"));
     }
     XUngrabPointer (dnd->display, CurrentTime);
     xdnd_reset (dnd);
@@ -1017,10 +1017,10 @@ int xdnd_handle_drop_events (DndClass * dnd, XEvent * xevent)
 {
     int result = 0;
     if (xevent->type == SelectionNotify) {
-	DEBUGOUT(XdbDebug(__FILE__, NULL, "got SelectionNotify"));
+	DEBUGOUT(_LtDebug(__FILE__, NULL, "got SelectionNotify"));
 	if (xevent->xselection.property == dnd->Xdnd_NON_PROTOCOL_ATOM && dnd->stage == XDND_DROP_STAGE_CONVERTING) {
 	    int error;
-	    DEBUGOUT(XdbDebug(__FILE__, NULL, "  property is Xdnd_NON_PROTOCOL_ATOM - getting selection"));
+	    DEBUGOUT(_LtDebug(__FILE__, NULL, "  property is Xdnd_NON_PROTOCOL_ATOM - getting selection"));
 	    error = xdnd_get_selection (dnd, dnd->dragger_window, xevent->xselection.property, xevent->xany.window);
 /* error is not actually used, i think future versions of the protocol maybe should return 
    an error status to the calling window with the XdndFinished client message */
@@ -1031,43 +1031,43 @@ int xdnd_handle_drop_events (DndClass * dnd, XEvent * xevent)
 	    dnd->stage = XDND_DROP_STAGE_IDLE;
 	    result = 1;
 	} else {
-	    DEBUGOUT(XdbDebug(__FILE__, NULL, "  property is not Xdnd_NON_PROTOCOL_ATOM - ignoring"));
+	    DEBUGOUT(_LtDebug(__FILE__, NULL, "  property is not Xdnd_NON_PROTOCOL_ATOM - ignoring"));
 	}
     } else if (xevent->type == ClientMessage) {
-	DEBUGOUT(XdbDebug(__FILE__, NULL, "got ClientMessage"));
+	DEBUGOUT(_LtDebug(__FILE__, NULL, "got ClientMessage"));
 	if (xevent->xclient.message_type == dnd->XdndEnter) {
-	    DEBUGOUT(XdbDebug(__FILE__, NULL, "  message_type is XdndEnter"));
+	    DEBUGOUT(_LtDebug(__FILE__, NULL, "  message_type is XdndEnter"));
 	    xdnd_reset (dnd);
 	    dnd->dragger_window = XDND_ENTER_SOURCE_WIN (xevent);
 	    dnd->dropper_window = xevent->xany.window;
 	    xdnd_xfree (dnd->dragger_typelist);
 	    if (XDND_ENTER_THREE_TYPES (xevent)) {
-		DEBUGOUT(XdbDebug(__FILE__, NULL, "    three types only"));
+		DEBUGOUT(_LtDebug(__FILE__, NULL, "    three types only"));
 		xdnd_get_three_types (dnd, xevent, &dnd->dragger_typelist);
 	    } else {
-		DEBUGOUT(XdbDebug(__FILE__, NULL, "    more than three types - getting list"));
+		DEBUGOUT(_LtDebug(__FILE__, NULL, "    more than three types - getting list"));
 		xdnd_get_type_list (dnd, dnd->dragger_window, &dnd->dragger_typelist);
 	    }
 	    if (dnd->dragger_typelist)
 		dnd->stage = XDND_DROP_STAGE_ENTERED;
 	    else
-		DEBUGOUT(XdbDebug(__FILE__, NULL, "      typelist returned as zero!"));
+		DEBUGOUT(_LtDebug(__FILE__, NULL, "      typelist returned as zero!"));
 	    dnd->dragging_version = XDND_ENTER_VERSION (xevent);
 	    result = 1;
 	} else if (xevent->xclient.message_type == dnd->XdndLeave) {
-	    DEBUGOUT(XdbDebug(__FILE__, NULL, "  message_type is XdndLeave"));
+	    DEBUGOUT(_LtDebug(__FILE__, NULL, "  message_type is XdndLeave"));
 	    if (dnd->dragger_window == XDND_LEAVE_SOURCE_WIN (xevent) && dnd->stage == XDND_DROP_STAGE_ENTERED) {
-		DEBUGOUT(XdbDebug(__FILE__, NULL, "    leaving"));
+		DEBUGOUT(_LtDebug(__FILE__, NULL, "    leaving"));
 		if (dnd->widget_apply_leave)
 		    (*dnd->widget_apply_leave) (dnd, xevent->xany.window);
 		dnd->stage = XDND_DROP_STAGE_IDLE;
 		xdnd_xfree (dnd->dragger_typelist);
 		result = 1;
 	    } else {
-		DEBUGOUT(XdbDebug(__FILE__, NULL, "    wrong stage or from wrong window"));
+		DEBUGOUT(_LtDebug(__FILE__, NULL, "    wrong stage or from wrong window"));
 	    }
 	} else if (xevent->xclient.message_type == dnd->XdndPosition) {
-	    DEBUGOUT(XdbDebug(__FILE__, NULL, "  message_type is XdndPosition"));
+	    DEBUGOUT(_LtDebug(__FILE__, NULL, "  message_type is XdndPosition"));
 	    if (dnd->dragger_window == XDND_POSITION_SOURCE_WIN (xevent) && dnd->stage == XDND_DROP_STAGE_ENTERED) {
 		int want_position;
 		Atom action;
@@ -1084,29 +1084,29 @@ int xdnd_handle_drop_events (DndClass * dnd, XEvent * xevent)
 		dnd->will_accept = (*dnd->widget_apply_position) (dnd, xevent->xany.window, dnd->dragger_window,
 		action, dnd->x, dnd->y, dnd->time, dnd->dragger_typelist,
 								  &want_position, &dnd->supported_action, &dnd->desired_type, &rectangle);
-		DEBUGOUT(XdbDebug(__FILE__, NULL, "    will accept = %d", dnd->will_accept));
-		DEBUGOUT(XdbDebug(__FILE__, NULL, "    sending status"));
-		DEBUGOUT(XdbDebug(__FILE__, NULL, "      action=%ld, rectangle = (x=%d, y=%d, w=%d, h=%d), (x,y)=(%d,%d) want_position=%d\n", dnd->supported_action, rectangle.x, rectangle.y, rectangle.width, rectangle.height, dnd->x, dnd->y, want_position));
+		DEBUGOUT(_LtDebug(__FILE__, NULL, "    will accept = %d", dnd->will_accept));
+		DEBUGOUT(_LtDebug(__FILE__, NULL, "    sending status"));
+		DEBUGOUT(_LtDebug(__FILE__, NULL, "      action=%ld, rectangle = (x=%d, y=%d, w=%d, h=%d), (x,y)=(%d,%d) want_position=%d\n", dnd->supported_action, rectangle.x, rectangle.y, rectangle.width, rectangle.height, dnd->x, dnd->y, want_position));
 		xdnd_send_status (dnd, dnd->dragger_window, xevent->xany.window, dnd->will_accept,
 				  want_position, rectangle.x, rectangle.y, rectangle.width, rectangle.height, dnd->supported_action);
 		result = 1;
 	    } else {
-		DEBUGOUT(XdbDebug(__FILE__, NULL, "    wrong stage or from wrong window"));
+		DEBUGOUT(_LtDebug(__FILE__, NULL, "    wrong stage or from wrong window"));
 	    }
 	} else if (xevent->xclient.message_type == dnd->XdndDrop) {
-	    DEBUGOUT(XdbDebug(__FILE__, NULL, "  message_type is XdndDrop"));
+	    DEBUGOUT(_LtDebug(__FILE__, NULL, "  message_type is XdndDrop"));
 	    if (dnd->dragger_window == XDND_DROP_SOURCE_WIN (xevent) && dnd->stage == XDND_DROP_STAGE_ENTERED) {
 		dnd->time = CurrentTime;
 		if (dnd_version_at_least (dnd->dragging_version, 1))
 		    dnd->time = XDND_DROP_TIME (xevent);
 		if (dnd->will_accept) {
-		    DEBUGOUT(XdbDebug(__FILE__, NULL, "    will_accept is true - converting selectiong"));
-		    DEBUGOUT(XdbDebug(__FILE__, NULL, "      my window is %ld", dnd->dropper_window));
-		    DEBUGOUT(XdbDebug(__FILE__, NULL, "        source window is %ld", dnd->dragger_window));
+		    DEBUGOUT(_LtDebug(__FILE__, NULL, "    will_accept is true - converting selectiong"));
+		    DEBUGOUT(_LtDebug(__FILE__, NULL, "      my window is %ld", dnd->dropper_window));
+		    DEBUGOUT(_LtDebug(__FILE__, NULL, "        source window is %ld", dnd->dragger_window));
 		    xdnd_convert_selection (dnd, dnd->dragger_window, dnd->dropper_window, dnd->desired_type);
 		    dnd->stage = XDND_DROP_STAGE_CONVERTING;
 		} else {
-		    DEBUGOUT(XdbDebug(__FILE__, NULL, "    will_accept is false - sending finished"));
+		    DEBUGOUT(_LtDebug(__FILE__, NULL, "    will_accept is false - sending finished"));
 		    if (dnd_version_at_least (dnd->dragging_version, 1))
 			xdnd_send_finished (dnd, dnd->dragger_window, xevent->xany.window, 1);
 		    xdnd_xfree (dnd->dragger_typelist);
@@ -1115,7 +1115,7 @@ int xdnd_handle_drop_events (DndClass * dnd, XEvent * xevent)
 		}
 		result = 1;
 	    } else {
-		DEBUGOUT(XdbDebug(__FILE__, NULL, "    wrong stage or from wrong window"));
+		DEBUGOUT(_LtDebug(__FILE__, NULL, "    wrong stage or from wrong window"));
 	    }
 	}
     }
