@@ -1,13 +1,19 @@
 /*
+   $Header: /cvsroot/lesstif/lesstif/test/Xm-2.0/combobox/test12.c,v 1.5 2001/05/15 13:51:56 amai Exp $
    This test case looks for memory leakage.
    Based on the test38.c from Xm/form.
  */
 
+
+#include <stdlib.h>
+#include <stdio.h>
 #include <unistd.h>
+
 #include <Xm/Xm.h>
 #include <Xm/ComboBox.h>
+#include <Xm/List.h>
 
-void 
+int
 main(int argc, char *argv[])
 {
     XtAppContext app;
@@ -20,7 +26,7 @@ main(int argc, char *argv[])
 
     shell = XtAppInitialize(&app, "Test", NULL, 0,
 			    &argc, argv, NULL, NULL, 0);
-    while (iter < 10000)
+    while (iter < 1000)
     {
 	before = sbrk((ptrdiff_t) 0);
 	w = XtCreateWidget("name", xmComboBoxWidgetClass, shell, NULL, 0);
