@@ -4,6 +4,7 @@
 
 #include <Xm/BulletinB.h>
 #include <Xm/ComboBoxP.h>
+#include <Xm/List.h>
 #include "XdbPrintResources.c"
 
 #if !defined(CB_List)
@@ -74,11 +75,11 @@ main(int argc, char **argv)
 
   XtRealizeWidget(toplevel);
 
-  #if 1
+#if 1
   XdbPrintResources(CB_ListShell(widget));
 
   XdbPrintResources(widget);
-  #endif
+#endif
 
   check_geometry(widget);
 
