@@ -60,7 +60,7 @@ main(int argc, char **argv)
 
 	XtRealizeWidget(toplevel);
 
-	XtAppMainLoop(app);
+	LessTifTestMainLoop(toplevel);
 
 	exit(0);
 }
