@@ -1,4 +1,4 @@
-/*
+/* $Header: /cvsroot/lesstif/lesstif/test/Xm/arrowbg/test4.c,v 1.6 2001/06/18 07:59:05 amai Exp $
    From:        Yasushi Yamasaki <yamapu@osk3.3web.ne.jp>
    To:          lesstif@hungry.com
    Subject:     bug report
@@ -6,12 +6,17 @@
    Cc:          yamapu@osk3.3web.ne.jp
  */
 
-/* test1.c */
+#include <stdlib.h>
+#include <stdio.h>
 #include <unistd.h>
+
 #include <Xm/Xm.h>
 #include <Xm/BulletinB.h>
 #include <Xm/ArrowBG.h>
 
+#include "../../common/Test.h"
+#include "../../common/DumpLayout.h"
+
 int
 main(int argc, char *argv[])
 {
@@ -32,14 +37,14 @@ main(int argc, char *argv[])
 	w = XtCreateWidget("name", xmArrowButtonGadgetClass, bb, NULL, 0);
 	XtDestroyWidget(w);
 	after = sbrk((ptrdiff_t) 0);
-	if ((int)after - (int)before > 0)
+	if ((int)((char *)after - (char *)before) > 0)
 	{
 	    if (iter != 0)
 	    {
 		/*
 		printf("%i %i %p %i\n", iter, iter - diff, after - before, (after - before) / (iter - diff));
 		 */
-		total += (int)after - (int)before;
+		total += (int)((char *)after - (char*)before);
 	    }
 	    diff = iter;
 	}
