@@ -1,4 +1,6 @@
 /*
+   $Header: /cvsroot/lesstif/lesstif/test/Xm/arrowbutton/test4.c,v 1.5 2001/08/28 14:45:46 amai Exp $
+
    From:        Yasushi Yamasaki <yamapu@osk3.3web.ne.jp>
    To:          lesstif@hungry.com
    Subject:     bug report
@@ -6,8 +8,10 @@
    Cc:          yamapu@osk3.3web.ne.jp
  */
 
-/* test1.c */
+#include <stdlib.h>
+#include <stdio.h>
 #include <unistd.h>
+
 #include <Xm/Xm.h>
 #include <Xm/BulletinB.h>
 #include <Xm/ArrowB.h>
