@@ -1,4 +1,4 @@
-/*
+/* $Header: /cvsroot/lesstif/lesstif/test/Xm/drawingarea/test6.c,v 1.6 2001/05/19 21:40:04 amai Exp $
    From:        Yasushi Yamasaki <yamapu@osk3.3web.ne.jp>
    To:          lesstif@hungry.com
    Subject:     bug report
@@ -6,8 +6,11 @@
    Cc:          yamapu@osk3.3web.ne.jp
  */
 
-/* test1.c */
+#include <stdlib.h>
+#include <stdio.h>
 #include <unistd.h>
+
+
 #include <Xm/Xm.h>
 #include <Xm/DrawingA.h>
 
