@@ -1,4 +1,4 @@
-/* $Id: test10.c,v 1.2 2000/12/17 19:20:39 rwscott Exp $ */
+/* $Id: test10.c,v 1.3 2001/05/18 12:49:24 rwscott Exp $ */
 /*
 Rick Scott wrote:
   
@@ -68,10 +68,17 @@ main(int argc, char **argv)
  * querying the current geometry.
  */
 {
+#if XmVERSION > 1
+static XtWidgetGeometry Expected[] = {
+   {CWWidth | CWHeight            ,    0,    0,  100,  100, 0,0,0, /* Form */},
+   {CWWidth | CWHeight | CWX | CWY,    0,    0,   76,   76, 0,0,0, /* Button1 */},
+};
+#else
 static XtWidgetGeometry Expected[] = {
    {CWWidth | CWHeight            ,    0,    0,  100,  100, 0,0,0, /* Form */},
    {CWWidth | CWHeight | CWX | CWY,    0,    0,   12,   12, 0,0,0, /* Button1 */},
 };
+#endif
 /* toplevel should be replaced with to correct applicationShell */
 PrintDetails(toplevel, Expected);
 }
