@@ -1,3 +1,4 @@
+/* $Header: /cvsroot/lesstif/lesstif/test/Xm/filesb/test7.c,v 1.10 2001/06/15 09:04:05 amai Exp $ */
 /*
 Received: from magi.com for rwscott@magi.com
  with iSTAR POP Server istar-vpopper (v1.13 12.2.1996) Sat Dec 13 16:06:11 1997
@@ -44,8 +45,21 @@ patch.
 -jon
 */
 
-/* test/filesb/test7.c */
-#include <Xm/XmAll.h>
+#include <stdlib.h>
+
+#include <Xm/Xm.h>
+#include <Xm/CascadeB.h>
+#include <Xm/FileSB.h>
+#include <Xm/Label.h>
+#include <Xm/RowColumn.h>
+#include <Xm/Separator.h>
+
+#include "../../common/Test.h"
+#include "../../common/DumpLayout.h"
+
+#include "mkdirtree.h"
+
+
 Widget GXCreateFileBox(Widget parent);
 Widget menubar,button;
 
@@ -55,6 +69,7 @@ static char *FallBack[] = {
 };
 
 Widget GXTopWidget, GXClipBox;
+
 int main(int argc, char **argv)
 {
   XtAppContext theApp;
@@ -71,9 +86,15 @@ int main(int argc, char **argv)
   
     
 {
+#if XmVERSION > 1
+    static XtWidgetGeometry Expected[] = {
+   {CWWidth | CWHeight            ,   57,   73,   34,   17, 0,0,0}, /* Label */ 
+};
+#else
     static XtWidgetGeometry Expected[] = {
    CWWidth | CWHeight            ,   57,   73,   34,   17, 0,0,0, /* Label */ 
-    };
+};
+#endif
     PrintDetails(GXTopWidget,Expected);
 };
   LessTifTestMainLoop(GXTopWidget);
@@ -96,7 +117,7 @@ GXCreateFileBox(Widget parent)
  * create a FileSelectionBox child of parent  
 -*/
 {
-    Arg args[20];
+    Arg args[2];
     int n = 0;
     Widget filew, menu;
     Widget work;
@@ -104,7 +125,7 @@ GXCreateFileBox(Widget parent)
     n = 0;
     /* XtSetArg(args[n], XmNdialogStyle, XmDIALOG_APPLICATION_MODAL);  n++; */
     filew = XmCreateFileSelectionDialog(parent, "FileBox", args, n);
-    XtAddCallback(filew,XmNcancelCallback, CancelCB, NULL);
+    XtAddCallback(filew,XmNcancelCallback, (XtCallbackProc)CancelCB, NULL);
     set_path(filew);
     /* these calls are here to force the menu bar to the top, but it fails
        under lesstif */
