@@ -1,15 +1,25 @@
+/* $Header: /cvsroot/lesstif/lesstif/test/Xm/filesb/test9.c,v 1.13 2001/06/15 09:04:05 amai Exp $ */
+
 #include <stdio.h>
+#include <stdlib.h>
+
 #include <Xm/Xm.h>
 #include <Xm/Label.h>
 #include <Xm/TextF.h>
 #include <Xm/Form.h>
 #include <Xm/RowColumn.h>
+#include <Xm/FileSBP.h>
 #include <Xm/FileSB.h>
 #include <Xm/PushB.h>
 #include <Xm/Frame.h>
 #include <Xm/Text.h>
 #include <Xm/MessageB.h>
 
+#include "../../common/Test.h"
+#include "../../common/DumpLayout.h"
+
+#include "mkdirtree.h"
+
 XmQualifyProc (*defaultQualifyProc)();
 Widget In;
 Widget Out;
@@ -81,7 +91,7 @@ StuffValues(Widget w, Widget In, XmFileSelectionBoxCallbackStruct *in)
 	StuffXmString(XtNameToWidget(In, "*pattern_Text"), in->pattern);
 }
 
-static XmQualifyProc 
+static void
 myQualifyProc(Widget w, XmFileSelectionBoxCallbackStruct *in, XmFileSelectionBoxCallbackStruct *out)
 {
 	printf("------ IN -----\n");
@@ -279,7 +289,7 @@ main(int argc, char **argv)
   XtSetArg(args[n], XmNeditable, False); n++;
   Out = CreateFSBcallbackStruct(Form, "Out", args, n);
   Qualify = XmCreatePushButton(Form, "Qualify", NULL, 0);
-  XtAddCallback(Qualify, XmNactivateCallback, (void *)QualifyCallback, NULL);
+  XtAddCallback(Qualify, XmNactivateCallback, (XtCallbackProc)QualifyCallback, NULL);
 
   XtVaSetValues(Qualify,
   	XmNleftAttachment, XmATTACH_FORM,
@@ -335,6 +345,98 @@ main(int argc, char **argv)
   }
 
   {
+#if XmVERSION > 1
+static XtWidgetGeometry Expected[] = {
+   {CWWidth | CWHeight            ,    0,    0,  800,  420, 0,0,0, /* MainForm */},
+   {CWWidth | CWHeight | CWX | CWY,   10,   10,  242,  365, 0,0,0, /* In */},
+   {CWWidth | CWHeight | CWX | CWY,   59,    0,  124,   17, 0,0,0, /* Input CallbackStruct */},
+   {CWWidth | CWHeight | CWX | CWY,    5,   17,  232,  343, 0,0,0, /* In */},
+   {CWWidth | CWHeight | CWX | CWY,    3,    3,  226,   31, 0,0,0, /* reason_Form */},
+   {CWWidth | CWHeight | CWX | CWY,    0,    0,   88,   31, 0,0,0, /* reason */},
+   {CWWidth | CWHeight | CWX | CWY,   88,    0,  138,   31, 0,0,0, /* reason_Text */},
+   {CWWidth | CWHeight | CWX | CWY,    3,   37,  226,   31, 0,0,0, /* event_Form */},
+   {CWWidth | CWHeight | CWX | CWY,    0,    0,   88,   31, 0,0,0, /* event */},
+   {CWWidth | CWHeight | CWX | CWY,   88,    0,  138,   31, 0,0,0, /* event_Text */},
+   {CWWidth | CWHeight | CWX | CWY,    3,   71,  226,   31, 0,0,0, /* value_Form */},
+   {CWWidth | CWHeight | CWX | CWY,    0,    0,   88,   31, 0,0,0, /* value */},
+   {CWWidth | CWHeight | CWX | CWY,   88,    0,  138,   31, 0,0,0, /* value_Text */},
+   {CWWidth | CWHeight | CWX | CWY,    3,  105,  226,   31, 0,0,0, /* length_Form */},
+   {CWWidth | CWHeight | CWX | CWY,    0,    0,   88,   31, 0,0,0, /* length */},
+   {CWWidth | CWHeight | CWX | CWY,   88,    0,  138,   31, 0,0,0, /* length_Text */},
+   {CWWidth | CWHeight | CWX | CWY,    3,  139,  226,   31, 0,0,0, /* mask_Form */},
+   {CWWidth | CWHeight | CWX | CWY,    0,    0,   88,   31, 0,0,0, /* mask */},
+   {CWWidth | CWHeight | CWX | CWY,   88,    0,  138,   31, 0,0,0, /* mask_Text */},
+   {CWWidth | CWHeight | CWX | CWY,    3,  173,  226,   31, 0,0,0, /* mask_length_Form */},
+   {CWWidth | CWHeight | CWX | CWY,    0,    0,   88,   31, 0,0,0, /* mask_length */},
+   {CWWidth | CWHeight | CWX | CWY,   88,    0,  138,   31, 0,0,0, /* mask_length_Text */},
+   {CWWidth | CWHeight | CWX | CWY,    3,  207,  226,   31, 0,0,0, /* dir_Form */},
+   {CWWidth | CWHeight | CWX | CWY,    0,    0,   88,   31, 0,0,0, /* dir */},
+   {CWWidth | CWHeight | CWX | CWY,   88,    0,  138,   31, 0,0,0, /* dir_Text */},
+   {CWWidth | CWHeight | CWX | CWY,    3,  241,  226,   31, 0,0,0, /* dir_length_Form */},
+   {CWWidth | CWHeight | CWX | CWY,    0,    0,   88,   31, 0,0,0, /* dir_length */},
+   {CWWidth | CWHeight | CWX | CWY,   88,    0,  138,   31, 0,0,0, /* dir_length_Text */},
+   {CWWidth | CWHeight | CWX | CWY,    3,  275,  226,   31, 0,0,0, /* pattern_Form */},
+   {CWWidth | CWHeight | CWX | CWY,    0,    0,   88,   31, 0,0,0, /* pattern */},
+   {CWWidth | CWHeight | CWX | CWY,   88,    0,  138,   31, 0,0,0, /* pattern_Text */},
+   {CWWidth | CWHeight | CWX | CWY,    3,  309,  226,   31, 0,0,0, /* pattern_length_Form */},
+   {CWWidth | CWHeight | CWX | CWY,    0,    0,   88,   31, 0,0,0, /* pattern_length */},
+   {CWWidth | CWHeight | CWX | CWY,   88,    0,  138,   31, 0,0,0, /* pattern_length_Text */},
+   {CWWidth | CWHeight | CWX | CWY,  262,   10,  276,  400, 0,0,0, /* FSB */},
+   {CWWidth | CWHeight | CWX | CWY,  182,   68,   83,   17, 0,0,0, /* Items */},
+   {CWWidth | CWHeight | CWX | CWY,  182,   85,   83,  184, 0,0,0, /* ItemsListSW */},
+   {CWWidth | CWHeight | CWX | CWY,   68,    0,   15,  165, 0,0,0, /* VertScrollBar */},
+   {CWWidth | CWHeight | CWX | CWY,    0,  169,   64,   15, 0,0,0, /* HorScrollBar */},
+   {CWWidth | CWHeight | CWX | CWY,    0,    0,   64,  165, 0,0,0, /* ItemsList */},
+   {CWWidth | CWHeight | CWX | CWY,   10,  279,  256,   17, 0,0,0, /* Selection */},
+   {CWWidth | CWHeight | CWX | CWY,   10,  296,  256,   31, 0,0,0, /* Text */},
+   {CWWidth | CWHeight | CWX | CWY,    0,  337,  276,    2, 0,0,0, /* Separator */},
+   {CWWidth | CWHeight | CWX | CWY,   10,  349,   64,   41, 0,0,0, /* OK */},
+   {CWWidth | CWHeight | CWX | CWY,   74,  349,   64,   41, 0,0,0, /* Apply */},
+   {CWWidth | CWHeight | CWX | CWY,  138,  349,   64,   41, 0,0,0, /* Cancel */},
+   {CWWidth | CWHeight | CWX | CWY,  202,  349,   64,   41, 0,0,0, /* Help */},
+   {CWWidth | CWHeight | CWX | CWY,   10,   10,  256,   17, 0,0,0, /* FilterLabel */},
+   {CWWidth | CWHeight | CWX | CWY,   10,   68,  162,   17, 0,0,0, /* Dir */},
+   {CWWidth | CWHeight | CWX | CWY,   10,   27,  256,   31, 0,0,0, /* FilterText */},
+   {CWWidth | CWHeight | CWX | CWY,   10,   85,  162,  184, 0,0,0, /* DirListSW */},
+   {CWWidth | CWHeight | CWX | CWY,  147,    0,   15,  165, 0,0,0, /* VertScrollBar */},
+   {CWWidth | CWHeight | CWX | CWY,    0,  169,  143,   15, 0,0,0, /* HorScrollBar */},
+   {CWWidth | CWHeight | CWX | CWY,    0,    0,  143,  165, 0,0,0, /* DirList */},
+   {CWWidth | CWHeight | CWX | CWY,  548,   10,  242,  365, 0,0,0, /* Out */},
+   {CWWidth | CWHeight | CWX | CWY,   56,    0,  130,   17, 0,0,0, /* Output CallbackStruct */},
+   {CWWidth | CWHeight | CWX | CWY,    5,   17,  232,  343, 0,0,0, /* Out */},
+   {CWWidth | CWHeight | CWX | CWY,    3,    3,  226,   31, 0,0,0, /* reason_Form */},
+   {CWWidth | CWHeight | CWX | CWY,    0,    0,   88,   31, 0,0,0, /* reason */},
+   {CWWidth | CWHeight | CWX | CWY,   88,    0,  138,   31, 0,0,0, /* reason_Text */},
+   {CWWidth | CWHeight | CWX | CWY,    3,   37,  226,   31, 0,0,0, /* event_Form */},
+   {CWWidth | CWHeight | CWX | CWY,    0,    0,   88,   31, 0,0,0, /* event */},
+   {CWWidth | CWHeight | CWX | CWY,   88,    0,  138,   31, 0,0,0, /* event_Text */},
+   {CWWidth | CWHeight | CWX | CWY,    3,   71,  226,   31, 0,0,0, /* value_Form */},
+   {CWWidth | CWHeight | CWX | CWY,    0,    0,   88,   31, 0,0,0, /* value */},
+   {CWWidth | CWHeight | CWX | CWY,   88,    0,  138,   31, 0,0,0, /* value_Text */},
+   {CWWidth | CWHeight | CWX | CWY,    3,  105,  226,   31, 0,0,0, /* length_Form */},
+   {CWWidth | CWHeight | CWX | CWY,    0,    0,   88,   31, 0,0,0, /* length */},
+   {CWWidth | CWHeight | CWX | CWY,   88,    0,  138,   31, 0,0,0, /* length_Text */},
+   {CWWidth | CWHeight | CWX | CWY,    3,  139,  226,   31, 0,0,0, /* mask_Form */},
+   {CWWidth | CWHeight | CWX | CWY,    0,    0,   88,   31, 0,0,0, /* mask */},
+   {CWWidth | CWHeight | CWX | CWY,   88,    0,  138,   31, 0,0,0, /* mask_Text */},
+   {CWWidth | CWHeight | CWX | CWY,    3,  173,  226,   31, 0,0,0, /* mask_length_Form */},
+   {CWWidth | CWHeight | CWX | CWY,    0,    0,   88,   31, 0,0,0, /* mask_length */},
+   {CWWidth | CWHeight | CWX | CWY,   88,    0,  138,   31, 0,0,0, /* mask_length_Text */},
+   {CWWidth | CWHeight | CWX | CWY,    3,  207,  226,   31, 0,0,0, /* dir_Form */},
+   {CWWidth | CWHeight | CWX | CWY,    0,    0,   88,   31, 0,0,0, /* dir */},
+   {CWWidth | CWHeight | CWX | CWY,   88,    0,  138,   31, 0,0,0, /* dir_Text */},
+   {CWWidth | CWHeight | CWX | CWY,    3,  241,  226,   31, 0,0,0, /* dir_length_Form */},
+   {CWWidth | CWHeight | CWX | CWY,    0,    0,   88,   31, 0,0,0, /* dir_length */},
+   {CWWidth | CWHeight | CWX | CWY,   88,    0,  138,   31, 0,0,0, /* dir_length_Text */},
+   {CWWidth | CWHeight | CWX | CWY,    3,  275,  226,   31, 0,0,0, /* pattern_Form */},
+   {CWWidth | CWHeight | CWX | CWY,    0,    0,   88,   31, 0,0,0, /* pattern */},
+   {CWWidth | CWHeight | CWX | CWY,   88,    0,  138,   31, 0,0,0, /* pattern_Text */},
+   {CWWidth | CWHeight | CWX | CWY,    3,  309,  226,   31, 0,0,0, /* pattern_length_Form */},
+   {CWWidth | CWHeight | CWX | CWY,    0,    0,   88,   31, 0,0,0, /* pattern_length */},
+   {CWWidth | CWHeight | CWX | CWY,   88,    0,  138,   31, 0,0,0, /* pattern_length_Text */},
+   {CWWidth | CWHeight | CWX | CWY,   10,  385,  242,   25, 0,0,0, /* Qualify */},
+};
+#else
     static XtWidgetGeometry Expected[] = {
       CWWidth | CWHeight            ,    6,   22,  808,  420, 0,0,0, /* MainForm */
       CWWidth | CWHeight | CWX | CWY,   10,   10,  242,  365, 0,0,0, /* In */
@@ -424,7 +526,8 @@ main(int argc, char **argv)
       CWWidth | CWHeight | CWX | CWY,    0,    0,   88,   31, 0,0,0, /* pattern_length */
       CWWidth | CWHeight | CWX | CWY,   88,    0,  138,   31, 0,0,0, /* pattern_length_Text */
       CWWidth | CWHeight | CWX | CWY,   10,  385,  242,   25, 0,0,0, /* Qualify */
-    };
+};
+#endif
     /* toplevel should be replaced with to correct applicationShell */
     PrintDetails(toplevel, Expected);
   }
