@@ -5,7 +5,8 @@
 #include <Xm/Form.h>
 #include <Xm/Label.h>
 
-#include "DumpLayout.h"
+#include "../../common/Test.h"
+#include "../../common/DumpLayout.h"
 
 void Doit(Widget w, XtPointer client, XtPointer call)
 {
@@ -58,9 +59,9 @@ main(int argc, char **argv)
     XtRealizeWidget(toplevel);
   {
   static XtWidgetGeometry Expected[] = {
-  	CWWidth | CWHeight,		0,	0,	94,	25,	0,0,0,	/* Form */
-  	CWWidth | CWHeight | CWX | CWY,	58,	0,	36,	25,	0,0,0,	/* two */
-  	CWWidth | CWHeight | CWX | CWY,	0,	0,	58,	17,	0,0,0,	/* two */
+  	{CWWidth | CWHeight,		0,	0,	94,	25,	0,0,0,	/* Form */},
+  	{CWWidth | CWHeight | CWX | CWY,	58,	0,	36,	25,	0,0,0,	/* two */},
+  	{CWWidth | CWHeight | CWX | CWY,	0,	0,	58,	17,	0,0,0,	/* two */},
 };
 
   PrintDetails(toplevel, Expected);
