@@ -10,6 +10,9 @@
 #include <Xm/PushBG.h>
 #include <Xm/Form.h>
 
+#include "../../common/Test.h"
+#include "../../common/DumpLayout.h"
+
 
 char *fallback[] = {
 	"*XmForm.marginWidth:	45",
@@ -47,8 +50,8 @@ main(int argc, char **argv)
 
   {
   static XtWidgetGeometry Expected[] = {
-  	CWWidth | CWHeight,              0,  0,120,100, 0,0,0,	/* Form */
-  	CWWidth | CWHeight | CWX | CWY, 45,25, 30, 25, 0,0,0,	/* two */
+  	{CWWidth | CWHeight,              0,  0,120,100, 0,0,0,	/* Form */},
+  	{CWWidth | CWHeight | CWX | CWY, 45,25, 30, 25, 0,0,0,	/* two */},
 };
 
   PrintDetails(toplevel, Expected);
