@@ -1,19 +1,17 @@
-/* $Header: /cvsroot/lesstif/lesstif/test/Xm/form/test3.c,v 1.7 2002/05/01 15:39:21 amai Exp $ */
 /**
  *
  * form1.c
  *
  **/
 
-#include <stdlib.h>
 #include <stdio.h>
-
 #include <Xm/Xm.h>
 #include <Xm/PushB.h>
 #include <Xm/PushBG.h>
 #include <Xm/Form.h>
 
 #include "../../common/Test.h"
+#include "../../common/DumpLayout.h"
 
 
 int
