@@ -1,4 +1,5 @@
-/*
+/* $Header: /cvsroot/lesstif/lesstif/test/Xm/form/test38.c,v 1.6 2001/05/16 09:37:13 amai Exp $
+
    From:        Yasushi Yamasaki <yamapu@osk3.3web.ne.jp>
    To:          lesstif@hungry.com
    Subject:     bug report
@@ -6,7 +7,9 @@
    Cc:          yamapu@osk3.3web.ne.jp
  */
 
-/* test1.c */
+#include <stdlib.h>
+#include <stdio.h>
+
 #include <unistd.h>
 #include <Xm/Xm.h>
 #include <Xm/Form.h>
