@@ -22,6 +22,9 @@
 #include <Xm/BulletinB.h>
 #include <Xm/TextF.h>
 
+#include "../../common/DumpLayout.h"
+#include "../../common/Test.h"
+
 typedef struct {
     	Widget cancel;
     	Widget ok;
@@ -66,7 +69,7 @@ Widget createDialog(Widget parent)
 {
     Arg arg[20];
     int n = 0;
-    Widget form,frame, label;
+    Widget form, label;
 
     XtSetArg(arg[n], XmNheight,              400);  n++;
     XtSetArg(arg[n], XmNdialogStyle,         XmDIALOG_APPLICATION_MODAL);  n++;
@@ -487,9 +490,9 @@ void GridDialog_DimensionCB(Widget    widget,
 	else
 	    XmToggleButtonSetState(dialog->leftbtn, True, False);
 
-	// make the form widget recalc its height requirement.  In the 1dH case,
-	// the align_form widget is getting too tall.  Changing from 1dH to either
-	// 2d or 1dV, then makes a mess on the screen.
+	/* make the form widget recalc its height requirement.  In the 1dH case,
+	   the align_form widget is getting too tall.  Changing from 1dH to either
+	   2d or 1dV, then makes a mess on the screen.*/
 	XtVaSetValues (dialog->align_form, XmNheight, 0, NULL);
     }
     else if(widget == dialog->twoDTButton)
@@ -625,7 +628,6 @@ main(int argc, char **argv)
   XtAppContext	app;
   Widget Shell;
   Widget Form;
-  Widget BottomLabel;
 
   XtSetLanguageProc(NULL, NULL, NULL);
 
@@ -644,216 +646,225 @@ main(int argc, char **argv)
  */
 {
 static XtWidgetGeometry Expected[] = {
-   CWWidth | CWHeight            ,  383,  472,  145,  287, 0,0,0, /* form */
-   CWWidth | CWHeight | CWX | CWY,   56,  252,   84,   25, 0,0,0, /* cancelButton */
-   CWWidth | CWHeight | CWX | CWY,    5,  252,   60,   25, 0,0,0, /* okButton */
-   CWWidth | CWHeight | CWX | CWY,    5,  240,  135,    2, 0,0,0, /* separator1 */
-   CWWidth | CWHeight | CWX | CWY,    5,   97,   73,   25, 0,0,0, /* llButton */
-   CWWidth | CWHeight | CWX | CWY,  108,   97,   73,   25, 0,0,0, /* lrButton */
-   CWWidth | CWHeight | CWX | CWY,   58,   62,   73,   25, 0,0,0, /* ctButton */
-   CWWidth | CWHeight | CWX | CWY,    5,   27,   73,   25, 0,0,0, /* ulButton */
-   CWWidth | CWHeight | CWX | CWY,  108,   27,   73,   25, 0,0,0, /* urButton */
-   CWWidth | CWHeight | CWX | CWY,    5,    0,   64,   17, 0,0,0, /* alignLabel */
-   CWWidth | CWHeight | CWX | CWY,    5,  240,  135,    2, 0,0,0, /* separator2 */
-   CWWidth | CWHeight | CWX | CWY,    5,  213,   40,   17, 0,0,0, /* hLabel */
-   CWWidth | CWHeight | CWX | CWY,  104,  199,   36,   31, 0,0,0, /* hNumber */
-   CWWidth | CWHeight | CWX | CWY,    5,  186,   40,   17, 0,0,0, /* vLabel */
-   CWWidth | CWHeight | CWX | CWY,  104,  172,   36,   31, 0,0,0, /* vNumber */
-   CWWidth | CWHeight | CWX | CWY,    5,  164,  135,   17, 0,0,0, /* spaceLabel */
-   CWWidth | CWHeight | CWX | CWY,    5,  152,  135,    2, 0,0,0, /* separator3 */
-   CWWidth | CWHeight | CWX | CWY,    3,   27,  139,  115, 0,0,0, /* gridType */
-   CWWidth | CWHeight | CWX | CWY,    3,    3,  133,   25, 0,0,0, /* noneTButton */
-   CWWidth | CWHeight | CWX | CWY,    3,   31,  133,   25, 0,0,0, /* oneDhTButton */
-   CWWidth | CWHeight | CWX | CWY,    3,   59,  133,   25, 0,0,0, /* oneDvTButton */
-   CWWidth | CWHeight | CWX | CWY,    3,   87,  133,   25, 0,0,0, /* twoDTButton */
-   CWWidth | CWHeight | CWX | CWY,    5,    5,  135,   17, 0,0,0, /* typeLabel */
+   {CWWidth | CWHeight            ,  357,  593,  145,  287, 0,0,0, /* form */},
+   {CWWidth | CWHeight | CWX | CWY,   56,  252,   84,   25, 0,0,0, /* cancelButton */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  252,   60,   25, 0,0,0, /* okButton */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  240,  135,    2, 0,0,0, /* separator1 */},
+   {CWWidth | CWHeight | CWX | CWY,    5,   97,   73,   25, 0,0,0, /* llButton */},
+   {CWWidth | CWHeight | CWX | CWY,  108,   97,   73,   25, 0,0,0, /* lrButton */},
+   {CWWidth | CWHeight | CWX | CWY,   58,   62,   73,   25, 0,0,0, /* ctButton */},
+   {CWWidth | CWHeight | CWX | CWY,    5,   27,   73,   25, 0,0,0, /* ulButton */},
+   {CWWidth | CWHeight | CWX | CWY,  108,   27,   73,   25, 0,0,0, /* urButton */},
+   {CWWidth | CWHeight | CWX | CWY,    5,    0,   64,   17, 0,0,0, /* alignLabel */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  240,  135,    2, 0,0,0, /* separator2 */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  213,   40,   17, 0,0,0, /* hLabel */},
+   {CWWidth | CWHeight | CWX | CWY,  104,  199,   36,   31, 0,0,0, /* hNumber */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  186,   40,   17, 0,0,0, /* vLabel */},
+   {CWWidth | CWHeight | CWX | CWY,  104,  172,   36,   31, 0,0,0, /* vNumber */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  164,  135,   17, 0,0,0, /* spaceLabel */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  152,  135,    2, 0,0,0, /* separator3 */},
+   {CWWidth | CWHeight | CWX | CWY,    3,   27,  139,  115, 0,0,0, /* gridType */},
+   {CWWidth | CWHeight | CWX | CWY,    3,    3,  133,   25, 0,0,0, /* noneTButton */},
+   {CWWidth | CWHeight | CWX | CWY,    3,   31,  133,   25, 0,0,0, /* oneDhTButton */},
+   {CWWidth | CWHeight | CWX | CWY,    3,   59,  133,   25, 0,0,0, /* oneDvTButton */},
+   {CWWidth | CWHeight | CWX | CWY,    3,   87,  133,   25, 0,0,0, /* twoDTButton */},
+   {CWWidth | CWHeight | CWX | CWY,    5,    5,  135,   17, 0,0,0, /* typeLabel */},
+   {CWWidth | CWHeight            ,    0,    0,   52,   17, 0,0,0, /* TipLabel */},
 
-   CWWidth | CWHeight            ,  383,  472,  196,  371, 0,0,0, /* form */
-   CWWidth | CWHeight | CWX | CWY,  107,  336,   84,   25, 0,0,0, /* cancelButton */
-   CWWidth | CWHeight | CWX | CWY,    5,  336,   60,   25, 0,0,0, /* okButton */
-   CWWidth | CWHeight | CWX | CWY,    5,  324,  186,    2, 0,0,0, /* separator1 */
-   CWWidth | CWHeight | CWX | CWY,    5,  252,  186,   62, 0,0,0, /* alignForm */
-   CWWidth | CWHeight | CWX | CWY,   58,   27,   73,   25, 0,0,0, /* ctButton */
-   CWWidth | CWHeight | CWX | CWY,    5,   27,   85,   25, 0,0,0, /* leftButton */
-   CWWidth | CWHeight | CWX | CWY,   90,   27,   91,   25, 0,0,0, /* rightButton */
-   CWWidth | CWHeight | CWX | CWY,    5,    0,   64,   17, 0,0,0, /* alignLabel */
-   CWWidth | CWHeight | CWX | CWY,    5,  240,  186,    2, 0,0,0, /* separator2 */
-   CWWidth | CWHeight | CWX | CWY,    5,  213,   91,   17, 0,0,0, /* hLabel */
-   CWWidth | CWHeight | CWX | CWY,  155,  199,   36,   31, 0,0,0, /* hNumber */
-   CWWidth | CWHeight | CWX | CWY,    5,  186,   91,   17, 0,0,0, /* vLabel */
-   CWWidth | CWHeight | CWX | CWY,  155,  172,   36,   31, 0,0,0, /* vNumber */
-   CWWidth | CWHeight | CWX | CWY,    5,  164,  186,   17, 0,0,0, /* spaceLabel */
-   CWWidth | CWHeight | CWX | CWY,    5,  152,  186,    2, 0,0,0, /* separator3 */
-   CWWidth | CWHeight | CWX | CWY,    3,   27,  190,  115, 0,0,0, /* gridType */
-   CWWidth | CWHeight | CWX | CWY,    3,    3,  184,   25, 0,0,0, /* noneTButton */
-   CWWidth | CWHeight | CWX | CWY,    3,   31,  184,   25, 0,0,0, /* oneDhTButton */
-   CWWidth | CWHeight | CWX | CWY,    3,   59,  184,   25, 0,0,0, /* oneDvTButton */
-   CWWidth | CWHeight | CWX | CWY,    3,   87,  184,   25, 0,0,0, /* twoDTButton */
-   CWWidth | CWHeight | CWX | CWY,    5,    5,  186,   17, 0,0,0, /* typeLabel */
+   {CWWidth | CWHeight            ,  357,  593,  196,  371, 0,0,0, /* form */},
+   {CWWidth | CWHeight | CWX | CWY,  107,  336,   84,   25, 0,0,0, /* cancelButton */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  336,   60,   25, 0,0,0, /* okButton */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  324,  186,    2, 0,0,0, /* separator1 */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  252,  186,   62, 0,0,0, /* alignForm */},
+   {CWWidth | CWHeight | CWX | CWY,   58,   27,   73,   25, 0,0,0, /* ctButton */},
+   {CWWidth | CWHeight | CWX | CWY,    5,   27,   85,   25, 0,0,0, /* leftButton */},
+   {CWWidth | CWHeight | CWX | CWY,   90,   27,   91,   25, 0,0,0, /* rightButton */},
+   {CWWidth | CWHeight | CWX | CWY,    5,    0,   64,   17, 0,0,0, /* alignLabel */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  240,  186,    2, 0,0,0, /* separator2 */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  213,   91,   17, 0,0,0, /* hLabel */},
+   {CWWidth | CWHeight | CWX | CWY,  155,  199,   36,   31, 0,0,0, /* hNumber */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  186,   91,   17, 0,0,0, /* vLabel */},
+   {CWWidth | CWHeight | CWX | CWY,  155,  172,   36,   31, 0,0,0, /* vNumber */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  164,  186,   17, 0,0,0, /* spaceLabel */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  152,  186,    2, 0,0,0, /* separator3 */},
+   {CWWidth | CWHeight | CWX | CWY,    3,   27,  190,  115, 0,0,0, /* gridType */},
+   {CWWidth | CWHeight | CWX | CWY,    3,    3,  184,   25, 0,0,0, /* noneTButton */},
+   {CWWidth | CWHeight | CWX | CWY,    3,   31,  184,   25, 0,0,0, /* oneDhTButton */},
+   {CWWidth | CWHeight | CWX | CWY,    3,   59,  184,   25, 0,0,0, /* oneDvTButton */},
+   {CWWidth | CWHeight | CWX | CWY,    3,   87,  184,   25, 0,0,0, /* twoDTButton */},
+   {CWWidth | CWHeight | CWX | CWY,    5,    5,  186,   17, 0,0,0, /* typeLabel */},
+   {CWWidth | CWHeight            ,    0,    0,   52,   17, 0,0,0, /* TipLabel */},
 
-   CWWidth | CWHeight            ,  383,  472,  145,  287, 0,0,0, /* form */
-   CWWidth | CWHeight | CWX | CWY,   56,  252,   84,   25, 0,0,0, /* cancelButton */
-   CWWidth | CWHeight | CWX | CWY,    5,  252,   60,   25, 0,0,0, /* okButton */
-   CWWidth | CWHeight | CWX | CWY,    5,  240,  135,    2, 0,0,0, /* separator1 */
-   CWWidth | CWHeight | CWX | CWY,   58,   27,   73,   25, 0,0,0, /* ctButton */
-   CWWidth | CWHeight | CWX | CWY,    5,   27,   85,   25, 0,0,0, /* leftButton */
-   CWWidth | CWHeight | CWX | CWY,   90,   27,   91,   25, 0,0,0, /* rightButton */
-   CWWidth | CWHeight | CWX | CWY,    5,    0,   64,   17, 0,0,0, /* alignLabel */
-   CWWidth | CWHeight | CWX | CWY,    5,  240,  135,    2, 0,0,0, /* separator2 */
-   CWWidth | CWHeight | CWX | CWY,    5,  213,   40,   17, 0,0,0, /* hLabel */
-   CWWidth | CWHeight | CWX | CWY,  104,  199,   36,   31, 0,0,0, /* hNumber */
-   CWWidth | CWHeight | CWX | CWY,    5,  186,   40,   17, 0,0,0, /* vLabel */
-   CWWidth | CWHeight | CWX | CWY,  104,  172,   36,   31, 0,0,0, /* vNumber */
-   CWWidth | CWHeight | CWX | CWY,    5,  164,  135,   17, 0,0,0, /* spaceLabel */
-   CWWidth | CWHeight | CWX | CWY,    5,  152,  135,    2, 0,0,0, /* separator3 */
-   CWWidth | CWHeight | CWX | CWY,    3,   27,  139,  115, 0,0,0, /* gridType */
-   CWWidth | CWHeight | CWX | CWY,    3,    3,  133,   25, 0,0,0, /* noneTButton */
-   CWWidth | CWHeight | CWX | CWY,    3,   31,  133,   25, 0,0,0, /* oneDhTButton */
-   CWWidth | CWHeight | CWX | CWY,    3,   59,  133,   25, 0,0,0, /* oneDvTButton */
-   CWWidth | CWHeight | CWX | CWY,    3,   87,  133,   25, 0,0,0, /* twoDTButton */
-   CWWidth | CWHeight | CWX | CWY,    5,    5,  135,   17, 0,0,0, /* typeLabel */
+   {CWWidth | CWHeight            ,  357,  593,  145,  287, 0,0,0, /* form */},
+   {CWWidth | CWHeight | CWX | CWY,   56,  252,   84,   25, 0,0,0, /* cancelButton */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  252,   60,   25, 0,0,0, /* okButton */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  240,  135,    2, 0,0,0, /* separator1 */},
+   {CWWidth | CWHeight | CWX | CWY,   58,   27,   73,   25, 0,0,0, /* ctButton */},
+   {CWWidth | CWHeight | CWX | CWY,    5,   27,   85,   25, 0,0,0, /* leftButton */},
+   {CWWidth | CWHeight | CWX | CWY,   90,   27,   91,   25, 0,0,0, /* rightButton */},
+   {CWWidth | CWHeight | CWX | CWY,    5,    0,   64,   17, 0,0,0, /* alignLabel */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  240,  135,    2, 0,0,0, /* separator2 */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  213,   40,   17, 0,0,0, /* hLabel */},
+   {CWWidth | CWHeight | CWX | CWY,  104,  199,   36,   31, 0,0,0, /* hNumber */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  186,   40,   17, 0,0,0, /* vLabel */},
+   {CWWidth | CWHeight | CWX | CWY,  104,  172,   36,   31, 0,0,0, /* vNumber */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  164,  135,   17, 0,0,0, /* spaceLabel */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  152,  135,    2, 0,0,0, /* separator3 */},
+   {CWWidth | CWHeight | CWX | CWY,    3,   27,  139,  115, 0,0,0, /* gridType */},
+   {CWWidth | CWHeight | CWX | CWY,    3,    3,  133,   25, 0,0,0, /* noneTButton */},
+   {CWWidth | CWHeight | CWX | CWY,    3,   31,  133,   25, 0,0,0, /* oneDhTButton */},
+   {CWWidth | CWHeight | CWX | CWY,    3,   59,  133,   25, 0,0,0, /* oneDvTButton */},
+   {CWWidth | CWHeight | CWX | CWY,    3,   87,  133,   25, 0,0,0, /* twoDTButton */},
+   {CWWidth | CWHeight | CWX | CWY,    5,    5,  135,   17, 0,0,0, /* typeLabel */},
+   {CWWidth | CWHeight            ,    0,    0,   52,   17, 0,0,0, /* TipLabel */},
 
-   CWWidth | CWHeight            ,  383,  472,  196,  441, 0,0,0, /* form */
-   CWWidth | CWHeight | CWX | CWY,  107,  406,   84,   25, 0,0,0, /* cancelButton */
-   CWWidth | CWHeight | CWX | CWY,    5,  406,   60,   25, 0,0,0, /* okButton */
-   CWWidth | CWHeight | CWX | CWY,    5,  394,  186,    2, 0,0,0, /* separator1 */
-   CWWidth | CWHeight | CWX | CWY,    5,  252,  186,  132, 0,0,0, /* alignForm */
-   CWWidth | CWHeight | CWX | CWY,   58,   62,   73,   25, 0,0,0, /* ctButton */
-   CWWidth | CWHeight | CWX | CWY,   58,   27,   91,   25, 0,0,0, /* upperButton */
-   CWWidth | CWHeight | CWX | CWY,   58,   97,   91,   25, 0,0,0, /* lowerButton */
-   CWWidth | CWHeight | CWX | CWY,    5,    0,   64,   17, 0,0,0, /* alignLabel */
-   CWWidth | CWHeight | CWX | CWY,    5,  240,  186,    2, 0,0,0, /* separator2 */
-   CWWidth | CWHeight | CWX | CWY,    5,  213,   91,   17, 0,0,0, /* hLabel */
-   CWWidth | CWHeight | CWX | CWY,  155,  199,   36,   31, 0,0,0, /* hNumber */
-   CWWidth | CWHeight | CWX | CWY,    5,  186,   91,   17, 0,0,0, /* vLabel */
-   CWWidth | CWHeight | CWX | CWY,  155,  172,   36,   31, 0,0,0, /* vNumber */
-   CWWidth | CWHeight | CWX | CWY,    5,  164,  186,   17, 0,0,0, /* spaceLabel */
-   CWWidth | CWHeight | CWX | CWY,    5,  152,  186,    2, 0,0,0, /* separator3 */
-   CWWidth | CWHeight | CWX | CWY,    3,   27,  190,  115, 0,0,0, /* gridType */
-   CWWidth | CWHeight | CWX | CWY,    3,    3,  184,   25, 0,0,0, /* noneTButton */
-   CWWidth | CWHeight | CWX | CWY,    3,   31,  184,   25, 0,0,0, /* oneDhTButton */
-   CWWidth | CWHeight | CWX | CWY,    3,   59,  184,   25, 0,0,0, /* oneDvTButton */
-   CWWidth | CWHeight | CWX | CWY,    3,   87,  184,   25, 0,0,0, /* twoDTButton */
-   CWWidth | CWHeight | CWX | CWY,    5,    5,  186,   17, 0,0,0, /* typeLabel */
+   {CWWidth | CWHeight            ,  357,  593,  196,  441, 0,0,0, /* form */},
+   {CWWidth | CWHeight | CWX | CWY,  107,  406,   84,   25, 0,0,0, /* cancelButton */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  406,   60,   25, 0,0,0, /* okButton */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  394,  186,    2, 0,0,0, /* separator1 */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  252,  186,  132, 0,0,0, /* alignForm */},
+   {CWWidth | CWHeight | CWX | CWY,   58,   62,   73,   25, 0,0,0, /* ctButton */},
+   {CWWidth | CWHeight | CWX | CWY,   58,   27,   91,   25, 0,0,0, /* upperButton */},
+   {CWWidth | CWHeight | CWX | CWY,   58,   97,   91,   25, 0,0,0, /* lowerButton */},
+   {CWWidth | CWHeight | CWX | CWY,    5,    0,   64,   17, 0,0,0, /* alignLabel */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  240,  186,    2, 0,0,0, /* separator2 */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  213,   91,   17, 0,0,0, /* hLabel */},
+   {CWWidth | CWHeight | CWX | CWY,  155,  199,   36,   31, 0,0,0, /* hNumber */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  186,   91,   17, 0,0,0, /* vLabel */},
+   {CWWidth | CWHeight | CWX | CWY,  155,  172,   36,   31, 0,0,0, /* vNumber */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  164,  186,   17, 0,0,0, /* spaceLabel */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  152,  186,    2, 0,0,0, /* separator3 */},
+   {CWWidth | CWHeight | CWX | CWY,    3,   27,  190,  115, 0,0,0, /* gridType */},
+   {CWWidth | CWHeight | CWX | CWY,    3,    3,  184,   25, 0,0,0, /* noneTButton */},
+   {CWWidth | CWHeight | CWX | CWY,    3,   31,  184,   25, 0,0,0, /* oneDhTButton */},
+   {CWWidth | CWHeight | CWX | CWY,    3,   59,  184,   25, 0,0,0, /* oneDvTButton */},
+   {CWWidth | CWHeight | CWX | CWY,    3,   87,  184,   25, 0,0,0, /* twoDTButton */},
+   {CWWidth | CWHeight | CWX | CWY,    5,    5,  186,   17, 0,0,0, /* typeLabel */},
+   {CWWidth | CWHeight            ,    0,    0,   52,   17, 0,0,0, /* TipLabel */},
 
-   CWWidth | CWHeight            ,  383,  472,  145,  287, 0,0,0, /* form */
-   CWWidth | CWHeight | CWX | CWY,   56,  252,   84,   25, 0,0,0, /* cancelButton */
-   CWWidth | CWHeight | CWX | CWY,    5,  252,   60,   25, 0,0,0, /* okButton */
-   CWWidth | CWHeight | CWX | CWY,    5,  240,  135,    2, 0,0,0, /* separator1 */
-   CWWidth | CWHeight | CWX | CWY,   58,   62,   73,   25, 0,0,0, /* ctButton */
-   CWWidth | CWHeight | CWX | CWY,   58,   27,   91,   25, 0,0,0, /* upperButton */
-   CWWidth | CWHeight | CWX | CWY,   58,   97,   91,   25, 0,0,0, /* lowerButton */
-   CWWidth | CWHeight | CWX | CWY,    5,    0,   64,   17, 0,0,0, /* alignLabel */
-   CWWidth | CWHeight | CWX | CWY,    5,  240,  135,    2, 0,0,0, /* separator2 */
-   CWWidth | CWHeight | CWX | CWY,    5,  213,   40,   17, 0,0,0, /* hLabel */
-   CWWidth | CWHeight | CWX | CWY,  104,  199,   36,   31, 0,0,0, /* hNumber */
-   CWWidth | CWHeight | CWX | CWY,    5,  186,   40,   17, 0,0,0, /* vLabel */
-   CWWidth | CWHeight | CWX | CWY,  104,  172,   36,   31, 0,0,0, /* vNumber */
-   CWWidth | CWHeight | CWX | CWY,    5,  164,  135,   17, 0,0,0, /* spaceLabel */
-   CWWidth | CWHeight | CWX | CWY,    5,  152,  135,    2, 0,0,0, /* separator3 */
-   CWWidth | CWHeight | CWX | CWY,    3,   27,  139,  115, 0,0,0, /* gridType */
-   CWWidth | CWHeight | CWX | CWY,    3,    3,  133,   25, 0,0,0, /* noneTButton */
-   CWWidth | CWHeight | CWX | CWY,    3,   31,  133,   25, 0,0,0, /* oneDhTButton */
-   CWWidth | CWHeight | CWX | CWY,    3,   59,  133,   25, 0,0,0, /* oneDvTButton */
-   CWWidth | CWHeight | CWX | CWY,    3,   87,  133,   25, 0,0,0, /* twoDTButton */
-   CWWidth | CWHeight | CWX | CWY,    5,    5,  135,   17, 0,0,0, /* typeLabel */
+   {CWWidth | CWHeight            ,  357,  593,  145,  287, 0,0,0, /* form */},
+   {CWWidth | CWHeight | CWX | CWY,   56,  252,   84,   25, 0,0,0, /* cancelButton */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  252,   60,   25, 0,0,0, /* okButton */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  240,  135,    2, 0,0,0, /* separator1 */},
+   {CWWidth | CWHeight | CWX | CWY,   58,   62,   73,   25, 0,0,0, /* ctButton */},
+   {CWWidth | CWHeight | CWX | CWY,   58,   27,   91,   25, 0,0,0, /* upperButton */},
+   {CWWidth | CWHeight | CWX | CWY,   58,   97,   91,   25, 0,0,0, /* lowerButton */},
+   {CWWidth | CWHeight | CWX | CWY,    5,    0,   64,   17, 0,0,0, /* alignLabel */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  240,  135,    2, 0,0,0, /* separator2 */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  213,   40,   17, 0,0,0, /* hLabel */},
+   {CWWidth | CWHeight | CWX | CWY,  104,  199,   36,   31, 0,0,0, /* hNumber */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  186,   40,   17, 0,0,0, /* vLabel */},
+   {CWWidth | CWHeight | CWX | CWY,  104,  172,   36,   31, 0,0,0, /* vNumber */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  164,  135,   17, 0,0,0, /* spaceLabel */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  152,  135,    2, 0,0,0, /* separator3 */},
+   {CWWidth | CWHeight | CWX | CWY,    3,   27,  139,  115, 0,0,0, /* gridType */},
+   {CWWidth | CWHeight | CWX | CWY,    3,    3,  133,   25, 0,0,0, /* noneTButton */},
+   {CWWidth | CWHeight | CWX | CWY,    3,   31,  133,   25, 0,0,0, /* oneDhTButton */},
+   {CWWidth | CWHeight | CWX | CWY,    3,   59,  133,   25, 0,0,0, /* oneDvTButton */},
+   {CWWidth | CWHeight | CWX | CWY,    3,   87,  133,   25, 0,0,0, /* twoDTButton */},
+   {CWWidth | CWHeight | CWX | CWY,    5,    5,  135,   17, 0,0,0, /* typeLabel */},
+   {CWWidth | CWHeight            ,    0,    0,   52,   17, 0,0,0, /* TipLabel */},
 
-   CWWidth | CWHeight            ,  383,  472,  196,  441, 0,0,0, /* form */
-   CWWidth | CWHeight | CWX | CWY,  107,  406,   84,   25, 0,0,0, /* cancelButton */
-   CWWidth | CWHeight | CWX | CWY,    5,  406,   60,   25, 0,0,0, /* okButton */
-   CWWidth | CWHeight | CWX | CWY,    5,  394,  186,    2, 0,0,0, /* separator1 */
-   CWWidth | CWHeight | CWX | CWY,    5,  252,  186,  132, 0,0,0, /* alignForm */
-   CWWidth | CWHeight | CWX | CWY,    5,   97,   73,   25, 0,0,0, /* llButton */
-   CWWidth | CWHeight | CWX | CWY,  108,   97,   73,   25, 0,0,0, /* lrButton */
-   CWWidth | CWHeight | CWX | CWY,   58,   62,   73,   25, 0,0,0, /* ctButton */
-   CWWidth | CWHeight | CWX | CWY,    5,   27,   73,   25, 0,0,0, /* ulButton */
-   CWWidth | CWHeight | CWX | CWY,  108,   27,   73,   25, 0,0,0, /* urButton */
-   CWWidth | CWHeight | CWX | CWY,    5,    0,   64,   17, 0,0,0, /* alignLabel */
-   CWWidth | CWHeight | CWX | CWY,    5,  240,  186,    2, 0,0,0, /* separator2 */
-   CWWidth | CWHeight | CWX | CWY,    5,  213,   91,   17, 0,0,0, /* hLabel */
-   CWWidth | CWHeight | CWX | CWY,  155,  199,   36,   31, 0,0,0, /* hNumber */
-   CWWidth | CWHeight | CWX | CWY,    5,  186,   91,   17, 0,0,0, /* vLabel */
-   CWWidth | CWHeight | CWX | CWY,  155,  172,   36,   31, 0,0,0, /* vNumber */
-   CWWidth | CWHeight | CWX | CWY,    5,  164,  186,   17, 0,0,0, /* spaceLabel */
-   CWWidth | CWHeight | CWX | CWY,    5,  152,  186,    2, 0,0,0, /* separator3 */
-   CWWidth | CWHeight | CWX | CWY,    3,   27,  190,  115, 0,0,0, /* gridType */
-   CWWidth | CWHeight | CWX | CWY,    3,    3,  184,   25, 0,0,0, /* noneTButton */
-   CWWidth | CWHeight | CWX | CWY,    3,   31,  184,   25, 0,0,0, /* oneDhTButton */
-   CWWidth | CWHeight | CWX | CWY,    3,   59,  184,   25, 0,0,0, /* oneDvTButton */
-   CWWidth | CWHeight | CWX | CWY,    3,   87,  184,   25, 0,0,0, /* twoDTButton */
-   CWWidth | CWHeight | CWX | CWY,    5,    5,  186,   17, 0,0,0, /* typeLabel */
+   {CWWidth | CWHeight            ,  357,  593,  196,  441, 0,0,0, /* form */},
+   {CWWidth | CWHeight | CWX | CWY,  107,  406,   84,   25, 0,0,0, /* cancelButton */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  406,   60,   25, 0,0,0, /* okButton */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  394,  186,    2, 0,0,0, /* separator1 */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  252,  186,  132, 0,0,0, /* alignForm */},
+   {CWWidth | CWHeight | CWX | CWY,    5,   97,   73,   25, 0,0,0, /* llButton */},
+   {CWWidth | CWHeight | CWX | CWY,  108,   97,   73,   25, 0,0,0, /* lrButton */},
+   {CWWidth | CWHeight | CWX | CWY,   58,   62,   73,   25, 0,0,0, /* ctButton */},
+   {CWWidth | CWHeight | CWX | CWY,    5,   27,   73,   25, 0,0,0, /* ulButton */},
+   {CWWidth | CWHeight | CWX | CWY,  108,   27,   73,   25, 0,0,0, /* urButton */},
+   {CWWidth | CWHeight | CWX | CWY,    5,    0,   64,   17, 0,0,0, /* alignLabel */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  240,  186,    2, 0,0,0, /* separator2 */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  213,   91,   17, 0,0,0, /* hLabel */},
+   {CWWidth | CWHeight | CWX | CWY,  155,  199,   36,   31, 0,0,0, /* hNumber */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  186,   91,   17, 0,0,0, /* vLabel */},
+   {CWWidth | CWHeight | CWX | CWY,  155,  172,   36,   31, 0,0,0, /* vNumber */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  164,  186,   17, 0,0,0, /* spaceLabel */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  152,  186,    2, 0,0,0, /* separator3 */},
+   {CWWidth | CWHeight | CWX | CWY,    3,   27,  190,  115, 0,0,0, /* gridType */},
+   {CWWidth | CWHeight | CWX | CWY,    3,    3,  184,   25, 0,0,0, /* noneTButton */},
+   {CWWidth | CWHeight | CWX | CWY,    3,   31,  184,   25, 0,0,0, /* oneDhTButton */},
+   {CWWidth | CWHeight | CWX | CWY,    3,   59,  184,   25, 0,0,0, /* oneDvTButton */},
+   {CWWidth | CWHeight | CWX | CWY,    3,   87,  184,   25, 0,0,0, /* twoDTButton */},
+   {CWWidth | CWHeight | CWX | CWY,    5,    5,  186,   17, 0,0,0, /* typeLabel */},
+   {CWWidth | CWHeight            ,    0,    0,   52,   17, 0,0,0, /* TipLabel */},
 
-   CWWidth | CWHeight            ,  383,  472,  145,  287, 0,0,0, /* form */
-   CWWidth | CWHeight | CWX | CWY,   56,  252,   84,   25, 0,0,0, /* cancelButton */
-   CWWidth | CWHeight | CWX | CWY,    5,  252,   60,   25, 0,0,0, /* okButton */
-   CWWidth | CWHeight | CWX | CWY,    5,  240,  135,    2, 0,0,0, /* separator1 */
-   CWWidth | CWHeight | CWX | CWY,    5,   97,   73,   25, 0,0,0, /* llButton */
-   CWWidth | CWHeight | CWX | CWY,  108,   97,   73,   25, 0,0,0, /* lrButton */
-   CWWidth | CWHeight | CWX | CWY,   58,   62,   73,   25, 0,0,0, /* ctButton */
-   CWWidth | CWHeight | CWX | CWY,    5,   27,   73,   25, 0,0,0, /* ulButton */
-   CWWidth | CWHeight | CWX | CWY,  108,   27,   73,   25, 0,0,0, /* urButton */
-   CWWidth | CWHeight | CWX | CWY,    5,    0,   64,   17, 0,0,0, /* alignLabel */
-   CWWidth | CWHeight | CWX | CWY,    5,  240,  135,    2, 0,0,0, /* separator2 */
-   CWWidth | CWHeight | CWX | CWY,    5,  213,   40,   17, 0,0,0, /* hLabel */
-   CWWidth | CWHeight | CWX | CWY,  104,  199,   36,   31, 0,0,0, /* hNumber */
-   CWWidth | CWHeight | CWX | CWY,    5,  186,   40,   17, 0,0,0, /* vLabel */
-   CWWidth | CWHeight | CWX | CWY,  104,  172,   36,   31, 0,0,0, /* vNumber */
-   CWWidth | CWHeight | CWX | CWY,    5,  164,  135,   17, 0,0,0, /* spaceLabel */
-   CWWidth | CWHeight | CWX | CWY,    5,  152,  135,    2, 0,0,0, /* separator3 */
-   CWWidth | CWHeight | CWX | CWY,    3,   27,  139,  115, 0,0,0, /* gridType */
-   CWWidth | CWHeight | CWX | CWY,    3,    3,  133,   25, 0,0,0, /* noneTButton */
-   CWWidth | CWHeight | CWX | CWY,    3,   31,  133,   25, 0,0,0, /* oneDhTButton */
-   CWWidth | CWHeight | CWX | CWY,    3,   59,  133,   25, 0,0,0, /* oneDvTButton */
-   CWWidth | CWHeight | CWX | CWY,    3,   87,  133,   25, 0,0,0, /* twoDTButton */
-   CWWidth | CWHeight | CWX | CWY,    5,    5,  135,   17, 0,0,0, /* typeLabel */
+   {CWWidth | CWHeight            ,  357,  593,  145,  287, 0,0,0, /* form */},
+   {CWWidth | CWHeight | CWX | CWY,   56,  252,   84,   25, 0,0,0, /* cancelButton */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  252,   60,   25, 0,0,0, /* okButton */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  240,  135,    2, 0,0,0, /* separator1 */},
+   {CWWidth | CWHeight | CWX | CWY,    5,   97,   73,   25, 0,0,0, /* llButton */},
+   {CWWidth | CWHeight | CWX | CWY,  108,   97,   73,   25, 0,0,0, /* lrButton */},
+   {CWWidth | CWHeight | CWX | CWY,   58,   62,   73,   25, 0,0,0, /* ctButton */},
+   {CWWidth | CWHeight | CWX | CWY,    5,   27,   73,   25, 0,0,0, /* ulButton */},
+   {CWWidth | CWHeight | CWX | CWY,  108,   27,   73,   25, 0,0,0, /* urButton */},
+   {CWWidth | CWHeight | CWX | CWY,    5,    0,   64,   17, 0,0,0, /* alignLabel */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  240,  135,    2, 0,0,0, /* separator2 */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  213,   40,   17, 0,0,0, /* hLabel */},
+   {CWWidth | CWHeight | CWX | CWY,  104,  199,   36,   31, 0,0,0, /* hNumber */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  186,   40,   17, 0,0,0, /* vLabel */},
+   {CWWidth | CWHeight | CWX | CWY,  104,  172,   36,   31, 0,0,0, /* vNumber */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  164,  135,   17, 0,0,0, /* spaceLabel */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  152,  135,    2, 0,0,0, /* separator3 */},
+   {CWWidth | CWHeight | CWX | CWY,    3,   27,  139,  115, 0,0,0, /* gridType */},
+   {CWWidth | CWHeight | CWX | CWY,    3,    3,  133,   25, 0,0,0, /* noneTButton */},
+   {CWWidth | CWHeight | CWX | CWY,    3,   31,  133,   25, 0,0,0, /* oneDhTButton */},
+   {CWWidth | CWHeight | CWX | CWY,    3,   59,  133,   25, 0,0,0, /* oneDvTButton */},
+   {CWWidth | CWHeight | CWX | CWY,    3,   87,  133,   25, 0,0,0, /* twoDTButton */},
+   {CWWidth | CWHeight | CWX | CWY,    5,    5,  135,   17, 0,0,0, /* typeLabel */},
+   {CWWidth | CWHeight            ,    0,    0,   52,   17, 0,0,0, /* TipLabel */},
 
-   CWWidth | CWHeight            ,  383,  472,  196,  441, 0,0,0, /* form */
-   CWWidth | CWHeight | CWX | CWY,  107,  406,   84,   25, 0,0,0, /* cancelButton */
-   CWWidth | CWHeight | CWX | CWY,    5,  406,   60,   25, 0,0,0, /* okButton */
-   CWWidth | CWHeight | CWX | CWY,    5,  394,  186,    2, 0,0,0, /* separator1 */
-   CWWidth | CWHeight | CWX | CWY,    5,  252,  186,  132, 0,0,0, /* alignForm */
-   CWWidth | CWHeight | CWX | CWY,    5,   97,   73,   25, 0,0,0, /* llButton */
-   CWWidth | CWHeight | CWX | CWY,  108,   97,   73,   25, 0,0,0, /* lrButton */
-   CWWidth | CWHeight | CWX | CWY,   58,   62,   73,   25, 0,0,0, /* ctButton */
-   CWWidth | CWHeight | CWX | CWY,    5,   27,   73,   25, 0,0,0, /* ulButton */
-   CWWidth | CWHeight | CWX | CWY,  108,   27,   73,   25, 0,0,0, /* urButton */
-   CWWidth | CWHeight | CWX | CWY,    5,    0,   64,   17, 0,0,0, /* alignLabel */
-   CWWidth | CWHeight | CWX | CWY,    5,  240,  186,    2, 0,0,0, /* separator2 */
-   CWWidth | CWHeight | CWX | CWY,    5,  213,   91,   17, 0,0,0, /* hLabel */
-   CWWidth | CWHeight | CWX | CWY,  155,  199,   36,   31, 0,0,0, /* hNumber */
-   CWWidth | CWHeight | CWX | CWY,    5,  186,   91,   17, 0,0,0, /* vLabel */
-   CWWidth | CWHeight | CWX | CWY,  155,  172,   36,   31, 0,0,0, /* vNumber */
-   CWWidth | CWHeight | CWX | CWY,    5,  164,  186,   17, 0,0,0, /* spaceLabel */
-   CWWidth | CWHeight | CWX | CWY,    5,  152,  186,    2, 0,0,0, /* separator3 */
-   CWWidth | CWHeight | CWX | CWY,    3,   27,  190,  115, 0,0,0, /* gridType */
-   CWWidth | CWHeight | CWX | CWY,    3,    3,  184,   25, 0,0,0, /* noneTButton */
-   CWWidth | CWHeight | CWX | CWY,    3,   31,  184,   25, 0,0,0, /* oneDhTButton */
-   CWWidth | CWHeight | CWX | CWY,    3,   59,  184,   25, 0,0,0, /* oneDvTButton */
-   CWWidth | CWHeight | CWX | CWY,    3,   87,  184,   25, 0,0,0, /* twoDTButton */
-   CWWidth | CWHeight | CWX | CWY,    5,    5,  186,   17, 0,0,0, /* typeLabel */
+   {CWWidth | CWHeight            ,  357,  593,  196,  441, 0,0,0, /* form */},
+   {CWWidth | CWHeight | CWX | CWY,  107,  406,   84,   25, 0,0,0, /* cancelButton */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  406,   60,   25, 0,0,0, /* okButton */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  394,  186,    2, 0,0,0, /* separator1 */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  252,  186,  132, 0,0,0, /* alignForm */},
+   {CWWidth | CWHeight | CWX | CWY,    5,   97,   73,   25, 0,0,0, /* llButton */},
+   {CWWidth | CWHeight | CWX | CWY,  108,   97,   73,   25, 0,0,0, /* lrButton */},
+   {CWWidth | CWHeight | CWX | CWY,   58,   62,   73,   25, 0,0,0, /* ctButton */},
+   {CWWidth | CWHeight | CWX | CWY,    5,   27,   73,   25, 0,0,0, /* ulButton */},
+   {CWWidth | CWHeight | CWX | CWY,  108,   27,   73,   25, 0,0,0, /* urButton */},
+   {CWWidth | CWHeight | CWX | CWY,    5,    0,   64,   17, 0,0,0, /* alignLabel */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  240,  186,    2, 0,0,0, /* separator2 */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  213,   91,   17, 0,0,0, /* hLabel */},
+   {CWWidth | CWHeight | CWX | CWY,  155,  199,   36,   31, 0,0,0, /* hNumber */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  186,   91,   17, 0,0,0, /* vLabel */},
+   {CWWidth | CWHeight | CWX | CWY,  155,  172,   36,   31, 0,0,0, /* vNumber */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  164,  186,   17, 0,0,0, /* spaceLabel */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  152,  186,    2, 0,0,0, /* separator3 */},
+   {CWWidth | CWHeight | CWX | CWY,    3,   27,  190,  115, 0,0,0, /* gridType */},
+   {CWWidth | CWHeight | CWX | CWY,    3,    3,  184,   25, 0,0,0, /* noneTButton */},
+   {CWWidth | CWHeight | CWX | CWY,    3,   31,  184,   25, 0,0,0, /* oneDhTButton */},
+   {CWWidth | CWHeight | CWX | CWY,    3,   59,  184,   25, 0,0,0, /* oneDvTButton */},
+   {CWWidth | CWHeight | CWX | CWY,    3,   87,  184,   25, 0,0,0, /* twoDTButton */},
+   {CWWidth | CWHeight | CWX | CWY,    5,    5,  186,   17, 0,0,0, /* typeLabel */},
+   {CWWidth | CWHeight            ,    0,    0,   52,   17, 0,0,0, /* TipLabel */},
 
-   CWWidth | CWHeight            ,  383,  472,  145,  371, 0,0,0, /* form */
-   CWWidth | CWHeight | CWX | CWY,   56,  336,   84,   25, 0,0,0, /* cancelButton */
-   CWWidth | CWHeight | CWX | CWY,    5,  336,   60,   25, 0,0,0, /* okButton */
-   CWWidth | CWHeight | CWX | CWY,    5,  324,  135,    2, 0,0,0, /* separator1 */
-   CWWidth | CWHeight | CWX | CWY,    5,  252,  135,   62, 0,0,0, /* alignForm */
-   CWWidth | CWHeight | CWX | CWY,   33,   27,   73,   25, 0,0,0, /* ctButton */
-   CWWidth | CWHeight | CWX | CWY,    5,   27,   85,   25, 0,0,0, /* leftButton */
-   CWWidth | CWHeight | CWX | CWY,   39,   27,   91,   25, 0,0,0, /* rightButton */
-   CWWidth | CWHeight | CWX | CWY,    5,    0,   64,   17, 0,0,0, /* alignLabel */
-   CWWidth | CWHeight | CWX | CWY,    5,  240,  135,    2, 0,0,0, /* separator2 */
-   CWWidth | CWHeight | CWX | CWY,    5,  213,   40,   17, 0,0,0, /* hLabel */
-   CWWidth | CWHeight | CWX | CWY,  104,  199,   36,   31, 0,0,0, /* hNumber */
-   CWWidth | CWHeight | CWX | CWY,    5,  186,   40,   17, 0,0,0, /* vLabel */
-   CWWidth | CWHeight | CWX | CWY,  104,  172,   36,   31, 0,0,0, /* vNumber */
-   CWWidth | CWHeight | CWX | CWY,    5,  164,  135,   17, 0,0,0, /* spaceLabel */
-   CWWidth | CWHeight | CWX | CWY,    5,  152,  135,    2, 0,0,0, /* separator3 */
-   CWWidth | CWHeight | CWX | CWY,    3,   27,  139,  115, 0,0,0, /* gridType */
-   CWWidth | CWHeight | CWX | CWY,    3,    3,  133,   25, 0,0,0, /* noneTButton */
-   CWWidth | CWHeight | CWX | CWY,    3,   31,  133,   25, 0,0,0, /* oneDhTButton */
-   CWWidth | CWHeight | CWX | CWY,    3,   59,  133,   25, 0,0,0, /* oneDvTButton */
-   CWWidth | CWHeight | CWX | CWY,    3,   87,  133,   25, 0,0,0, /* twoDTButton */
-   CWWidth | CWHeight | CWX | CWY,    5,    5,  135,   17, 0,0,0, /* typeLabel */
+   {CWWidth | CWHeight            ,  357,  593,  145,  371, 0,0,0, /* form */},
+   {CWWidth | CWHeight | CWX | CWY,   56,  336,   84,   25, 0,0,0, /* cancelButton */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  336,   60,   25, 0,0,0, /* okButton */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  324,  135,    2, 0,0,0, /* separator1 */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  252,  135,   62, 0,0,0, /* alignForm */},
+   {CWWidth | CWHeight | CWX | CWY,   33,   27,   73,   25, 0,0,0, /* ctButton */},
+   {CWWidth | CWHeight | CWX | CWY,    5,   27,   85,   25, 0,0,0, /* leftButton */},
+   {CWWidth | CWHeight | CWX | CWY,   39,   27,   91,   25, 0,0,0, /* rightButton */},
+   {CWWidth | CWHeight | CWX | CWY,    5,    0,   64,   17, 0,0,0, /* alignLabel */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  240,  135,    2, 0,0,0, /* separator2 */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  213,   40,   17, 0,0,0, /* hLabel */},
+   {CWWidth | CWHeight | CWX | CWY,  104,  199,   36,   31, 0,0,0, /* hNumber */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  186,   40,   17, 0,0,0, /* vLabel */},
+   {CWWidth | CWHeight | CWX | CWY,  104,  172,   36,   31, 0,0,0, /* vNumber */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  164,  135,   17, 0,0,0, /* spaceLabel */},
+   {CWWidth | CWHeight | CWX | CWY,    5,  152,  135,    2, 0,0,0, /* separator3 */},
+   {CWWidth | CWHeight | CWX | CWY,    3,   27,  139,  115, 0,0,0, /* gridType */},
+   {CWWidth | CWHeight | CWX | CWY,    3,    3,  133,   25, 0,0,0, /* noneTButton */},
+   {CWWidth | CWHeight | CWX | CWY,    3,   31,  133,   25, 0,0,0, /* oneDhTButton */},
+   {CWWidth | CWHeight | CWX | CWY,    3,   59,  133,   25, 0,0,0, /* oneDvTButton */},
+   {CWWidth | CWHeight | CWX | CWY,    3,   87,  133,   25, 0,0,0, /* twoDTButton */},
+   {CWWidth | CWHeight | CWX | CWY,    5,    5,  135,   17, 0,0,0, /* typeLabel */},
+   {CWWidth | CWHeight            ,    0,    0,   52,   17, 0,0,0, /* TipLabel */},
 };
 
   LessTifTestWaitForIt(Shell);
