@@ -1,3 +1,8 @@
+/* $Header: /cvsroot/lesstif/lesstif/test/Xm/label/test3.c,v 1.10 2001/05/18 12:49:24 rwscott Exp $ */
+#include <stdlib.h>
+#include <stdio.h>
+#include <unistd.h>
+
 #include <Xm/Xm.h>
 #include <Xm/MainW.h>
 #include <Xm/ArrowB.h>
@@ -14,8 +19,10 @@
 #include <Xm/Scale.h>
 #include <Xm/Text.h>
 
-#include <stdio.h>
-#include <unistd.h>
+#include "../../common/Test.h"
+#include "../../common/DumpLayout.h"
+
+
 
 #define SCREEN_NUMBER           0
 #define MAX_SWITCH              8
@@ -60,20 +67,17 @@ main(int argc, char **argv)
   Widget            led_label;
   Widget            switch_label[MAX_SWITCH];
   Widget            switches_label,switch_box,switch_on_label,switch_off_label;
-  Widget            led_frame,led_column,leds_label;
+  Widget            led_frame,led_column;
   Widget            adc_label;
-  Widget            switches_row;
   Display           *display;
   Window            root_window;
   GC                graphics_context;
   XGCValues         values;
   unsigned long     value_mask;
-  long              event_mask;
   Font              label_font;
   XColor            closest_color,exact_color;
   Arg               args[5];   
-  XmString          label_string,dummy_string,on_string,off_string;
-  XtInputId         inputId;
+  XmString          label_string,dummy_string;
    
   toplevel = XtVaAppInitialize(&theApp, "ICTP_examples", NULL, 0,
 			       &argc, argv, FallBack, NULL);
@@ -384,6 +388,70 @@ main(int argc, char **argv)
  * querying the current geometry.
  */
 {
+#if XmVERSION > 1
+static XtWidgetGeometry Expected[] = {
+   {CWWidth | CWHeight            ,  243,  311,  180,  306, 0,0,0, /* main_window */},
+   {CWWidth | CWHeight | CWX | CWY,    0,   31,  180,    2, 0,0,0, /* Separator1 */},
+   {CWWidth | CWHeight | CWX | CWY,    0,   33,  180,  273, 0,0,0, /* form */},
+   {CWWidth | CWHeight | CWX | CWY,   30,   30,   58,   17, 0,0,0, /* lcd_label */},
+   {CWWidth | CWHeight | CWX | CWY,   30,   47,   98,   21, 0,0,0, /* lcd_frame */},
+   {CWWidth | CWHeight | CWX | CWY,    2,    2,   94,   17, 0,0,0, /* lcd */},
+   {CWWidth | CWHeight | CWX | CWY,  158,   30,   58,   17, 0,0,0, /* led_label */},
+   {CWWidth | CWHeight | CWX | CWY,  158,   47,  217,   48, 0,0,0, /* led_frame */},
+   {CWWidth | CWHeight | CWX | CWY,    2,    2,  213,   44, 0,0,0, /* led_clumn */},
+   {CWWidth | CWHeight | CWX | CWY,    3,    3,   14,   34, 0,0,0, /* led */},
+   {CWWidth | CWHeight | CWX | CWY,   24,    3,   14,   34, 0,0,0, /* led */},
+   {CWWidth | CWHeight | CWX | CWY,   45,    3,   14,   34, 0,0,0, /* led */},
+   {CWWidth | CWHeight | CWX | CWY,   66,    3,   14,   34, 0,0,0, /* led */},
+   {CWWidth | CWHeight | CWX | CWY,   87,    3,   14,   34, 0,0,0, /* led */},
+   {CWWidth | CWHeight | CWX | CWY,  108,    3,   14,   34, 0,0,0, /* led */},
+   {CWWidth | CWHeight | CWX | CWY,  129,    3,   14,   34, 0,0,0, /* led */},
+   {CWWidth | CWHeight | CWX | CWY,  150,    3,   14,   34, 0,0,0, /* led */},
+   {CWWidth | CWHeight | CWX | CWY,  171,    3,   14,   34, 0,0,0, /* led */},
+   {CWWidth | CWHeight | CWX | CWY,  192,    3,   14,   34, 0,0,0, /* led */},
+   {CWWidth | CWHeight | CWX | CWY,   30,   98,   52,   17, 0,0,0, /* switches_label */},
+   {CWWidth | CWHeight | CWX | CWY,   30,  115,  238,   66, 0,0,0, /* switch_box */},
+   {CWWidth | CWHeight | CWX | CWY,    0,    0,   16,   17, 0,0,0, /* switch_label */},
+   {CWWidth | CWHeight | CWX | CWY,    0,   17,   27,   49, 0,0,0, /* on_off_box */},
+   {CWWidth | CWHeight | CWX | CWY,    3,    3,   21,   20, 0,0,0, /* on_switches */},
+   {CWWidth | CWHeight | CWX | CWY,    3,   26,   21,   20, 0,0,0, /* off_switches */},
+   {CWWidth | CWHeight | CWX | CWY,   27,    0,   16,   17, 0,0,0, /* switch_label */},
+   {CWWidth | CWHeight | CWX | CWY,   27,   17,   27,   49, 0,0,0, /* on_off_box */},
+   {CWWidth | CWHeight | CWX | CWY,    3,    3,   21,   20, 0,0,0, /* on_switches */},
+   {CWWidth | CWHeight | CWX | CWY,    3,   26,   21,   20, 0,0,0, /* off_switches */},
+   {CWWidth | CWHeight | CWX | CWY,   54,    0,   16,   17, 0,0,0, /* switch_label */},
+   {CWWidth | CWHeight | CWX | CWY,   54,   17,   27,   49, 0,0,0, /* on_off_box */},
+   {CWWidth | CWHeight | CWX | CWY,    3,    3,   21,   20, 0,0,0, /* on_switches */},
+   {CWWidth | CWHeight | CWX | CWY,    3,   26,   21,   20, 0,0,0, /* off_switches */},
+   {CWWidth | CWHeight | CWX | CWY,   81,    0,   16,   17, 0,0,0, /* switch_label */},
+   {CWWidth | CWHeight | CWX | CWY,   81,   17,   27,   49, 0,0,0, /* on_off_box */},
+   {CWWidth | CWHeight | CWX | CWY,    3,    3,   21,   20, 0,0,0, /* on_switches */},
+   {CWWidth | CWHeight | CWX | CWY,    3,   26,   21,   20, 0,0,0, /* off_switches */},
+   {CWWidth | CWHeight | CWX | CWY,  108,    0,   16,   17, 0,0,0, /* switch_label */},
+   {CWWidth | CWHeight | CWX | CWY,  108,   17,   27,   49, 0,0,0, /* on_off_box */},
+   {CWWidth | CWHeight | CWX | CWY,    3,    3,   21,   20, 0,0,0, /* on_switches */},
+   {CWWidth | CWHeight | CWX | CWY,    3,   26,   21,   20, 0,0,0, /* off_switches */},
+   {CWWidth | CWHeight | CWX | CWY,  135,    0,   16,   17, 0,0,0, /* switch_label */},
+   {CWWidth | CWHeight | CWX | CWY,  135,   17,   27,   49, 0,0,0, /* on_off_box */},
+   {CWWidth | CWHeight | CWX | CWY,    3,    3,   21,   20, 0,0,0, /* on_switches */},
+   {CWWidth | CWHeight | CWX | CWY,    3,   26,   21,   20, 0,0,0, /* off_switches */},
+   {CWWidth | CWHeight | CWX | CWY,  162,    0,   16,   17, 0,0,0, /* switch_label */},
+   {CWWidth | CWHeight | CWX | CWY,  162,   17,   27,   49, 0,0,0, /* on_off_box */},
+   {CWWidth | CWHeight | CWX | CWY,    3,    3,   21,   20, 0,0,0, /* on_switches */},
+   {CWWidth | CWHeight | CWX | CWY,    3,   26,   21,   20, 0,0,0, /* off_switches */},
+   {CWWidth | CWHeight | CWX | CWY,  189,    0,   16,   17, 0,0,0, /* switch_label */},
+   {CWWidth | CWHeight | CWX | CWY,  189,   17,   27,   49, 0,0,0, /* on_off_box */},
+   {CWWidth | CWHeight | CWX | CWY,    3,    3,   21,   20, 0,0,0, /* on_switches */},
+   {CWWidth | CWHeight | CWX | CWY,    3,   26,   21,   20, 0,0,0, /* off_switches */},
+   {CWWidth | CWHeight | CWX | CWY,  216,   17,   16,   17, 0,0,0, /* switch_on_label */},
+   {CWWidth | CWHeight | CWX | CWY,  216,   39,   22,   17, 0,0,0, /* switch_off_label */},
+   {CWWidth | CWHeight | CWX | CWY,   30,  211,   94,   17, 0,0,0, /* adc_label */},
+   {CWWidth | CWHeight | CWX | CWY,   30,  238,  250,   35, 0,0,0, /* slider */},
+   {CWWidth | CWHeight | CWX | CWY,    0,   16,  250,   19, 0,0,0, /* Scrollbar */},
+   {CWWidth | CWHeight | CWX | CWY,    0,    0,  180,   31, 0,0,0, /* menu_bar */},
+   {CWWidth | CWHeight | CWX | CWY,    5,    5,   40,   21, 0,0,0, /* file_button */},
+};
+#else
 static XtWidgetGeometry Expected[] = {
    CWWidth | CWHeight            ,  771,  192,  180,  314, 0,0,0, /* main_window */
    CWWidth | CWHeight | CWX | CWY,    0,   31,  180,    2, 0,0,0, /* Separator1 */
@@ -446,6 +514,7 @@ static XtWidgetGeometry Expected[] = {
    CWWidth | CWHeight | CWX | CWY,    0,    0,  180,   31, 0,0,0, /* menu_bar */
    CWWidth | CWHeight | CWX | CWY,    5,    5,   40,   21, 0,0,0, /* file_button */
 };
+#endif
 /* toplevel should be replaced with to correct applicationShell */
 PrintDetails(toplevel, Expected);
 }
@@ -479,17 +548,26 @@ void
 toggled_proc(Widget w,XtPointer client_data,XtPointer call_data)
 /*==========================================================*/
 {
-  int which = (int)client_data;
   int i;
   XmToggleButtonCallbackStruct *state = 
      (XmToggleButtonCallbackStruct *) call_data;
 
   for (i=0;i<MAX_SWITCH;i++)
+  {
     if (XtParent(w) == on_off_box[i]) 
+    {
       if (strcmp(XtName(w),"on_switches") == 0) 
+      {
 	if (state -> set) 
+	{
            ICTP_IO_switch_state |= 1<<(MAX_SWITCH-i-1);
+        }
         else
+        {
            ICTP_IO_switch_state &= ~(1<<(MAX_SWITCH-i-1));
+        }
+      }
+    }
+  }
 printf("%x\n",ICTP_IO_switch_state);
 }
