@@ -1,4 +1,4 @@
-/*
+/* $Header: /cvsroot/lesstif/lesstif/test/Xm/label/test7.c,v 1.5 2001/06/18 08:33:07 amai Exp $
    From:        Yasushi Yamasaki <yamapu@osk3.3web.ne.jp>
    To:          lesstif@hungry.com
    Subject:     bug report
@@ -7,7 +7,10 @@
  */
 
 /* test1.c */
+#include <stdlib.h>
+#include <stdio.h>
 #include <unistd.h>
+
 #include <Xm/Xm.h>
 #include <Xm/Label.h>
 
@@ -30,14 +33,14 @@ main(int argc, char *argv[])
 	w = XtCreateWidget("name", xmLabelWidgetClass, shell, NULL, 0);
 	XtDestroyWidget(w);
 	after = sbrk((ptrdiff_t) 0);
-	if ((int)after - (int)before > 0)
+	if ((int)((char *)after - (char *)before) > 0)
 	{
 	    if (iter != 0)
 	    {
 		/*
 		printf("%i %i %p %i\n", iter, iter - diff, after - before, (after - before) / (iter - diff));
 		 */
-		total += (int)after - (int)before;
+		total += (int)((char *)after - (char *)before);
 	    }
 	    diff = iter;
 	}
