@@ -1,5 +1,6 @@
 #include <stdio.h>
 #include <Xm/List.h>
+#include "../../common/XdbPrintTree.c"
 
 char *days[] = { "Sunday", "Monday", "Tuesday", "Wednesday", "Thursday",
 		     "Friday", "Saturday" };
@@ -33,7 +34,17 @@ main(int argc, char **argv)
   
     XtRealizeWidget(toplevel);
 
-    XtAppMainLoop(app);
+    XdbPrintTree(toplevel);
+
+
+{
+static XtWidgetGeometry Expected[] = {
+   CWWidth | CWHeight            ,   57,   73,   64,  119, 0,0,0, /* test_of_list */
+};
+/* toplevel should be replaced with to correct applicationShell */
+PrintDetails(toplevel, Expected);
+}
+  LessTifTestMainLoop(toplevel);
 
     exit(0);
 }
