@@ -1,6 +1,7 @@
 #include <stdio.h>
 #include <Xm/List.h>
 #include <Xm/BulletinB.h>
+#include "../../common/XdbPrintTree.c"
 
 int
 main(int argc, char **argv)
@@ -26,7 +27,20 @@ main(int argc, char **argv)
     XtManageChild(listw);
 
     XtRealizeWidget(toplevel);
-    XtAppMainLoop(app);
+
+    XdbPrintTree(toplevel);
+
+
+{
+static XtWidgetGeometry Expected[] = {
+   CWWidth | CWHeight            ,   56,   72,  200,  200, 0,0,0, /* bb */
+   CWWidth | CWHeight | CWX | CWY,   20,   20,   48,   87, 0,0,0, /* listSW */
+   CWWidth | CWHeight | CWX | CWY,    0,    0,   48,   87, 0,0,0, /* list */
+};
+/* toplevel should be replaced with to correct applicationShell */
+PrintDetails(toplevel, Expected);
+}
+  LessTifTestMainLoop(toplevel);
 
     exit(0);
 }
