@@ -2,7 +2,10 @@
 
 #include <stdio.h>
 #include <Xm/List.h>
-#include "XdbPrintTree.c"
+#include "../../common/XdbPrintTree.c"
+
+#include "../../common/Test.h"
+#include "../../common/DumpLayout.h"
 
 int
 main(int argc, char **argv)
@@ -22,9 +25,15 @@ main(int argc, char **argv)
     XdbPrintTree(toplevel);
 
 {
+#if XmVERSION > 1
+static XtWidgetGeometry Expected[] = {
+   {CWWidth | CWHeight            ,   57,   73,   16,   23, 0,0,0}, /* test_of_list */
+};
+#else
 static XtWidgetGeometry Expected[] = {
    CWWidth | CWHeight            ,   57,   73,   18,   26, 0,0,0, /* test_of_list */
 };
+#endif
 /* toplevel should be replaced with to correct applicationShell */
 PrintDetails(toplevel, Expected);
 }
