@@ -1,3 +1,7 @@
+/* $Header: /cvsroot/lesstif/lesstif/test/Xm/mainw/test11.c,v 1.7 2001/05/15 14:08:33 amai Exp $ */
+
+#include <stdlib.h>
+
 #include <Xm/Xm.h>
 #include <Xm/MainW.h>
 #include <Xm/RowColumn.h>
@@ -376,4 +380,5 @@ PrintDetails(top, Expected);
 }
   LessTifTestMainLoop(top);
 
+   exit(0);
 }
