@@ -1,4 +1,4 @@
-/* $Id: MegaB.c,v 1.1 1997/02/20 02:57:01 miers Exp $ */
+/* $Id: MegaB.c,v 1.4 2000/07/14 15:17:39 danny Exp $ */
 /*
  * Copyright 1994 John L. Cwikla
  *
@@ -470,8 +470,10 @@ static XtWidgetProc destroy(Widget _mbw)
 	XtReleaseGC((Widget)_mbw, COPY_GC(_mbw));
 	XtReleaseGC((Widget)_mbw, SELECT_GC(_mbw));
 
-	for(i=0;i<ICOUNT(_mbw);i++)
-		_XmStringFree(ITEMS(_mbw)[i]);
+      for(i=0;i<ICOUNT(_mbw);i++) {
+              if(ITEMS(_mbw)[i] != LABEL(_mbw)._label)
+                      _XmStringFree(ITEMS(_mbw)[i]);
+      }
 
 	XtFree((char *)ITEMS(_mbw));
 	XtFree((char *)DATA(_mbw));
