@@ -1,5 +1,5 @@
 /**
- * $Id: test20.c,v 1.1 2000/10/11 08:32:02 amai Exp $
+ * $Id: test20.c,v 1.2 2001/05/06 22:14:52 rwscott Exp $
  *
  * Check whether the warning convenience functions do work,
  * at least w/o segfaulting ...
@@ -16,8 +16,13 @@ int main() {
   int i=1;
 
 #if XmVERSION >= 2  
+#if XmREVISION > 0  
+  XmeWarning(NULL, "This is a simple test for XmeWarning\n"
+             );
+#else
   XmeWarning(NULL, "This is a %s test (%i) for %s\n",
              text, i, func);
+#endif
 #endif
   exit(0);
 }
