@@ -36,13 +36,24 @@ main(int argc, char **argv)
 
   toplevel = XtVaAppInitialize(&app, "Label", NULL, 0, &argc, argv, NULL, NULL);
 
-  one = XtVaCreateManagedWidget("button", xmPushButtonWidgetClass, toplevel,
+  one = XtVaCreateManagedWidget("button button", xmPushButtonWidgetClass, toplevel,
 				NULL);
 
   XtAddCallback(one, XmNactivateCallback, cb, NULL);
 
   XtRealizeWidget(toplevel);
+  {
+  static XtWidgetGeometry Expected[] = {
+  	CWWidth | CWHeight,		0,	0,	90,	25,	0,0,0,	/* Form */
+  	CWWidth | CWHeight | CWX | CWY,	45,	30,	30,	25,	0,0,0,	/* two */
+};
+
+  PrintDetails(toplevel, Expected);
+  }
+  LessTifTestMainLoop(toplevel);
+  /*
   XtAppMainLoop(app);
+  */
   /* NOTREACHED */
   exit(0);
 }
