@@ -14,6 +14,9 @@
 #include <Xm/PushB.h>
 #include <Xm/Separator.h>
 
+#include "../../common/Test.h"
+#include "../../common/DumpLayout.h"
+
 int
 main(int argc, char **argv)
 {
@@ -67,13 +70,13 @@ main(int argc, char **argv)
 
   {
   static XtWidgetGeometry Expected[] = {
-  	CWWidth | CWHeight,		0,	0,	117,	87,	0,0,0,
-  	CWWidth | CWHeight | CWX | CWY,	3,	3,	54,	25,	0,0,0,
-  	CWWidth | CWHeight | CWX | CWY,	3,	31,	54,	25,	0,0,0,
-  	CWWidth | CWHeight | CWX | CWY,	3,	59,	54,	25,	0,0,0,
-  	CWWidth | CWHeight | CWX | CWY,	60,	3,	54,	25,	0,0,0,
-  	CWWidth | CWHeight | CWX | CWY,	60,	31,	54,	25,	0,0,0,
-  	CWWidth | CWHeight | CWX | CWY,	60,	59,	54,	25,	0,0,0,
+  	{CWWidth | CWHeight,		0,	0,	117,	87,	0,0,0,},
+  	{CWWidth | CWHeight | CWX | CWY,	3,	3,	54,	25,	0,0,0,},
+  	{CWWidth | CWHeight | CWX | CWY,	3,	31,	54,	25,	0,0,0,},
+  	{CWWidth | CWHeight | CWX | CWY,	3,	59,	54,	25,	0,0,0,},
+  	{CWWidth | CWHeight | CWX | CWY,	60,	3,	54,	25,	0,0,0,},
+  	{CWWidth | CWHeight | CWX | CWY,	60,	31,	54,	25,	0,0,0,},
+  	{CWWidth | CWHeight | CWX | CWY,	60,	59,	54,	25,	0,0,0,},
 };
 
   PrintDetails(toplevel, Expected);
