@@ -1,4 +1,4 @@
-/*
+/* $Header: /cvsroot/lesstif/lesstif/test/Xm/togglebutton/test7.c,v 1.5 2001/05/15 15:05:21 amai Exp $
    From:        Yasushi Yamasaki <yamapu@osk3.3web.ne.jp>
    To:          lesstif@hungry.com
    Subject:     bug report
@@ -6,12 +6,13 @@
    Cc:          yamapu@osk3.3web.ne.jp
  */
 
-/* test1.c */
+#include <stdio.h>
 #include <unistd.h>
+
 #include <Xm/Xm.h>
 #include <Xm/ToggleB.h>
 
-void 
+int
 main(int argc, char *argv[])
 {
     XtAppContext app;
