@@ -1,8 +1,9 @@
 /**
  *
- * $Id: DumpLayout.c,v 1.14 1999/10/23 12:39:28 amai Exp $
+ * $Id: DumpLayout.c,v 1.20 2001/05/15 08:12:53 amai Exp $
  *
  * Copyright (C) 1996 Free Software Foundation, Inc.
+ * Copyright (C) 1996-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,7 +23,7 @@
  *
  **/
 
-#undef DO_MAIN
+
 /* rws 7 Apr 1997
    It is best to start this with -geometry +500+500 (or whatever)
    otherwise the time to place it by the window manager bungs up the
@@ -31,60 +32,31 @@
    Is there a event, or callback one can use to figure out when the
    window has been placed????
  */
+
+#include <stdlib.h>
 #include <stdio.h>
+
 #include <X11/X.h>
 #include <X11/Intrinsic.h>
 #include <X11/IntrinsicP.h>
 #include <X11/StringDefs.h>
-#include "Test.h"
 
-#ifdef DO_MAIN
-#include <stdlib.h>
-#include <Xm/Xm.h>
-#include <Xm/Form.h>
-#include <Xm/Label.h>
+#include "DumpLayout.h"
 
-typedef struct
-{
-    int time;
-}
-AppResources_t, *AppResourcesPtr;
-AppResources_t AppResources;
-
-static String FallBack[] =
-{
-    "*borderWidth: 1",
-    "*geometry: +500+500",
-    NULL};
-
-static XtResource resources[] =
-{
-	/*
-	   {"time","time",XtRInt,sizeof(int),XtOffset(AppResourcesPtr,time),XtRImmediate, (void *)1000},
-	 */
-};
-
-static XrmOptionDescRec opTable[] =
-{
-    {"-time", ".time", XrmoptionSepArg, NULL},
-};
-
-
-XtAppContext app;
-#endif
 
 typedef struct
 {
     Widget W;
     XtWidgetGeometry *Expected;
     int version;
-}
-Request;
+} Request;
 
 static Boolean GlobalResult = True;
 static int slop;
 extern int GlobalErrors;
 
+int  LessTifTestGetSlop(Widget w);
+
 static void
 PrintWidgetDetails(Widget W, XtWidgetGeometry *ExpectedResults)
 {
@@ -144,15 +116,15 @@ PrintWidgetDetails(Widget W, XtWidgetGeometry *ExpectedResults)
 	}
 	else
 	{
-	    if (result_index == 0)
+	    if (result_index == 0 || XtIsShell(XtParent(W)))
 	    {
-		printf("   CWWidth | CWHeight            ,");
+		printf("   {CWWidth | CWHeight            ,");
 	    }
 	    else
 	    {
-		printf("   CWWidth | CWHeight | CWX | CWY,");
+		printf("   {CWWidth | CWHeight | CWX | CWY,");
 	    }
-	    printf(" %4i, %4i, %4i, %4i, 0,0,0, /* %s */\n",
+	    printf(" %4i, %4i, %4i, %4i, 0,0,0, /* %s */},\n",
 		   geo.x, geo.y, geo.width, geo.height, XtName(W));
 	}
 
@@ -311,7 +283,7 @@ _PrintDetails(Request * request)
     return (True);
 }
 
-Boolean
+static void
 PrintDetailsVersion(Widget W, XtWidgetGeometry *Expected, int version)
 {
     static Request request;
@@ -326,80 +298,20 @@ PrintDetailsVersion(Widget W, XtWidgetGeometry *Expected, int version)
     request.Expected = Expected;
     request.version = version;
 
-    XtAppAddTimeOut(XtWidgetToApplicationContext(W), 0, (void *)_PrintDetails, &request);
-    return(False);
+    XtAppAddTimeOut(XtWidgetToApplicationContext(W), 0UL,
+                    (XtTimerCallbackProc)_PrintDetails, &request);
 }
 
-Boolean
+
+extern void
 PrintDetails(Widget W, XtWidgetGeometry *Expected)
 {
     PrintDetailsVersion(W, Expected, 1);
 }
 
-Boolean
+
+extern void
 PrintDetails2(Widget W, XtWidgetGeometry *Expected)
 {
     PrintDetailsVersion(W, Expected, 2);
 }
-
-#ifdef DO_MAIN
-int
-main(int argc, char **argv)
-{
-    Widget toplevel, Form, BottomLabel, TopLabel;
-
-    XtSetLanguageProc(NULL, NULL, NULL);
-
-    toplevel = XtVaAppInitialize(&app,
-				 "Form1",
-				 opTable, XtNumber(opTable),
-				 &argc, argv,
-				 FallBack, NULL);
-
-    XtGetApplicationResources(toplevel,
-			      &AppResources,
-			      resources, XtNumber(resources),
-			      NULL, 0);
-
-    XtVaSetValues(toplevel,
-		  XmNresizePolicy, XmRESIZE_ANY,
-		  XmNallowShellResize, True,
-		  NULL);
-
-    Form = XmCreateForm(toplevel, "Form", NULL, 0);
-    XtVaSetValues(Form,
-		  XmNresizePolicy, XmRESIZE_ANY,
-		  XmNallowShellResize, True,
-		  NULL);
-
-    TopLabel = XmCreateLabel(Form, "TopLabelTop", NULL, 0);
-    BottomLabel = XmCreateLabel(Form, "BottomLabel", NULL, 0);
-
-    XtVaSetValues(TopLabel,
-		  XmNtopAttachment, XmATTACH_FORM,
-		  XmNbottomAttachment, XmATTACH_WIDGET,
-		  XmNbottomWidget, BottomLabel,
-		  XmNleftAttachment, XmATTACH_FORM,
-		  XmNrightAttachment, XmATTACH_FORM,
-		  NULL);
-    XtManageChild(TopLabel);
-
-    XtVaSetValues(BottomLabel,
-		  XmNtopAttachment, XmATTACH_NONE,
-		  XmNbottomAttachment, XmATTACH_FORM,
-		  XmNleftAttachment, XmATTACH_FORM,
-		  XmNrightAttachment, XmATTACH_FORM,
-		  NULL);
-    XtManageChild(BottomLabel);
-
-    XtManageChild(Form);
-
-    XtRealizeWidget(toplevel);
-
-    PrintDetails(toplevel);
-
-    XtAppMainLoop(app);
-
-    exit(0);
-}
-#endif
