@@ -1,8 +1,9 @@
 /**
  *
- * $Id: DumpLayout.h,v 1.2 1998/09/27 11:54:37 rwscott Exp $
+ * $Id: DumpLayout.h,v 1.4 2000/10/21 09:51:59 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,4 +23,13 @@
  *
  **/
 
-Boolean PrintDetails(Widget W, XtWidgetGeometry *Expected);
+/* Exports from DumpLayout.c */
+
+#ifndef _TEST_DUMPLAYOUT_H
+#define _TEST_DUMPLAYOUT_H
+
+void PrintDetails(Widget W, XtWidgetGeometry *Expected);
+
+void PrintDetails2(Widget W, XtWidgetGeometry *Expected);
+
+#endif /* _TEST_DUMPLAYOUT_H */
